#!perl

use strict;
use warnings;
$|=1;
use Test::More tests => 1;
use DBI;
#use DBD::SQLite;
use File::Spec;
use File::Path;
use File::Basename;

# rebuild cpanstats db

my $f = File::Spec->catfile('t','_DBDIR','test.db');
unlink $f if -f $f;
mkpath( dirname($f) );

my $dbh = DBI->connect("dbi:SQLite:dbname=$f", '', '', {AutoCommit=>1});
$dbh->do(q{
  CREATE TABLE cpanstats (
                          id            INTEGER PRIMARY KEY,
                          state         TEXT,
                          postdate      TEXT,
                          tester        TEXT,
                          dist          TEXT,
                          version       TEXT,
                          platform      TEXT,
                          perl          TEXT,
                          osname        TEXT,
                          osvers        TEXT,
                          fulldate      TEXT
  )
});

while(<DATA>){
  chomp;
  $dbh->do('INSERT INTO cpanstats ( id, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate ) VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )', {}, split(/\|/,$_) );
}

$dbh->do(q{ CREATE INDEX distverstate ON cpanstats (dist, version, state) });
$dbh->do(q{ CREATE INDEX ixdate ON cpanstats (postdate) });
$dbh->do(q{ CREATE INDEX ixperl ON cpanstats (perl) });
$dbh->do(q{ CREATE INDEX ixplat ON cpanstats (platform) });

my ($ct) = $dbh->selectrow_array('select count(*) from cpanstats');

$dbh->disconnect;

is($ct, 14034, "row count for cpanstats");

#select * from cpanstats where state='cpan' and dist in (SELECT dist from ixlatest where author='DCANTRELL')
# sqlite> select * from cpanstats where postdate=200901 order by dist limit 20;
# id|state|postdate|tester|dist|version|platform|perl|osname|osvers|date
__DATA__
3031|pass|199910|schinder@pobox.com|Statistics-ChiSquare|0.2|PA-RISC1.1|5.4.4|hpux|10.20|199910191643
3032|pass|199910|schinder@pobox.com|Statistics-ChiSquare|0.2|sun4-solaris|5.5.3|solaris|2.7|199910191644
3121|pass|199910|schinder@pobox.com|Statistics-ChiSquare|0.2|ppc-linux|5.5.3|linux|2.2.10|199910221334
3147|pass|199910|ljmoore@freespace.net (Larry Moore)|Statistics-ChiSquare|0.2|MacOS_CFM68K|5.4.0|MacOS|7.6|199910230929
18566|pass|200102|a.calpini@alos.it ("alos.it/a.calpini")|Data-Compare|0.01|MSWin32-x86-multi-thread|5.6.0|MSWin32|4.0|200102091428
18584|pass|200102|schinder@pobox.com|Data-Hexdumper|0.01|ppc-linux|5.6.0|linux|2.2.14|200102091544
18585|pass|200102|schinder@pobox.com|Data-Hexdumper|0.01|sun4-solaris|5.6.0|solaris|2.7|200102091544
18586|pass|200102|schinder@pobox.com|Data-Hexdumper|0.01|PA-RISC1.1|5.6.0|hpux|10.20|200102091544
18661|pass|200102|a.calpini@alos.it ("alos.it/a.calpini")|Data-Hexdumper|0.01|MSWin32-x86-multi-thread|5.6.0|MSWin32|4.0|200102121237
19470|pass|200103|a.calpini@alos.it ("alos.it/a.calpini")|Statistics-ChiSquare|0.2|MSWin32-x86-multi-thread|5.6.0|MSWin32|4.0|200103011637
21002|unknown|200104|cpantest@quaday.com (Tim Ayers)|Pony|1.01|sparc-openbsd|5.6.0|openbsd|2.8|200104050832
21167|pass|200104|cpantest@quaday.com (Tim Ayers)|Tie-Scalar-Decay|1.0|sparc-openbsd|5.6.0|openbsd|2.8|200104110838
22016|pass|200104|kriegjcb@CMC01SE.rz.ruhr-uni-bochum.de|Tie-Scalar-Decay|1.1|i686-linux|5.7.1|linux|2.2.16|200104251735
22040|unknown|200104|kriegjcb@sunu991.ruhr-uni-bochum.de|Data-Compare|0.02|sun4-solaris|5.6.1|solaris|2.8|200104260801
22045|pass|200104|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.02|sun4-solaris|5.6.1|solaris|2.8|200104260812
22158|pass|200104|cpantest@quaday.com (Tim Ayers)|Data-Compare|0.02|sparc-openbsd|5.6.0|openbsd|2.8|200104270739
22176|pass|200104|kriegjcb@CMC01SE.rz.ruhr-uni-bochum.de|Data-Compare|0.02|i686-linux|5.7.1|linux|2.2.16|200104271607
22192|pass|200104|schinder@pobox.com|Tie-Scalar-Decay|1.1|sun4-solaris|5.6.1|solaris|2.7|200104271416
22193|pass|200104|schinder@pobox.com|Tie-Scalar-Decay|1.1|PA-RISC1.1|5.6.1|hpux|10.20|200104271416
22194|fail|200104|schinder@pobox.com|Tie-Scalar-Decay|1.1|ppc-linux|5.6.1|linux|2.4.2|200104271420
23486|pass|200105|Jost.Krieger@ruhr-uni-bochum.de|Tie-Scalar-Decay|1.1.1|sun4-solaris|5.6.1|solaris|2.8|200105221052
23554|pass|200105|cpantest@quaday.com (Tim Ayers)|Tie-Scalar-Decay|1.1.1|OpenBSD.sparc-openbsd|5.6.1|openbsd|2.8|200105230932
24779|unknown|200106|code@leegoddard.com (Lee Goddard)|Acme-Pony|1.1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200106202115
24988|pass|200106|Jost.Krieger@ruhr-uni-bochum.de|Tie-Hash-Rank|1.0.1|sun4-solaris|5.6.1|solaris|2.8|200106281517
25189|unknown|200107|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.1|sun4-solaris|5.6.1|solaris|2.8|200107091033
27937|unknown|200110|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris|5.6.1|solaris|2.8|200110101407
29413|pass|200111|gellyfish@gellyfish.com (Jonathan Stowe)|Tie-Hash-Transactional|1.0|i686-linux|5.6.1|linux|2.2.16-22|200111112039
30073|pass|200111|ethan@r220-1.rz.RWTH-Aachen.DE (Tassilo von Parseval)|Statistics-ChiSquare|0.3|i686-linux-thread|5.7.2|linux|2.4.13|200111240806
30092|pass|200111|riechert@pobox.com (Andreas Marcel Riechert)|Statistics-ChiSquare|0.3|i686-linux|5.6.1|linux|2.2.14-5.0|200111241833
30240|pass|200111|randy@theoryx5.uwinnipeg.ca (Randy Kobes)|Statistics-ChiSquare|0.3|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200111252029
31844|unknown|200201|riechert@pobox.com (Andreas Marcel Riechert)|Acme-Pony|1.1.2|i686-linux|5.6.1|linux|2.2.14-5.0|200201051646
32918|pass|200201|easmith@beatrice.rutgers.edu (Ed Allen Smith)|Data-Compare|0.02|IP30-R12000-irix|5.6.0|irix|6.5|200201231304
36386|pass|200204|autrijus@www.autrijus.org (Autrijus Tang)|Data-Compare|0.02|i386-freebsd|5.7.3 patch 15354|freebsd|4.5-release|200204011435
36442|unknown|200204|autrijus@www.autrijus.org (Autrijus Tang)|Acme-Pony|1.1.2|i386-freebsd|5.7.3 patch 15354|freebsd|4.5-release|200204021614
48917|pass|200207|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-ChiSquare|0.3|sun4-solaris|5.8.0|solaris|2.8|200207310932
48959|pass|200207|perl_test@logicalchaos.org ((Automated Perl Test Account))|Statistics-ChiSquare|0.3|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200207310518
50072|pass|200208|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|0.01|sun4-solaris|5.8.0|solaris|2.8|200208051136
50073|pass|200208|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Transactional|1.0|sun4-solaris|5.8.0|solaris|2.8|200208051138
50115|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Hexdumper|0.01|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208050731
50116|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Tie-Hash-Transactional|1.0|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208050731
50564|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Compare|0.02|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208060203
53617|pass|200208|alian@cpan.org|Data-Compare|0.02|i386-netbsd|5.8.0|netbsd|1.5.2|200208141515
54328|pass|200208|smoke@nambit.net (Dans Testorama)|Data-Compare|0.02|i386-freebsd|5.6.1|freebsd|4.2-release|200208162340
54333|pass|200208|smoke@nambit.net (Dans Testorama)|Data-Compare|0.02|i386-freebsd-thread-multi|5.8.0|freebsd|4.2-release|200208162342
54350|unknown|200208|smoke@nambit.net (Dans Testorama)|Acme-Pony|1.1.2|i386-freebsd|5.5.3|freebsd|4.0-current|200208170011
54351|unknown|200208|smoke@nambit.net (Dans Testorama)|Acme-Pony|1.1.2|i386-freebsd|5.6.1|freebsd|4.2-release|200208170011
54352|unknown|200208|smoke@nambit.net (Dans Testorama)|Acme-Pony|1.1.2|i386-freebsd-thread-multi|5.8.0|freebsd|4.2-release|200208170012
54628|pass|200208|smoke@nambit.net (Dans Testorama)|Statistics-ChiSquare|0.3|i386-freebsd|5.5.3|freebsd|4.0-current|200208170322
54629|pass|200208|smoke@nambit.net (Dans Testorama)|Statistics-ChiSquare|0.3|i386-freebsd|5.6.1|freebsd|4.2-release|200208170322
54630|pass|200208|smoke@nambit.net (Dans Testorama)|Statistics-ChiSquare|0.3|i386-freebsd-thread-multi|5.8.0|freebsd|4.2-release|200208170322
55844|pass|200208|alian@cpan.org|Data-Hexdumper|0.01|i386-netbsd|5.8.0|netbsd|1.5.2|200208190038
56068|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Compare|0.02|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200208191423
56910|pass|200208|alian@cpan.org (alian)|Data-Compare|0.02|OpenBSD.i386-openbsd|5.8.0|openbsd|3.0|200208221001
56921|pass|200208|alian@cpan.org (alian)|Data-Hexdumper|0.01|OpenBSD.i386-openbsd|5.8.0|openbsd|3.0|200208221028
58539|pass|200208|alian@cpan.org (alian)|Data-Compare|0.02|i386-freebsd|5.8.0|freebsd|4.6.2-release|200208301816
58554|pass|200208|alian@cpan.org (alian)|Data-Hexdumper|0.01|i386-freebsd|5.8.0|freebsd|4.6.2-release|200208301832
60246|unknown|200209|perl_test@logicalchaos.org ((Automated Perl Test Account))|Acme-Licence|1.0|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200209190454
60251|unknown|200209|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Licence|1.0|sun4-solaris|5.8.0|solaris|2.8|200209191322
60401|pass|200209|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Hexdumper|1.0.1|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200209200810
60428|pass|200209|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.0.1|sun4-solaris|5.8.0|solaris|2.8|200209201635
61369|pass|200209|root@thesafrans.com ((root))|Statistics-ChiSquare|0.3|i686-linux|5.8.0|linux|2.4.7-10|200209290847
61871|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|Statistics-ChiSquare|0.3|i586-linux|5.8.0|linux|2.2.16c32_iii|200209301534
61914|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|Data-Compare|0.02|i586-linux|5.8.0|linux|2.2.16c32_iii|200209301558
61923|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|Data-Hexdumper|1.0.1|i586-linux|5.8.0|linux|2.2.16c32_iii|200209301602
62459|unknown|200210|jlatour@www.arens.nl (Jeroen Latour)|Acme-Pony|1.1.2|i586-linux|5.8.0|linux|2.2.16c32_iii|200210012348
62470|unknown|200210|jlatour@www.arens.nl (Jeroen Latour)|Acme-Licence|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200210020052
62479|unknown|200210|perl_test@logicalchaos.org ((Automated Perl Test Account))|Acme-Pony|1.1.2|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200210011738
64602|unknown|200210|root@godzilla.uni.to (root)|Acme-Pony|1.1.2|i386-linux|5.6.1|linux|2.4.17-0.13smp|200210161825
68081|pass|200211|alian@cpan.org|Statistics-ChiSquare|0.3|i386-netbsd|5.8.0|netbsd|1.5.2|200211151932
68422|pass|200211|alian@cpan.org (Alian - CPANPLUS/auto)|Statistics-ChiSquare|0.3|OpenBSD.i386-openbsd|5.8.0|openbsd|3.0|200211152330
70145|pass|200211|alian@cpan.org (Alian - CPANPLUS/auto)|Data-Hexdumper|1.0.1|i386-netbsd|5.8.0|netbsd|1.5.2|200211210114
70469|pass|200211|alian@cpan.org|Data-Compare|0.02|sparc-netbsd|5.6.1|netbsd|1.5.1|200211211430
70495|pass|200211|alian@cpan.org (Alian - CPANPLUS/auto)|Statistics-ChiSquare|0.3|i386-freebsd|5.8.0|freebsd|4.6.2-release|200211211354
70505|pass|200211|alian@cpan.org|Data-Hexdumper|1.0.1|sparc-netbsd|5.6.1|netbsd|1.5.1|200211211512
78607|pass|200302|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|Data-Compare|0.02|i386-netbsd-thread-multi|5.8.0|netbsd|1.6|200302110230
78663|pass|200302|alian@cpan.org ((CPAN Tester = CPAN++ automate))|Data-Compare|0.02|ppc-linux|5.8.0|linux|2.4.18-0.9a|200302110322
78789|pass|200302|alian@cpan.org ((CPAN Tester''CPAN++ automate))|Data-Compare|0.02|sun4-solaris|5.8.0|solaris|2.7|200302110526
79039|pass|200302|alian@cpan.org ((CPAN Tester_CPAN++ automate))|Data-Compare|0.02|ppc-linux|5.8.0|linux|2.2.16|200302110959
79143|pass|200302|alian@cpan.org|Data-Compare|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200302111124
79430|pass|200302|alian@cpan.org ((alian))|Data-Compare|0.02|sparc-linux|5.6.1|linux|2.4.18|200302120456
79656|pass|200302|alian@cpan.org ((CPAN Tester / CPAN++ automate))|Data-Compare|0.02|sparc-netbsd|5.8.0|netbsd|1.5.3|200302130551
86049|pass|200303|root@localhost.localdomain ((root))|Data-Compare|0.02|i386-linux|5.8.0|linux|2.4.18-11smp|200303300513
90155|pass|200305|alian@cpan.org ((alian))|Data-Hexdumper|1.0.1|i686-linux-thread-multi-64all-ld|5.8.0|linux|2.4.20|200305131230
91242|pass|200305|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|1.0|sun4-solaris|5.8.0|solaris|2.8|200305242112
91335|pass|200305|cpantester@calaquendi.net ((Jeroen Latour))|Bryar|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200305260746
91402|fail|200305|crazyinsomniac@yahoo.com (DH)|Bryar|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200305270008
92820|pass|200306|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|1.2|sun4-solaris|5.8.0|solaris|2.8|200306150155
94030|pass|200306|cpantester@calaquendi.net ((Jeroen Latour))|NestedMap|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200306261252
94034|pass|200306|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|NestedMap|1.0|sun4-solaris|5.8.0|solaris|2.8|200306261239
94252|pass|200306|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Find-Rule-Permissions|1.0|sun4-solaris|5.8.0|solaris|2.8|200306300842
94315|pass|200306|cpantester@calaquendi.net ((Jeroen Latour))|File-Find-Rule-Permissions|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200306302104
95944|pass|200307|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Find-Rule-Permissions|1.1|sun4-solaris|5.8.0|solaris|2.8|200307230034
97303|pass|200308|cpantester@calaquendi.net ((Jeroen Latour))|File-Find-Rule-Permissions|1.1|i586-linux|5.8.0|linux|2.2.16c32_iii|200308061042
97862|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.1|sun4-solaris|5.8.0|solaris|2.8|200308101707
98649|fail|200308|cpantester@calaquendi.net ((Jeroen Latour))|Bryar|2.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200308161636
98691|fail|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|2.0|sun4-solaris|5.8.0|solaris|2.8|200308161658
99060|pass|200308|root@dropbear ((root))|Data-Hexdumper|1.1|i586-linux|5.8.0|linux|2.4.20-22em|200308221803
99725|pass|200308|cpantester@calaquendi.net ((Jeroen Latour))|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|i586-linux|5.8.0|linux|2.2.16c32_iii|200308290931
99860|pass|200308|crazyinsomniac@yahoo.com|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200308310346
100133|pass|200309|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|sun4-solaris|5.8.0|solaris|2.8|200309011741
100444|pass|200309|jlatour@calaquendi.net|Acme-Scurvy-Whoreson-BilgeRat|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200309030257
100450|pass|200309|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.0|sun4-solaris|5.8.0|solaris|2.8|200309030244
103212|pass|200309|Perl_Test@LogicalChaos.org|Data-Hexdumper|1.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200309280407
104500|unknown|200310|kriegjcb@mi.ruhr-uni-bochum.de ((Jost Krieger))|Acme-Pony|1.1.2|sun4-solaris|5.8.1|solaris|2.8|200310061309
105242|pass|200310|webmaster@thr.msu.edu|Data-Compare|0.02|i386-freebsd|5.6.1|freebsd|5.1-current|200310091009
105391|pass|200310|webmaster@thr.msu.edu|Data-Hexdumper|1.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310091842
105564|pass|200310|webmaster@thr.msu.edu|File-Find-Rule-Permissions|1.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310100200
107669|pass|200310|webmaster@thr.msu.edu|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|i386-freebsd|5.6.1|freebsd|5.1-current|200310191312
107670|pass|200310|webmaster@thr.msu.edu|Tie-Hash-Transactional|1.0|i386-freebsd|5.6.1|freebsd|5.1-current|200310191312
107671|pass|200310|webmaster@thr.msu.edu|Tie-Hash-Rank|1.0.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310191312
107672|pass|200310|webmaster@thr.msu.edu|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310191313
107712|pass|200310|Perl_Test@LogicalChaos.org|Tie-Hash-Rank|1.0.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200310191223
107713|pass|200310|Perl_Test@LogicalChaos.org|Tie-Scalar-Decay|1.1.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200310191223
107906|pass|200310|nothingmuch@woobling.org|Games-Dice-Advanced|1.0|darwin|5.8.1|darwin|6.8|200310210201
108039|pass|200310|webmaster@thr.msu.edu|Games-Dice-Advanced|1.0|i386-freebsd|5.6.1|freebsd|5.1-current|200310211714
108140|pass|200310|Perl_Test@LogicalChaos.org|Games-Dice-Advanced|1.0|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200310220104
108339|pass|200310|barbie@missbarbell.co.uk (Barbie)|Games-Dice-Advanced|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200310222256
108348|pass|200310|nothingmuch@woobling.org|Net-Random|1.0|darwin|5.8.1|darwin|6.8|200310230107
108357|pass|200310|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Net-Random|1.0|sun4-solaris|5.8.1|solaris|2.8|200310230036
108976|fail|200310|barbie@missbarbell.co.uk (Barbie)|Net-Random|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200310280741
111603|pass|200311|nothingmuch@woobling.org|Sub-WrapPackages|1.0|darwin|5.8.1|darwin|6.8|200311152328
111628|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Sub-WrapPackages|1.0|sun4-solaris|5.8.1|solaris|2.8|200311161149
111640|pass|200311|nothingmuch@woobling.org|Statistics-ChiSquare|0.5|darwin|5.8.1|darwin|6.8|200311161944
111706|pass|200311|nothingmuch@woobling.org|Statistics-ChiSquare|0.5|powerpc-linux|5.8.0|linux|2.4.23-pre5|200311172329
111711|pass|200311|nothingmuch@woobling.org|Tie-Hash-Longest|1.1|darwin|5.8.1|darwin|6.8|200311180043
111714|pass|200311|nothingmuch@woobling.org|Tie-Hash-Longest|1.1|powerpc-linux|5.8.0|linux|2.4.23-pre5|200311180020
111767|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Statistics-ChiSquare|0.5|sun4-solaris|5.8.1|solaris|2.8|200311181021
111776|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Tie-Hash-Longest|1.1|sun4-solaris|5.8.1|solaris|2.8|200311181049
111919|pass|200311|webmaster@thr.msu.edu|Sub-WrapPackages|1.0|i386-freebsd|5.8.2|freebsd|5.1-current|200311191538
111932|pass|200311|webmaster@thr.msu.edu|Statistics-ChiSquare|0.5|i386-freebsd|5.8.2|freebsd|5.1-current|200311191552
111946|pass|200311|webmaster@thr.msu.edu|Tie-Hash-Longest|1.1|i386-freebsd|5.8.2|freebsd|5.1-current|200311191635
111994|pass|200311|barbie@missbarbell.co.uk (Barbie)|Tie-Hash-Longest|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311200824
112009|pass|200311|barbie@missbarbell.co.uk (Barbie)|Statistics-ChiSquare|0.5|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311200824
112018|pass|200311|barbie@missbarbell.co.uk (Barbie)|Sub-WrapPackages|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311200824
112080|pass|200311|nothingmuch@woobling.org|Statistics-SerialCorrelation|1.0|darwin|5.8.1|darwin|6.8|200311211439
112103|pass|200311|nothingmuch@woobling.org|Statistics-SerialCorrelation|1.0|powerpc-linux|5.8.0|linux|2.4.23-pre5|200311211803
112146|pass|200311|webmaster@thr.msu.edu|Statistics-SerialCorrelation|1.0|i386-freebsd|5.8.2|freebsd|5.1-current|200311220119
112172|pass|200311|Perl_Test@LogicalChaos.org|Sub-WrapPackages|1.0|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220236
112185|pass|200311|Perl_Test@LogicalChaos.org|Statistics-ChiSquare|0.5|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220248
112197|pass|200311|Perl_Test@LogicalChaos.org|Tie-Hash-Longest|1.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220323
112240|pass|200311|Perl_Test@LogicalChaos.org|Statistics-SerialCorrelation|1.0|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220439
112272|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Statistics-SerialCorrelation|1.0|sun4-solaris|5.8.1|solaris|2.8|200311221038
112788|pass|200311|barbie@missbarbell.co.uk (Barbie)|Statistics-SerialCorrelation|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311270726
113523|pass|200312|root@uk-wrk-0017 ((root))|Sub-WrapPackages|1.0|i386-linux|5.8.1|linux|2.4.22-xfs+ti1211|200312021956
114594|fail|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Bryar|2.1|sun4-solaris|5.8.1|solaris|2.8|200312121042
115002|pass|200312|barbie@missbarbell.co.uk (Barbie)|Bryar|2.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312152024
115405|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|File-Find-Rule-Permissions|1.2|sun4-solaris|5.8.1|solaris|2.8|200312191034
115506|pass|200312|webmaster@thr.msu.edu|File-Find-Rule-Permissions|1.2|i386-freebsd|5.6.1|freebsd|5.2-beta|200312200410
115565|na|200312|barbie@missbarbell.co.uk (Barbie)|File-Find-Rule-Permissions|1.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312201228
115890|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.03|sun4-solaris|5.8.1|solaris|2.8|200312241039
115892|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.04|sun4-solaris|5.8.1|solaris|2.8|200312241040
115938|pass|200312|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.04|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312242048
115941|pass|200312|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312242048
115967|pass|200312|lithron@bellsouth.net|Data-Compare|0.04|cygwin-thread-multi-64int|5.8.2|cygwin|1.5.5(0.9432)|200312250300
115981|pass|200312|webmaster@thr.msu.edu|Data-Compare|0.03|i386-freebsd|5.8.2|freebsd|5.2-current|200312251145
115983|pass|200312|webmaster@thr.msu.edu|Data-Compare|0.04|i386-freebsd|5.8.2|freebsd|5.2-current|200312251146
116371|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.05|sun4-solaris|5.8.1|solaris|2.8|200312311027
116578|pass|200401|webmaster@thr.msu.edu|Data-Compare|0.05|i386-freebsd|5.8.2|freebsd|5.2-current|200401021841
117144|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.05|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401062214
117236|pass|200401|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.06|sun4-solaris|5.8.1|solaris|2.8|200401070853
117337|pass|200401|jlatour@calaquendi.net|Data-Compare|0.06|i586-linux|5.8.2|linux|2.2.16c37_iii|200401080005
117380|pass|200401|webmaster@thr.msu.edu|Data-Compare|0.06|i386-freebsd|5.8.2|freebsd|5.2-current|200401080041
117485|pass|200401|jlatour@calaquendi.net|Data-Compare|0.07|i586-linux|5.8.2|linux|2.2.16c37_iii|200401081057
117505|pass|200401|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.07|sun4-solaris|5.8.1|solaris|2.8|200401081034
117607|pass|200401|webmaster@thr.msu.edu|Data-Compare|0.07|i386-freebsd|5.8.2|freebsd|5.2-current|200401090408
117898|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.07|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401100851
117907|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.06|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401100851
119387|pass|200401|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.08|sun4-solaris|5.8.1|solaris|2.8|200401210824
119444|pass|200401|steve@gandalf.workpc.tds.net ((root))|Data-Compare|0.08|i386-linux|5.8.1|linux|2.4.21-2.elsmp|200401211242
119557|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.08|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401222135
119724|pass|200401|steve@gandalf.workpc.tds.net ((root))|Bryar|2.3|i386-linux|5.8.1|linux|2.4.21-2.elsmp|200401231111
119747|pass|200401|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Bryar|2.2|sun4-solaris|5.8.1|solaris|2.8|200401241057
119757|pass|200401|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Statistics-SerialCorrelation|1.1|sun4-solaris|5.8.1|solaris|2.8|200401241132
119881|pass|200401|webmaster@thr.msu.edu|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.2|freebsd|5.2-current|200401260203
120817|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402030754
120850|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.3|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402030754
120895|pass|200402|barbie@missbarbell.co.uk (Barbie)|Statistics-SerialCorrelation|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402030755
121670|pass|200402|nothingmuch@woobling.org|Bryar|2.4|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402081917
121763|pass|200402|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Bryar|2.5|sun4-solaris|5.8.1|solaris|2.8|200402091052
122036|pass|200402|nothingmuch@woobling.org|Bryar|2.6|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402111538
122175|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.5|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402120813
122192|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.4|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402120813
122308|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.6|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402130742
123333|pass|200402|nothingmuch@woobling.org|Data-Hexdumper|1.2|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402201702
123394|pass|200402|cpansmoke@alternation.net|Data-Hexdumper|1.2|i586-linux|5.8.0|linux|2.4.22-4tr|200402210507
123399|pass|200402|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Hexdumper|1.2|sun4-solaris|5.8.1|solaris|2.8|200402211022
123609|pass|200402|webmaster@thr.msu.edu|Data-Hexdumper|1.2|i386-freebsd|5.8.2|freebsd|5.2-current|200402221849
123735|pass|200402|nothingmuch@woobling.org|Data-Compare|0.09|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402240107
123796|pass|200402|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.09|sun4-solaris|5.8.1|solaris|2.8|200402241052
123817|pass|200402|cpansmoke@alternation.net|Data-Compare|0.09|i586-linux|5.8.0|linux|2.4.22-4tr|200402240807
123896|pass|200402|webmaster@thr.msu.edu|Data-Compare|0.09|i386-freebsd|5.8.2|freebsd|5.2-current|200402241850
124187|pass|200402|barbie@missbarbell.co.uk (Barbie)|Data-Hexdumper|1.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402260808
124420|pass|200402|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.09|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402270721
127016|pass|200403|nothingmuch@woobling.org|Data-Compare|0.1|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200403131335
127052|pass|200403|cpansmoke@alternation.net|Data-Compare|0.1|i586-linux|5.8.0|linux|2.4.22-4tr|200403131807
127114|pass|200403|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Data-Compare|0.1|sun4-solaris|5.8.1|solaris|2.8|200403141030
127238|pass|200403|webmaster@thr.msu.edu|Data-Compare|0.1|i386-freebsd|5.8.2|freebsd|5.2-current|200403141830
128050|pass|200403|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200403180756
129983|pass|200403|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200403291616
132100|pass|200404|cpansmoke@alternation.net|Bryar|2.6|i586-linux|5.8.0|linux|2.4.22-4tr|200404090008
132861|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Bryar|2.6|sun4-solaris|5.8.1|solaris|2.8|200404150923
142676|pass|200406|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.11|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200406030737
142964|pass|200406|rrwo@cpan.org|Data-Compare|0.11|MSWin32-x86-multi-thread|5.8.3|MSWin32|4.0|200406040942
146822|pass|200407|cpansmoke@alternation.net|Data-Compare|0.11|i586-linux|5.8.0|linux|2.4.22-4tr|200407050908
147721|pass|200407|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-ChiSquare|0.5|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200407080346
148267|pass|200407|rrwo@cpan.org|Class-CanBeA|1.0|MSWin32-x86-multi-thread|5.8.3|MSWin32|4.0|200407110109
148277|pass|200407|rrwo@cpan.org|Class-CanBeA|1.0|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200407110250
148287|pass|200407|cpansmoke@alternation.net|Class-CanBeA|1.0|i586-linux|5.8.0|linux|2.4.22-4tr|200407110408
148986|pass|200407|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Class-CanBeA|1.0|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200407140502
151471|pass|200407|webmaster@thr.msu.edu|Data-Compare|0.11|i386-freebsd-64int|5.8.4|freebsd|5.2-current|200407301504
154082|pass|200408|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.0|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200408182140
154114|pass|200408|cpantester@thr.msu.edu|Number-Phone|1.0|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200408190127
154121|pass|200408|rrwo@cpan.org|Number-Phone|1.0|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200408190341
154183|pass|200408|martin.thurn@ngc.com ("Thurn, Martin")|Number-Phone|1.0|sun4-solaris|5.9.1|solaris|2.8|200408190754
155673|unknown|200409|jim@jimandkoka.com|Acme-Pony|1.1.2|darwin-2level|5.8.4|darwin|7.3.0|200409021509
156532|pass|200409|Jost.Krieger+perl@rub.de|Net-Random|1.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409071326
156605|pass|200409|alian@cpan.org ((CPAN Tester + CPAN++ automate))|Net-Random|1.1|ppc-linux|5.8.4|linux|2.4.19-4a|200409072209
156606|pass|200409|alian@cpan.org ((CPAN Tester. CPAN++ automate))|Net-Random|1.1|OpenBSD.i386-openbsd|5.8.4|openbsd|3.5|200409080011
156917|fail|200409|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|Net-Random|1.1|i386-netbsd-64int|5.8.4|netbsd|1.6|200409090006
157366|pass|200409|barbie@missbarbell.co.uk (Barbie)|Net-Random|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409110708
158211|pass|200409|Jost.Krieger+perl@rub.de|Number-Phone|1.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409160411
158232|pass|200409|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|Number-Phone|1.1|i386-netbsd-64int|5.8.4|netbsd|1.6|200409161150
158233|pass|200409|alian@cpan.org ((CPAN Tester. CPAN++ automate))|Number-Phone|1.1|OpenBSD.i386-openbsd|5.8.4|openbsd|3.5|200409161349
158237|pass|200409|alian@cpan.org ((alian))|Number-Phone|1.1|sparc64-linux|5.8.5|linux|2.4.18|200409161204
158254|pass|200409|martin.thurn@ngc.com ("Thurn, Martin")|Number-Phone|1.1|sun4-solaris|5.9.1|solaris|2.8|200409160520
158727|pass|200409|cpantester@thr.msu.edu|Net-Random|1.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200409171223
158921|pass|200409|cpantester@thr.msu.edu|Number-Phone|1.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200409180135
159531|pass|200409|alian@cpan.org ((CPAN Tester + CPAN++ automate))|Number-Phone|1.1|ppc-linux|5.8.4|linux|2.4.19-4a|200409210855
159704|pass|200409|barbie@missbarbell.co.uk (Barbie)|Number-Phone|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409220830
160038|pass|200409|Jost.Krieger+perl@rub.de|Number-Phone|1.2|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409230357
160051|pass|200409|alian@cpan.org ((CPAN Tester + CPAN++ automate))|Number-Phone|1.2|ppc-linux|5.8.4|linux|2.4.19-4a|200409230919
160093|pass|200409|martin.thurn@ngc.com ("Thurn, Martin")|Number-Phone|1.2|sun4-solaris|5.9.1|solaris|2.8|200409230617
162192|pass|200410|Jost.Krieger+perl@rub.de|Number-Phone|1.2001|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410132331
162785|pass|200410|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|2.8_01|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410190938
162948|pass|200410|Jost.Krieger+perl@rub.de|Number-Phone|1.3|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410210359
163103|pass|200410|Jost.Krieger+perl@rub.de|Bryar|2.6|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410230659
163394|pass|200410|Jost.Krieger+perl@rub.de|Acme-Scurvy-Whoreson-BilgeRat|1.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410260359
163426|pass|200410|shlomif@iglu.org.il (Shlomi Fish)|Number-Phone|1.3|i686-linux|5.8.5|linux|2.6.8.1-10mdksmp|200410261443
163536|pass|200410|barbie@missbarbell.co.uk|Number-Phone|1.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200410270912
164481|pass|200411|cpantester@thr.msu.edu|Number-Phone|1.2|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411021233
164948|pass|200411|cpantester@thr.msu.edu|Number-Phone|1.2001|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411031032
165117|pass|200411|corion+cpansmoker@corion.net|Acme-Scurvy-Whoreson-BilgeRat|1.1|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411031909
165645|pass|200411|saper@cpan.org|Data-Compare|0.11|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200411071232
165739|pass|200411|corion-cpansmoker@corion.net|Data-Transactional|0.1|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411071010
165993|pass|200411|cpantester@thr.msu.edu|Data-Transactional|0.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411090940
166096|pass|200411|saper@cpan.org|Data-Compare|0.13|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200411110826
166129|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.12|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200411100845
166130|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.13|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200411100846
166207|pass|200411|barbie@missbarbell.co.uk|Number-Phone|1.2001|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411101259
166420|pass|200411|rrwo@cpan.org|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200411110047
166421|pass|200411|rrwo@cpan.org|Data-Compare|0.12|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200411110048
166465|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.3001|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200411111217
166521|pass|200411|barbie@missbarbell.co.uk|Number-Phone|1.3|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411111855
166525|fail|200411|barbie@missbarbell.co.uk|Bryar|2.8_01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411111855
166546|fail|200411|barbie@missbarbell.co.uk|Data-Compare|0.13|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411111855
166588|pass|200411|cpantester@thr.msu.edu|Data-Compare|0.12|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411111416
166590|pass|200411|cpantester@thr.msu.edu|Data-Compare|0.13|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411111416
166610|pass|200411|corion-cpansmoker@corion.net|Number-Phone|1.3001|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411112036
166652|pass|200411|cpantester@thr.msu.edu|Number-Phone|1.3001|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411111530
166717|pass|200411|Jost.Krieger+cpanplus@rub.de|Data-Transactional|0.1|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200411120929
167036|pass|200411|shlomif@iglu.org.il (Shlomi Fish)|Number-Phone|1.3001|i686-linux|5.8.5|linux|2.6.8.1-10mdksmp|200411132058
169429|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.3002|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200411261633
169442|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.9.1|linux|2.6.8.1|200411262046
169444|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i386-linux-thread|5.8.4|linux|2.6.7-gentoo-r11|200411262047
169521|fail|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.5.4|linux|2.6.8.1|200411262045
169522|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.6.2|linux|2.6.8.1|200411262046
169524|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux-thread-multi|5.9.1|linux|2.6.8.1|200411262047
169526|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.8.5|linux|2.6.8.1|200411262048
169528|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux-thread-multi|5.8.5|linux|2.6.8.1|200411262048
169559|pass|200411|corion-cpansmoker@corion.net|Number-Phone|1.3002|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411270047
169740|pass|200411|saper@cpan.org|Number-Phone|1.3002|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200411271546
169753|pass|200411|saper@cpan.org|Number-Phone|1.3002|darwin|5.6.0|darwin|6.0|200411271602
172027|pass|200412|Jost.Krieger+cpanplus@rub.de|Number-Phone|1.3003|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200412060512
172039|fail|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.5.4|linux|2.6.8.1|200412061054
172045|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.6.2|linux|2.6.8.1|200412061106
172055|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.9.2 patch 23609|linux|2.6.8.1|200412061115
172072|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux-thread-multi|5.9.2 patch 23609|linux|2.6.8.1|200412061138
172080|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.8.6|linux|2.6.8.1|200412061149
172095|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412061203
172107|pass|200412|saper@cpan.org|Number-Phone|1.3003|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200412061110
172118|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i386-linux-thread|5.8.4|linux|2.6.7-gentoo-r11|200412061222
172178|pass|200412|corion-cpansmoker@corion.net|Number-Phone|1.3003|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200412061934
172666|pass|200412|foo@bar.com|Acme-Pony|1.1.2|darwin-thread-multi-2level|5.8.1 RC3|darwin|7.0|200412081422
172735|fail|200412|nothingmuch@woobling.org|Data-Compare|0.13|i686-linux|5.6.2|linux|2.6.8.1|200412090318
172774|pass|200412|nothingmuch@woobling.org|Data-Compare|0.13|i686-linux|5.8.6|linux|2.6.8.1|200412090439
172783|pass|200412|nothingmuch@woobling.org|Data-Compare|0.13|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412090454
174147|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux|5.6.2|linux|2.6.8.1|200412151759
174466|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux|5.9.2 patch 23656|linux|2.6.8.1|200412170002
174476|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux-thread-multi|5.9.2 patch 23656|linux|2.6.8.1|200412170021
174501|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412170049
174828|pass|200412|saper@cpan.org|Sub-WrapPackages|1.0|darwin|5.6.0|darwin|6.0|200412190038
175191|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux|5.6.2|linux|2.6.8.1|200412211016
175207|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux|5.9.2 patch 23662|linux|2.6.8.1|200412211029
175225|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux-thread-multi|5.9.2 patch 23662|linux|2.6.8.1|200412211043
175238|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i386-linux-thread|5.8.4|linux|2.6.7-gentoo-r11|200412211101
175264|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux|5.8.6|linux|2.6.8.1|200412211123
175282|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412211139
175392|pass|200412|rrwo@cpan.org|Class-CanBeA|1.1|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200412211514
175604|pass|200412|Jost.Krieger@ruhr-uni-bochum.de|Class-CanBeA|1.1|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200412221554
175780|pass|200412|saper@cpan.org|Class-CanBeA|1.1|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200412230008
176594|pass|200501|rrwo@cpan.org|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200501011906
176599|pass|200501|rrwo@cpan.org|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200501011908
177521|pass|200501|cpantester@thr.msu.edu|Number-Phone|1.3003|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501080223
177682|pass|200501|cpantester@thr.msu.edu|Sub-WrapPackages|1.0|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501080846
177830|pass|200501|cpantester@thr.msu.edu|Class-CanBeA|1.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501090029
178996|pass|200501|saper@cpan.org|Data-Compare|0.13|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200501162222
179170|pass|200501|root@fisharerojo.org ((Charlie &))|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-openbsd|5.8.5|openbsd|3.6|200501180850
179209|pass|200501|shlomif@iglu.org.il (Shlomi Fish)|Sub-WrapPackages|1.0|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200501181930
179679|pass|200501|rrwo@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200501201640
180545|pass|200501|saperghis@aacom.fr|Data-Compare|0.13|i386-linux|5.8.3|linux|2.6.0-1mdkenterprise|200501241408
180718|pass|200501|root@fisharerojo.org ((Charlie &))|Bryar|2.6|i386-openbsd|5.8.5|openbsd|3.6|200501250751
181235|fail|200501|corion-cpansmoker@corion.net|Palm-SMS|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200501290957
181709|pass|200502|cpansmoke@alternation.net|Sub-WrapPackages|1.0|i586-linux|5.8.3|linux|2.4.21-13trfirewallsmp|200502020612
181897|pass|200502|saper@cpan.org|Sub-WrapPackages|1.0|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200502022306
182231|pass|200502|cpantester@thr.msu.edu|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-64int|5.8.6|freebsd|5.3-stable|200502031858
185115|pass|200502|rrwo@cpan.org|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200502182335
189095|pass|200503|saper@cpan.org|Data-Hexdumper|1.2|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503100108
196329|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504032333
196772|pass|200504|cpan@calaquendi.net|Data-Compare|0.13|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200504042125
197527|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.3003|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504081244
197600|pass|200504|rrwo@cpan.org|Number-Phone|1.3003|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200504081254
197676|pass|200504|saper@cpan.org|Number-Phone|1.3003|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200504082105
197683|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.3003|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504090406
198129|pass|200504|saper@cpan.org|Number-Phone|1.3003|sun4-solaris|5.8.5|solaris|2.9|200504111111
198209|pass|200504|corion-cpanplus@corion.net|Number-Phone|1.3003|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504111758
198491|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.3004|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504131128
198591|pass|200504|corion-cpanplus@corion.net|Number-Phone|1.3004|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504132021
208372|pass|200505|saper@cpan.org|Number-Phone|1.4|sun4-solaris|5.8.5|solaris|2.9|200505191028
208402|pass|200505|imacat@mail.imacat.idv.tw|Number-Phone|1.4|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200505192028
208414|pass|200505|imacat@mail.imacat.idv.tw|Number-Phone|1.4|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200505192055
208419|pass|200505|imacat@mail.imacat.idv.tw|Number-Phone|1.4|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200505192057
208639|pass|200505|Jost.Krieger@ruhr-uni-bochum.de|Number-Phone|1.4|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200505200649
208931|pass|200505|corion-cpanplus@corion.net|Number-Phone|1.4|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200505202142
209198|pass|200505|saper@cpan.org|Number-Phone|1.4|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200505220037
211199|pass|200505|root@houseabsolute.urth.org ((root))|Data-Compare|0.13|i386-linux|5.8.4|linux|2.4.27-ti1211|200505310008
211443|fail|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-SMS|0.01|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506020717
214964|pass|200506|saper@cpan.org|Number-Phone|1.4|darwin|5.6.0|darwin|6.0|200506120128
219764|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.4001|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506281457
220045|pass|200506|imacat@mail.imacat.idv.tw|Number-Phone|1.4001|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200506291710
220096|pass|200506|saper@cpan.org|Number-Phone|1.4001|sun4-solaris|5.8.5|solaris|2.9|200506291213
220127|pass|200506|imacat@mail.imacat.idv.tw|Number-Phone|1.4001|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506292034
220138|pass|200506|imacat@mail.imacat.idv.tw|Number-Phone|1.4001|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200506292041
220280|pass|200506|corion-cpanplus@corion.net|Number-Phone|1.4001|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506300845
220308|pass|200506|corion-cpanplus@corion.net|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506300919
220438|pass|200506|imacat@mail.imacat.idv.tw|Data-Compare|0.13|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200506302053
220485|pass|200506|imacat@mail.imacat.idv.tw|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506302147
220553|pass|200507|saper@cpan.org|Number-Phone|1.4001|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200507010001
220664|pass|200507|root@berthoudwireless.net ((root))|Data-Compare|0.13|i686-linux|5.8.7|linux|2.6.12-gentoo-r2|200507010103
223927|pass|200507|saper@cpan.org|Data-Compare|0.13|sun4-solaris|5.8.5|solaris|2.9|200507130954
226474|pass|200507|saper@cpan.org|Number-Phone|1.4001|darwin|5.6.0|darwin|6.0|200507210008
228104|pass|200507|imacat@mail.imacat.idv.tw|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200507272149
229324|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508011634
230507|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4002|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508032142
230641|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4002|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508042018
230643|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4002|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200508042019
231459|pass|200508|corion-cpanplus@corion.net|Number-Phone|1.4002|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200508072159
232232|pass|200508|saper@cpan.org|Number-Phone|1.4002|sun4-solaris|5.8.5|solaris|2.9|200508091108
233794|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Hexdumper|1.2|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508141701
234470|pass|200508|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.2|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508170017
236166|pass|200508|gwood@email.mot.com ((George W Wood))|Data-Compare|0.13|i686-linux|5.8.6|linux|2.4.21-20.elsmp|200508220342
236819|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.4003|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508241729
236907|pass|200508|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.4003|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200508241616
236968|pass|200508|saper@cpan.org|Number-Phone|1.4003|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200508242102
237109|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4003|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508250747
237124|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4003|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508250805
237270|pass|200508|rrwo@cpan.org|Number-Phone|1.4003|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200508251439
244310|pass|200509|meneldor@metallibrary.ru|Data-Hexdumper|1.2|i386-linux|5.8.3|linux|2.4.21-9.elsmp|200509161951
244808|pass|200509|ultradm@cpan.org|Data-Compare|0.13|i686-linux-thread|5.8.6|linux|2.6.11-gentoo-r6|200509172039
245054|pass|200509|corion-cpanplus@corion.net|Data-Hexdumper|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200509172204
245305|pass|200509|njh@despammed.com|Data-Hexdumper|1.2|ppc-linux|5.8.3|linux|2.6.6-1.1326smp|200509171902
246450|pass|200509|david@landgren.net|Data-Hexdumper|1.2|i386-freebsd|5.8.1|freebsd|5.4-stable|200509191213
247422|pass|200509|njh@despammed.com|Data-Compare|0.13|i386-linux|5.8.7|linux|2.4.27-ti1211|200509201402
258137|pass|200510|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.4004|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200510121351
258161|pass|200510|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.4004|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200510120819
258306|pass|200510|corion-cpanplus@corion.net|Number-Phone|1.4004|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200510122021
258774|pass|200510|njh@despammed.com|Number-Phone|1.4004|i386-linux|5.8.5|linux|2.4.21-25.elsmp|200510131058
258922|pass|200510|saper@cpan.org|Number-Phone|1.4004|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510132040
259968|pass|200510|saper@cpan.org|Number-Phone|1.5|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510161745
260021|pass|200510|imacat@mail.imacat.idv.tw|Number-Phone|1.5|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200510170414
260029|pass|200510|imacat@mail.imacat.idv.tw|Number-Phone|1.5|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200510170421
260051|pass|200510|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.5|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200510170844
260191|pass|200510|imacat@mail.imacat.idv.tw|Number-Phone|1.4004|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200510180825
260587|pass|200510|corion-cpanplus@corion.net|Number-Phone|1.5|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200510192027
260898|pass|200510|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.5|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200510202001
261368|pass|200510|njh@despammed.com|Number-Phone|1.5|i386-linux|5.8.6|linux|2.4.21-27.0.2.elsmp|200510221455
261541|pass|200510|njh@despammed.com|Number-Phone|1.5|ppc-linux|5.8.3|linux|2.6.6-1.1326smp|200510221844
262207|pass|200510|njh@despammed.com|Number-Phone|1.5|i486-linux-gnu|5.8.7|linux|2.6.14-rc4|200510251548
264405|pass|200511|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200511010235
265861|pass|200511|njh@despammed.com|Data-Compare|0.13|ppc-linux|5.8.3|linux|2.6.6-1.1326smp|200511051614
267538|pass|200511|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200511120225
269770|pass|200511|postmaster@amsfep18-int.chello.nl|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200511201354
275357|pass|200512|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|1.2|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200512140828
275393|pass|200512|leeym@utopia.leeym.com ((Yen-Ming Lee))|Net-Random|1.2|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200512141740
275676|pass|200512|njh@despammed.com|Net-Random|1.2|i386-linux|5.8.6|linux|2.6.9-22.18.bz155725.elsmp|200512150658
275830|pass|200512|corion-cpanplus@corion.net|Net-Random|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200512151939
279001|pass|200512|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Class-CanBeA|1.2|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200512291152
279781|pass|200601|corion-cpanplus@corion.net|Class-CanBeA|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200601011841
281710|pass|200601|saper@cpan.org|Class-CanBeA|1.2|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200601110339
281711|pass|200601|saper@cpan.org|Class-CanBeA|1.2|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200601110339
286555|pass|200601|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Overwrite|1.0|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200601301202
287234|pass|200602|leeym@utopia.leeym.com ((Yen-Ming Lee))|File-Overwrite|1.0|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200602012357
289121|pass|200602|gam3-cpanplus@gam3.net|Data-Compare|0.13|i486-linux-gnu|5.8.7|linux|2.6.14-rc4|200602101344
300432|pass|200603|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200603200436
305984|pass|200604|edepagne@184dhcp145.pl.eso.org ((root))|Statistics-ChiSquare|0.5|i386-linux|5.8.7|linux|2.6.3-28mdk-i686-up-4gb|200604080602
308015|pass|200604|root@chorny.net|Statistics-ChiSquare|0.5|i686-linux|5.8.8|linux|2.4.20-8smp|200604180521
312967|pass|200605|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200605092239
314112|pass|200605|Jost.Krieger+perl@rub.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200605151414
326166|pass|200606|root@webigail.pooq.com ((root))|Data-Compare|0.13|i386-linux|5.8.8|linux|2.6.12-12mdksmp|200606301715
326827|pass|200607|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.01|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200607041255
326894|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607050456
326896|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607050458
327028|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607060241
327156|pass|200607|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.02|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200607061747
330218|pass|200607|imacat@mail.imacat.idv.tw|Data-Compare|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607190322
331278|pass|200607|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607200146
331975|pass|200607|imacat@mail.imacat.idv.tw|Number-Phone|1.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607202026
332024|pass|200607|imacat@mail.imacat.idv.tw|Number-Phone|1.4004|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607201820
333143|pass|200607|imacat@mail.imacat.idv.tw|Net-Random|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607220710
333371|pass|200607|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607221801
334134|pass|200607|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607231648
335574|pass|200607|imacat@mail.imacat.idv.tw|Data-Compare|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607251327
336203|pass|200607|imacat@mail.imacat.idv.tw|Number-Phone|1.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607260008
336692|pass|200607|imacat@mail.imacat.idv.tw|Net-Random|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607261742
336789|pass|200607|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607262132
337018|pass|200607|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607270205
337872|pass|200607|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sub-WrapPackages|1.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200607271444
338614|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607281708
338982|pass|200607|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607291323
340236|pass|200608|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608030100
340401|pass|200608|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sub-WrapPackages|1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200608031203
340715|pass|200608|jworkman@pimpworks.org (Jeff Workman)|Acme-Licence|1.0|i386-netbsd|5.8.3|netbsd|1.6.2|200608031600
341364|pass|200608|corion-cpanplus@corion.net|Sub-WrapPackages|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200608050855
342214|pass|200608|cogent@cpan.org|Data-Compare|0.13|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200608100437
344460|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.51|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608240204
344713|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.52|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250509
344714|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.54|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250524
344715|fail|200608|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250524
344716|fail|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.53|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250527
344828|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.55|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608260505
344829|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608260515
348551|pass|200609|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200609140041
348707|pass|200609|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200609140529
349313|pass|200609|alexchorny@gmail.com (Alexandr Ciornii)|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.4.20-8smp|200609141102
351783|pass|200609|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|0.13|i486-linux-gnu|5.8.7|linux|2.6.10|200609251531
353009|pass|200609|mark.gardner@bms.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.4.21-37.0.1.el|200609281424
356781|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200610082338
357072|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-freebsd-64int|5.8.5|freebsd|5.3-release|200610091142
358244|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.20-8|200610111335
358966|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|alpha-freebsd|5.8.7|freebsd|6.0-release|200610121131
359236|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610121735
361330|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181038
365977|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200610301814
366628|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610311115
367382|pass|200611|andreas.koenig.gmwojprw@franz.ak.mind.de ((Andreas J. Koenig))|Data-Compare|0.14|i686-linux-64int|5.9.5|linux|2.6.17-2-k7|200611012205
367439|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200611020324
367783|pass|200611|imacat@mail.imacat.idv.tw|Data-Compare|0.14|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200611030258
367810|pass|200611|alexchorny@gmail.com|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200611020952
367872|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200611022046
368276|pass|200611|fayland@gmail.com|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200611030209
368354|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200611031157
368655|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200611031750
370342|pass|200611|davidp@preshweb.co.uk ("David Precious")|Data-Compare|0.14|i486-linux|5.8.7|linux|2.4.31|200611081605
370768|pass|200611|bladebrown@mail.ru|Data-Hexdumper|1.2|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200611110950
370898|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200611112020
371195|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200611121102
371918|fail|200611|alexchorny@gmail.com|Bryar|2.6|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200611121255
372376|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200611132232
373000|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200611141002
373148|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200611140821
381086|pass|200612|gooba42@gmail.com|Games-Dice-Advanced|1.1|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200612010507
382411|pass|200612|cogent@cpan.org|Data-Compare|0.14|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200612030522
383534|unknown|200612|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200612052257
385883|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200612130007
386086|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200612132153
386324|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200612141113
386332|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200612141052
386341|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200612141125
386581|pass|200612|corion-cpanplus@corion.net|Number-Phone|1.56|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200612142241
387488|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|sun4-solaris-64int|5.8.8|solaris|2.7|200612161308
388186|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|alpha-freebsd|5.8.7|freebsd|6.0-release|200612181024
393599|pass|200701|saper@cpan.org|Sub-WrapPackages|1.2|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701021141
393934|pass|200701|autarch@urth.org|Data-Compare|0.14|i486-linux-gnu|5.8.8|linux|2.6.15.7|200701030556
394575|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701041619
395005|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|sun4-solaris-64int|5.8.8|solaris|2.7|200701060943
395212|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|alpha-freebsd|5.8.7|freebsd|6.0-release|200701061407
395489|pass|200701|njh@despammed.com|Data-Compare|0.14|i486-linux-gnu|5.8.7|linux|2.6.10|200701070017
395731|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701071231
396008|pass|200701|claco@chrislaco.com|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200701080049
396170|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701081709
396447|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701090751
398116|pass|200701|saper@cpan.org|Data-Compare|0.14|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701111152
400138|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200701161135
401271|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701171904
401652|pass|200701|james@mastros.biz|Number-Phone|1.56|i486-linux-gnu|5.8.8|linux|2.6.18.3|200701180143
402258|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200701191454
402576|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701210243
402577|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701210247
402614|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701211110
402616|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701211114
402617|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701211115
402745|fail|200701|chris@bingosnet.co.uk|Bryar|3.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701212346
402746|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701212348
402878|fail|200701|saper@cpan.org|Net-Random|1.3|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701220934
403051|pass|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701221027
403054|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|alpha-freebsd|5.8.7|freebsd|6.0-release|200701221135
403141|pass|200701|imacat@mail.imacat.idv.tw|Net-Random|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200701222020
403217|pass|200701|chris@bingosnet.co.uk|Net-Random|1.3|alpha-freebsd|5.8.7|freebsd|6.0-release|200701221247
403247|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701221245
403469|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701221428
403807|fail|200701|corion-cpanplus@corion.net|Bryar|3.0|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200701221903
403808|fail|200701|corion-cpanplus@corion.net|Net-Random|1.3|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200701221903
404101|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701231253
404652|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-openbsd|5.8.8|openbsd|4.0|200701241445
404654|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-openbsd|5.8.8|openbsd|4.0|200701241445
404727|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701241624
404728|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701241624
404938|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701242140
404939|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701242143
405024|fail|200701|bricas@cpan.org|Net-Random|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200701241254
405090|fail|200701|bricas@cpan.org|Bryar|3.0|i486-linux-gnu|5.8.8|linux|2.6.15.7|200701241253
406240|pass|200701|corion-cpanplus@corion.net|XML-Tiny|1.0|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200701271603
406297|pass|200701|imacat@mail.imacat.idv.tw|XML-Tiny|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200701280232
406369|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701281727
406372|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701281730
406388|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701281814
406449|pass|200701|saper@cpan.org|Number-Phone|1.56|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701282030
406568|pass|200701|saper@cpan.org|XML-Tiny|1.0|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701291002
406701|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701291118
406775|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701291146
407142|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701291804
407210|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701291938
407352|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701292244
407472|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701300837
407503|pass|200701|saper@cpan.org|XML-Tiny|1.01|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701301003
407507|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701300910
407521|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701300936
407580|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|alpha-freebsd|5.8.7|freebsd|6.0-release|200701301052
407581|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|alpha-freebsd|5.8.7|freebsd|6.0-release|200701301053
407664|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701301210
407864|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701301354
408226|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701310829
408246|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701310844
408304|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701310925
408321|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-openbsd|5.8.8|openbsd|4.0|200701310943
408322|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-openbsd|5.8.8|openbsd|4.0|200701310944
408323|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-openbsd|5.8.8|openbsd|4.0|200701310944
408325|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701310944
408457|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-openbsd|5.8.8|openbsd|4.0|200701311200
408469|pass|200701|imacat@mail.imacat.idv.tw|XML-Tiny|1.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200701312008
408518|pass|200701|saper@cpan.org|XML-Tiny|1.02|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701311345
408519|pass|200701|saper@cpan.org|XML-Tiny|1.02|i686-linux|5.4.4|linux|2.6.8.1-10mdk|200701311346
408662|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311611
408663|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311611
408664|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311611
408851|pass|200701|castaway@desert-island.dynodns.net|Data-Compare|0.14|i686-linux-thread|5.8.7|linux|2.6.15.1|200701311544
409022|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702010958
409023|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702010958
409131|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200702012013
409233|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702011557
409389|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702011906
409390|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702011906
409399|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702012025
409400|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702012025
409816|pass|200702|jrockway@cpan.org|Data-Compare|0.14|i486-linux-gnu|5.8.8|linux|2.6.18.3|200702021305
409919|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200702030740
409976|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702031408
409980|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702031502
410113|pass|200702|smueller@cpan.org ("Steffen Mueller")|XML-Tiny|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200702032114
410364|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-openbsd|5.8.8|openbsd|4.0|200702041215
410380|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702041245
410746|pass|200702|saper@cpan.org|XML-Tiny|1.03|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702051015
410765|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702050953
410944|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|alpha-freebsd|5.8.7|freebsd|6.0-release|200702051437
410945|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|alpha-freebsd|5.8.7|freebsd|6.0-release|200702051437
411263|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702060952
411314|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702062123
411349|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702062145
411552|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702062002
411568|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702062036
411918|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200702071720
413290|pass|200702|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200702112331
413292|pass|200702|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|i686-linux|5.8.8|linux|2.4.27-3-686|200702112335
413328|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702120203
413330|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702120204
413341|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702120314
413385|pass|200702|saper@cpan.org|XML-Tiny|1.04|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702121120
413428|pass|200702|saper@cpan.org|XML-Tiny|1.04|i686-linux|5.4.4|linux|2.6.8.1-10mdk|200702121203
413448|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|alpha-freebsd|5.8.7|freebsd|6.0-release|200702121122
413729|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702121534
413903|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702121813
414124|pass|200702|chris@bingosnet.co.uk|Data-Compare|0.14|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702122206
414424|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.04|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702132233
414887|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702140850
415005|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702140853
415088|pass|200702|saper@cpan.org|XML-Tiny|1.04|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200702141401
415282|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702142048
415613|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-openbsd|5.8.8|openbsd|4.0|200702151026
416151|pass|200702|david@cantrell.org.uk|Number-Phone|1.56|i686-linux|5.6.2|linux|2.4.27-3-686|200702160107
416160|pass|200702|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200702160110
416168|pass|200702|david@cantrell.org.uk|Number-Phone|1.56|i686-linux|5.6.2|linux|2.4.27-3-686|200702160110
416390|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702161340
420805|pass|200702|chris@bingosnet.co.uk|Data-Compare|0.14|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241548
421144|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702242015
421152|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702242018
421157|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702242023
421523|pass|200702|david@cantrell.org.uk|Data-Compare|0.14|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702251914
421525|fail|200702|david@cantrell.org.uk|Data-Compare|0.14|i686-linux|5.6.2|linux|2.4.27-3-686|200702251914
421552|pass|200702|david@cantrell.org.uk|Number-Phone|1.5601|i686-linux|5.6.2|linux|2.4.27-3-686|200702251920
421581|pass|200702|david@cantrell.org.uk|Number-Phone|1.5601|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702251927
421634|pass|200702|david@cantrell.org.uk|Data-Compare|0.14|i686-linux|5.8.8|linux|2.4.27-3-686|200702251941
421661|pass|200702|david@cantrell.org.uk|Number-Phone|1.5601|i686-linux|5.8.8|linux|2.4.27-3-686|200702251947
422037|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|alpha-freebsd|5.8.7|freebsd|6.0-release|200702261104
422104|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261121
422151|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702261228
422169|pass|200702|imacat@mail.imacat.idv.tw|Number-Phone|1.5601|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702262037
422879|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702270133
423054|pass|200702|saper@cpan.org|Data-Compare|0.15|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702271007
423090|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.15|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702270927
423091|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.5601|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702270928
423199|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270958
423480|pass|200702|david@cantrell.org.uk|Data-Compare|0.15|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702271507
423670|pass|200702|david@cantrell.org.uk|Data-Compare|0.15|i686-linux|5.8.8|linux|2.4.27-3-686|200702271636
424064|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702280418
424067|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702280420
424100|pass|200702|corion-cpanplus@corion.net|Data-Compare|0.16|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280837
424204|pass|200702|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.16|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702281107
424249|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702281202
424258|fail|200702|Jost.Krieger@ruhr-uni-bochum.de|Net-Random|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702281235
424590|pass|200702|david@cantrell.org.uk|XML-Tiny|1.05|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702281549
424641|pass|200702|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200702281449
424664|pass|200702|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702281502
424839|pass|200702|david@cantrell.org.uk|XML-Tiny|1.05|i686-linux|5.6.2|linux|2.4.27-3-686|200702281459
425056|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703010144
425143|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703010319
425147|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703010323
425457|pass|200703|saper@cpan.org|Data-Compare|0.16|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703011023
425610|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703011040
425615|pass|200703|david@cantrell.org.uk|XML-Tiny|1.05|i686-linux|5.8.8|linux|2.4.27-3-686|200703011042
425718|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.16|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703011108
425719|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|1.4|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703011109
425723|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703011109
425770|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703011115
425784|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703011121
425799|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-openbsd|5.8.8|openbsd|4.0|200703011122
425819|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-openbsd|5.8.8|openbsd|4.0|200703011129
425969|pass|200703|imacat@mail.imacat.idv.tw|XML-Tiny|1.05|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703012155
425979|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703011402
426002|pass|200703|david@cantrell.org.uk|Net-Random|1.4|i686-linux|5.6.2|linux|2.4.27-3-686|200703011412
426092|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703011503
426155|pass|200703|david@cantrell.org.uk|Net-Random|1.4|i686-linux|5.8.8|linux|2.4.27-3-686|200703011528
426308|pass|200703|david@cantrell.org.uk|Net-Random|1.4|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703011415
426482|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703012329
426483|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703012335
426651|pass|200703|saper@cpan.org|Net-Random|1.4|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021008
426712|pass|200703|saper@cpan.org|XML-Tiny|1.05|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021050
426868|pass|200703|imacat@mail.imacat.idv.tw|Net-Random|1.4|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022135
426952|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703021425
426980|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021435
427087|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703021536
427212|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021558
427213|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021559
427431|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703031108
427432|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703031108
428389|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703050518
428390|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703050520
428391|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703050521
428489|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|alpha-freebsd|5.8.7|freebsd|6.0-release|200703051004
428490|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|alpha-freebsd|5.8.7|freebsd|6.0-release|200703051005
428491|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|alpha-freebsd|5.8.7|freebsd|6.0-release|200703051005
428598|pass|200703|srezic@iconmobile.com (Slaven Rezic)|Data-Compare|0.16|i686-linux|5.8.7|linux|2.4.20-18.8|200703051233
428962|pass|200703|david@cantrell.org.uk|XML-Tiny|1.06|i686-linux|5.8.8|linux|2.4.27-3-686|200703051539
429094|pass|200703|david@cantrell.org.uk|XML-Tiny|1.06|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703051734
429161|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051912
429162|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051912
429163|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051913
429176|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051926
429179|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051927
429180|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051928
429695|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703061105
429805|pass|200703|imacat@mail.imacat.idv.tw|XML-Tiny|1.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703062107
430026|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061525
430283|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061713
430284|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061714
430700|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703070516
431402|pass|200703|njh@bandsman.co.uk|Data-Compare|0.16|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080651
432496|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090229
432921|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703091413
433143|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-openbsd|5.8.8|openbsd|4.0|200703091651
433802|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703101135
436498|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130946
436583|pass|200703|Jost.Krieger@ruhr-uni-bochum.de|Net-Random|1.4|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703131155
436826|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200703131620
436857|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703131628
436923|fail|200703|david@cantrell.org.uk|Number-Phone|1.5601|i686-linux|5.8.8|linux|2.4.27-3-686|200703131515
437019|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131809
437354|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141014
437425|pass|200703|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703141958
437858|fail|200703|chris@bingosnet.co.uk|Number-Phone|1.5601|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703150458
437859|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703150506
437965|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-openbsd|5.8.8|openbsd|4.0|200703150950
437967|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.57|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703151000
437969|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703151001
437970|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-openbsd|5.8.8|openbsd|4.0|200703150952
437971|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-openbsd|5.8.8|openbsd|4.0|200703150953
438217|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703151453
438220|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703151453
438278|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|i686-linux|5.6.2|linux|2.4.27-3-686|200703151537
438279|pass|200703|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200703151539
438390|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151638
438391|pass|200703|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151638
438441|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|i686-linux|5.8.8|linux|2.4.27-3-686|200703151714
438442|pass|200703|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200703151716
438515|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703151958
438516|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703152000
438527|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151616
439309|pass|200703|imacat@mail.imacat.idv.tw|Number-Phone|1.57|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703170044
439389|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170812
439391|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170813
439392|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170813
439763|pass|200703|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703171627
439973|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703171908
440130|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703171754
440280|fail|200703|corion-cpanplus@corion.net|Number-Phone|1.57|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703172321
440293|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172124
440294|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172126
440295|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172126
440390|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703181013
440713|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703181558
440867|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703181921
441193|pass|200703|jrockway@cpan.org|Data-Compare|0.16|i486-linux-gnu|5.8.8|linux|2.6.18.3|200703181659
441296|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703191312
441475|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703192317
441520|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703192340
441568|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.8.8|linux|2.4.27-3-686|200703200007
441785|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|alpha-freebsd|5.8.7|freebsd|6.0-release|200703201026
441798|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|alpha-freebsd|5.8.7|freebsd|6.0-release|200703201027
441880|pass|200703|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703201956
441964|pass|200703|davidp@preshweb.co.uk ("David Precious")|Data-Compare|0.16|i486-linux|5.8.7|linux|2.4.31|200703201224
442206|pass|200703|corion-cpanplus@corion.net|Number-Phone|1.57|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703202030
442207|pass|200703|corion-cpanplus@corion.net|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703202030
442408|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703210008
442410|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703210010
442474|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703210214
442479|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703210218
442482|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703210224
442587|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703210706
442624|pass|200703|wyant@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.8|darwin|7.9.0|200703210259
442968|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703211540
442976|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200703211618
443027|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200703211731
443143|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703212141
443144|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703212142
443425|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703220318
443561|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703220515
444751|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703232117
444790|pass|200703|dither@gmail.com|Data-Compare|0.16|i386-freebsd-64int|5.8.8|freebsd|5.4-release|200703231735
444941|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703240104
445126|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-openbsd|5.8.8|openbsd|4.0|200703240725
445864|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703242336
447207|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200703261737
447526|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.8.8|linux|2.4.27-3-686|200703262159
447776|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200703271458
447879|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703271609
449979|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703301451
450622|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703302101
454327|pass|200704|chris@bingosnet.co.uk|Acme-Pony|1.1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200704051030
454539|pass|200704|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200704051512
454755|pass|200704|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704051622
458609|pass|200704|tom@eborcom.com ("Tom Hukins")|Sub-WrapPackages|1.2|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200704121137
458708|pass|200704|tom@eborcom.com ("Tom Hukins")|XML-Tiny|1.06|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200704121420
459149|pass|200704|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|2.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200704130952
459445|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200704131703
459556|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200704131846
459577|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200704131927
460125|pass|200704|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200704142351
460308|pass|200704|david@cantrell.org.uk|Net-Random|2.0|i686-linux|5.6.2|linux|2.4.27-3-686|200704142209
460619|pass|200704|david@cantrell.org.uk|Net-Random|2.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704151540
461008|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200704161042
461251|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200704161338
462048|pass|200704|saper@cpan.org|Net-Random|2.0|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200704171032
462055|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200704170903
462970|pass|200704|alexchorny@gmail.com (Alexandr Ciornii)|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.20-8smp|200704180113
463006|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200704181224
463921|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i386-openbsd|5.8.8|openbsd|4.0|200704190037
465406|pass|200704|david@cantrell.org.uk|Net-Random|2.0|i686-linux|5.8.3|linux|2.4.22-physmem-patch3-5um|200704201622
466836|pass|200704|david@cantrell.org.uk|File-Overwrite|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704231400
468218|pass|200704|david@cantrell.org.uk|Class-CanBeA|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200704251738
468223|pass|200704|david@cantrell.org.uk|Class-CanBeA|1.2|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704251844
474057|pass|200705|xdg@hyperbolic.net (DAGOLDEN)|Net-Random|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200705040829
475133|pass|200705|chaddai.fouche@gmail.com ("Chaddai Fouche")|Data-Compare|0.16|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200705052338
475141|pass|200705|chaddai.fouche@gmail.com ("Chaddai Fouche")|Data-Compare|0.16|MSWin32-x86-multi-thread|5.9.5|MSWin32|4.0|200705052344
475387|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.9.5|linux|2.6.18-4-k7|200705061119
475972|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200705070015
476806|fail|200705|bsmith@cpan.org|Bryar|3.0|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705061925
476985|pass|200705|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200705071450
477045|pass|200705|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200705071614
478961|fail|200705|bsmith@cpan.org|Bryar|3.0|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705091231
483520|pass|200705|bsmith@cpan.org|Data-Compare|0.16|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705131130
484000|pass|200705|bsmith@cpan.org|Data-Hexdumper|1.2|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705131435
484013|fail|200705|bsmith@cpan.org|Data-Transactional|0.1|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705131441
498580|pass|200705|tom@eborcom.com ("Tom Hukins")|Data-Compare|0.16|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200705301013
499954|pass|200705|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200705311327
499957|pass|200705|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200705311330
500760|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200706020634
500763|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200706020637
501025|pass|200706|david@cantrell.org.uk|Number-Phone|1.58|i686-linux|5.6.2|linux|2.4.27-3-686|200706031142
501028|pass|200706|david@cantrell.org.uk|Number-Phone|1.58|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200706031245
501042|pass|200706|imacat@mail.imacat.idv.tw|Number-Phone|1.58|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200706031911
501405|pass|200706|saper@cpan.org|Number-Phone|1.58|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200706041055
501492|pass|200706|stro@cpan.org|Number-Phone|1.58|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200706031924
501643|pass|200706|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.58|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200706041402
501841|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i386-pc-solaris2.11|5.8.7|solaris|2.11|200706041812
502234|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200706050932
502780|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200706060804
503556|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200706061615
503784|pass|200706|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.9.5 patch 31335|linux|2.4.27-3-686|200706062047
504111|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200706071044
504704|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200706071858
519559|pass|200706|david@cantrell.org.uk|NestedMap|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200706261547
527714|pass|200707|stro@cpan.org|Tie-Hash-Rank|1.0.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707041839
527792|pass|200707|stro@cpan.org|Data-Compare|0.16|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707041757
528095|pass|200707|stro@cpan.org|Acme-Pony|1.1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707041749
532760|pass|200707|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200707101103
532768|pass|200707|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.9.5 patch 31416|linux|2.4.27-3-686|200707101104
536645|pass|200707|david@cantrell.org.uk|Class-CanBeA|1.2|i686-linux|5.9.5|linux|2.4.27-3-686|200707142021
537892|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200707152130
538989|pass|200707|overlordq@gmail.com|Data-Compare|0.16|i486-linux-gnu|5.8.8|linux|2.6.18.3|200707161626
541445|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200707182344
541446|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200707182344
541447|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.9.5|linux|2.4.27-3-686|200707182345
541450|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707190052
546402|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707250634
546525|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707250749
551041|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i686-linux|5.9.5|linux|2.4.27-3-686|200707301143
551134|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i686-linux|5.8.8|linux|2.4.27-3-686|200707301418
551151|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707301537
551157|fail|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i686-linux|5.6.2|linux|2.4.27-3-686|200707301412
551158|pass|200707|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200707301408
551428|pass|200707|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707310541
551444|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-TreoPhoneCallDB|1.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707310704
551498|pass|200707|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200707310826
551733|pass|200707|ferreira@cpan.org ("Adriano Ferreira")|Data-Compare|0.16|cygwin|5.9.5|cygwin|1.5.24(0.15642)|200707311148
551763|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707311721
551794|pass|200707|tom@eborcom.com ("Tom Hukins")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.9.5 patch 31576|linux|2.6.17-11-generic|200707311337
551801|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200707311725
551813|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200707311818
551815|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux|5.9.5|linux|2.4.27-3-686|200707311828
552449|pass|200708|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708020036
552542|pass|200708|stro@cpan.org|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708011914
553871|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708032142
553873|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708032144
554693|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708041837
554699|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708041840
555029|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708050148
555030|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708050150
555430|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708051356
555431|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708051400
555684|fail|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.8.3|linux|2.4.22-rc2-ac2|200708051931
555827|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708052212
555828|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708052214
556260|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708061125
556303|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708061143
558672|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708072108
558814|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200708080159
558828|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|i686-linux|5.8.3|linux|2.4.22-physmem-patch3-5um|200708071720
558868|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708080137
558881|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708080141
559090|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708080854
559174|pass|200708|saper@cpan.org|Data-Compare|0.17|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200708081011
559259|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200708081147
559501|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i686-linux|5.8.8|linux|2.4.27-3-686|200708081457
559543|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.17|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708081416
559576|pass|200708|tom@eborcom.com ("Tom Hukins")|Data-Compare|0.17|i686-linux|5.9.5 patch 31576|linux|2.6.17-11-generic|200708080757
559775|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708081635
559788|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i686-linux|5.6.2|linux|2.4.27-3-686|200708081706
559811|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i686-linux|5.9.5|linux|2.4.27-3-686|200708081751
559866|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200708081955
559868|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.3|linux|2.6.14|200708081956
559872|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200708081958
559876|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200708081959
559878|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200708082000
559880|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.4|linux|2.6.18-4-k7|200708082001
559882|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.3|linux|2.6.18-4-k7|200708082002
559883|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200708082003
559905|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.1 patch 21538|linux|2.4.22-rc2-ac2|200708081957
559906|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.9.2|linux|2.6.18-4-k7|200708081956
559907|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200708081958
560131|pass|200708|feldt@nhn.ou.edu|Data-Compare|0.17|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200708081419
560273|pass|200708|g.grigelionis@computer.org|Data-Compare|0.17|i586-linux-thread-multi|5.8.8|linux|2.6.16|200708081741
561378|pass|200708|stro@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708091302
561436|pass|200708|imacat@mail.imacat.idv.tw|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708092112
561571|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708091651
561620|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708091620
561639|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708091626
561654|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708091612
561872|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708092054
562017|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708092047
562255|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708092050
563659|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|darwin-2level|5.9.5|darwin|8.10.1|200708101841
563736|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708101903
564951|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708111221
565096|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708111422
566789|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200708121117
567459|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200708121328
569962|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.9.5 patch 31701|netbsd|3.1|200708131004
570482|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708131205
571994|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708131852
573512|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.9.5 patch 31711|linux|2.6.16.19|200708141248
574134|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708141634
577657|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|darwin-2level|5.9.5|darwin|8.10.1|200708160846
577933|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708161122
578018|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|i686-linux|5.8.8|linux|2.4.27-3-686|200708161225
578081|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|i686-linux|5.9.5|linux|2.4.27-3-686|200708161239
578089|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708161137
581816|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708172240
582029|pass|200708|tony@develop-help.com|Number-Phone|1.58|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708181009
582646|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708190002
582647|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708190003
582649|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708190004
582650|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708190005
582652|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708190006
582653|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708190007
582654|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708190009
582655|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708190010
583002|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200708190601
583066|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708190837
583126|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200708191235
583431|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708191551
583694|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708191732
583699|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708191734
583850|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708191937
584790|pass|200708|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708201327
584903|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708200824
584909|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708200827
584915|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708200829
584924|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708200832
584932|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708200834
584938|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708200837
584941|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708200841
584952|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200342
585019|pass|200708|saper@cpan.org|CPAN-FindDependencies|1.02|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200708201042
585127|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200543
585132|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200545
585137|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200547
585170|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201137
585345|pass|200708|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708201950
585388|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201318
585397|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201321
585398|pass|200708|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708202021
585401|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201324
585417|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708201331
585420|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708201334
585423|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708201338
585425|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708201341
585428|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708201344
585430|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708201348
585431|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708201350
585436|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708201353
585809|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708201719
585816|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708201722
585822|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708201724
585836|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708201727
585840|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708201729
585844|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708201731
585847|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708201733
585854|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708201736
586798|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708210028
586800|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708210031
586802|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708210034
587051|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708210635
587052|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708210635
587053|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708210636
587054|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708210636
587055|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708210636
587056|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708210636
587057|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708210636
587058|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708210637
587059|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708210637
587240|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|1.02|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708210843
587241|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708210844
587255|pass|200708|saper@cpan.org|Data-Hexdumper|1.3|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200708211047
587301|pass|200708|plu@pqpq.de|Data-Compare|0.17|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211044
587322|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211012
587418|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i386-freebsd|5.9.5|freebsd|6.2-release|200708211028
587508|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211103
587652|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211244
587655|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211245
587656|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211247
587657|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211247
587803|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200708211459
587851|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200708211525
587855|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux|5.9.5|linux|2.4.27-3-686|200708211529
587856|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211534
587942|pass|200708|plu@pqpq.de|Number-Phone|1.58|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211120
588007|pass|200708|plu@pqpq.de|Data-Compare|0.17|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211358
588093|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|darwin-2level|5.9.5|darwin|8.10.1|200708211615
588147|pass|200708|plu@pqpq.de|CPAN-FindDependencies|1.01|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211533
588180|pass|200708|plu@pqpq.de|Number-Phone|1.58|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211424
588194|pass|200708|tom@eborcom.com ("Tom Hukins")|Data-Hexdumper|1.3|i686-linux|5.9.5 patch 31576|linux|2.6.17-11-generic|200708211135
588231|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211653
588253|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211656
588256|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211658
588258|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211658
588287|pass|200708|plu@pqpq.de|CPAN-FindDependencies|1.02|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211533
588363|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i386-freebsd|5.9.5|freebsd|6.2-release|200708211830
588480|fail|200708|plu@pqpq.de|CPAN-FindDependencies|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211532
588481|pass|200708|plu@pqpq.de|Data-Hexdumper|1.3|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211534
588709|pass|200708|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212106
588724|pass|200708|david@cantrell.org.uk|Bryar|3.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212109
588730|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.0.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588735|pass|200708|david@cantrell.org.uk|File-Overwrite|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588736|pass|200708|david@cantrell.org.uk|Data-Transactional|0.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588738|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588739|pass|200708|david@cantrell.org.uk|Games-Dice-Advanced|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212111
588740|pass|200708|david@cantrell.org.uk|NestedMap|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212111
588744|pass|200708|david@cantrell.org.uk|Net-Random|2.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212113
588751|pass|200708|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200708212116
588764|pass|200708|david@cantrell.org.uk|Statistics-ChiSquare|0.5|i686-linux|5.6.2|linux|2.4.27-3-686|200708212117
588765|pass|200708|david@cantrell.org.uk|Sub-WrapPackages|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200708212118
588766|pass|200708|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212117
588767|pass|200708|david@cantrell.org.uk|Tie-Hash-Longest|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212118
588768|pass|200708|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212118
588819|fail|200708|david@cantrell.org.uk|Tie-STDOUT|1.02|i686-linux|5.6.2|linux|2.4.27-3-686|200708212145
588820|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212146
588822|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212146
588824|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|i686-linux|5.6.2|linux|2.4.27-3-686|200708212146
588886|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212205
589058|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212319
589059|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212319
589061|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212320
589063|unknown|200708|david@cantrell.org.uk|Acme-Licence|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212318
589066|pass|200708|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212318
589067|unknown|200708|david@cantrell.org.uk|Acme-Pony|1.1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212318
589072|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212320
589087|fail|200708|david@cantrell.org.uk|Bryar|3.0|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589089|pass|200708|david@cantrell.org.uk|Class-CanBeA|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589093|fail|200708|david@cantrell.org.uk|Data-Transactional|0.1|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589095|pass|200708|david@cantrell.org.uk|File-Overwrite|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589096|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589099|pass|200708|david@cantrell.org.uk|Net-Random|2.0|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589100|pass|200708|david@cantrell.org.uk|Games-Dice-Advanced|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589102|pass|200708|david@cantrell.org.uk|NestedMap|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589105|pass|200708|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-2level|5.9.5|darwin|8.10.1|200708212327
589106|pass|200708|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589107|pass|200708|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589110|pass|200708|david@cantrell.org.uk|Statistics-ChiSquare|0.5|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589112|pass|200708|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589114|pass|200708|david@cantrell.org.uk|Tie-Hash-Longest|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589115|pass|200708|david@cantrell.org.uk|Sub-WrapPackages|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589116|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.02|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589117|pass|200708|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589119|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589120|pass|200708|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589121|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589122|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589147|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589149|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.0.1|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589707|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708220732
589902|pass|200708|stro@cpan.org|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708221013
589905|pass|200708|stro@cpan.org|CPAN-FindDependencies|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708220951
589906|pass|200708|stro@cpan.org|CPAN-FindDependencies|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708220952
589960|pass|200708|stro@cpan.org|CPAN-FindDependencies|1.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708220951
590091|pass|200708|chaddai.fouche@gmail.com ("Chaddai Fouche")|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708221618
590117|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221558
590120|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221600
590122|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221601
590124|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221601
590675|pass|200708|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708230522
591020|pass|200708|tony@develop-help.com|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708230944
591446|pass|200708|bob@randomness.org.uk ("bob walker")|Bryar|3.0|i86pc-solaris|5.8.8|solaris|2.10|200708231015
591701|pass|200708|cpan@pqpq.de|CPAN-FindDependencies|1.02|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231335
591731|pass|200708|cpan@pqpq.de|Data-Hexdumper|1.3|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231335
591734|pass|200708|cpan@pqpq.de|CPAN-FindDependencies|1.0|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231334
591735|pass|200708|cpan@pqpq.de|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231335
591769|pass|200708|cpan@pqpq.de|Data-Compare|0.17|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231210
592026|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231648
592027|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231649
592028|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231651
592029|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231651
592644|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708232350
592919|pass|200708|cogent@cpan.org|Data-Compare|0.17|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200708231440
593087|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708240501
593443|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241048
593448|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241050
593461|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241047
593475|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241050
594276|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708250644
594281|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708250648
594282|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708250649
594391|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.02|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200708250940
594684|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708251155
594685|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708251156
594686|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708251156
595047|pass|200708|srezic@cpan.org|CPAN-FindDependencies|1.02|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200708251106
595064|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708251908
595274|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708260006
595275|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708260007
595276|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708260007
595889|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708262118
595890|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708262118
597202|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708281836
597204|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708281837
597205|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708281837
597207|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708281837
597208|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708281838
597209|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708281838
597210|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708281838
597211|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708281839
597213|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708281839
597630|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708290537
597669|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708290641
597670|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708290642
597671|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708290643
597672|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708290643
597673|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708290644
597674|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708290644
597675|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708290645
597676|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708290646
597713|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|darwin-2level|5.9.5|darwin|8.10.1|200708290946
597716|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.4.27-3-686|200708290951
597730|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|i686-linux|5.9.5|linux|2.4.27-3-686|200708290959
597780|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708291105
597790|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708291109
597795|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200708291110
597813|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux|5.9.5|linux|2.4.27-3-686|200708291219
597905|pass|200708|stro@cpan.org|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708291330
597961|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Transactional|1.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708291427
597962|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.03|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708291427
598003|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|i386-freebsd|5.9.5|freebsd|6.2-release|200708290937
598061|pass|200708|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708292348
598091|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200708291141
598406|pass|200708|imacat@mail.imacat.idv.tw|Data-Transactional|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708301923
598875|pass|200708|tony@develop-help.com|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708311047
598876|na|200708|tony@develop-help.com|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708311048
598901|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708310354
598903|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708310355
598905|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708310356
598907|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708310358
598909|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708310359
598911|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708310400
598913|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708310401
598915|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708310402
599214|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708311420
599278|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708311520
599522|pass|200709|cpan@pqpq.de|Data-Transactional|1.0|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200709010933
599523|pass|200709|cpan@pqpq.de|Tie-STDOUT|1.03|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200709010933
599621|pass|200709|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709010951
599788|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709011328
599789|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709011328
599841|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200709011415
599842|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200709011417
599847|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200709011421
599849|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200709011422
599850|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200709011423
599851|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.4|linux|2.6.18-4-k7|200709011424
599852|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.3|linux|2.6.18-4-k7|200709011425
599853|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200709011426
599857|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.9.3|linux|2.6.14|200709011418
599858|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200709011420
600229|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709011840
600617|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709012018
600618|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709012018
600620|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709012019
600828|pass|200709|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709012036
601889|pass|200709|chris@bingosnet.co.uk|Acme-Licence|1.0|i386-netbsd-thread-multi-64int|5.9.5|netbsd|3.1|200709021301
602062|pass|200709|chris@bingosnet.co.uk|Acme-Pony|1.1.2|i386-netbsd-thread-multi-64int|5.9.5|netbsd|3.1|200709021344
602128|pass|200709|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-netbsd-thread-multi-64int|5.9.5|netbsd|3.1|200709021403
602983|pass|200709|bob@randomness.org.uk ("bob walker")|Tie-STDOUT|1.03|i86pc-solaris|5.8.8|solaris|2.10|200709021453
603004|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709020706
603202|pass|200709|jrockway@cpan.org|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.18.3|200709011804
603343|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200709021923
603344|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200709021923
603532|pass|200709|corion-cpanplus@corion.net|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200709022206
603534|pass|200709|corion-cpanplus@corion.net|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200709022207
603536|fail|200709|corion-cpanplus@corion.net|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200709022208
603917|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200709030032
604525|pass|200709|cpan@pqpq.de|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200709031103
604902|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200709031349
604903|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200709031350
604907|pass|200709|saper@cpan.org|Tie-STDOUT|1.03|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200709031450
605243|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200709031624
605244|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200709031624
605308|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200709031812
605309|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200709031813
606619|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200709040455
606840|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709040750
606845|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709040750
607296|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709041124
607298|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709041124
607602|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709041352
607854|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200709041631
607857|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200709041631
607951|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709041750
609071|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200709050035
609076|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200709050036
609166|pass|200709|cpan@pqpq.de|Tie-STDOUT|1.03|i86pc-solaris|5.9.5 patch 31788|solaris|2.10|200709042059
609202|pass|200709|cpan@pqpq.de|Data-Transactional|1.0|i86pc-solaris|5.9.5 patch 31788|solaris|2.10|200709042059
609215|pass|200709|cpan@pqpq.de|Data-Compare|0.17|i86pc-solaris|5.9.5 patch 31788|solaris|2.10|200709042059
610943|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200709052027
611293|pass|200709|perlgeek@perlgeek.net|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.6.9-42.0.3.elsmp|200709060223
611964|pass|200709|davidp@preshweb.co.uk ("David Precious")|Data-Compare|0.17|i486-linux|5.8.7|linux|2.4.31|200709061158
612850|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200709062106
616595|pass|200709|cpan@0x64.nl|XML-Tiny|1.06|x86_64-linux-gnu|5.8.8|linux|2.6.18-1-amd64|200709081211
617035|pass|200709|david@cantrell.org.uk|Data-Compare|0.02|i686-linux|5.6.2|linux|2.4.27-3-686|200709090041
617180|pass|200709|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709090338
617430|pass|200709|smueller@cpan.org ("Steffen Mueller")|XML-Tiny|1.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200709091052
620597|pass|200709|david@cantrell.org.uk|Data-Compare|0.02|darwin-2level|5.9.5|darwin|8.10.1|200709102055
622464|pass|200709|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|0.17|sun4-solaris|5.8.8|solaris|2.8|200709111136
623174|pass|200709|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709112108
625331|pass|200709|david@cantrell.org.uk|Data-Compare|0.17|sun4-solaris|5.9.5|solaris|2.9|200709121723
631722|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200709151723
632261|pass|200709|gabor@pti.co.il ("Gabor Szabo")|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151533
632453|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|0.17|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151221
634970|pass|200709|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709160900
636217|pass|200709|cpan@pqpq.de|Data-Compare|0.17|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200709162224
644503|pass|200709|srezic@cpan.org|CPAN-FindDependencies|1.02|amd64-freebsd|5.10.0 patch 31894|freebsd|6.2-release|200709200002
645430|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.10.0 patch 31906|linux|2.6.16.38|200709201232
647235|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200709210757
649448|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200709220425
649692|pass|200709|srezic@cpan.org|CPAN-FindDependencies|1.02|i386-freebsd|5.10.0 patch 31938|freebsd|6.1-release|200709220244
650269|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200709221114
651644|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200709230013
653290|unknown|200709|david@cantrell.org.uk|Acme-Licence|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231412
653303|unknown|200709|david@cantrell.org.uk|Acme-Pony|1.1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231415
653315|pass|200709|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231416
653355|fail|200709|david@cantrell.org.uk|Bryar|3.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231422
653360|pass|200709|david@cantrell.org.uk|Class-CanBeA|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231423
653373|pass|200709|david@cantrell.org.uk|Data-Hexdumper|1.0.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231425
653383|pass|200709|david@cantrell.org.uk|Data-Hexdumper|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231426
653410|fail|200709|david@cantrell.org.uk|Data-Transactional|0.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231428
653422|pass|200709|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231429
653424|pass|200709|chris@bingosnet.co.uk|Acme-Pony|1.1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200709231454
653426|pass|200709|david@cantrell.org.uk|File-Overwrite|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231431
653429|pass|200709|david@cantrell.org.uk|Games-Dice-Advanced|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231432
653434|pass|200709|david@cantrell.org.uk|NestedMap|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231434
653448|pass|200709|david@cantrell.org.uk|Net-Random|2.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231438
653454|pass|200709|david@cantrell.org.uk|Number-Phone|1.58|i386-freebsd|5.9.5|freebsd|6.2-release|200709231439
653465|pass|200709|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.9.5|freebsd|6.2-release|200709231442
653473|pass|200709|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231444
653479|pass|200709|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231446
653484|pass|200709|david@cantrell.org.uk|Statistics-ChiSquare|0.5|i386-freebsd|5.9.5|freebsd|6.2-release|200709231449
653494|pass|200709|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231450
653506|pass|200709|david@cantrell.org.uk|Tie-Hash-Longest|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231453
653512|pass|200709|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231454
653518|pass|200709|david@cantrell.org.uk|Tie-STDOUT|1.02|i386-freebsd|5.9.5|freebsd|6.2-release|200709231456
653529|pass|200709|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231457
653534|pass|200709|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231459
653538|pass|200709|david@cantrell.org.uk|XML-Tiny|1.06|i386-freebsd|5.9.5|freebsd|6.2-release|200709231500
653652|pass|200709|david@cantrell.org.uk|Sub-WrapPackages|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231452
663263|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|0.9|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710012251
663600|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710012338
663601|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710012335
663602|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710012334
663613|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710012336
663622|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710012337
663623|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710012337
663624|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710012336
664271|pass|200710|cpan@pqpq.de|Devel-CheckOS|0.92|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710020911
664272|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710020710
664273|pass|200710|cpan@pqpq.de|Devel-CheckOS|0.91|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710020911
664275|pass|200710|cpan@pqpq.de|Devel-CheckOS|0.9|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710020911
664608|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|darwin-2level|5.9.5|darwin|8.10.1|200710021141
664666|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|darwin-2level|5.9.5|darwin|8.10.1|200710021152
664742|pass|200710|srezic@cpan.org|Data-Compare|0.17|i686-linux|5.10.0 patch 31937|linux|2.6.18-4-486|200710021313
664771|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|sun4-solaris|5.9.5|solaris|2.9|200710020627
664779|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i386-freebsd|5.9.5|freebsd|6.2-release|200710021131
664789|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i686-linux|5.8.8|linux|2.4.27-3-686|200710021233
664790|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i686-linux|5.9.5|linux|2.4.27-3-686|200710021234
665010|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i686-linux|5.9.5|linux|2.4.27-3-686|200710021358
665011|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710021258
665091|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i686-linux|5.8.8|linux|2.4.27-3-686|200710021421
665092|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i686-linux|5.6.2|linux|2.4.27-3-686|200710021421
665097|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i386-freebsd|5.9.5|freebsd|6.2-release|200710021324
665102|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|sun4-solaris|5.9.5|solaris|2.9|200710020824
665182|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i686-linux|5.6.2|linux|2.4.27-3-686|200710021445
665351|pass|200710|srezic@cpan.org|Devel-CheckOS|0.92|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710020837
665385|pass|200710|saper@cpan.org|Devel-CheckOS|0.92|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710021621
665491|pass|200710|srezic@cpan.org|Devel-CheckOS|0.92|amd64-freebsd|5.10.0 patch 31995|freebsd|6.2-release|200710020837
665546|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710021501
665823|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710021809
665827|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710021807
665828|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710021808
665829|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710021808
665831|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710021806
665832|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710021805
665833|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710021804
666004|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux|5.10.0|linux|2.6.22-1-k7|200710021710
666037|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710021839
666053|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710021846
666078|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710021853
666102|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710021958
666107|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710021959
666113|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710021901
666149|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710021908
666179|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710021915
666199|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710022002
666204|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710021922
666222|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710022000
666228|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710022001
666229|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710022001
666230|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710022000
666239|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710021929
666247|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710021931
666540|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux|5.10.0|linux|2.6.22-1-k7|200710022105
667743|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux|5.10.0|linux|2.6.22-1-k7|200710031215
667823|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|0.91|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710031934
667829|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|0.92|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710031944
667886|pass|200710|saper@cpan.org|File-Find-Rule-Permissions|1.3|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710031453
668899|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200710032339
668904|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200710032341
668977|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|darwin-2level|5.9.5|darwin|8.10.1|200710040024
668982|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|sun4-solaris|5.9.5|solaris|2.9|200710040024
668983|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|darwin-2level|5.9.5|darwin|8.10.1|200710040024
668985|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200710040025
668989|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|sun4-solaris|5.9.5|solaris|2.9|200710040027
668990|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i386-freebsd|5.9.5|freebsd|6.2-release|200710040028
669006|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i686-linux|5.9.5|linux|2.4.27-3-686|200710040037
669009|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i686-linux|5.9.5|linux|2.4.27-3-686|200710040038
669010|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710040038
669019|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710040043
669023|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200710040045
669026|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200710040046
669230|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.22-1-k7|200710040801
669588|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710042126
669592|pass|200710|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710042127
669812|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710041746
669813|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710041744
669814|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710041748
669815|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710041750
669816|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710041752
669817|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710041754
669818|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710041756
669820|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710041758
669822|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710041800
670143|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710042349
670144|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710042352
670145|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710042353
670146|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710042355
670148|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710042358
670150|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710050004
670153|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710050007
670155|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710050009
670157|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710050012
670386|pass|200710|alexchorny@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710040629
670692|pass|200710|alexchorny@gmail.com|Devel-CheckOS|1.0|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710040629
670971|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710051147
671194|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710051318
671198|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710051320
671199|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710051323
671200|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710051325
671201|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710051327
671202|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710051329
671215|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710051331
671220|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710051333
671223|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710051335
671243|pass|200710|rlane10@wi.rr.com|Number-Phone|1.58|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200710050721
671301|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710051410
671306|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710051413
671308|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710051415
671312|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710051417
671318|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710051420
671322|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710051422
671325|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710051425
671326|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710051427
671328|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710051429
671367|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710051606
671369|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710051607
671370|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710051608
671371|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710051608
671374|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710051609
671377|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710051609
671400|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710051610
671477|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710051757
673261|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710061431
674252|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710061335
674519|fail|200710|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.1|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710061502
674615|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|darwin-2level|5.9.5|darwin|8.10.1|200710062344
674617|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|sun4-solaris|5.9.5|solaris|2.9|200710061745
674669|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710070004
674672|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i686-linux|5.9.5|linux|2.4.27-3-686|200710070004
674674|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200710070005
674727|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200710070039
674728|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200710070039
675923|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710080206
676370|pass|200710|alexchorny@gmail.com|Devel-CheckOS|1.1|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710071351
676967|pass|200710|saper@cpan.org|Devel-CheckOS|1.1|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710081119
677780|pass|200710|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32039|freebsd|6.2-release|200710082304
677917|pass|200710|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.6.2|freebsd|6.2-release|200710082309
679862|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710101039
679863|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710101041
679870|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710101043
679875|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710101045
679883|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710101048
679889|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710101050
679894|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710101052
679895|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710101054
679896|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710101056
680299|pass|200710|david@valuesofn.com|Data-Compare|0.17|darwin-2level|5.8.8|darwin|8.8.2|200710101043
681705|pass|200710|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.1|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710111716
682486|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710121126
683801|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710131421
683802|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.6.2|freebsd|6.2-release|200710131422
683803|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710131421
683804|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.5.5|freebsd|6.2-release|200710131422
685543|pass|200710|srezic@cpan.org|Devel-CheckOS|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710141046
685544|pass|200710|srezic@cpan.org|Devel-CheckOS|1.1|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710141045
685545|pass|200710|srezic@cpan.org|Devel-CheckOS|1.1|amd64-freebsd|5.6.2|freebsd|6.2-release|200710141046
686176|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710141723
686178|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710141723
686180|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710141724
686183|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710141724
686207|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710141723
686209|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710141723
686210|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710141724
686293|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710141815
686295|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710141815
686300|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710141815
686304|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710141816
686308|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710141816
686373|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710141816
686378|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710141815
686488|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710141935
686622|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710142014
686730|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.6.2|freebsd|6.2-release|200710142111
686818|pass|200710|srezic@cpan.org|Devel-CheckOS|1.2|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710150044
686938|pass|200710|srezic@cpan.org|Devel-CheckOS|1.2|amd64-freebsd|5.6.2|freebsd|6.2-release|200710150113
686952|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.5.5|freebsd|6.2-release|200710150117
687066|pass|200710|andy@hexten.net|Data-Hexdumper|1.3|i86pc-solaris-64int|5.8.4|solaris|2.11|200710150226
687689|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200710151304
687691|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200710151305
687712|pass|200710|xdg@hyperbolic.net (DAGOLDEN)|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710150820
687716|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710151333
687717|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710151334
688024|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i686-linux|5.9.5|linux|2.4.27-3-686|200710151516
688025|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i686-linux|5.8.8|linux|2.4.27-3-686|200710151516
688026|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|darwin-2level|5.9.5|darwin|8.10.1|200710151508
688030|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200710151507
688096|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|sun4-solaris|5.9.5|solaris|2.9|200710150937
688180|pass|200710|saper@cpan.org|Devel-AssertLib|0.1|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710151711
688233|pass|200710|imacat@mail.imacat.idv.tw|Devel-AssertLib|0.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710152339
688356|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200710151316
688419|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710151750
689795|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710160742
689801|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710160743
690422|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710162118
690817|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.10.0 patch 31906|linux|2.6.16.38|200710161710
690828|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.10.0 patch 31906|linux|2.6.16.38|200710161711
691859|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710170645
691860|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710170645
691861|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710170645
691862|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710170646
691863|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710170646
691864|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710170646
691865|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710170646
691866|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710170647
691867|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710170647
691868|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710170647
691869|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710170648
691870|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710170649
691871|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710170649
691872|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710170650
691873|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710170650
691874|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710170651
691875|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710170651
691876|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710170652
692213|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710171009
692214|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710171010
692388|pass|200710|cpan@pqpq.de|Devel-CheckOS|1.2|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710171254
692389|pass|200710|cpan@pqpq.de|Devel-AssertLib|0.1|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710171254
693524|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710180053
693559|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710180055
693630|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710180016
693641|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710180017
693720|pass|200710|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.10.0 patch 31938|freebsd|6.1-release|200710180126
693798|pass|200710|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710180126
693802|pass|200710|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200710180127
695204|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710181755
695210|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710181758
695352|pass|200710|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|sun4-solaris|5.9.5|solaris|2.9|200710181429
695818|pass|200710|xdg@hyperbolic.net (DAGOLDEN)|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710181841
695827|pass|200710|xdg@hyperbolic.net (DAGOLDEN)|Devel-CheckLib|0.2|i686-linux-64int-ld|5.8.8|linux|2.6.17-10-generic|200710181845
695959|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710190300
696149|pass|200710|cpan@pqpq.de|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710190702
696435|pass|200710|cpan@pqpq.de|Devel-CheckLib|0.2|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710190814
696830|pass|200710|saper@cpan.org|Devel-CheckLib|0.2|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710191054
696970|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191005
696972|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191005
696974|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191006
697028|pass|200710|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.2|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710190612
697605|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191626
697844|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710191859
697845|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710191900
697846|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710191900
698349|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710200033
698350|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710200035
698351|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710200037
698796|fail|200710|mr.muskrat@perlgeek.net ("Mr. Muskrat")|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200031
698896|unknown|200710|mr.muskrat@perlgeek.net ("Mr. Muskrat")|Devel-AssertLib|0.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200030
698912|pass|200710|mr.muskrat@perlgeek.net ("Mr. Muskrat")|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200032
699054|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710201144
699218|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710200134
699476|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|darwin-2level|5.9.5|darwin|8.10.1|200710201531
699498|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i686-linux|5.9.5|linux|2.4.27-3-686|200710201535
699502|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i686-linux|5.8.8|linux|2.4.27-3-686|200710201535
699537|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710202240
699565|pass|200710|icerider70@gmail.com ("ICERIDER")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710200957
699613|pass|200710|mmusgrove@cpan.org|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200902
699617|pass|200710|mmusgrove@cpan.org|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200937
699640|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i686-linux|5.6.2|linux|2.4.27-3-686|200710201631
699764|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i386-freebsd|5.9.5|freebsd|6.2-release|200710201454
699784|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|sun4-solaris|5.9.5|solaris|2.9|200710201118
699895|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710201649
700529|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710202034
700532|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710202035
700533|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710202036
700907|pass|200710|mmusgrove@cpan.org|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710201315
701122|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710202334
701123|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710202335
701125|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710202336
701127|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710202336
701130|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710202337
701131|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710202337
701133|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710202338
701134|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710202339
701136|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710202339
701604|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710210601
702100|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710211441
702101|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710211441
702102|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710211442
702158|pass|200710|bob@randomness.org.uk ("bob walker")|Devel-CheckLib|0.2|i86pc-solaris|5.8.8|solaris|2.10|200710211502
702598|fail|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-AssertLib|0.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710211728
702757|fail|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd|5.10.0 patch 31938|freebsd|6.1-release|200710212020
702758|pass|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710212020
702759|fail|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd|5.6.2|freebsd|6.1-release|200710212021
702855|fail|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd|5.5.5|freebsd|6.1-release|200710212111
703302|pass|200710|bob@randomness.org.uk|Devel-CheckOS|1.2|i386-openbsd|5.8.8|openbsd|4.2|200710212258
703306|pass|200710|bob@randomness.org.uk|Devel-CheckLib|0.2|i386-openbsd|5.8.8|openbsd|4.2|200710212259
704075|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710221130
704614|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710221350
705556|pass|200710|andy@hexten.net|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.15.7|200710222023
706080|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710222325
707010|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.2|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230655
707013|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230655
707652|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230718
708218|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230351
708858|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710231428
708917|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710231407
708922|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|File-Find-Rule-Permissions|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710231407
709511|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710231759
710694|fail|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.2|200710241103
710738|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.2|200710241111
711237|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710241518
711238|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710241519
711240|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710241519
711243|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710241520
711245|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710241519
711247|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710241519
711778|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710242156
711936|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710242158
711937|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710242158
711939|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710242158
711940|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710242159
711941|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710242159
711942|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710242200
711943|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710242200
711944|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710242200
711945|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710242201
712027|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd|5.10.0 patch 32171|freebsd|6.1-release|200710242237
712321|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd|5.5.5|freebsd|6.1-release|200710250037
712334|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd|5.6.2|freebsd|6.1-release|200710242345
712381|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250128
713464|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250735
713625|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250848
713802|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250829
714082|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710251121
714083|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710251121
714227|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.07|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710251225
714305|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|darwin-2level|5.9.5|darwin|8.10.1|200710251427
714319|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i686-linux|5.6.2|linux|2.4.27-3-686|200710251428
714330|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i686-linux|5.9.5|linux|2.4.27-3-686|200710251430
714400|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710251353
714407|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|sun4-solaris|5.9.5|solaris|2.9|200710250851
714443|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i686-linux|5.8.8|linux|2.4.27-3-686|200710251513
714470|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i386-freebsd|5.9.5|freebsd|6.2-release|200710251113
714489|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710251631
714490|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710251633
714492|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710251633
714493|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710251634
714498|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710251632
714500|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710251632
714524|pass|200710|andy@hexten.net|Data-Hexdumper|1.3|powerpc-linux-gnu|5.8.8|linux|2.6.17-10-powerpc64-smp|200710251645
714870|pass|200710|imacat@mail.imacat.idv.tw|XML-Tiny|1.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710260119
714943|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710252029
715122|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710252155
715413|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710252223
715420|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710252224
715423|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710252225
715425|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710252225
715427|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710252226
715428|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710252227
715432|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710252227
715434|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710252228
715435|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710252229
715463|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.6.2|freebsd|6.2-release|200710252317
715653|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.5.5|freebsd|6.2-release|200710260039
715764|pass|200710|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710260041
715840|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710260247
715852|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710260233
715853|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710260233
716103|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710260752
716290|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710260935
716541|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710261317
716957|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|darwin-2level|5.9.5|darwin|8.10.1|200710261635
716962|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i686-linux|5.9.5|linux|2.4.27-3-686|200710261636
716977|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i686-linux|5.8.8|linux|2.4.27-3-686|200710261638
716993|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i386-freebsd|5.9.5|freebsd|6.2-release|200710261351
717087|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i686-linux|5.6.2|linux|2.4.27-3-686|200710261725
717191|pass|200710|imacat@mail.imacat.idv.tw|XML-Tiny|1.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710270055
717424|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|sun4-solaris|5.9.5|solaris|2.9|200710261445
717447|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710262045
717448|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710262046
717474|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710262133
717475|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710262134
717581|pass|200710|icerider70@gmail.com ("ICERIDER")|XML-Tiny|1.07|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710261644
718615|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710271354
718617|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710271354
719002|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710270712
719003|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710270712
719671|pass|200710|mmusgrove@cpan.org|XML-Tiny|1.08|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710280102
719929|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710280342
719930|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710280342
721013|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.10.0 patch 32199|netbsd|3.1|200710281256
721014|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.10.0 patch 32199|netbsd|3.1|200710281256
721312|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710281527
721313|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710281528
722085|pass|200710|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0 patch 32199|netbsd|3.1|200710281954
722872|pass|200710|mmusgrove@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710290333
723241|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710291142
723243|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710291142
723796|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710291858
723799|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710291859
723801|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710291900
723806|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710291901
723808|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710291902
723809|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710291903
724183|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710292135
724187|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710292136
724259|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710292255
724288|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710292317
724381|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710292352
724384|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.6.2|freebsd|6.2-release|200710292347
724386|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710292353
724392|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710292353
724403|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710292353
724404|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710292353
724405|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710292354
724510|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.5.5|freebsd|6.2-release|200710300021
724537|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.5.5|freebsd|6.2-release|200710300027
724568|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.6.2|freebsd|6.2-release|200710300026
724572|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710300026
724585|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710300025
724754|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710300127
724755|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710300128
724756|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710300128
724757|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710300128
724758|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710300129
724759|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710300129
724761|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710300129
724762|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710300130
724767|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710300130
725114|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710300556
725116|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710300556
725117|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710300557
725118|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710300557
725119|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710300557
725120|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710300558
725123|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710300558
725125|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710300558
725127|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710300559
725167|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.10|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710300816
725313|pass|200710|cpan@0x64.nl|Bryar|3.0|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200710300124
725387|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301051
725389|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301051
725391|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301052
725392|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301051
725433|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i686-linux|5.8.8|linux|2.4.27-3-686|200710301118
725438|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|darwin-2level|5.9.5|darwin|8.10.1|200710301119
725448|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i686-linux|5.9.5|linux|2.4.27-3-686|200710301124
725561|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i686-linux|5.9.5|linux|2.4.27-3-686|200710301228
725576|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i686-linux|5.6.2|linux|2.4.27-3-686|200710301230
725595|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i686-linux|5.8.8|linux|2.4.27-3-686|200710301232
725596|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|darwin-2level|5.9.5|darwin|8.10.1|200710301232
725706|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710301302
725747|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i686-linux|5.6.2|linux|2.4.27-3-686|200710301249
725750|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|sun4-solaris|5.9.5|solaris|2.9|200710300813
725806|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i386-freebsd|5.9.5|freebsd|6.2-release|200710301029
725849|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710301411
725881|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|sun4-solaris|5.9.5|solaris|2.9|200710300937
725967|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710301630
725968|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710301631
725969|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710301631
725970|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710301632
725978|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710301631
725980|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710301631
726169|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301718
726170|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301718
726171|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301718
726172|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301719
726508|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200710302036
726675|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200710302055
726727|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710302109
726791|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200710302200
726828|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i386-freebsd|5.9.5|freebsd|6.2-release|200710301059
726836|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.5.5|freebsd|6.2-release|200710302227
726852|fail|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.5.5|freebsd|6.2-release|200710302232
727114|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710310013
727115|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710310014
727116|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710310014
727117|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710310014
727118|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710310015
727120|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710310015
727121|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710310015
727122|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710310016
727123|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710310016
727192|pass|200710|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710310050
727341|pass|200710|mmusgrove@cpan.org|XML-Tiny|1.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310337
727446|pass|200710|mmusgrove@cpan.org|XML-Tiny|1.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310008
727554|pass|200710|mmusgrove@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310116
727762|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311018
727763|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311019
727764|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311019
727765|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311020
727781|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710311052
727820|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710311203
728112|pass|200711|imacat@mail.imacat.idv.tw|XML-Tiny|1.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010038
728139|pass|200711|imacat@mail.imacat.idv.tw|XML-Tiny|1.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010058
728217|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010151
728275|pass|200710|saper@cpan.org|XML-Tiny|1.08|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710311957
728443|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux|5.9.5|linux|2.4.27-3-686|200710312032
728512|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312101
728514|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312101
728517|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312102
728518|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312102
728552|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux|5.6.2|linux|2.4.27-3-686|200710312115
728555|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|darwin-2level|5.9.5|darwin|8.10.1|200710312116
728567|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux|5.8.8|linux|2.4.27-3-686|200710312117
728568|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i386-freebsd|5.9.5|freebsd|6.2-release|200710312115
728604|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|sun4-solaris|5.9.5|solaris|2.9|200710311636
728605|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710312136
728884|pass|200711|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711010041
729616|pass|200711|icerider70@gmail.com ("ICERIDER")|XML-Tiny|1.10|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010424
730066|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711010550
730773|pass|200711|icerider70@gmail.com ("ICERIDER")|Devel-CheckLib|0.3|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010651
731697|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711011807
731701|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711011807
731719|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011714
731720|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.08|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011714
731721|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011715
731722|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011715
731730|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711011808
731782|fail|200711|david@cantrell.org.uk|Palm-SMS|0.02|darwin-2level|5.9.5|darwin|8.10.1|200711011729
732214|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.6.2|freebsd|6.2-release|200711012140
732229|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711012145
732356|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711012145
732438|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.5.5|freebsd|6.2-release|200711012223
732646|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711012233
732819|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012325
732820|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012325
732821|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012326
732822|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012326
733089|pass|200711|mmusgrove@cpan.org|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711020241
733397|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711020511
733409|pass|200711|mmusgrove@cpan.org|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711020026
733855|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux|5.6.2|linux|2.4.27-3-686|200711021208
733946|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711021252
734213|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711021542
734243|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|darwin-2level|5.9.5|darwin|8.10.1|200711021558
734247|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux|5.9.5|linux|2.4.27-3-686|200711021559
734259|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i386-freebsd|5.9.5|freebsd|6.2-release|200711021552
734350|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.10.0 patchlevel 32202|MSWin32|5.2|200711021633
734384|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux|5.8.8|linux|2.4.27-3-686|200711021559
734440|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021640
734442|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021640
734443|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021641
734445|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021641
734649|pass|200711|andy@hexten.net|Devel-CheckOS|1.2|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711021844
734964|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711022109
734969|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711022109
734970|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711022110
734983|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711022111
734990|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711022111
734991|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711022111
734996|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711022112
735000|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711022110
735001|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711022110
735073|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|sun4-solaris|5.9.5|solaris|2.9|200711021627
735204|pass|200711|cpan@0x64.nl|XML-Tiny|1.11|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200711022008
735291|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711022208
735637|pass|200711|david@cantrell.org.uk|Data-Compare|0.02|i386-freebsd|5.9.5|freebsd|6.2-release|200711030027
735719|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030139
735720|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030140
735721|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030140
735724|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030141
735927|pass|200711|mmusgrove@cpan.org|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711030313
736341|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.02|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711031033
736770|pass|200711|alexchorny@gmail.com|Devel-CheckLib|0.3|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030412
736772|pass|200711|alexchorny@gmail.com|XML-Tiny|1.11|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030412
736795|pass|200711|mmusgrove@cpan.org|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711030733
737084|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030337
737086|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030337
737087|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030338
737089|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030338
737280|pass|200711|imacat@mail.imacat.idv.tw|XML-Tiny|1.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711032258
738907|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040155
738908|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040155
738909|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040155
738910|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040156
739569|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041250
739570|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041250
739571|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041251
739572|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041251
740713|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050044
740714|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050044
740715|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050044
740716|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050045
741522|pass|200711|cpan@pqpq.de|XML-Tiny|1.11|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741523|pass|200711|cpan@pqpq.de|XML-Tiny|1.10|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741524|pass|200711|cpan@pqpq.de|XML-Tiny|1.09|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741525|pass|200711|cpan@pqpq.de|Devel-CheckLib|0.3|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741809|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711051058
742656|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|darwin-2level|5.9.5|darwin|9.0.0|200711051831
743026|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052057
743028|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052058
743035|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052057
743052|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052056
743914|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711060535
745365|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711061836
746713|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711070246
746714|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711070246
747954|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200711071243
748739|pass|200711|andy@hexten.net|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711071835
749141|pass|200711|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.2|i86pc-solaris|5.8.8|solaris|2.10|200711072025
749292|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711072209
749304|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711072211
749306|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711072212
749311|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711072214
749312|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711072215
749316|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711072216
749324|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711072218
749330|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711072219
749605|pass|200711|bob@randomness.org.uk ("bob walker")|CPAN-FindDependencies|1.02|i86pc-solaris|5.8.8|solaris|2.10|200711072344
749902|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711080739
749905|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711080739
749907|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711080740
749909|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711080741
749910|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711080741
749912|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711080742
749914|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711080743
749917|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711080643
749954|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711080738
750004|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711080815
750021|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711080824
750025|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711080830
750026|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711080834
750042|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711080840
750060|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711080848
750106|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711080859
750197|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|1.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711080817
750202|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.41|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711080818
750450|pass|200711|bob@randomness.org.uk ("bob walker")|CPAN-FindDependencies|1.1|i86pc-solaris|5.8.8|solaris|2.10|200711081027
751024|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711081552
751025|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|darwin-thread-multi-2level|5.10.0 patch 32245|darwin|9.0.0|200711081554
751606|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|darwin-2level|5.9.5|darwin|8.10.1|200711081833
751640|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|i686-linux|5.9.5|linux|2.4.27-3-686|200711081842
751643|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200711081843
751647|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200711081843
751663|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711081939
751724|pass|200711|srezic@cpan.org|Devel-CheckOS|1.41|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711081941
751804|pass|200711|srezic@cpan.org|Devel-CheckOS|1.41|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711082040
751901|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711082039
752045|pass|200711|srezic@cpan.org|Devel-CheckOS|1.41|amd64-freebsd|5.6.2|freebsd|6.2-release|200711082125
752282|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|darwin-2level|5.9.5|darwin|8.10.1|200711090012
752289|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|darwin-2level|5.9.5|darwin|8.10.1|200711090014
752314|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090031
752315|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090032
752317|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090033
752318|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090034
752322|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|i686-linux|5.8.8|linux|2.4.27-3-686|200711090038
752326|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|i686-linux|5.9.5|linux|2.4.27-3-686|200711090039
752338|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i686-linux|5.8.8|linux|2.4.27-3-686|200711090045
752342|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i686-linux|5.9.5|linux|2.4.27-3-686|200711090046
752367|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|i686-linux|5.6.2|linux|2.4.27-3-686|200711090058
752369|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i686-linux|5.6.2|linux|2.4.27-3-686|200711090100
752699|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090104
752721|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090112
752722|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.41|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090113
752727|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|CPAN-FindDependencies|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090120
753143|fail|200711|mmusgrove@cpan.org|Devel-CheckOS|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090606
753276|na|200711|mmusgrove@cpan.org|Devel-CheckOS|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090711
753277|fail|200711|mmusgrove@cpan.org|Devel-CheckOS|1.41|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090713
753292|pass|200711|mmusgrove@cpan.org|CPAN-FindDependencies|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090726
754375|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711100554
754643|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711100042
754646|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711100044
754648|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711100046
754981|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.41|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711101304
754998|pass|200711|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711101311
755487|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|sun4-solaris|5.9.5|solaris|2.9|200711100348
755495|fail|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711100951
755563|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711101013
755568|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711101014
755573|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711101015
758030|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711110901
758033|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711110907
758036|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711110912
758039|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711110918
758050|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711110923
758056|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711110928
758060|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711110932
758061|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711110937
758062|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi|5.6.2|darwin|8.10.0|200711110938
758063|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711110940
758065|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711110941
758066|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711110942
758068|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711110943
758070|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711110944
758072|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711110946
758073|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711110947
758074|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711110948
758077|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi|5.6.2|darwin|8.10.0|200711110952
758078|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711110953
758081|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711110955
758082|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711110956
758083|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711110958
758084|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711110959
758085|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711111000
758087|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711111001
758088|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711111002
758230|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711111148
758232|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711111149
758233|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711111149
758235|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711111151
758239|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711111152
758242|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711111153
758243|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711111154
758246|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711111155
758247|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711111156
758365|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111346
758366|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111347
758367|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111348
758725|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711111840
758726|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711111840
758727|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711111841
758728|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711111841
758729|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711111842
758730|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711111842
758731|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711111843
758732|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711111844
758735|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711111844
758765|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711111859
758779|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711111903
758783|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711111907
758798|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711111911
758810|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711111914
758828|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711111918
758842|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711111922
758852|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711111925
758997|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711112053
759211|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711112249
759785|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|sun4-solaris|5.9.5|solaris|2.9|200711120107
759793|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711120012
759916|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711120108
760130|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711120257
761118|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120944
761122|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120944
761123|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120945
761727|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.41|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711121152
761946|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121258
761955|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121300
761962|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121301
762712|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0 patch 32280|netbsd|3.1|200711121713
764083|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i386-freebsd|5.9.5|freebsd|6.2-release|200711122250
764588|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130237
764591|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130237
764854|pass|200711|icerider70@gmail.com ("ICERIDER")|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711130039
765192|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711131007
765193|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711131008
765194|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711131009
765970|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i386-linux|5.8.5|linux|2.6.9-42.elsmp|200711131828
766337|pass|200711|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711132151
766737|pass|200711|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711140001
766767|pass|200711|icerider70@gmail.com ("ICERIDER")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711140002
767072|pass|200711|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200711140233
767176|pass|200711|bob@randomness.org.uk ("bob walker")|XML-Tiny|1.11|i86pc-solaris|5.8.8|solaris|2.10|200711140157
768950|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711142150
769960|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711150217
769974|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711150218
770001|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711150224
770227|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711150336
771720|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711151421
773882|pass|200711|andy@hexten.net|Devel-CheckOS|1.41|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711160111
774066|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711160119
775025|pass|200711|andy@hexten.net|Devel-CheckOS|1.41|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711161355
776151|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0 patch 32330|linux|2.6.22-14-generic|200711161734
779725|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd|5.10.0 patch 32367|freebsd|6.2-release|200711172259
779882|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711171714
780203|pass|200711|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32367|freebsd|6.2-release|200711180053
780237|pass|200711|mmusgrove@cpan.org|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711171759
782724|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200711181939
783177|pass|200711|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200711182121
783899|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.10.0|linux|2.6.16.38|200711190054
784863|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711191100
790887|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711202149
790891|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711202150
790893|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711202150
790896|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711202151
790898|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711202151
790899|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711202152
790900|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711202153
791726|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 32389|linux|2.6.22-1-k7|200711210525
791728|pass|200711|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711210436
792257|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711211005
792263|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711211005
792268|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711211006
792275|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711211006
792278|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711211007
792281|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711211008
792287|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711211008
792289|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711211009
792294|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711211009
792332|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711211015
792411|pass|200711|srezic@cpan.org|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711211155
792711|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200711211315
792839|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711211437
793079|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711211551
793685|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711211914
793833|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|darwin-2level|5.9.5|darwin|8.10.1|200711211958
793845|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux|5.8.8|linux|2.4.27-3-686|200711212002
793890|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux|5.6.2|linux|2.4.27-3-686|200711212013
793933|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux|5.9.5|linux|2.4.27-3-686|200711212018
793969|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i386-freebsd|5.9.5|freebsd|6.2-release|200711212013
794720|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711220351
794722|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711220351
794724|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711220352
794732|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711220354
794757|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711220352
794758|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711220353
794759|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711220353
794883|fail|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.10.0 patch 32367|freebsd|6.2-release|200711220756
794928|na|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.5.5|freebsd|6.2-release|200711220815
794967|pass|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711220802
794968|pass|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200711220809
795134|fail|200711|srezic@cpan.org|Bryar|3.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711221015
796071|fail|200711|icerider70@gmail.com ("ICERIDER")|Bryar|3.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711220952
796188|fail|200711|icerider70@gmail.com ("ICERIDER")|Bryar|3.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711220952
796262|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711230041
796506|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711221727
796514|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711221732
796522|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711221737
796553|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711221742
796572|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711221748
796574|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711221753
796578|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711221758
796586|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711221803
796609|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0_rc3|200711221805
796624|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711221809
796632|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|sun4-solaris|5.9.5|solaris|2.9|200711221409
796633|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711222008
796792|pass|200711|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200711230101
796943|pass|200711|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200711230101
797187|pass|200711|david@cantrell.org.uk|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230002
797200|pass|200711|david@cantrell.org.uk|CPAN-FindDependencies|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230006
797203|pass|200711|david@cantrell.org.uk|Data-Compare|0.17|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230006
797204|pass|200711|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230007
797205|pass|200711|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230006
797207|pass|200711|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230007
797208|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230007
797226|pass|200711|david@cantrell.org.uk|File-Overwrite|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230021
797227|pass|200711|david@cantrell.org.uk|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230021
797228|pass|200711|david@cantrell.org.uk|NestedMap|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230022
797240|pass|200711|david@cantrell.org.uk|Net-Random|2.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230026
797246|pass|200711|david@cantrell.org.uk|Number-Phone|1.58|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230028
797251|pass|200711|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230029
797265|pass|200711|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797266|pass|200711|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797268|pass|200711|david@cantrell.org.uk|Tie-STDOUT|1.03|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797269|pass|200711|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797270|pass|200711|david@cantrell.org.uk|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797271|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230032
797770|fail|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0_rc3|200711230741
798215|pass|200711|david@cantrell.org.uk|Bryar|3.0|i686-linux|5.8.8|linux|2.4.27-3-686|200711231110
798251|fail|200711|david@cantrell.org.uk|Bryar|3.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711231131
798475|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711231503
799278|fail|200711|david@cantrell.org.uk|Bryar|3.0|sun4-solaris|5.9.5|solaris|2.9|200711231241
799280|fail|200711|david@cantrell.org.uk|Bryar|3.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711231841
799737|fail|200711|david@cantrell.org.uk|Bryar|3.0|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200711232131
799879|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200711232234
800041|pass|200711|david@cantrell.org.uk|CPAN-FindDependencies|1.1|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200711231702
800120|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200711231717
800122|pass|200711|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200711231717
800244|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711240055
800714|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711240531
802110|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711241858
802164|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0 patch 32478|linux|2.6.18-5-686|200711241915
804772|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i386-freebsd-thread-multi|5.10.0 patch 32487|freebsd|6.2-release|200711251905
805243|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711252121
805468|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|ppc-linux-thread-multi|5.10.0 patch 32376|linux|2.6.20-16-powerpc|200711252222
805729|pass|200711|david@cantrell.org.uk|Tie-STDOUT|1.03|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200711260042
805754|pass|200711|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200711260050
805787|pass|200711|david@cantrell.org.uk|Net-Random|2.0|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200711260103
806233|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711260744
807683|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711261548
807867|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711261640
807929|pass|200711|stro@cpan.org|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711261758
809202|pass|200711|david@cantrell.org.uk|Data-Hexdumper|1.3|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200711262249
810317|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711270828
811314|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711271352
811999|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200711271804
813087|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711280142
813495|fail|200711|chris@bingosnet.co.uk|Bryar|3.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200711280649
813940|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711281215
814046|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711281320
814406|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200711281443
814407|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi|5.6.2|darwin|8.10.0|200711281444
814413|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711281445
814415|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711281446
814417|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711281447
814420|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711281448
814424|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711281449
814427|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711281450
814429|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711281451
814433|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711281452
815957|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711290131
816430|fail|200711|chris@bingosnet.co.uk|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711290454
818090|pass|200711|srezic@cpan.org|Data-Compare|0.17|i386-freebsd|5.10.0 patch 32478|freebsd|6.1-release|200711291851
818305|pass|200711|srezic@cpan.org|Data-Compare|0.17|i386-freebsd|5.6.2|freebsd|6.1-release|200711292028
819571|pass|200711|alexchorny@gmail.com|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711300129
819990|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.2|200711301328
820335|pass|200711|alexchorny@gmail.com|Data-Compare|0.17|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711300740
820981|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302032
821716|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302146
821881|pass|200711|david@cantrell.org.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200711302135
822556|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302357
822812|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302254
823787|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712010557
825915|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200712012335
825953|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712020017
826485|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200712020732
828013|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200712021707
828319|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0_rc3|200712030142
829840|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux|5.10.0|linux|2.6.22-1-k7|200712031905
829850|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200712031910
829873|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200712031916
829878|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200712031921
829881|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200712031926
829889|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200712031932
829908|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200712031938
829926|pass|200712|srezic@cpan.org|Data-Compare|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712031942
830133|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712032137
830134|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712032135
830173|pass|200712|xdg@hyperbolic.net (DAGOLDEN)|CPAN-FindDependencies|1.99_01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712031555
830197|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200712032138
831557|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712040554
831803|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712040900
831868|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200712040923
831873|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200712040927
831878|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200712040930
831888|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200712040934
831893|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200712040938
831897|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200712040942
831902|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200712040946
831907|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200712040949
831993|pass|200712|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|1.99_01|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200712041045
832037|pass|200712|srezic@cpan.org|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712041214
832173|pass|200712|icerider70@gmail.com ("ICERIDER")|CPAN-FindDependencies|1.99_01|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712040644
832268|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712041351
832504|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712041628
832963|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712040744
834171|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712050347
834470|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712050739
834935|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712050000
835613|pass|200712|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.99_01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200712060104
835862|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712051931
836161|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712050931
836650|pass|200712|david@cantrell.org.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200712052301
836743|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712051300
837303|pass|200712|srezic@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712061010
837491|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200712061102
838315|pass|200712|dillman@ria.buffalo.edu|Devel-CheckOS|1.42|sun4-solaris|5.8.8|solaris|2.9|200712061058
838624|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712062244
838827|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712070122
839373|pass|200712|notbenh@cpan.org|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712061109
839420|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712070844
840134|pass|200712|andy@hexten.net|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.10.0 patch 32560|darwin|9.1.0|200712071523
840932|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712072327
840955|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712072337
840967|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712072342
840982|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712072348
841002|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712080006
841011|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712080012
841362|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712080341
841879|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712080232
841964|pass|200712|g.grigelionis@computer.org|Devel-CheckOS|1.42|i586-linux-thread-multi|5.8.8|linux|2.6.16|200712080029
842674|pass|200712|david@cantrell.org.uk|Devel-CheckOS|1.42|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200712082045
842797|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200712082257
843205|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200712090321
843500|pass|200712|cpan@pqpq.de|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712090923
843671|pass|200712|cpan@pqpq.de|CPAN-FindDependencies|1.99_01|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712091035
844619|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200712091711
846267|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712100820
846955|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712101233
847107|pass|200712|d@0x64.nl|Devel-CheckOS|1.42|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200712101305
847826|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712101833
848586|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712110203
848851|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712110636
849160|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200712111048
849338|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712111202
850973|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712112231
852048|pass|200712|paranoid@sarpedon.site5.com ((Mike Bissett))|Data-Compare|0.17|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200712121210
852788|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712121443
852849|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200712120434
854890|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712131119
855361|pass|200712|rlane10@wi.rr.com|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.8|darwin|8.9.0|200712130738
857132|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200712141556
857136|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.22-1-k7|200712141557
857139|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200712141558
857142|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200712141559
857143|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200712141600
857146|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200712141601
857148|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200712141602
857151|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200712141604
857197|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712141517
857215|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712141525
857223|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712141532
857243|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712141540
857270|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200712141547
857285|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200712141555
857307|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200712141603
857326|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712141611
857348|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712141620
857425|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712141822
857789|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712142121
857887|pass|200712|icerider70@gmail.com ("ICERIDER")|CPAN-FindDependencies|2.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712141449
857999|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712142200
858010|fail|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200712142141
858011|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200712142142
858012|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200712142144
858013|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200712142145
858014|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200712142146
858016|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200712142147
858018|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200712142149
858020|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200712142150
858175|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200712150009
859571|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200712152036
860492|pass|200712|overlordq@gmail.com|Net-Random|2.0|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712160142
860548|pass|200712|overlordq@gmail.com|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712160211
861014|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712161129
861340|pass|200712|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200712170123
862554|pass|200712|andy@hexten.net|Number-Phone|1.58|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862555|pass|200712|andy@hexten.net|Class-CanBeA|1.2|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862556|pass|200712|andy@hexten.net|Data-Compare|0.17|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862557|pass|200712|andy@hexten.net|Data-Transactional|1.0|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862558|pass|200712|andy@hexten.net|Net-Random|2.0|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862559|pass|200712|andy@hexten.net|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170018
862561|pass|200712|andy@hexten.net|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170020
862562|pass|200712|andy@hexten.net|Devel-CheckLib|0.3|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170020
862563|pass|200712|andy@hexten.net|Games-Dice-Advanced|1.1|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170021
862763|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi|5.6.2|darwin|8.10.0|200712170404
863091|pass|200712|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|2.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200712170901
863578|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712170416
864697|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712180430
865057|pass|200712|cpan@pqpq.de|CPAN-FindDependencies|2.0|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712180921
865873|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712181359
866599|pass|200712|salvacpan@gmail.com|Data-Compare|0.17|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200712181435
866762|pass|200712|andy@hexten.net|Devel-CheckLib|0.3|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181902
866770|pass|200712|andy@hexten.net|Devel-CheckLib|0.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181803
866873|pass|200712|andy@hexten.net|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181751
866889|pass|200712|andy@hexten.net|Games-Dice-Advanced|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181917
867078|pass|200712|andy@hexten.net|Class-CanBeA|1.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181849
867192|pass|200712|andy@hexten.net|Number-Phone|1.58|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181931
867193|pass|200712|andy@hexten.net|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181931
867611|pass|200712|andy@hexten.net|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181816
867648|pass|200712|andy@hexten.net|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182105
867785|pass|200712|andy@hexten.net|Net-Random|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182123
868027|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712182138
868129|pass|200712|andy@hexten.net|CPAN-FindDependencies|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182225
868221|pass|200712|andy@hexten.net|Data-Compare|0.17|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182234
868223|pass|200712|andy@hexten.net|Data-Transactional|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182235
868857|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712190230
870729|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712191657
872660|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712200418
874234|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0|linux|2.6.22-1-k7|200712202153
874402|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0|linux|2.6.22-1-k7|200712202233
874775|pass|200712|bricas@cpan.org ("Brian Cassidy")|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712201446
875337|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux|5.11.0|linux|2.6.22-1-k7|200712210125
875730|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200712210230
877394|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0|linux|2.6.22-1-k7|200712210733
877531|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.11.0|linux|2.6.22-1-k7|200712211038
878404|pass|200712|bricas@cpan.org ("Brian Cassidy")|Devel-CheckLib|0.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712210939
878801|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200712211947
879522|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712212314
879947|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220025
880232|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712220044
880595|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220224
880734|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220340
880776|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220304
884030|pass|200712|david@cantrell.org.uk|Bryar|2.8_02|i686-linux|5.6.2|linux|2.4.27-3-686|200712222041
885997|pass|200712|stro@cpan.org|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200712230141
888988|pass|200712|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0|freebsd|6.2-release|200712241030
889201|pass|200712|andy@hexten.net|XML-Tiny|1.11|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200712241127
890820|pass|200712|cpan@pqpq.de|Devel-CheckOS|1.42|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712251539
891034|pass|200712|rlane10@wi.rr.com|Devel-CheckOS|1.42|darwin-2level|5.10.0|darwin|8.11.0|200712250509
892422|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712260259
894567|fail|200712|david@cantrell.org.uk|Bryar|2.8_02|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200712270027
894603|pass|200712|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712270134
894628|pass|200712|rlane10@wi.rr.com|XML-Tiny|1.11|darwin-2level|5.10.0|darwin|8.11.0|200712261305
894709|pass|200712|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.42|i386-linux|5.8.8|linux|2.6.18-53.el5|200712270448
895423|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271029
895613|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271144
896014|pass|200712|claco@chrislaco.com ("Christopher H. Laco")|Data-Compare|0.17|darwin-thread-multi-2level|5.8.6|darwin|8.0|200712270048
896291|pass|200712|icerider70@gmail.com ("ICERIDER")|Data-Compare|0.17|i386-linux|5.8.8|linux|2.6.18-53.el5|200712270727
896293|pass|200712|root@alysande.altrion.org ((System Administrator))|Devel-CheckOS|1.42|darwin-2level|5.10.0|darwin|8.11.1|200712271305
896347|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271437
896767|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271414
897406|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200712271820
897407|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271021
897430|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200712271826
897445|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712271817
897550|pass|200712|david@cantrell.org.uk|Net-Random|2.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200712271856
897601|pass|200712|david@cantrell.org.uk|Net-Random|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712271853
897769|pass|200712|david@cantrell.org.uk|Net-Random|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200712271354
897863|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712271233
897915|pass|200712|david@cantrell.org.uk|Net-Random|2.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200712272028
897993|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712271258
898157|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200712272144
898228|pass|200712|david@cantrell.org.uk|Net-Random|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200712272152
898271|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712272143
899962|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200712281636
900858|pass|200712|imacat@mail.imacat.idv.tw|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200712290438
903334|pass|200712|rlane10@wi.rr.com|Tie-STDOUT|1.03|darwin-2level|5.10.0|darwin|8.11.0|200712300053
904773|pass|200712|srezic@cpan.org|Statistics-ChiSquare|0.5|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712302026
904802|pass|200712|srezic@cpan.org|Statistics-SerialCorrelation|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712302034
905218|pass|200712|rlane10@wi.rr.com|Devel-CheckOS|1.42|i686-linux|5.10.0|linux|2.6.23.1luckyseven|200712301444
906166|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712310730
906374|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712310854
906487|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712311007
906696|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712311151
906698|na|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712311154
906700|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712311157
906701|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712311159
906705|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200712311202
906707|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200712311204
906712|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200712311206
906715|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712311208
906717|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712311210
907980|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712310840
908298|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712310949
908891|pass|200712|cpantester@zombie.org.uk|Data-Compare|0.17|x86_64-linux-ld|5.11.0 patch 32787|linux|2.6.22-3-amd64|200712311732
910528|pass|200712|cpantester@zombie.org.uk|Data-Compare|0.17|x86_64-linux-ld|5.11.0 patch 32790|linux|2.6.22-3-amd64|200712312036
911392|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200801011056
911683|pass|200801|cpantester@zombie.org.uk|Data-Compare|0.17|x86_64-linux-ld|5.11.0 patch 32790|linux|2.6.22-3-amd64|200801011209
912997|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32792|linux|2.6.22-3-amd64|200801012023
914399|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32792|linux|2.6.22-3-amd64|200801020106
914536|pass|200801|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.18-5-686|200801021551
914904|pass|200801|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200801021710
915075|pass|200801|andy@hexten.net|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200801021749
915506|pass|200801|andy@hexten.net|Statistics-ChiSquare|0.5|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200801022013
915791|pass|200801|d@0x64.nl|XML-Tiny|1.11|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801021048
916082|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32805|linux|2.6.22-3-amd64|200801022238
917482|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200801030803
918102|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32800|linux|2.6.22-3-amd64|200801021356
918614|pass|200801|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200801031055
919916|pass|200801|imacat@mail.imacat.idv.tw|Number-Phone|1.58|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801040155
920490|pass|200801|d@0x64.nl|Data-Compare|0.17|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801032352
921985|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32809|linux|2.6.22-3-amd64|200801041016
923011|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32824|linux|2.6.22-3-amd64|200801041358
923177|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|i86pc-solaris|5.10.0|solaris|2.10|200801041601
923700|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32832|linux|2.6.22-3-amd64|200801041845
923985|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200801042006
924386|pass|200801|david@cantrell.org.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801042156
924870|pass|200801|david@cantrell.org.uk|Data-Compare|0.17|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801050035
926854|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200801052014
927106|pass|200801|david@cantrell.org.uk|Data-Compare|0.17|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801051404
927629|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.11.0 patch 32837|cygwin|1.5.24(0.15642)|200801060155
930316|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.11.0 patch 32864|cygwin|1.5.24(0.15642)|200801070135
931226|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801071157
931657|pass|200801|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|0.17|sun4-solaris|5.10.0|solaris|2.8|200801070928
931974|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200801071713
932623|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801072025
934822|pass|200801|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.17|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801081334
938822|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801091702
939607|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.11.0 patch 32908|linux|2.6.18-5-alpha-generic|200801092044
939664|pass|200801|david@cantrell.org.uk|Bryar|2.6|i686-linux|5.6.2|linux|2.4.27-3-686|200801092100
939750|fail|200801|david@cantrell.org.uk|Bryar|3.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801092123
940465|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|i86pc-solaris|5.8.8|solaris|2.10|200801100207
946793|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.11.0 patch 32953|cygwin|1.5.24(0.15642)|200801120913
947178|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32966|linux|2.6.22-3-amd64|200801121142
953318|fail|200801|rjbs@cpan.org|Bryar|3.0|darwin-2level|5.10.0|darwin|9.1.0|200801141030
955700|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Data-Compare|0.17|i686-linux-64int-ld|5.8.8|linux|2.6.22-14-generic|200801150051
955762|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Data-Compare|0.17|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-generic|200801150101
956019|pass|200801|robertl@apnic.net ("Robert Loomans")|Data-Compare|0.17|darwin-thread-multi-2level|5.8.8|darwin|8.11.1|200801151755
958423|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801152111
958437|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801152114
958862|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0|linux|2.6.22-1-k7|200801160016
958863|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200801160016
958866|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200801160016
958869|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200801160017
958871|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200801160017
958873|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200801160018
958875|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200801160019
959222|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|i86pc-solaris|5.8.8|solaris|2.10|200801160124
959225|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|i86pc-solaris|5.10.0|solaris|2.10|200801160125
959422|pass|200801|icerider70@gmail.com ("ICERIDER")|Data-Compare|1.18|i386-linux|5.8.8|linux|2.6.18-53.el5|200801160210
960005|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|CPAN-FindDependencies|1.99_01|i686-linux-64int-ld|5.8.8|linux|2.6.22-14-generic|200801160419
960006|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.42|i686-linux-64int-ld|5.8.8|linux|2.6.22-14-generic|200801160419
960026|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801160430
960030|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi|5.6.2|darwin|8.10.0|200801160433
960035|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200801160439
960318|pass|200801|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200801161514
960472|pass|200801|Jost.Krieger+perl@rub.de|Data-Compare|1.18|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801160920
960531|pass|200801|d@0x64.nl (DEVOGON)|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801160948
961467|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801161415
961485|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i686-linux|5.8.8|linux|2.4.27-3-686|200801161417
961502|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801161347
961506|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801160820
961509|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801161420
961510|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801161420
961520|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i686-linux|5.6.2|linux|2.4.27-3-686|200801161421
961562|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 32981|linux|2.6.18-5-alpha-generic|200801161431
961963|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200801161638
962412|pass|200801|cpantester@hotmail.co.uk|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.11.0 patch 32982|linux|2.6.22-3-amd64|200801161929
962482|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.10.0|freebsd|6.2-release|200801162046
963003|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.6.2|freebsd|6.2-release|200801162135
963156|pass|200801|g.grigelionis@computer.org|Data-Compare|1.18|i586-linux-thread-multi|5.8.8|linux|2.6.16|200801162212
963203|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200801162221
963745|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801162358
963770|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801170006
964012|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801170031
964037|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200801170036
964040|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200801170039
964071|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200801170059
964084|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200801170102
964087|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200801170105
964091|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200801170108
964106|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200801170112
964125|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200801170115
964127|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200801170118
964635|pass|200801|d@0x64.nl (DEVOGON)|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801170756
964967|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200801170952
965354|pass|200801|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.18|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200801171203
966001|pass|200801|imacat@mail.imacat.idv.tw|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200801180044
967324|pass|200801|salve.nilsen@met.no ("Salve J Nilsen")|Data-Compare|1.18|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200801171735
967365|pass|200801|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.18|sun4-solaris|5.10.0|solaris|2.8|200801171332
968007|pass|200801|overlordq@gmail.com|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.22.10|200801180317
968952|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200801181450
969190|pass|200801|d@0x64.nl (DEVOGON)|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.22-3-486|200801181718
969205|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200801181623
969783|pass|200801|dillman@ria.buffalo.edu|Data-Compare|1.18|sun4-solaris|5.8.8|solaris|2.9|200801181347
970950|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.42|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-generic|200801190046
972266|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801191057
972674|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.42|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801191419
972689|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.42|i686-linux|5.10.0|linux|2.6.22-3-486|200801191423
972692|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.3|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801191423
972693|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.3|i686-linux|5.10.0|linux|2.6.22-3-486|200801191425
974401|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33004|cygwin|1.5.24(0.15642)|200801192233
974723|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200801200019
974764|pass|200801|david@cantrell.org.uk|Class-CanBeA|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200048
974766|pass|200801|david@cantrell.org.uk|Data-Hexdumper|1.0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200049
974769|pass|200801|david@cantrell.org.uk|Data-Hexdumper|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200050
974786|fail|200801|david@cantrell.org.uk|Net-Random|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200104
974787|pass|200801|david@cantrell.org.uk|Number-Phone|1.58|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200105
974789|pass|200801|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200106
974791|pass|200801|david@cantrell.org.uk|Statistics-ChiSquare|0.5|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200109
974793|pass|200801|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200109
974795|pass|200801|david@cantrell.org.uk|Sub-WrapPackages|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200110
974797|pass|200801|david@cantrell.org.uk|Tie-Hash-Longest|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200111
974799|pass|200801|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200111
974800|pass|200801|david@cantrell.org.uk|Tie-STDOUT|1.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200111
974803|pass|200801|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200112
974806|pass|200801|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200113
974809|pass|200801|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200113
974811|pass|200801|david@cantrell.org.uk|XML-Tiny|1.06|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200114
975159|pass|200801|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.18|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-386|200801200355
975983|pass|200801|andy@hexten.net|Data-Compare|1.18|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200801201242
976661|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801201822
977539|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801202155
977631|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801202104
977717|pass|200801|david@cantrell.org.uk|NestedMap|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202208
977792|fail|200801|david@cantrell.org.uk|Bryar|3.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202224
977962|pass|200801|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202248
978266|unknown|200801|david@cantrell.org.uk|Acme-Licence|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202350
978376|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801210111
978612|unknown|200801|david@cantrell.org.uk|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210109
978852|fail|200801|david@cantrell.org.uk|Data-Transactional|0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210149
978863|pass|200801|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210151
978893|pass|200801|david@cantrell.org.uk|File-Overwrite|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210158
978896|pass|200801|david@cantrell.org.uk|Games-Dice-Advanced|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210159
978966|pass|200801|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210217
978970|pass|200801|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210219
979198|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801210425
979494|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200801210515
980641|fail|200801|d@0x64.nl (DEVOGON)|Bryar|3.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801211628
980947|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33022|linux|2.6.18-5-alpha-generic|200801211712
982905|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200801220618
983254|pass|200801|fayland@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200801220922
983260|pass|200801|rlane10@wi.rr.com|Data-Compare|1.18|darwin-2level-ld|5.10.0|darwin|8.11.0|200801220144
987518|pass|200801|andy@hexten.net|Data-Compare|1.18|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200801231403
987884|fail|200801|david@cantrell.org.uk|Bryar|2.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801231711
988738|pass|200801|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801240003
989519|pass|200801|callen@kpi-consulting.net|Devel-CheckOS|1.42|i386-linux|5.8.8|linux|2.6.9-42.0.3.elsmp|200801231502
989759|pass|200801|stro@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200801240511
994236|pass|200801|rjbs@cpan.org|Data-Compare|1.18|darwin-2level|5.10.0|darwin|9.1.0|200801261005
994237|pass|200801|rjbs@cpan.org|Data-Compare|1.18|darwin-2level|5.10.0|darwin|9.1.0|200801261005
996329|pass|200801|david@cantrell.org.uk|CPAN-FindDependencies|2.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801271620
998612|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|i86pc-solaris|5.8.8|solaris|2.10|200801281301
998621|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|i86pc-solaris|5.10.0|solaris|2.10|200801281302
999761|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801281923
1000713|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801282355
1000716|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801282358
1000819|pass|200801|g.grigelionis@computer.org|Devel-CheckOS|1.42|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200801282113
1000850|pass|200801|g.grigelionis@computer.org|Devel-CheckOS|1.42|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200801282117
1001686|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801290757
1001838|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801291312
1001936|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801291540
1002105|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801291616
1002250|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33082|linux|2.6.18-5-alpha-generic|200801291819
1002345|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801291841
1002699|pass|200801|cpantester@hotmail.co.uk|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.11.0 patch 33109|linux|2.6.22-3-amd64|200801292057
1002733|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200801292109
1006145|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.11.0 patch 33125|netbsd|4.0|200801310014
1006342|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801310442
1008067|pass|200801|david@cantrell.org.uk|XML-Tiny|1.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801311506
1008614|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200802010308
1008765|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200802010622
1009502|pass|200802|ferreira@cpan.org|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200802011257
1010498|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802020418
1010848|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.11.0 patch 33163|cygwin|1.5.24(0.15642)|200802021012
1010888|pass|200802|feldt@nhn.ou.edu|Data-Compare|1.18|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200802011342
1011511|pass|200802|andy@hexten.net|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200802021419
1012282|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8|linux|2.6.14|200802022222
1012807|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-CanBeA|1.2|i686-linux-64int|5.8.8|linux|2.6.14|200802030414
1013908|pass|200802|rjbs@cpan.org|Data-Compare|1.18|darwin-2level|5.10.0|darwin|9.1.0|200802031115
1014995|pass|200802|claco@chrislaco.com ("Christopher H. Laco")|Data-Compare|1.18|darwin-thread-multi-2level|5.8.6|darwin|8.0|200802031702
1016124|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.11.0 patch 33228|linux|2.6.16.38|200802041359
1017394|pass|200802|rlane10@wi.rr.com|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.23.1luckyseven|200802041337
1017716|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802050423
1021750|fail|200802|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200802062240
1027183|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200802091719
1030279|pass|200802|autarch@urth.org|Devel-CheckOS|1.42|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200802101104
1031268|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200802110552
1031357|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200802110628
1033621|pass|200802|autarch@urth.org|Data-Compare|1.18|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200802111240
1036645|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802131211
1036650|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802131213
1036653|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802131215
1036660|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802131217
1036665|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802131220
1036669|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802131223
1038238|pass|200802|d@0x64.nl (DEVOGON)|Number-Phone|1.58|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802140759
1038319|pass|200802|d@0x64.nl (DEVOGON)|Number-Phone|1.58|i686-linux|5.10.0|linux|2.6.22-3-486|200802140931
1038655|pass|200802|david@cantrell.org.uk|Number-Phone|1.58|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802141118
1038698|pass|200802|david@cantrell.org.uk|Number-Phone|1.58|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802141225
1038987|pass|200802|david@cantrell.org.uk|Number-Phone|1.58|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802141532
1040103|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802150401
1040104|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802150401
1040105|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802150401
1040106|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802150402
1040107|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802150402
1040108|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802150402
1040520|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.58|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802151127
1040656|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802151141
1040805|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802151235
1040850|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200802151310
1040931|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.42|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802151346
1041070|pass|200802|cpantester@hotmail.co.uk|Number-Phone|1.58|x86_64-linux-thread-multi-ld|5.11.0 patch 33317|linux|2.6.22-3-amd64|200802151430
1041385|pass|200802|cpantester@hotmail.co.uk|CPU-Emulator-Memory|1.0|x86_64-linux-thread-multi-ld|5.11.0 patch 33317|linux|2.6.22-3-amd64|200802151500
1041451|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200802151656
1041529|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802151718
1041778|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802151914
1041836|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802151957
1041864|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802152026
1041899|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802152026
1041986|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802152119
1042830|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200802161045
1043635|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200802161908
1043680|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802162012
1043681|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802162012
1043682|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802162012
1043683|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802162012
1043684|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802162013
1043685|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802162013
1043686|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802162013
1043687|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802162014
1043688|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802162014
1043689|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802162014
1043725|pass|200802|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802170429
1044143|pass|200802|g.grigelionis@computer.org|Devel-CheckOS|1.42|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200802162101
1044165|pass|200802|g.grigelionis@computer.org|Data-Compare|1.18|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200802162129
1044281|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200802170216
1044955|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200802171216
1045272|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|cygwin-thread-multi-64int|5.11.0 patch 33318|cygwin|1.5.24(0.15642)|200802171534
1045402|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200802171038
1045403|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802171639
1045878|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802171913
1045909|pass|200802|cpantester@hotmail.co.uk|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.11.0 patch 33325|linux|2.6.22-3-amd64|200802171932
1046019|pass|200802|cpantester@hotmail.co.uk|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.11.0 patch 33325|linux|2.6.22-3-amd64|200802171959
1046334|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802172212
1046421|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802172247
1046511|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200802180017
1046517|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802180019
1046529|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802180021
1046827|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.11.0 patch 33318|cygwin|1.5.24(0.15642)|200802180336
1047355|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200802180921
1047665|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.11.0 patch 33325|linux|2.6.18-5-alpha-generic|200802181229
1047818|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200802181324
1048072|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|alpha-linux-thread-multi|5.11.0 patch 33325|linux|2.6.18-5-alpha-generic|200802181442
1048201|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200802181524
1049215|pass|200802|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802182238
1049645|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802190111
1049667|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802190131
1050454|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200802191305
1050470|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200802191323
1050471|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802191323
1050472|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802191324
1050914|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33325|linux|2.6.18-5-alpha-generic|200802191607
1051021|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.11.0 patch 33334|linux|2.6.16.38|200802191639
1051219|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.11.0 patch 33334|linux|2.6.16.38|200802191819
1051837|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0 patch 33334|linux|2.6.16.38|200802192329
1052526|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802201039
1053541|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200802201212
1053595|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802201220
1053936|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200802201357
1054546|pass|200802|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.0|i686-linux|5.10.0|linux|2.6.22-3-486|200802201934
1057443|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200802211259
1059347|pass|200802|d@0x64.nl ("DEVOGON")|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802220038
1060654|pass|200802|stro@cpan.org|Class-CanBeA|1.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802211610
1061638|pass|200802|stro@cpan.org|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802220802
1061838|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802221641
1061925|pass|200802|stro@cpan.org|Devel-AssertLib|0.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802221016
1061941|pass|200802|stro@cpan.org|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802221018
1062177|pass|200802|d@0x64.nl ("DEVOGON")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802221926
1062313|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802221916
1062433|pass|200802|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802222043
1062487|unknown|200802|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230357
1062489|unknown|200802|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230358
1062491|pass|200802|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230358
1062503|fail|200802|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230401
1062507|pass|200802|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230402
1062510|pass|200802|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230403
1062512|pass|200802|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230403
1062516|pass|200802|imacat@mail.imacat.idv.tw|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230404
1062517|pass|200802|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230404
1062521|pass|200802|imacat@mail.imacat.idv.tw|Data-Transactional|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230405
1062523|pass|200802|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230405
1062526|fail|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230406
1062529|pass|200802|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230407
1062532|pass|200802|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230407
1062534|pass|200802|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230408
1062537|pass|200802|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230409
1062544|pass|200802|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230412
1062554|pass|200802|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230413
1062556|pass|200802|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230414
1062561|pass|200802|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230414
1062567|pass|200802|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230415
1062571|pass|200802|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230415
1062573|pass|200802|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230416
1062576|pass|200802|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230416
1062581|pass|200802|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230417
1062582|pass|200802|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230417
1062583|pass|200802|imacat@mail.imacat.idv.tw|XML-Tiny|1.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230418
1062858|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802222106
1062932|pass|200802|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802222236
1062969|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802222147
1063197|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802222304
1063404|pass|200802|cpantester@hotmail.co.uk|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.11.0 patch 33346|linux|2.6.22-3-amd64|200802221902
1063577|pass|200802|stro@cpan.org|Games-Dice-Advanced|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802230059
1064682|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200802230840
1064703|pass|200802|d@0x64.nl (DEVOGON)|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802230944
1066771|pass|200802|srezic@cpan.org|Tie-Hash-Longest|1.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232046
1066779|pass|200802|srezic@cpan.org|Tie-Hash-Rank|1.0.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232046
1067204|pass|200802|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232147
1067751|pass|200802|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232144
1069310|pass|200802|srezic@cpan.org|Data-Hexdumper|1.3|amd64-freebsd|5.10.0|freebsd|6.2-release|200802241047
1070548|pass|200802|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802242001
1070873|pass|200802|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802242125
1071241|pass|200802|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802242226
1071744|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802250102
1071782|pass|200802|srezic@cpan.org|Data-Hexdumper|1.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802250116
1071902|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802250138
1072310|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200802250340
1073849|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200802251738
1074148|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200802251900
1074970|fail|200802|srezic@cpan.org|CPU-Emulator-Memory|1.0|amd64-freebsd|5.5.5|freebsd|6.2-release|200802252312
1075214|fail|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.5.5|freebsd|6.2-release|200802252348
1075256|pass|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802260012
1076381|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|alpha-linux-thread-multi|5.11.0 patch 33365|linux|2.6.18-5-alpha-generic|200802260931
1076900|pass|200802|stro@cpan.org|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802260921
1077232|pass|200802|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200802261643
1077815|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33365|linux|2.6.18-5-alpha-generic|200802261908
1078107|pass|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.10.0|freebsd|6.2-release|200802262125
1078409|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802262304
1078638|pass|200802|andy@hexten.net|Data-Hexdumper|1.3|i386-netbsd|5.8.8|netbsd|3.1|200802262241
1078761|pass|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.6.2|freebsd|6.2-release|200802262356
1079212|pass|200802|stro@cpan.org|NestedMap|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802270116
1079566|pass|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802271221
1079567|pass|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802271222
1079627|fail|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802271247
1081377|pass|200802|stro@cpan.org|Number-Phone|1.58|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802271210
1082191|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802272252
1082196|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802272253
1082201|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802272254
1082205|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802272254
1082208|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802272256
1082209|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802272256
1082741|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200802280301
1082847|pass|200802|stro@cpan.org|Statistics-ChiSquare|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802280359
1083055|pass|200802|stro@cpan.org|Statistics-SerialCorrelation|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802280146
1083328|pass|200802|d@0x64.nl (DEVOGON)|Number-Phone|1.581|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802280857
1083450|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.6.2|freebsd|6.2-release|200802281005
1083451|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802281005
1083456|na|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.5.5|freebsd|6.2-release|200802280849
1083536|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802281005
1083539|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.10.0|freebsd|6.2-release|200802281005
1083913|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i686-linux|5.8.8|linux|2.4.27-3-686|200802281253
1083955|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.581|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200802281338
1083992|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i686-linux|5.6.2|linux|2.4.27-3-686|200802281357
1084043|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802281426
1084397|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802281624
1084412|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802281612
1084423|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200802281043
1084809|pass|200802|d@0x64.nl|Number-Phone|1.581|i686-linux|5.10.0|linux|2.6.22-3-486|200802282044
1085311|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802282220
1085315|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802282220
1085318|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802282221
1085326|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802282222
1085331|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802282222
1085334|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802282223
1085752|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802290020
1085753|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802290020
1085754|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802290021
1085755|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802290021
1085756|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802290022
1085758|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802290022
1085783|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802290024
1085784|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802290024
1085785|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802290025
1085786|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802290025
1085810|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802290024
1085811|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802290024
1085818|pass|200802|stro@cpan.org|Tie-Hash-Longest|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290133
1085828|pass|200802|stro@cpan.org|Tie-Hash-Rank|1.0.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290135
1085940|pass|200802|stro@cpan.org|Tie-Scalar-Decay|1.1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290003
1086158|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.581|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200802290102
1086808|pass|200802|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802291357
1086809|pass|200802|imacat@mail.imacat.idv.tw|Number-Phone|1.581|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802291358
1086909|pass|200802|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.1001|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802290725
1086987|pass|200802|stro@cpan.org|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290139
1087243|pass|200802|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802290837
1087254|na|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.5.5|freebsd|6.2-release|200802290841
1087257|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802290841
1087392|pass|200802|imacat@mail.imacat.idv.tw|Number-Phone|1.581|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802291728
1087462|pass|200802|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd|5.10.0|freebsd|6.2-release|200802290958
1087479|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.10.0|freebsd|6.2-release|200802291017
1087738|pass|200802|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802291223
1087808|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802291206
1087820|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.581|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802291209
1088420|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i686-linux|5.8.8|linux|2.4.27-3-686|200802291542
1088421|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200802291542
1088423|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.4.27-3-686|200802291542
1088438|fail|200802|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802291520
1088488|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802291646
1088490|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802291647
1088491|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802291647
1088496|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291626
1088497|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802291651
1088498|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291628
1088499|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802291652
1088501|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802291652
1088502|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i686-linux|5.6.2|linux|2.4.27-3-686|200802291653
1088503|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200802291653
1088504|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291629
1088505|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i686-linux|5.6.2|linux|2.4.27-3-686|200802291654
1088757|pass|200802|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291930
1089198|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802292052
1089200|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802292052
1089202|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802292053
1089203|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802292053
1089205|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802292054
1089207|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802292054
1089209|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802292054
1089210|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802292055
1089212|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802292055
1089213|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802292056
1089296|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802292222
1089383|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292310
1089384|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292311
1089386|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292311
1089387|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.581|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292312
1089556|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802292338
1089559|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802292339
1089561|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802292339
1089562|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802292339
1089563|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802292340
1089565|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802292340
1089566|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802292340
1089568|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802292341
1089569|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802292341
1089571|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802292342
1089572|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802292342
1089573|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802292342
1089574|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802292343
1089576|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802292343
1089578|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802292344
1089580|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802292344
1089581|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802292344
1089583|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802292345
1089586|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802292345
1089588|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802292345
1089617|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802292355
1089621|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802292356
1089625|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802292356
1089803|pass|200803|icerider70@gmail.com ("ICERIDER")|Number-Phone|1.581|i386-linux|5.8.8|linux|2.6.18-53.el5|200803010151
1089978|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803010318
1089979|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803010319
1089983|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803010319
1091103|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.6.2|freebsd|6.2-release|200803011302
1091197|pass|200803|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.22-3-486|200803011427
1091212|pass|200803|d@0x64.nl (DEVOGON)|Number-Phone|1.581|i686-linux|5.10.0|linux|2.6.22-3-486|200803011443
1091352|pass|200803|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Memory|1.0|i386-linux|5.8.8|linux|2.6.18-53.el5|200803010851
1091742|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803011746
1091891|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803011756
1092328|fail|200803|andy@hexten.net|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803012024
1092354|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803020435
1092383|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.001|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803020446
1092386|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803020446
1092659|pass|200803|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803012108
1092959|pass|200803|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020039
1093139|pass|200803|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020102
1094820|pass|200803|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803021432
1094966|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021600
1094968|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021600
1094970|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021601
1094978|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021604
1095292|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803021652
1095759|pass|200803|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803021909
1095788|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021917
1095789|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021917
1095791|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021918
1095803|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021918
1095808|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021919
1095809|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021919
1095811|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021920
1095813|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021920
1095815|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021921
1095821|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021922
1095822|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021922
1095823|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021923
1096373|pass|200803|srezic@cpan.org|Data-Hexdumper|1.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200803022143
1096416|pass|200803|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803022230
1096935|pass|200803|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803021712
1096946|pass|200803|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803021713
1096963|pass|200803|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803021714
1096964|pass|200803|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Memory|1.1001|i386-linux|5.8.8|linux|2.6.18-53.el5|200803021714
1097054|pass|200803|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200803030000
1097084|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803030214
1098112|pass|200803|stro@cpan.org|Number-Phone|1.581|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803031135
1098687|pass|200803|d@0x64.nl ("DEVOGON")|CPU-Emulator-Memory|1.1001|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803031242
1099024|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031447
1099026|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031448
1099029|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031448
1099031|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031450
1099628|pass|200803|stro@cpan.org|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803032027
1099664|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040107
1099666|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040108
1099669|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040108
1099674|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040111
1100247|pass|200803|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200803032215
1100248|na|200803|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.6.2|freebsd|6.2-release|200803032215
1100533|pass|200803|stro@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040008
1100537|pass|200803|stro@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040009
1100802|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803032326
1100928|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040020
1101250|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040142
1101756|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040434
1101874|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803041208
1102093|pass|200803|stro@cpan.org|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040643
1103433|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040929
1103711|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041016
1104229|pass|200803|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.42|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803041047
1104296|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041207
1104629|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041241
1104915|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803041323
1105211|pass|200803|stro@cpan.org|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803041613
1105438|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8|linux|2.6.14|200803041602
1105779|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041713
1105891|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041708
1105955|pass|200803|andy@hexten.net|Number-Phone|1.581|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803041654
1107340|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042222
1107362|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042255
1107366|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803042256
1107381|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803042257
1107382|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.8.8|linux|2.6.14|200803042257
1107384|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803042259
1107386|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803042259
1107387|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803042300
1107408|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803042257
1107423|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042251
1107614|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042331
1108058|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042331
1108061|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042332
1108065|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042333
1108080|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042335
1109224|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803050548
1109254|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803050457
1109259|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803050458
1109263|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803050459
1109269|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803050500
1109275|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803050501
1109279|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803050501
1109282|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803050502
1109284|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803050503
1109288|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803050504
1109292|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803050504
1109373|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803050617
1109863|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.6.2|freebsd|6.2-release|200803050722
1109864|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.10.0|freebsd|6.2-release|200803050722
1109984|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.5.5|freebsd|6.2-release|200803050836
1110587|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.4|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803051857
1110726|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803051124
1110843|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803051203
1111089|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051404
1111091|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051405
1111095|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051407
1111102|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051408
1111109|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051410
1111240|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200803051449
1111292|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.4|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803051454
1111491|pass|200803|andy@hexten.net|Number-Phone|1.581|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200803051556
1111498|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051558
1111809|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803051707
1111850|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i686-linux|5.6.2|linux|2.4.27-3-686|200803051716
1111851|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i686-linux|5.8.8|linux|2.4.27-3-686|200803051717
1112005|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803051747
1112021|pass|200803|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.10.0|freebsd|6.2-release|200803051839
1112103|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803051758
1112105|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.4|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803051759
1112985|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803052123
1113234|pass|200803|d@0x64.nl ("DEVOGON")|Number-Phone|1.581|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803052211
1113289|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.4|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803052224
1113959|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.8.8 patch 33436|linux|2.6.22-1-k7|200803060059
1114475|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.8.8 patch 33436|linux|2.6.22-1-k7|200803060313
1115303|pass|200803|stro@cpan.org|Net-Random|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803060814
1115390|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803060747
1115424|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803060744
1117012|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061219
1117025|pass|200803|stro@cpan.org|Number-Phone|1.581|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803061327
1117073|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061137
1117075|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061137
1117077|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061138
1117079|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061138
1117086|pass|200803|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803061340
1117231|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061205
1117687|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803061318
1117693|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803061319
1117694|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803061320
1118024|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803061412
1118753|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckLib|0.4|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803061721
1118838|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061739
1119041|pass|200803|d@0x64.nl ("DEVOGON")|CPAN-FindDependencies|2.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803061805
1119501|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.4|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803070159
1119566|pass|200803|stro@cpan.org|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803062004
1119718|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061924
1119800|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200803061839
1119955|pass|200803|andy@hexten.net|Data-Compare|1.18|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200803061932
1120096|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803062000
1120629|pass|200803|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd|5.6.2|freebsd|6.2-release|200803062319
1120958|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070001
1121130|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803062341
1121862|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070301
1122380|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070500
1122639|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070021
1122686|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070547
1123451|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200803070919
1123847|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071224
1123868|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071229
1124313|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071514
1124659|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071714
1124710|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071711
1125157|pass|200803|d@0x64.nl|Devel-CheckLib|0.4|i686-linux|5.10.0|linux|2.6.22-3-486|200803071854
1125298|pass|200803|d@0x64.nl|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.22-3-486|200803071916
1126853|fail|200803|d@0x64.nl ("DEVOGON")|Bryar|3.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803072259
1126885|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803071606
1126910|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.42|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803072306
1126958|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803072218
1127166|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803080007
1127202|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i686-cygwin-thread-multi-64int|5.11.0 patch 33450|cygwin|1.5.24(0.15642)|200803072324
1127604|pass|200803|d@0x64.nl|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.22-3-486|200803080142
1127792|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-cygwin-thread-multi-64int|5.11.0 patch 33450|cygwin|1.5.24(0.15642)|200803080054
1128559|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200803080351
1128897|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080630
1129275|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.4|i686-linux|5.10.0|linux|2.6.22-3-486|200803080819
1129286|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|darwin-2level|5.8.8|darwin|8.10.1|200803080814
1129634|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080853
1129685|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080905
1130112|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080921
1131122|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-cygwin-thread-multi-64int|5.11.0 patch 33450|cygwin|1.5.24(0.15642)|200803081156
1131719|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803081236
1132402|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081702
1132651|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081738
1132947|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081626
1133084|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|darwin-2level|5.8.8|darwin|8.10.1|200803081604
1133252|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081858
1133258|pass|200803|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200803081629
1133307|pass|200803|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803081632
1134224|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803082210
1134295|pass|200803|d@0x64.nl|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.22-3-486|200803082233
1134317|pass|200803|stro@cpan.org|Sub-WrapPackages|1.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803082331
1135446|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200803090046
1135548|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200803090105
1136200|pass|200803|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803090407
1137541|pass|200803|d@0x64.nl ("DEVOGON")|XML-Tiny|1.11|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803091228
1137905|pass|200803|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803090836
1137986|pass|200803|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803091335
1138137|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803091353
1138692|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803091548
1139225|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803091727
1139601|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803091824
1139874|pass|200803|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803091845
1140020|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803091835
1140224|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803091919
1140377|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803091942
1140430|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803092053
1140490|pass|200803|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.6.2|freebsd|6.2-release|200803092059
1140822|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803092158
1141239|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803092254
1141354|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803100000
1141393|pass|200803|d@0x64.nl (DEVOGON)|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803100018
1141448|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803092324
1142886|pass|200803|daxim@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803092241
1143297|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803101156
1143388|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803101336
1144603|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|alpha-linux-thread-multi|5.11.0 patch 33456|linux|2.6.18-5-alpha-generic|200803101704
1144632|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803101810
1144753|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33456|linux|2.6.18-5-alpha-generic|200803101728
1145110|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803101835
1146007|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102130
1146153|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102210
1146201|pass|200803|schwern@pobox.com|Devel-CheckLib|0.4|darwin-thread-multi-2level|5.8.8|darwin|8.8.1|200803101116
1146230|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102214
1147736|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.11.0 patch 33467|linux|2.6.16.38|200803110257
1147779|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33467|linux|2.6.16.38|200803110307
1147933|fail|200803|imacat@mail.imacat.idv.tw|Palm-SMS|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803111159
1148083|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|darwin-2level|5.8.8|darwin|8.10.1|200803110610
1148832|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111132
1148834|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111133
1148837|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111133
1148839|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111133
1148988|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111231
1148993|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111232
1148994|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111233
1148995|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111234
1149737|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0 patch 33467|linux|2.6.16.38|200803111346
1150508|pass|200803|d@0x64.nl ("DEVOGON")|File-Find-Rule-Permissions|1.3|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803111731
1151369|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33456|linux|2.6.18-5-alpha-generic|200803111923
1151818|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112101
1152039|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112202
1152397|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112317
1152971|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803120059
1153370|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803120240
1153517|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803120254
1153896|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200803120341
1154487|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803120848
1155279|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121135
1155343|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121113
1155416|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121030
1155581|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121207
1156349|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121248
1157352|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122103
1157355|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122104
1157358|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803122104
1157363|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122105
1157366|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122105
1157369|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122106
1157374|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8|linux|2.6.14|200803122107
1157385|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803122107
1157390|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803122107
1157394|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803122108
1157434|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122119
1157436|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122120
1157438|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803122120
1157439|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122121
1157441|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122121
1157443|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122122
1157447|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8|linux|2.6.14|200803122122
1157449|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803122123
1157450|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803122124
1157454|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803122125
1157638|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|darwin-2level|5.8.8|darwin|8.10.1|200803122209
1157643|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|darwin-2level|5.8.8|darwin|8.10.1|200803122205
1158128|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803122231
1158271|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122351
1158283|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122353
1158286|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122354
1158289|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803122355
1158291|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122355
1158292|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122356
1158310|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122359
1158312|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8|linux|2.6.14|200803130000
1158313|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.8.8|linux|2.6.14|200803130001
1158316|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803130003
1158400|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803130004
1158411|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122357
1158412|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122359
1158422|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|i586-linux-thread-multi|5.8.8|linux|2.6.16|200803122325
1158434|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200803130003
1158441|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200803130011
1158519|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122357
1158521|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122352
1158548|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803122351
1158832|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130127
1159673|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130437
1160079|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130539
1160098|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130545
1160108|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130546
1160637|pass|200803|hohokus@gmail.com|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803121942
1160646|pass|200803|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200803130956
1160656|pass|200803|artur+cpan@niif.spb.su|Devel-CheckOS|1.43|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200803130833
1160961|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803130957
1160963|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803130957
1160965|pass|200803|d@0x64.nl|CPU-Emulator-Z80|0.9|i686-linux|5.10.0|linux|2.6.22-3-486|200803131104
1160988|pass|200803|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200803130949
1160990|pass|200803|d@0x64.nl|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803131109
1160994|pass|200803|d@0x64.nl|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.22-3-486|200803131111
1161055|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803131026
1161078|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|i686-linux|5.8.8|linux|2.4.27-3-686|200803131035
1161086|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i686-linux|5.8.8|linux|2.4.27-3-686|200803131036
1161091|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803131041
1161093|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803131039
1161099|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803131044
1161521|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803131308
1161673|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803131453
1161703|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803131500
1161788|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803131414
1161794|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.4.27-3-686|200803131415
1161800|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803131418
1161845|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803131424
1161859|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i686-linux|5.6.2|linux|2.4.27-3-686|200803131427
1161889|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i686-linux|5.6.2|linux|2.4.27-3-686|200803131432
1161990|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.22-3-486|200803131558
1162040|fail|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803131611
1162060|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803131508
1162067|pass|200803|d@0x64.nl|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803131616
1162156|pass|200803|justinr@pollackassociates.com|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803130840
1162359|pass|200803|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131154
1162362|pass|200803|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131155
1162405|pass|200803|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131204
1162419|pass|200803|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131205
1162522|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803131630
1162536|pass|200803|rlane10@wi.rr.com|Devel-CheckOS|1.43|darwin-2level-ld|5.10.0|darwin|8.11.0|200803130855
1163299|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803131849
1163308|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803131851
1163319|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803131852
1163412|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132004
1163421|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132011
1163434|pass|200803|d@0x64.nl (DEVOGON)|Number-Phone|1.581|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803131922
1163766|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.10.0|freebsd|6.2-release|200803132120
1163769|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.10.0|freebsd|6.2-release|200803132120
1163771|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803132121
1163772|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803132121
1163818|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132126
1164045|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132031
1164132|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803132151
1164362|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803132246
1164411|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132303
1164413|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132302
1164476|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803132247
1164479|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803132250
1164492|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132301
1164500|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132301
1164748|pass|200803|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803140009
1164865|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803131853
1164866|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803131854
1164886|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803140006
1164887|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803140007
1164888|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803140008
1164889|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803140009
1164896|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803140013
1164899|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803140014
1164902|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803140015
1164995|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803140114
1165001|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803140118
1165072|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|0.9|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803141048
1165073|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803141048
1165074|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.43|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803141048
1165344|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140603
1165350|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140604
1165353|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140605
1165354|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140606
1165541|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803141620
1165549|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.43|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803141622
1165579|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|0.9|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803141634
1165909|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803141047
1166648|pass|200803|dillman@ria.buffalo.edu|Devel-CheckOS|1.43|sun4-solaris|5.10.0|solaris|2.9|200803141303
1167659|pass|200803|pjacklam@online.no|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803142333
1167878|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150009
1167910|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150015
1167915|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150016
1167924|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150018
1168085|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33523|linux|2.6.22-1-k7|200803150144
1168411|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33523|linux|2.6.22-1-k7|200803150255
1168612|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150315
1168614|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150316
1168616|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150318
1168618|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150320
1168671|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803150345
1168674|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803150347
1168676|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803150349
1168679|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803150350
1168682|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803150352
1168773|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803150425
1168780|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803150426
1168783|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803150428
1168787|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803150429
1168791|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803150431
1168843|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803150452
1168844|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803150453
1168847|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803150455
1168848|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803150456
1168850|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803150457
1168852|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803150459
1168855|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803150500
1168857|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803150501
1168862|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803150502
1168863|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803150504
1169140|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.6.2|freebsd|6.2-release|200803150824
1169142|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.6.2|freebsd|6.2-release|200803150824
1170491|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803151654
1171035|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803152243
1171036|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803152243
1171715|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803160058
1172433|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160609
1172435|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160609
1172436|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160610
1172438|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160611
1172467|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803160656
1172895|pass|200803|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803161138
1173125|pass|200803|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803161212
1173183|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803161216
1173817|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161246
1174405|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200803151032
1174545|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161404
1174714|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803161337
1174721|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803161338
1174724|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803161339
1174757|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161451
1176590|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161921
1176723|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161932
1176968|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161952
1176971|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161954
1176974|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161956
1176979|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161958
1177423|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162007
1177430|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162008
1177436|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162011
1177445|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162014
1178306|pass|200803|d@0x64.nl ("DEVOGON")|CPU-Emulator-Z80|0.9|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803170730
1178312|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803170734
1178317|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803170735
1179297|pass|200803|jrockway@cpan.org|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200803170556
1179476|pass|200803|stro@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803171456
1179553|pass|200803|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.581|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803170934
1180042|pass|200803|stro@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803171718
1180067|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171523
1180073|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171524
1180076|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171525
1180083|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171526
1181294|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803172316
1181486|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803172255
1182212|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180154
1182266|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180159
1182400|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180219
1182464|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180238
1183117|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180413
1183120|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180414
1183122|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180415
1183125|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180416
1183818|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803180856
1183820|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803180857
1183823|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803180858
1184296|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803181113
1184598|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803181322
1185299|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803181634
1185301|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803181635
1185302|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803181634
1185643|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181710
1185646|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181711
1185669|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181713
1185676|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181714
1186256|pass|200803|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200803182000
1186749|pass|200803|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803182152
1187699|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803190210
1189947|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191518
1189953|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191519
1189956|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191520
1190402|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191634
1190403|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191635
1190405|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191635
1190469|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803191916
1190666|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803191844
1191004|fail|200803|srezic@cpan.org|Bryar|3.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803192109
1191974|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200158
1192362|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200342
1192598|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803200110
1192731|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200339
1193708|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200740
1193709|pass|200803|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193710|pass|200803|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193712|pass|200803|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193714|pass|200803|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193716|pass|200803|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193717|pass|200803|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193719|pass|200803|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193720|pass|200803|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193725|pass|200803|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201442
1197084|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.18|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803202243
1197372|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201903
1198104|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210453
1198112|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210455
1198152|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210504
1198166|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210507
1198952|pass|200803|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803210013
1198983|pass|200803|d@0x64.nl ("DEVOGON")|Data-Transactional|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803210932
1198998|pass|200803|d@0x64.nl ("DEVOGON")|Tie-STDOUT|1.03|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803210934
1200386|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33543|cygwin|1.5.24(0.15642)|200803211349
1201926|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33547|linux|2.6.22-1-k7|200803212318
1202128|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33547|linux|2.6.22-1-k7|200803212309
1203286|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803221120
1204426|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803222136
1204805|pass|200803|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803230315
1205235|fail|200803|imacat@mail.imacat.idv.tw|Palm-SMS|0.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803231512
1205373|pass|200803|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803231644
1207445|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803240109
1208722|pass|200803|pjacklam@online.no|Statistics-ChiSquare|0.5|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803240946
1209414|pass|200803|pjacklam@online.no|Statistics-SerialCorrelation|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803241042
1211329|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803242029
1211522|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803242028
1211793|pass|200803|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200803242136
1211844|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803241943
1211972|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803242157
1213162|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803250221
1213482|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803250005
1214140|pass|200803|victorg@hacktux.com|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.18-53.1.13.el5|200803250023
1219608|pass|200803|mthurn@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803260359
1222775|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.6.2|freebsd|6.1-release|200803270221
1223051|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270427
1223335|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270607
1223339|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270608
1223390|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270618
1223398|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270615
1224707|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803271100
1224842|pass|200803|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803271844
1225443|pass|200803|andy@hexten.net|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803271533
1227809|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281302
1227848|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281322
1228566|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281513
1228671|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281726
1228876|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200803281722
1228967|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200803281737
1229101|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281854
1229520|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803282040
1230271|pass|200803|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803290030
1231970|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803291342
1232260|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200803291414
1232395|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33584|netbsd|4.0|200803291444
1232715|pass|200803|srezic@cpan.org|Data-Compare|1.18|i386-freebsd|5.10.0|freebsd|6.1-release|200803291728
1232969|pass|200803|srezic@cpan.org|Data-Compare|1.18|i386-freebsd|5.6.2|freebsd|6.1-release|200803291533
1233051|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33584|netbsd|4.0|200803291737
1233578|pass|200803|icerider70@gmail.com ("ICERIDER")|Devel-CheckLib|0.4|i386-linux|5.8.8|linux|2.6.18-53.el5|200803291440
1233672|pass|200803|srezic@cpan.org|Data-Compare|1.18|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803292004
1234280|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.581|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803292355
1234283|fail|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803292256
1234304|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33592|cygwin|1.5.24(0.15642)|200803292311
1235061|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803301032
1235065|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803301033
1235068|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8|linux|2.6.14|200803301034
1235070|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803301035
1235073|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803301036
1235078|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803301037
1236117|pass|200803|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803301809
1236572|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200803301949
1236770|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803302143
1236800|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803302152
1237579|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200803302354
1237843|pass|200803|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803310046
1238161|pass|200803|icerider70@gmail.com ("ICERIDER")|Devel-CheckLib|0.5|i386-linux|5.8.8|linux|2.6.18-53.el5|200803310322
1238163|pass|200803|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.43|i386-linux|5.8.8|linux|2.6.18-53.el5|200803310324
1238202|pass|200803|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Z80|0.9|i386-linux|5.8.8|linux|2.6.18-53.el5|200803310336
1239152|pass|200803|d@0x64.nl|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.22-3-486|200803311156
1239517|pass|200803|flemming@ipk-gatersleben.de|Data-Compare|1.18|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200803311253
1240050|pass|200803|flemming@ipk-gatersleben.de|File-Find-Rule-Permissions|1.3|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200803311452
1240150|pass|200803|flemming@ipk-gatersleben.de|Devel-CheckOS|1.43|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200803311452
1240236|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803311522
1240361|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803311646
1240809|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200803311748
1241129|pass|200803|d@0x64.nl (DEVOGON)|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803311839
1241188|pass|200803|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803311943
1241491|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.6.2|freebsd|6.1-release|200803312138
1241502|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.6.2|freebsd|6.1-release|200803312143
1241637|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33609|netbsd|3.1|200803312125
1242439|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 33609|netbsd|3.1|200804010218
1242549|pass|200804|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804010215
1242883|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010613
1243016|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010702
1243595|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010745
1244664|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804011204
1245283|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804011238
1245469|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010443
1245671|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804011411
1246102|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200804011728
1246605|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804011834
1247239|pass|200804|srezic@cpan.org|Data-Compare|1.18|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804020018
1249436|fail|200804|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804020616
1250046|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804021400
1250303|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804021720
1250327|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804021640
1250845|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804021958
1250931|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.5.5|freebsd|6.1-release|200804022228
1251046|pass|200804|g.grigelionis@computer.org|Devel-CheckOS|1.43|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200804022200
1251060|na|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.5.5|freebsd|6.1-release|200804022228
1251663|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804030054
1252351|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804030743
1252495|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.6.2|freebsd|6.1-release|200804030804
1252565|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.10.0|freebsd|6.1-release|200804030807
1252690|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804030846
1252944|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031013
1253193|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031110
1253816|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804031219
1254074|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031419
1254640|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031557
1254832|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031639
1256353|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804032241
1256641|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804040035
1256699|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804040046
1258103|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804040823
1258262|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804040844
1258588|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804040903
1258998|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804041115
1259325|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804041211
1259700|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804041104
1260650|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33643|cygwin|1.5.24(0.15642)|200804041859
1261597|pass|200804|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.10.0|freebsd|6.1-release|200804050039
1261932|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050156
1262025|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050243
1262253|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050337
1262830|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050707
1262965|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050734
1263296|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050833
1264058|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804051046
1264059|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804051047
1264192|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804051048
1264387|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.6.2|freebsd|6.1-release|200804051254
1264466|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804051243
1264548|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804051244
1264550|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804051245
1264740|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200804051349
1265774|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.10.0|freebsd|6.1-release|200804051816
1265782|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd|5.10.0|freebsd|6.1-release|200804051819
1265898|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.10.0|freebsd|6.1-release|200804051818
1266599|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804052116
1267915|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060102
1267993|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060048
1268179|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060113
1268941|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060231
1269251|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060207
1270069|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804061049
1270100|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804061054
1270807|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804061538
1271214|pass|200804|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.15.7|200804062023
1272262|pass|200804|daxim@cpan.org|XML-Tiny|1.11|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804062307
1272703|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200804070033
1273196|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070512
1273374|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070526
1273441|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070552
1273961|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070811
1274437|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804070943
1274783|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804071031
1275261|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33655|linux|2.6.21.5-smp|200804071002
1275273|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804071154
1275419|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33655|linux|2.6.18-5-alpha-generic|200804071127
1275742|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33655|netbsd|3.1|200804071205
1275956|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33655|darwin|8.10.0|200804071235
1276355|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804071621
1276975|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804071919
1280289|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.6.2|freebsd|6.1-release|200804080705
1282762|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|2.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804081911
1285009|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090442
1285671|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090643
1285857|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090734
1286432|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090756
1286479|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090922
1286504|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090219
1286579|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804090930
1287189|pass|200804|rafl@debian.org|Data-Compare|1.18|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200804091259
1287547|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804091419
1288483|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804091852
1289736|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.10.0|freebsd|6.1-release|200804100214
1291176|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200804101229
1292857|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33659|darwin|8.10.0|200804102014
1292969|pass|200804|srezic@cpan.org|Data-Compare|1.18|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804102153
1294270|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.6.2|freebsd|6.1-release|200804110417
1295251|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.11.0 patch 33659|solaris|2.11|200804111006
1296395|pass|200804|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804111548
1296444|fail|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|3.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804111559
1298893|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33669|cygwin|1.5.24(0.15642)|200804112348
1299784|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804120744
1299806|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804120736
1300813|fail|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.10.0|freebsd|6.1-release|200804121203
1302083|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121611
1302530|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121655
1302619|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121648
1302734|pass|200804|andy@hexten.net|Devel-CheckLib|0.5|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200804121616
1302878|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121725
1303747|pass|200804|bobtfish@bobtfish.net|Data-Compare|1.18|darwin-thread-multi-2level|5.8.6|darwin|8.0|200804121656
1304958|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33670|openbsd|4.2|200804122311
1306578|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.6.2|freebsd|6.1-release|200804131000
1307348|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200804131229
1308479|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804131759
1308506|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.10.0|freebsd|6.1-release|200804131809
1309852|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200804132352
1309901|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804140004
1309990|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200804140024
1310065|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804140032
1310264|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804140112
1312796|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33673|linux|2.6.18-5-alpha-generic|200804141247
1314443|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33673|netbsd|3.1|200804142104
1314651|pass|200804|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200804142240
1316284|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804150951
1318154|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33684|darwin|8.10.0|200804151533
1318181|pass|200804|srezic@cpan.org|Data-Compare|1.18|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804151633
1319178|pass|200804|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804152010
1319424|pass|200804|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804152133
1319427|pass|200804|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804152135
1320037|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160006
1320202|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160045
1320688|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160154
1320854|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160153
1321240|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804160306
1321718|pass|200804|bobtfish@bobtfish.net|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200804160036
1321958|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160426
1322246|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160545
1322346|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160609
1322726|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160707
1322791|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160722
1323725|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160935
1323925|pass|200804|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160955
1324139|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160937
1324238|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804161023
1324470|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200804161007
1324479|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200804161008
1324893|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804161208
1325309|pass|200804|daxim@cpan.org|Devel-CheckOS|1.43|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804161332
1329851|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170219
1330384|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200804170602
1330587|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804170816
1330869|pass|200804|srezic@cpan.org|Data-Hexdumper|1.3|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170940
1330877|pass|200804|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170941
1331563|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171159
1331870|pass|200804|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171256
1333040|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.5.5|freebsd|6.1-release|200804171656
1333594|pass|200804|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171929
1333630|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171941
1334678|pass|200804|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804172336
1334892|pass|200804|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.11.0 patch 33684|darwin|8.10.0|200804172324
1334893|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200804172324
1336996|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.4.27-2-386|200804181300
1337168|pass|200804|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804181149
1338088|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200804181535
1338833|pass|200804|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804181627
1340146|pass|200804|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804182058
1341403|pass|200804|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804190052
1342227|pass|200804|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804190341
1343054|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33713|netbsd|3.1|200804191000
1343247|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 33713|netbsd|3.1|200804191113
1343738|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33713|cygwin|1.5.24(0.15642)|200804191330
1344079|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|cygwin-thread-multi-64int|5.11.0 patch 33713|cygwin|1.5.24(0.15642)|200804191507
1344109|pass|200804|stro@cpan.org|XML-Tiny|1.11|i686-linux|5.8.8|linux|2.4.27-2-386|200804191416
1344425|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris|5.10.0|solaris|2.9|200804191717
1344978|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.4.27-2-386|200804191700
1345067|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200804192108
1346102|pass|200804|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804192337
1346403|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804192340
1346430|unknown|200804|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804200042
1346569|pass|200804|stro@cpan.org|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.4.27-2-386|200804200011
1346627|unknown|200804|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804200043
1347609|pass|200804|cpansmoker@renormalist.net ("Steffen Schwigon")|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.18-5-k7|200804200050
1348140|pass|200804|cpansmoker@renormalist.net ("Steffen Schwigon")|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.18-5-k7|200804200841
1348289|pass|200804|cpansmoker@renormalist.net ("Steffen Schwigon")|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.18-5-k7|200804200911
1348942|pass|200804|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804201142
1349045|pass|200804|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804201117
1349578|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201309
1349660|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201322
1349824|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201341
1349960|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201306
1350142|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201239
1350369|pass|200804|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804201434
1350385|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|darwin-2level|5.10.0|darwin|8.11.1|200804201202
1351314|pass|200804|artur+cpan@niif.spb.su|XML-Tiny|1.11|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200804201138
1352831|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|darwin-2level|5.10.0|darwin|8.11.1|200804201815
1352844|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.11.0 patch 33714|linux|2.6.16.38|200804202018
1352857|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201809
1353180|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33714|linux|2.6.16.38|200804202058
1354151|pass|200804|stro@cpan.org|XML-Tiny|1.11|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804210414
1355985|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33714|openbsd|4.1|200804211355
1356080|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33716|linux|2.6.18-5-alpha-generic|200804211407
1357339|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.18|sun4-solaris|5.10.0|solaris|2.9|200804211952
1357838|pass|200804|stro@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804212200
1359285|unknown|200804|stro@cpan.org|Acme-Licence|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200804220029
1360100|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|i686-linux|5.8.8|linux|2.4.27-2-386|200804220442
1360220|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200804220549
1360275|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33714|openbsd|4.1|200804220557
1360430|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33714|openbsd|4.1|200804220712
1360762|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|sun4-solaris|5.10.0|solaris|2.9|200804221035
1361828|unknown|200804|stro@cpan.org|Acme-Licence|1.0|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804221657
1361841|unknown|200804|stro@cpan.org|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.4.27-2-386|200804221541
1362745|pass|200804|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804221953
1362863|pass|200804|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804221951
1362883|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.4.27-2-386|200804222000
1362913|unknown|200804|stro@cpan.org|Acme-Licence|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804222148
1365292|pass|200804|mgardner@usatech.com|Data-Compare|1.18|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200804221340
1365401|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.4.27-2-386|200804231029
1365419|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804231207
1365571|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804231245
1365589|pass|200804|rafl@debian.org|XML-Tiny|1.11|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200804230011
1365735|pass|200804|mgardner@usatech.com|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200804221350
1366323|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200804231630
1366439|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804231843
1366955|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804231902
1367132|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804232203
1368275|pass|200804|chris@bingosnet.co.uk|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240105
1368277|pass|200804|chris@bingosnet.co.uk|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240106
1368280|pass|200804|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240107
1368324|pass|200804|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240122
1368325|pass|200804|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240123
1368334|pass|200804|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240126
1368335|pass|200804|chris@bingosnet.co.uk|Class-CanBeA|1.2|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240126
1368340|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240127
1368341|pass|200804|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240128
1368343|pass|200804|chris@bingosnet.co.uk|Data-Transactional|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240129
1368347|pass|200804|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240130
1368352|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240131
1368354|pass|200804|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240132
1368358|pass|200804|chris@bingosnet.co.uk|File-Overwrite|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240132
1368360|pass|200804|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240133
1368362|pass|200804|chris@bingosnet.co.uk|NestedMap|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240133
1368371|pass|200804|chris@bingosnet.co.uk|Net-Random|2.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240138
1368372|pass|200804|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240139
1368373|pass|200804|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240141
1368375|pass|200804|chris@bingosnet.co.uk|Statistics-ChiSquare|0.5|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240142
1368376|pass|200804|chris@bingosnet.co.uk|Statistics-SerialCorrelation|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240142
1368377|pass|200804|chris@bingosnet.co.uk|Sub-WrapPackages|1.2|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240143
1368378|pass|200804|chris@bingosnet.co.uk|Tie-Hash-Longest|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240143
1368379|pass|200804|chris@bingosnet.co.uk|Tie-Hash-Rank|1.0.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240143
1368380|pass|200804|chris@bingosnet.co.uk|Tie-STDOUT|1.03|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240144
1368381|pass|200804|chris@bingosnet.co.uk|Tie-Scalar-Decay|1.1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240144
1368383|pass|200804|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240145
1368386|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240145
1371563|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804250734
1372822|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804251054
1373335|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804250926
1373398|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.11.0 patch 33741|freebsd|7.0-release|200804251510
1373795|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200804251645
1375050|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 33741|freebsd|7.0-release|200804260104
1375153|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.11.0 patch 33741|freebsd|7.0-release|200804260154
1375157|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804260235
1375177|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804260242
1375466|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804260413
1377678|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33741|darwin|8.10.0|200804262114
1380106|pass|200804|alexchorny@gmail.com|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804271820
1380947|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804281120
1382101|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804281840
1382290|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804281946
1384214|pass|200804|daxim@cpan.org|CPU-Emulator-Z80|0.9|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290214
1384220|pass|200804|daxim@cpan.org|Devel-CheckLib|0.5|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290215
1384268|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804290043
1385201|pass|200804|daxim@cpan.org|Bryar|3.0|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290723
1385859|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804290843
1386203|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804291034
1386295|pass|200804|tester@tcool.org ("ishigaki")|Data-Compare|1.18|i386-freebsd-64int|5.8.8|freebsd|5.4-release-p16|200804291212
1391895|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33741|darwin|8.10.0|200805011812
1392094|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805011924
1392295|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012217
1392648|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012357
1392682|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012352
1392765|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012331
1393191|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805020601
1394719|na|200805|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.5.5|freebsd|6.1-release|200805021325
1396129|na|200805|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.5.5|freebsd|6.1-release|200805021916
1396253|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805021945
1396966|na|200805|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.5.5|freebsd|6.1-release|200805022257
1397502|pass|200805|gam3-cpanp@gam3.net|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.22.10|200805020917
1397513|pass|200805|ewhipple@kubuntu-1.americanstaffing.org ((ewhipple))|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200805021038
1397923|na|200805|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200805030108
1398049|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805030108
1398157|pass|200805|srezic@cpan.org|Data-Hexdumper|1.3|i386-freebsd|5.5.5|freebsd|6.1-release|200805030059
1398349|pass|200805|jrockway@cpan.org|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200805021352
1398975|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805030441
1401073|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805031752
1401597|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805031236
1402427|pass|200805|d@0x64.nl ("DEVOGON")|Devel-CheckLib|0.5|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032247
1402547|fail|200805|chris@bingosnet.co.uk|Palm-SMS|0.02|darwin-thread-multi-64int-2level|5.11.0 patch 33782|darwin|8.10.0|200805032158
1402664|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805032304
1403160|pass|200805|d@0x64.nl ("DEVOGON")|XML-Tiny|1.11|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040108
1403333|pass|200805|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.43|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040137
1403502|pass|200805|d@0x64.nl ("DEVOGON")|Data-Compare|1.18|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040200
1404074|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805040138
1404127|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805040133
1404862|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33782|openbsd|4.2|200805041041
1406078|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805041339
1406538|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805041535
1407046|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805041750
1407061|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200805041858
1407291|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805041929
1408339|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33782|openbsd|4.2|200805050643
1409006|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805051201
1410617|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33788|netbsd|4.0|200805052144
1410773|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33788|linux|2.6.24-17-generic|200805052323
1413440|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33788|netbsd|4.0|200805061317
1414429|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805061700
1414480|fail|200805|chris@bingosnet.co.uk|Bryar|3.0|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805061751
1416098|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805070052
1417178|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805070124
1417798|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805070924
1418235|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805071058
1418752|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805071326
1419366|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805071751
1420893|pass|200805|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.10.0|freebsd|6.1-release|200805080836
1422492|pass|200805|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.18|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805081517
1423103|pass|200805|d@0x64.nl|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.22.10|200805081919
1423254|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.11.0 patch 33789|solaris|2.10|200805082054
1424466|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805090547
1425874|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805090915
1426736|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.18|darwin-2level|5.8.1|darwin|7.9.0|200805091542
1427856|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805092020
1428749|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805092230
1428861|pass|200805|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.43|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200805092240
1428880|pass|200805|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.43|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200805092244
1429209|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33797|darwin|8.10.0|200805092351
1430158|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33797|darwin|8.10.0|200805100357
1431052|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33797|linux|2.6.24-17-generic|200805100805
1431653|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101021
1432538|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101402
1432694|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101402
1433056|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckOS|1.43|darwin-2level|5.8.1|darwin|7.9.0|200805101404
1433313|pass|200805|icerider70@gmail.com ("ICERIDER")|XML-Tiny|1.11|i386-linux|5.8.8|linux|2.6.18-53.el5|200805100903
1433348|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33796|cygwin|1.5.24(0.15642)|200805101508
1433636|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101544
1434358|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805101412
1434661|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805101847
1435099|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Data-Compare|1.18|i686-linux|5.11.0 patch 33797|linux|2.6.24-17-generic|200805102320
1436231|pass|200805|jj@jonallen.info ("JJ")|XML-Tiny|1.11|darwin-2level|5.8.1|darwin|7.9.0|200805110257
1436370|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805110336
1437768|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805110214
1438065|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805110149
1438346|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805111359
1438484|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805111438
1438874|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33816|linux|2.6.21.5-smp|200805111621
1438928|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805111638
1439819|pass|200805|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200805112200
1439820|na|200805|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.6.2|freebsd|6.1-release|200805112201
1441505|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805120600
1441873|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805120751
1443828|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805121541
1444415|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805121738
1444798|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200805122042
1445168|pass|200805|srezic@cpan.org|Data-Hexdumper|1.3|i386-freebsd|5.6.2|freebsd|6.1-release|200805122155
1445749|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805122232
1445774|pass|200805|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200805130718
1446070|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805130005
1446250|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200805130109
1446252|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200805130110
1446254|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200805130111
1446260|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8|linux|2.6.14|200805130112
1446262|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200805130113
1446263|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200805130113
1446267|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200805130114
1446271|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200805130115
1446273|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200805130116
1446274|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200805130216
1446276|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805130218
1446279|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805130220
1446294|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200805130127
1446649|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200805130443
1446652|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200805130443
1446655|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200805130444
1446656|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200805130444
1446659|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200805130445
1446665|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200805130445
1446669|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200805130446
1446671|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200805130447
1446674|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200805130447
1446676|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200805130448
1447210|pass|200805|d@0x64.nl ("DEVOGON")|Data-Compare|1.19|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200805130904
1447307|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805130810
1447348|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200805130716
1447365|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200805130219
1447405|pass|200805|rafl@debian.org|Data-Compare|1.19|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200805130713
1447428|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i686-linux|5.8.8|linux|2.4.27-3-686|200805130827
1447433|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200805130829
1447622|pass|200805|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.19|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805130901
1447705|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.19|darwin-2level|5.8.1|darwin|7.9.0|200805130933
1447804|pass|200805|imacat@mail.imacat.idv.tw|Data-Compare|1.19|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200805131651
1447805|pass|200805|imacat@mail.imacat.idv.tw|Data-Compare|1.19|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200805131651
1447883|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200805131008
1447892|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200805130735
1448176|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805131111
1448508|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.11.0 patch 33822|freebsd|7.0-release|200805131027
1448683|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200805131253
1448737|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i686-linux|5.6.2|linux|2.4.27-3-686|200805131306
1448903|pass|200805|hohokus@gmail.com|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805130857
1449105|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.11.0 patch 33822|linux|2.6.18-5-alpha-generic|200805131449
1449658|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805131025
1449817|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.11.0 patch 33822|darwin|8.10.0|200805131730
1449960|pass|200805|jj@jonallen.info ("JJ")|CPU-Emulator-Memory|1.1001|darwin-2level|5.8.1|darwin|7.9.0|200805131811
1449999|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckLib|0.5|darwin-2level|5.8.1|darwin|7.9.0|200805131821
1450090|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200805131934
1450191|pass|200805|d@0x64.nl (DEVOGON)|Data-Compare|1.19|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200805131835
1450235|pass|200805|g.grigelionis@computer.org|Data-Compare|1.19|i586-linux-thread-multi|5.8.8|linux|2.6.16|200805131958
1450615|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd|5.10.0|freebsd|6.1-release|200805132205
1451204|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd|5.6.2|freebsd|6.1-release|200805140013
1451206|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805140015
1451390|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33822|openbsd|4.2|200805132353
1451490|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200805140016
1451562|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805140029
1451906|pass|200805|rlane10@wi.rr.com|Data-Compare|1.19|darwin-2level-ld|5.10.0|darwin|8.11.0|200805131335
1452642|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805140623
1453081|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200805140836
1453184|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805140900
1453262|pass|200805|jj@jonallen.info ("JJ")|Number-Phone|1.581|darwin-2level|5.8.1|darwin|7.9.0|200805140826
1453544|pass|200805|claco@chrislaco.com ("Christopher H. Laco")|Data-Compare|1.19|darwin-thread-multi-2level|5.8.6|darwin|8.0|200805140110
1453574|pass|200805|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.43|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805141023
1454231|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33822|darwin|8.10.0|200805141259
1454795|pass|200805|stro@cpan.org|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200805141727
1455003|pass|200805|stro@cpan.org|Data-Compare|1.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200805141817
1455200|pass|200805|jj@jonallen.info ("JJ")|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.1|darwin|7.9.0|200805141701
1455314|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805141105
1455526|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805141019
1456155|pass|200805|d@0x64.nl ("DEVOGON")|Data-Compare|1.19|i686-linux|5.10.0|linux|2.6.22-3-486|200805142209
1456214|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805142209
1456357|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805142248
1456779|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200805142347
1456839|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805141907
1457182|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805150105
1458610|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805150835
1459230|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200805151214
1460527|pass|200805|stro@cpan.org|Devel-CheckOS|1.43|armv5tejl-linux|5.8.8|linux|2.6.17.14|200805151846
1460623|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805151656
1460959|pass|200805|dillman@ria.buffalo.edu|Data-Compare|1.19|sun4-solaris|5.10.0|solaris|2.9|200805150915
1461199|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805151803
1461793|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805151626
1461874|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805151640
1462583|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805160026
1462813|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805160218
1463177|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805160229
1463182|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805160229
1463203|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805160233
1463474|fail|200805|chris@bingosnet.co.uk|Bryar|3.0|darwin-thread-multi-64int-2level|5.11.0 patch 33824|darwin|8.10.0|200805160418
1463606|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.11.0 patch 33824|darwin|8.10.0|200805160448
1464426|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805160243
1464429|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200805160143
1465183|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805161049
1465966|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161339
1466142|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161335
1466168|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.11.0 patch 33831|netbsd|4.0|200805160737
1466808|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161613
1466853|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161715
1467732|pass|200805|david@cantrell.org.uk|CPAN-FindDependencies|2.0|IP35-irix|5.8.8|irix|6.5|200805162203
1467738|pass|200805|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|IP35-irix|5.8.8|irix|6.5|200805162204
1467769|pass|200805|david@cantrell.org.uk|Class-CanBeA|1.2|IP35-irix|5.8.8|irix|6.5|200805162209
1467784|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|IP35-irix|5.8.8|irix|6.5|200805162211
1467790|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.3|IP35-irix|5.8.8|irix|6.5|200805162212
1467792|pass|200805|david@cantrell.org.uk|Data-Transactional|1.0|IP35-irix|5.8.8|irix|6.5|200805162213
1467796|pass|200805|david@cantrell.org.uk|Devel-CheckLib|0.5|IP35-irix|5.8.8|irix|6.5|200805162213
1467804|pass|200805|david@cantrell.org.uk|Devel-CheckOS|1.43|IP35-irix|5.8.8|irix|6.5|200805162214
1467811|pass|200805|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|IP35-irix|5.8.8|irix|6.5|200805162215
1467815|pass|200805|david@cantrell.org.uk|File-Overwrite|1.0|IP35-irix|5.8.8|irix|6.5|200805162215
1467819|pass|200805|david@cantrell.org.uk|Games-Dice-Advanced|1.1|IP35-irix|5.8.8|irix|6.5|200805162216
1467823|pass|200805|david@cantrell.org.uk|NestedMap|1.0|IP35-irix|5.8.8|irix|6.5|200805162216
1467841|pass|200805|david@cantrell.org.uk|Net-Random|2.0|IP35-irix|5.8.8|irix|6.5|200805162219
1467846|pass|200805|david@cantrell.org.uk|Number-Phone|1.581|IP35-irix|5.8.8|irix|6.5|200805162220
1467856|pass|200805|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|IP35-irix|5.8.8|irix|6.5|200805162221
1467869|pass|200805|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.11.0 patch 33824|darwin|8.10.0|200805162123
1467879|pass|200805|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|IP35-irix|5.8.8|irix|6.5|200805162225
1467884|pass|200805|david@cantrell.org.uk|Statistics-ChiSquare|0.5|IP35-irix|5.8.8|irix|6.5|200805162225
1467885|pass|200805|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|IP35-irix|5.8.8|irix|6.5|200805162226
1467893|pass|200805|david@cantrell.org.uk|Sub-WrapPackages|1.2|IP35-irix|5.8.8|irix|6.5|200805162227
1467896|pass|200805|david@cantrell.org.uk|Tie-Hash-Longest|1.1|IP35-irix|5.8.8|irix|6.5|200805162227
1467900|pass|200805|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|IP35-irix|5.8.8|irix|6.5|200805162228
1467903|pass|200805|david@cantrell.org.uk|Tie-STDOUT|1.03|IP35-irix|5.8.8|irix|6.5|200805162228
1467906|pass|200805|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|IP35-irix|5.8.8|irix|6.5|200805162229
1467908|pass|200805|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|IP35-irix|5.8.8|irix|6.5|200805162229
1467909|pass|200805|david@cantrell.org.uk|XML-Tiny|1.11|IP35-irix|5.8.8|irix|6.5|200805162230
1468355|pass|200805|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805170020
1468495|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|cygwin-thread-multi-64int|5.11.0 patch 33836|cygwin|1.5.25(0.15642)|200805162356
1468894|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805170117
1469173|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.581|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805170251
1469324|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805170336
1469658|pass|200805|jj@jonallen.info ("JJ")|Bryar|3.0|darwin-2level|5.8.1|darwin|7.9.0|200805170606
1470250|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805170326
1470540|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200805170334
1471030|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33831|netbsd|4.0|200805170512
1473276|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33836|cygwin|1.5.25(0.15642)|200805171845
1474419|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805172158
1474499|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805172209
1474669|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171833
1474670|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171833
1474676|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171834
1475128|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805172348
1475216|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.581|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805180005
1475628|pass|200805|g.grigelionis@computer.org|Data-Compare|1.19|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200805172247
1475926|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805180241
1476902|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200805180007
1477233|pass|200805|jj@jonallen.info ("JJ")|File-Find-Rule-Permissions|1.3|darwin-2level|5.8.1|darwin|7.9.0|200805180904
1479601|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805181231
1480382|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200805182014
1480561|pass|200805|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200805190443
1480879|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805181630
1480882|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805180852
1481334|fail|200805|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805181746
1481748|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805182258
1482086|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805190039
1482184|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200805190202
1482186|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200805190202
1482187|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200805190202
1482189|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200805190202
1482190|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200805190203
1482191|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200805190203
1482193|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200805190203
1482194|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200805190204
1482196|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200805190204
1482197|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200805190204
1482284|pass|200805|stro@cpan.org|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200805190430
1482543|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200805190422
1482545|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805190423
1482546|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805190425
1482735|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805190027
1482909|pass|200805|jj@jonallen.info ("JJ")|Data-Transactional|1.0|darwin-2level|5.8.1|darwin|7.9.0|200805190618
1482957|pass|200805|jj@jonallen.info ("JJ")|Tie-STDOUT|1.03|darwin-2level|5.8.1|darwin|7.9.0|200805190640
1483249|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805190900
1483386|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200805191049
1483387|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200805191050
1483454|pass|200805|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.4|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200805191703
1483455|pass|200805|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.4|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200805191703
1483524|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200805191018
1483536|pass|200805|jj@jonallen.info ("JJ")|Data-Hexdumper|1.4|darwin-2level|5.8.1|darwin|7.9.0|200805191021
1483579|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.4.27-3-686|200805191026
1483593|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200805191028
1483622|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200805190431
1483630|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200805190718
1483690|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200805190944
1483703|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|IP35-irix|5.8.8|irix|6.5|200805191145
1484127|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i686-linux|5.6.2|linux|2.4.27-3-686|200805191221
1484190|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805191236
1484331|pass|200805|stro@cpan.org|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200805191506
1484424|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805191331
1485485|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191154
1486143|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805191312
1486218|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805191411
1486232|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805191914
1486326|pass|200805|jj@jonallen.info ("JJ")|Palm-TreoPhoneCallDB|1.1|darwin-2level|5.8.1|darwin|7.9.0|200805191942
1486432|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191502
1486442|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191503
1486855|pass|200805|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191602
1487259|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805192153
1487680|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.6.2|freebsd|6.1-release|200805200038
1488161|pass|200805|feldt@nhn.ou.edu|Data-Compare|1.19|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200805191428
1489311|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805200546
1489810|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.10.0|freebsd|6.1-release|200805200901
1489931|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805200241
1490380|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200805201058
1490505|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805200147
1490736|pass|200805|d@0x64.nl ("DEVOGON")|Data-Hexdumper|1.4|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200805201311
1491016|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805201248
1491047|pass|200805|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200752
1491605|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200852
1492814|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805201725
1493168|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200805201705
1493397|pass|200805|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805201231
1493723|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805201734
1493871|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805201917
1494038|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805202004
1494083|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805202115
1494478|pass|200805|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805201620
1494758|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200805202316
1494873|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805202306
1495109|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805202251
1495311|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805210027
1495328|pass|200805|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805210132
1495828|pass|200805|jj@jonallen.info ("JJ")|Net-Random|2.0|darwin-2level|5.8.1|darwin|7.9.0|200805210434
1496297|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805210724
1497266|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200805211319
1497286|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200805211325
1497634|pass|200805|jj@jonallen.info ("JJ")|Number-Phone-UK-DetailedLocations|1.3|darwin-2level|5.8.1|darwin|7.9.0|200805211454
1497883|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805210933
1497924|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805210936
1498842|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200805212052
1499156|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805212132
1499608|pass|200805|d@0x64.nl (DEVOGON)|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200805220051
1500298|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805220037
1500367|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200805220152
1500524|pass|200805|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805220119
1501526|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805220657
1501834|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200805220845
1502059|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200805220843
1502062|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200805220844
1502068|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200805220845
1502069|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8|linux|2.6.14|200805220845
1502073|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200805220847
1502087|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200805220851
1502088|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200805220852
1504694|pass|200805|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.43|i486-linux-gnu|5.10.0|linux|2.6.24.4|200805222319
1504918|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805222259
1505260|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805230048
1505550|fail|200805|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805230140
1505637|pass|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805230230
1506120|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805230724
1506208|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805230759
1506315|pass|200805|jj@jonallen.info ("JJ")|Games-Dice-Advanced|1.1|darwin-2level|5.8.1|darwin|7.9.0|200805230737
1506856|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231023
1506900|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200805230934
1507112|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805230941
1507301|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231205
1507645|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231316
1508364|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231302
1508500|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200805231410
1509961|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231127
1510117|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200805231809
1510229|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200805231850
1510416|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805231459
1510860|pass|200805|jj@jonallen.info ("JJ")|Sub-WrapPackages|1.2|darwin-2level|5.8.1|darwin|7.9.0|200805232145
1511003|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200805232101
1512245|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805240206
1512408|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200805240348
1513036|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805240848
1513111|pass|200805|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.10.0|freebsd|6.1-release|200805240835
1513937|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241100
1515510|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805241515
1515514|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241615
1515633|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241635
1515743|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241652
1516065|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805241728
1516784|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805241904
1516931|fail|200805|srezic@cpan.org|Bryar|3.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805241940
1517129|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200805241305
1517199|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805241040
1517200|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241039
1517791|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805241538
1517792|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805241538
1518444|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200805250045
1519128|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805250431
1519161|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805250425
1519188|fail|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805250422
1520092|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200805251403
1520295|pass|200805|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805251044
1520358|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200805251605
1520824|pass|200805|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200805251949
1520825|pass|200805|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.10.0|freebsd|6.1-release|200805251949
1521312|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805252129
1521493|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805252213
1521967|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805252315
1522401|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805260053
1522787|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200805260024
1523008|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805260301
1523621|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805260529
1523732|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0 patch 33921|linux|2.4.26|200805260503
1525227|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 33921|darwin|8.10.0|200805261723
1525775|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33921|linux|2.4.26|200805262215
1526175|unknown|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805262000
1526260|pass|200805|stro@cpan.org|Data-Compare|1.19|i686-linux|5.8.8|linux|2.4.27-2-386|200805270227
1527261|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805270739
1527373|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805270839
1528611|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805271252
1528936|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805271348
1529854|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805271519
1529942|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckOS|1.43|darwin-2level|5.8.2|darwin|7.9.0|200805271516
1531701|unknown|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805271600
1531753|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805271604
1531855|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805271618
1532012|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805272231
1533859|pass|200805|jj@jonallen.info ("JJ")|Data-Hexdumper|1.4|darwin-2level|5.8.2|darwin|7.9.0|200805280504
1534264|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200805280623
1534518|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.19|darwin-2level|5.8.2|darwin|7.9.0|200805280702
1534830|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200805280835
1534833|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805280836
1534837|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805280837
1534968|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200805281011
1534970|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200805281011
1534971|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.10.0 patch 33921|darwin|8.10.0|200805280911
1534974|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200805281011
1534976|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200805281012
1534978|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200805281012
1534979|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200805281013
1534981|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.8.8|linux|2.6.14|200805281013
1534982|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200805281013
1534986|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200805281014
1534989|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200805281015
1535216|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.6|sun4-solaris|5.10.0|solaris|2.9|200805281141
1535363|pass|200805|imacat@mail.imacat.idv.tw|Number-Phone|1.6|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200805281807
1535406|pass|200805|imacat@mail.imacat.idv.tw|Number-Phone|1.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200805281814
1535658|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200805281052
1535682|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200805281157
1535806|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805280721
1536198|pass|200805|stro@cpan.org|Number-Phone|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200805281549
1536545|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i686-linux|5.6.2|linux|2.4.27-3-686|200805281657
1537012|pass|200805|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.10.0|freebsd|6.1-release|200805281511
1537078|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 33942|linux|2.4.26|200805281715
1537130|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|IP35-irix|5.8.8|irix|6.5|200805281838
1537263|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200805280739
1537595|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281352
1537697|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805281949
1537706|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.4|sun4-solaris|5.10.0|solaris|2.9|200805282003
1537736|pass|200805|srezic@cpan.org|Number-Phone|1.6|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805281901
1537752|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i686-linux|5.8.8|linux|2.4.27-3-686|200805282041
1537844|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.5.5|freebsd|6.1-release|200805281852
1537953|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200805281321
1538003|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200805282101
1538119|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281438
1538401|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805282009
1539141|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281600
1539258|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281618
1539381|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.19|sun4-solaris|5.10.0|solaris|2.9|200805282235
1540914|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281955
1541207|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290225
1541712|pass|200805|stro@cpan.org|Number-Phone|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200805290428
1541900|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290306
1542288|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290451
1542404|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33942|linux|2.4.26|200805290404
1542411|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805290305
1542913|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290508
1543246|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckOS|1.43|darwin-2level|5.8.3|darwin|7.9.0|200805290544
1543714|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290151
1543716|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290151
1543723|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290152
1544485|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290403
1545530|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Number-Phone|1.581|i686-linux|5.11.0 patch 33939|linux|2.6.24-17-generic|200805291306
1546019|pass|200805|jj@jonallen.info ("JJ")|Number-Phone|1.6|darwin-2level|5.8.3|darwin|7.9.0|200805291421
1546378|fail|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291059
1546701|pass|200805|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200805300056
1546823|fail|200805|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291223
1547548|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291502
1547613|pass|200805|jj@jonallen.info ("JJ")|Number-Phone|1.6|darwin-2level|5.8.2|darwin|7.9.0|200805292012
1547844|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805292232
1547908|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291631
1547923|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291632
1548260|pass|200805|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291807
1549334|pass|200805|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300138
1549677|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300301
1550907|pass|200805|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300326
1551105|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805301000
1551379|pass|200805|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300436
1551554|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805301024
1552861|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300915
1553080|pass|200805|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805301002
1553233|pass|200805|jj@jonallen.info ("JJ")|Data-Hexdumper|1.4|darwin-2level|5.8.3|darwin|7.9.0|200805301529
1553452|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805301607
1553827|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 33947|linux|2.4.26|200805301707
1554311|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.19|darwin-2level|5.8.3|darwin|7.9.0|200805301832
1555790|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200805302248
1556369|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310153
1556382|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310149
1557706|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310526
1558052|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33947|linux|2.4.26|200805310524
1558204|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310629
1558565|pass|200805|jj@jonallen.info ("JJ")|XML-Tiny|1.11|darwin-2level|5.8.2|darwin|7.9.0|200805310703
1559072|na|200805|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805310424
1559315|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311047
1559566|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311146
1559768|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311229
1560142|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311240
1560523|fail|200805|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805310810
1560668|pass|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805310821
1561580|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805311505
1561739|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200805311427
1563597|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311346
1563631|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311949
1563925|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805312016
1564012|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311430
1564013|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311431
1565202|pass|200805|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311633
1565287|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200805311647
1566031|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200805311827
1566359|unknown|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311901
1567194|pass|200806|icerider70@gmail.com ("ICERIDER")|Data-Compare|1.19|i386-linux|5.8.8|linux|2.6.18-53.el5|200806010053
1567352|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010110
1567593|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010135
1567652|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200806010141
1567710|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200806010147
1567753|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200806010153
1569849|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.10.0 patch 33947|cygwin|1.5.25(0.15642)|200806011153
1570315|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806010845
1570728|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010925
1570773|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806010933
1571548|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011106
1571625|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200806011615
1571654|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011119
1572524|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806011401
1572574|fail|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806011421
1574018|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011810
1574265|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011854
1574269|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011854
1574295|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011857
1574313|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806020000
1575798|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806020329
1575812|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020331
1575813|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020331
1575819|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020332
1576599|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020112
1578359|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806021115
1578579|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806021128
1578637|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020544
1578699|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200806021049
1578853|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806020604
1578906|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806021204
1579398|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020705
1579434|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806020709
1580012|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806021223
1581408|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021328
1581689|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200806021910
1581836|pass|200806|jj@jonallen.info ("JJ")|XML-Tiny|1.11|darwin-2level|5.8.3|darwin|7.9.0|200806021935
1581849|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021441
1581858|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021442
1582149|pass|200806|flemming@ipk-gatersleben.de|Data-Compare|1.19|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200806021423
1582419|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806022203
1582436|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021604
1582778|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021631
1583949|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021819
1583985|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021821
1584228|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806030046
1584692|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200806030026
1584702|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021928
1584989|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021949
1585271|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806030216
1585349|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030023
1587211|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030010
1587592|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030118
1589241|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030433
1589570|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030510
1590004|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030604
1590985|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030830
1591364|pass|200806|icerider70@gmail.com ("ICERIDER")|Data-Hexdumper|1.4|i386-linux|5.8.8|linux|2.6.18-53.el5|200806030838
1591564|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200806031308
1592681|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200806031827
1594222|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031907
1594268|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031916
1596106|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806040506
1596136|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040103
1596418|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040139
1596420|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040140
1597040|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040324
1598207|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040538
1599062|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806040715
1599765|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040824
1599815|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040829
1599859|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040835
1600101|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806040852
1602119|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806041622
1602224|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806041822
1602252|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806041824
1602709|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041318
1602894|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806041850
1603182|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041406
1604234|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806041543
1604457|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041611
1604702|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041631
1604828|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806041642
1605376|fail|200806|jj@jonallen.info ("JJ")|CPAN-FindDependencies|2.0|darwin-2level|5.8.1|darwin|7.9.0|200806042232
1606004|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806050018
1606511|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806050051
1606666|pass|200806|icerider70@gmail.com ("ICERIDER")|Number-Phone|1.6|i386-linux|5.8.8|linux|2.6.18-53.el5|200806041827
1607012|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806050157
1607495|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050045
1609203|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris|5.10.0|solaris|2.9|200806050719
1609209|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris|5.10.0|solaris|2.9|200806050720
1609274|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris|5.10.0|solaris|2.9|200806050731
1609546|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050239
1609548|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050239
1609553|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050240
1610500|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050511
1610872|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051117
1612263|pass|200806|rurban@x-ray.at (Reini Urban)|Data-Compare|1.19|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.25(0.15642)|200806051131
1612459|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051454
1613348|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051119
1613350|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051119
1613481|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051131
1614296|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051253
1615657|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051522
1616492|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051650
1616507|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051652
1616957|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051741
1617027|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051749
1617452|pass|200806|david@cantrell.org.uk|XML-Tiny|1.11|IP35-irix-64int|5.8.8|irix|6.5|200806060027
1617506|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051831
1617508|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051832
1617612|pass|200806|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|IP35-irix-64int|5.8.8|irix|6.5|200806060044
1617620|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|IP35-irix-64int|5.8.8|irix|6.5|200806060044
1618807|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060122
1619151|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806060405
1619228|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806060216
1619306|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060225
1620600|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806060107
1622038|pass|200806|stro@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.4.27-2-386|200806060117
1622052|pass|200806|stro@cpan.org|CPU-Emulator-Z80|0.9|i686-linux|5.8.8|linux|2.4.27-2-386|200806060118
1622201|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061127
1623332|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060916
1623843|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806061504
1624056|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806061023
1624257|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806061039
1624325|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806061044
1624400|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806061052
1625162|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061703
1626149|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806061413
1626487|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806061453
1627601|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806062213
1628001|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806061748
1629230|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|sun4-solaris|5.10.0|solaris|2.9|200806070226
1629294|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070036
1629367|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070044
1629841|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070146
1630504|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070320
1631286|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070101
1631562|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070138
1631563|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070138
1632128|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070307
1632247|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070335
1632360|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070354
1633163|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070545
1634343|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070823
1634390|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070827
1634430|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070833
1635103|pass|200806|andy@hexten.net|Data-Compare|1.19|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071437
1635106|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071437
1635216|pass|200806|andy@hexten.net|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071445
1635218|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071445
1635354|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200806071455
1635515|pass|200806|andy@hexten.net|Number-Phone|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071505
1635990|pass|200806|andy@hexten.net|Number-Phone|1.6|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071524
1636361|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806071453
1636805|pass|200806|stro@cpan.org|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.4.27-2-386|200806071730
1637399|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071448
1637953|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071623
1638005|pass|200806|stro@cpan.org|Data-Transactional|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200806072033
1638178|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071700
1639376|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080352
1639451|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080007
1640367|pass|200806|jj@jonallen.info ("JJ")|Devel-CheckLib|0.5|darwin-2level|5.8.2|darwin|7.9.0|200806080749
1641848|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080705
1641850|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080705
1641862|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080707
1642539|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080853
1642540|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080854
1642550|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080855
1643221|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Memory|1.1001|darwin-2level|5.8.3|darwin|7.9.0|200806081536
1643232|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Z80|0.9|darwin-2level|5.8.3|darwin|7.9.0|200806081537
1643318|pass|200806|jj@jonallen.info ("JJ")|Devel-CheckLib|0.5|darwin-2level|5.8.3|darwin|7.9.0|200806081554
1643424|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806081116
1644483|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806081431
1645296|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806081757
1646787|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806090359
1646850|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806090948
1647408|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Memory|1.1001|darwin-2level|5.8.2|darwin|7.9.0|200806091145
1647420|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806091147
1647683|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806090759
1648404|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806090946
1648608|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806091520
1649407|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091208
1649840|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806091325
1650133|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806091233
1650326|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091553
1650336|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091554
1651712|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091940
1652060|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100044
1653013|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806100317
1653402|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100019
1653717|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100117
1654962|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100426
1655173|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100502
1655194|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806100505
1655216|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806100508
1655523|pass|200806|jj@jonallen.info ("JJ")|File-Overwrite|1.0|darwin-2level|5.8.1|darwin|7.9.0|200806101102
1655746|pass|200806|jj@jonallen.info ("JJ")|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.2|darwin|7.9.0|200806101129
1657381|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101014
1657448|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101021
1658997|pass|200806|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806100709
1659175|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101422
1659193|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|2.0|sun4-solaris|5.10.0|solaris|2.9|200806102025
1659368|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.11.0 patch 34031|linux|2.6.18-5-alpha-generic|200806101942
1659428|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101451
1659430|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101451
1660151|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101620
1660908|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806101750
1661054|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101804
1661124|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806102322
1662159|pass|200806|jj@jonallen.info ("JJ")|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.3|darwin|7.9.0|200806110209
1662363|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110130
1662410|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110134
1662449|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110138
1664439|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806110439
1664738|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110545
1665737|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110746
1665964|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110814
1666351|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110922
1666368|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806111417
1666437|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110933
1667846|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806111412
1668478|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806111638
1669283|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.18-8.el5|200806120142
1669424|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806120259
1669539|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120117
1669540|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120117
1669547|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120118
1669897|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806120423
1670596|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120003
1671876|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806120241
1672276|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806120933
1672311|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120336
1672452|fail|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|3.0|sun4-solaris|5.10.0|solaris|2.9|200806120955
1672725|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120443
1673498|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120646
1673962|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806120744
1674081|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120801
1674093|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120802
1674468|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120851
1675737|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121133
1676188|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121226
1676852|pass|200806|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.19|sun4-solaris|5.10.0|solaris|2.8|200806121006
1677239|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806121957
1677784|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806122038
1678451|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121559
1679107|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121659
1680250|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806121900
1680311|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806121912
1680879|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130037
1681135|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130111
1682379|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806130553
1684521|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130829
1684598|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130837
1685330|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806130950
1686169|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131105
1686172|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131105
1686674|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131150
1686957|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131217
1686959|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131218
1687989|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131500
1688343|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131528
1688392|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132133
1688860|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132202
1689558|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806132254
1689563|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806132255
1689568|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806132255
1689573|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806132256
1689579|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806132257
1689623|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806132300
1689644|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806132302
1689666|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806132304
1689729|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806132257
1689733|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200806132259
1689826|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131713
1690007|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806131927
1690730|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132226
1690743|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132221
1690801|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131827
1691351|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131909
1691414|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131913
1691484|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131917
1691805|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806140110
1693311|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200806140324
1693934|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806140325
1693991|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806140331
1694046|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806140339
1694082|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806140343
1694324|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140001
1694392|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806140606
1694436|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806140510
1694616|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140025
1696842|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200806141100
1696860|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806141107
1696874|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806141101
1696950|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806141132
1696955|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806140533
1696965|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806141035
1697410|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140818
1697529|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140837
1697947|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140939
1698033|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140950
1698059|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Z80|1.0|darwin-2level|5.8.3|darwin|7.9.0|200806141453
1698529|pass|200806|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806142300
1698538|pass|200806|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806142301
1699335|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806141722
1699342|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806141723
1699778|pass|200806|stro@cpan.org|XML-Tiny|1.11|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806142055
1700297|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806141629
1700782|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806141752
1701090|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806150036
1702144|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806150218
1702831|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151122
1702859|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151142
1702893|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151145
1703095|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806151047
1703430|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151344
1703470|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806151250
1703635|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|sun4-solaris|5.10.0|solaris|2.9|200806151434
1704329|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151039
1704932|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806151653
1704995|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806151702
1705126|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806151716
1705195|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806151722
1705271|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806151727
1705279|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151230
1705323|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806151733
1706395|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806152106
1706425|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806152058
1706452|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806151921
1707633|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806160103
1707653|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160101
1707663|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160102
1707973|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160144
1708315|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|sun4-solaris|5.10.0|solaris|2.9|200806160502
1708637|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0 patch 34034|darwin|8.10.0|200806160805
1708672|pass|200806|andy@hexten.net|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806160903
1708673|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806160905
1709088|pass|200806|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Z80|1.0|i386-linux|5.8.8|linux|2.6.18-53.el5|200806160648
1709801|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161222
1709934|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806161651
1710635|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161430
1710712|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161446
1711100|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806162138
1711102|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806162139
1711104|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806162139
1711107|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.8.8|linux|2.6.14|200806162139
1711109|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806162139
1711111|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806162140
1711114|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806162140
1711130|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161542
1711213|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161554
1711344|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806162139
1711788|pass|200806|jj@jonallen.info ("JJ")|Number-Phone|1.6|darwin-2level|5.8.1|darwin|7.9.0|200806162225
1712009|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806162253
1712014|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200806162255
1712052|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806162257
1712140|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806162312
1712173|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200806162314
1712180|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806162316
1713291|pass|200806|icerider70@gmail.com ("ICERIDER")|Data-Transactional|1.02|i386-linux|5.8.8|linux|2.6.18-53.el5|200806170216
1713400|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170325
1713550|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170343
1713618|pass|200806|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200806171259
1713683|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170407
1713736|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170019
1713937|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806170606
1713951|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806170608
1714719|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170416
1714825|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200806170905
1714858|pass|200806|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806171643
1714961|pass|200806|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806171700
1714995|pass|200806|stro@cpan.org|Data-Transactional|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806171208
1714999|pass|200806|stro@cpan.org|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806171208
1715113|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170534
1715183|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i686-linux|5.8.8|linux|2.4.27-3-686|200806171047
1715190|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i686-linux|5.6.2|linux|2.4.27-3-686|200806171048
1715208|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i686-linux|5.8.8|linux|2.4.27-3-686|200806171047
1715210|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i686-linux|5.6.2|linux|2.4.27-3-686|200806171048
1715252|pass|200806|jj@jonallen.info ("JJ")|Data-Transactional|1.02|darwin-2level|5.8.2|darwin|7.9.0|200806171056
1715318|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806171105
1715320|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806171105
1715342|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806170509
1715353|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806170510
1715365|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806171106
1715367|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806171107
1715383|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Transactional|1.02|sun4-solaris|5.10.0|solaris|2.9|200806171214
1715448|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806171059
1715465|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806171101
1715871|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170756
1716180|pass|200806|david@cantrell.org.uk|Data-Compare|1.19|IP35-irix-64int|5.8.8|irix|6.5|200806171455
1716184|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|IP35-irix-64int|5.8.8|irix|6.5|200806171455
1716186|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|IP35-irix-64int|5.8.8|irix|6.5|200806171455
1716276|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170912
1716633|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806171400
1716636|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806171400
1716688|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171006
1716761|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806170909
1716770|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806170910
1716945|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806171504
1717130|pass|200806|robertl@apnic.net ("Robert Loomans")|CPAN-FindDependencies|2.0|darwin-2level|5.8.8|darwin|9.2.2|200806171530
1717223|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.03|sun4-solaris|5.10.0|solaris|2.9|200806171701
1717464|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806171732
1718386|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171319
1718665|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806171931
1719000|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806171958
1719112|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171420
1719207|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806172032
1719292|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806171946
1719316|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806171948
1719348|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806171950
1719382|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806171952
1719408|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806171954
1719445|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806171956
1719472|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806171958
1719487|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806172000
1719502|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806172001
1719510|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.6.2|freebsd|6.1-release|200806172058
1719534|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806172004
1719991|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806172058
1720006|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806172059
1720028|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806172101
1720046|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806172202
1720049|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806172103
1720057|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806172104
1720065|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806172105
1720087|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806172107
1720104|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806172108
1720126|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806172110
1720153|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806172111
1720412|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806172156
1720585|na|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.5.5|freebsd|6.1-release|200806172255
1720855|pass|200806|david@cantrell.org.uk|Devel-CheckOS|1.43|IP35-irix-64int|5.8.8|irix|6.5|200806172325
1721186|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806180001
1721360|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171817
1721943|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806172057
1722051|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806180106
1722175|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171926
1722205|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.10.0|freebsd|6.1-release|200806180128
1722423|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200806180029
1722727|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806180144
1722737|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200806180244
1723607|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180258
1723848|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806180539
1723888|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180348
1725628|pass|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806180837
1726053|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806180944
1726116|na|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.5.5|freebsd|6.1-release|200806180953
1726167|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806180942
1726246|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806180959
1726885|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180509
1727011|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180517
1727998|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806181118
1728032|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806180257
1728632|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806181255
1729448|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180919
1729848|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180951
1729855|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180950
1730104|pass|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.6.2|freebsd|6.1-release|200806181532
1730602|pass|200806|stro@cpan.org|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.4.27-2-386|200806181452
1730977|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181129
1731015|pass|200806|stro@cpan.org|File-Overwrite|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200806181535
1732000|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|sun4-solaris|5.10.0|solaris|2.9|200806181923
1732178|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181340
1733402|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181558
1733445|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181602
1733518|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181606
1735264|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806190000
1735338|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806181844
1735339|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806181844
1736559|pass|200806|stro@cpan.org|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806190450
1736819|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190232
1737043|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190418
1737055|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190419
1737077|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190421
1737080|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190421
1737088|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190422
1737193|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190352
1737404|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190037
1737459|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190048
1737510|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190053
1737535|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190058
1738004|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190237
1738286|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806190841
1739632|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190843
1739702|pass|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806191453
1740244|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191013
1740729|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806191653
1741329|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806191749
1741735|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191338
1741954|pass|200806|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806192004
1742423|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192013
1742430|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192014
1742448|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192017
1742449|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192017
1742455|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192019
1742894|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191719
1743652|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191852
1744687|pass|200806|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.6.2|freebsd|6.1-release|200806200318
1744728|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200133
1745499|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200427
1745508|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200428
1745580|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200338
1745643|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200444
1745655|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200446
1745714|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200355
1746263|na|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200113
1746585|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200154
1747063|pass|200806|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200848
1747364|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806200933
1747482|pass|200806|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.10.0|freebsd|6.1-release|200806200954
1748185|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806201012
1748835|pass|200806|srezic@cpan.org|Net-Random|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806201319
1749601|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200926
1749788|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201454
1749808|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201455
1749834|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201500
1749849|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201502
1749881|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201013
1750206|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201137
1750249|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806201605
1750719|na|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201458
1751000|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0 patch 34065|linux|2.4.26|200806202127
1752441|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806210053
1752510|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210004
1752784|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210050
1753897|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210326
1753972|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210338
1754219|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210029
1755355|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210532
1755663|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210653
1757045|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211146
1757339|na|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211228
1757376|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211233
1757418|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211240
1758182|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806211908
1758185|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806211908
1758189|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806211910
1759401|na|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220030
1759456|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220039
1759671|pass|200806|rjbs@cpan.org|Data-Compare|1.19|darwin-2level|5.10.0|darwin|9.1.0|200806220149
1759781|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806220346
1759782|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806220347
1759787|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806220348
1760117|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806220459
1760119|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806220459
1760130|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806220500
1761272|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220437
1761507|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220540
1761508|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220540
1762012|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220748
1762046|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806221116
1762754|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221051
1763690|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.18-5-686|200806221802
1764682|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221424
1765012|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221441
1765096|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221446
1765124|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221448
1765127|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221448
1765208|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221453
1765564|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806222048
1765798|pass|200806|andy@hexten.net|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806222033
1766324|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221605
1766480|pass|200806|andy@hexten.net|Data-Transactional|1.02|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806222113
1767765|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221755
1767873|pass|200806|stro@cpan.org|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.4.27-2-386|200806230109
1768010|pass|200806|stro@cpan.org|Data-Compare|1.19|i686-linux|5.10.0|linux|2.4.27-2-386|200806230128
1768606|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221943
1768644|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221946
1768673|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221950
1769631|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806230341
1770114|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806230642
1770299|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806230724
1770586|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230204
1770609|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230207
1770610|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230207
1770857|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230233
1770858|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230233
1770886|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806230728
1770959|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230246
1771753|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230450
1772060|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230550
1772065|pass|200806|stro@cpan.org|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200806231141
1772583|pass|200806|srezic@cpan.org|Devel-CheckLib|0.5|i486-linux-gnu|5.8.8|linux|2.6.22.10|200806231259
1774401|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231217
1775143|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231356
1775988|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806232121
1775991|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806232121
1776015|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806232123
1776860|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231816
1777468|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200806240003
1777470|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200806240005
1777653|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806240214
1777657|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806240214
1777673|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806240116
1777675|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806240116
1777677|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806240217
1777685|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806240118
1777743|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240127
1778008|pass|200806|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200806240417
1778545|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240331
1779184|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240047
1779573|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240137
1780615|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240409
1780753|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240429
1781189|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240524
1782392|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240811
1782638|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240847
1782872|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240926
1783244|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806241025
1783498|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806241059
1785150|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806241944
1785597|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250244
1786349|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806250134
1786732|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806250710
1786739|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|2.0|sun4-solaris|5.10.0|solaris|2.9|200806250908
1786870|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806250724
1787188|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806250740
1787558|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806250647
1787890|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806250520
1788301|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250554
1788304|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250554
1789082|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806251123
1789201|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250741
1790185|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250949
1790585|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806251642
1790586|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806251642
1790589|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806251642
1790595|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.8.8|linux|2.6.14|200806251642
1790599|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806251643
1790852|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806251642
1790854|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806251643
1790858|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806251643
1791331|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806251204
1791378|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806251207
1791409|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806251211
1793688|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806252241
1793705|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806252246
1793794|fail|200806|srezic@cpan.org|DBIx-Class-SingletonRows|0.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806252323
1795338|pass|200806|danl@metrex.net|Data-Compare|1.19|i586-linux-thread-multi|5.10.0|linux|2.6.25|200806260023
1795508|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806260948
1795580|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806260400
1795706|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261019
1796391|pass|200806|stro@cpan.org|Data-Compare|1.19|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806260455
1796581|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd|5.11.0 patch 34085|openbsd|4.1|200806260621
1796835|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806260800
1797399|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261514
1797468|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261456
1797741|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261530
1798310|fail|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806261650
1798878|fail|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806261706
1799261|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806261934
1799264|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806261934
1799266|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806261934
1799293|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261937
1799302|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806261938
1799396|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|i686-linux|5.8.8|linux|2.4.27-3-686|200806261703
1799427|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806261935
1799462|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806261936
1799463|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806261937
1799469|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.8.8|linux|2.6.14|200806261936
1800691|pass|200806|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806261801
1801186|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200806261850
1801665|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270028
1802752|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|DBIx-Class-SingletonRows|0.1|sun4-solaris|5.10.0|solaris|2.9|200806270638
1802983|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270136
1802984|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270136
1803070|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|darwin-2level|5.8.8|darwin|8.10.1|200806270744
1803075|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|darwin-2level|5.8.8|darwin|8.10.1|200806270744
1803651|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270316
1803652|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270316
1803824|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270355
1804043|pass|200806|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806270937
1804246|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270522
1804400|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|DBIx-Class-SingletonRows|0.11|sun4-solaris|5.10.0|solaris|2.9|200806271202
1804487|fail|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806271132
1804540|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806270546
1804665|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|sun4-solaris|5.10.0|solaris|2.9|200806271315
1804813|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270753
1805948|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806271358
1806046|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271150
1806122|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200806271432
1806936|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|IP35-irix-64int|5.8.8|irix|6.5|200806272105
1806945|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271506
1807304|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806271548
1807966|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806271729
1808105|pass|200806|stro@cpan.org|Devel-CheckOS|1.43|armv5tejl-linux|5.10.0|linux|2.6.17.14|200806280102
1809253|fail|200806|icerider70@gmail.com ("ICERIDER")|DBIx-Class-SingletonRows|0.11|i386-linux|5.8.8|linux|2.6.18-53.el5|200806280206
1810869|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280426
1810950|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280434
1813714|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281155
1813849|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806281343
1814361|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281300
1814366|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281300
1814639|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806281931
1815011|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806282015
1815274|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806282048
1815862|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281540
1815886|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806282010
1815954|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200806281547
1815995|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|IP35-irix-64int|5.8.8|irix|6.5|200806282149
1817322|pass|200806|stro@cpan.org|Palm-SMS|0.02|i686-linux|5.8.8|linux|2.4.27-2-386|200806290122
1817742|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281911
1817860|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806290032
1818177|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806290200
1818908|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290106
1820182|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806290329
1820329|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806290007
1820383|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806290014
1820882|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Games-Dice-Advanced|1.1|sun4-solaris|5.10.0|solaris|2.9|200806290715
1821606|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806290644
1822116|pass|200806|andy@hexten.net|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806290951
1822309|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290530
1822949|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290755
1823789|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200806291145
1824422|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sub-WrapPackages|1.2|sun4-solaris|5.10.0|solaris|2.9|200806291954
1824425|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200806291355
1824977|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200806291536
1826691|pass|200806|andy@hexten.net|Devel-CheckLib|0.5|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806300051
1826968|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300042
1827379|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300225
1828898|pass|200806|stro@cpan.org|XML-Tiny|1.11|armv5tejl-linux|5.10.0|linux|2.6.17.14|200806301547
1829462|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301028
1830918|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301443
1830919|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200806301443
1831419|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301631
1831425|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200806301631
1831539|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301648
1832513|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806302346
1833685|pass|200807|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807010141
1833952|pass|200807|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010218
1834202|pass|200807|stro@cpan.org|Class-CanBeA|1.2|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807011305
1834458|pass|200807|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010357
1836068|pass|200807|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807010526
1837205|fail|200807|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010935
1837251|pass|200807|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010950
1839694|pass|200807|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807011613
1839907|pass|200807|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807011646
1840333|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807011737
1840334|pass|200807|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200807011737
1840914|pass|200807|stro@cpan.org|Devel-CheckLib|0.5|os2|5.10.0|os2|2.45|200807020331
1842188|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807021131
1842724|pass|200807|stro@cpan.org|XML-DoubleEncodedEntities|1.0|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807021706
1842760|pass|200807|stro@cpan.org|XML-DoubleEncodedEntities|1.0|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807021715
1842991|pass|200807|stro@cpan.org|Devel-CheckOS|1.43|os2|5.10.0|os2|2.45|200807021803
1843586|pass|200807|andy@hexten.net|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200807022017
1844679|pass|200807|stro@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807030836
1845117|pass|200807|stro@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031253
1845123|pass|200807|stro@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031258
1845746|pass|200807|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200807030249
1847050|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807030911
1847135|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807030919
1847182|unknown|200807|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200807031854
1847204|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Overwrite|1.0|sun4-solaris|5.10.0|solaris|2.9|200807032050
1849403|unknown|200807|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200807032210
1849983|pass|200807|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807031927
1850429|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040048
1851555|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Class-CanBeA|1.2|sun4-solaris|5.10.0|solaris|2.9|200807040710
1852008|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|darwin-2level|5.10.0|darwin|8.11.1|200807040854
1852380|pass|200807|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040421
1852837|pass|200807|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040634
1857100|pass|200807|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050239
1857594|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050403
1857595|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050403
1857796|pass|200807|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050437
1858026|pass|200807|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.6.2|freebsd|6.1-release|200807051120
1858459|pass|200807|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050641
1858671|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050727
1860147|pass|200807|stro@cpan.org|Data-Transactional|1.0|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807051639
1864049|pass|200807|sanko@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.11.0 patch 34101|MSWin32|5.1|200807051408
1865845|pass|200807|postmaster@TOMXP.spectra-direct.com|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200807071710
1870236|pass|200807|mgardner@usatech.com|Data-Compare|1.19|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200807081438
1870237|pass|200807|sanko@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.11.0 patch 34107|MSWin32|5.1|200807080816
1870763|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090026
1871046|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090005
1871077|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090000
1871298|pass|200807|bob@randomness.org.uk ("bob walker")|Data-Compare|1.19|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200807090112
1871307|pass|200807|bob@randomness.org.uk ("bob walker")|Data-Compare|1.19|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200807090114
1871711|fail|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-SMS|0.02|sun4-solaris|5.10.0|solaris|2.9|200807090504
1871761|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090518
1871953|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|sun4-solaris|5.10.0|solaris|2.9|200807090630
1874988|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807100101
1875310|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807100240
1877308|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-64int|5.11.0 patch 34114|openbsd|4.1|200807101527
1879484|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200807110816
1879866|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|sun4-solaris|5.10.0|solaris|2.9|200807111104
1880013|pass|200807|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200807111811
1880015|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200807111209
1880023|pass|200807|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200807111815
1880186|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200807111238
1880257|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200807111333
1880431|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200807111434
1880469|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34117|openbsd|4.3|200807111214
1880550|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200807111538
1880567|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200807110851
1880653|pass|200807|david@cantrell.org.uk|Data-Hexdumper|1.4|IP35-irix-64int|5.8.8|irix|6.5|200807111613
1880661|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|IP35-irix-64int|5.8.8|irix|6.5|200807111614
1880688|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200807110844
1880690|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200807110844
1880696|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200807111521
1880888|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200807110924
1880913|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200807111604
1881263|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807111611
1881373|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807111700
1881381|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807111706
1881526|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200807111839
1881589|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|sun4-solaris|5.10.0|solaris|2.9|200807112102
1881597|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807112010
1881631|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807112030
1881979|pass|200807|pjacklam@online.no|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.25(0.15642)|200807120016
1882976|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807120643
1883227|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807121146
1883249|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807121153
1883279|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807121206
1883513|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807121315
1883722|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807121410
1883742|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807121416
1884017|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807121625
1884092|pass|200807|sanko@cpan.org|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.11.0 patch 34116|MSWin32|5.1|200807120352
1884116|fail|200807|sanko@cpan.org|Palm-Treo680MessagesDB|1.0|MSWin32-x86-multi-thread|5.11.0 patch 34116|MSWin32|5.1|200807120358
1884331|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807121639
1884411|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807121621
1884991|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807121957
1885642|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807122151
1886018|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807122246
1886250|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807130030
1886715|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807130209
1887496|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807130705
1887713|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807131014
1887720|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807131017
1888851|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807131751
1888875|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807131803
1889291|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807132039
1889768|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807140010
1889801|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807140028
1889814|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807140047
1889836|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807140059
1889837|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807140101
1889858|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807140115
1890161|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807140411
1891058|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807141140
1891574|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807141638
1891600|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807141652
1891730|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Longest|1.1|sun4-solaris|5.10.0|solaris|2.9|200807141846
1891733|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-ChiSquare|0.5|sun4-solaris|5.10.0|solaris|2.9|200807141847
1891774|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807141758
1891813|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807141811
1893246|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807150513
1893480|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34134|openbsd|4.2|200807150707
1893723|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807150928
1893919|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807151108
1894000|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807151145
1894908|pass|200807|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.10.0|freebsd|6.1-release|200807151806
1897024|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|NestedMap|1.0|sun4-solaris|5.10.0|solaris|2.9|200807160638
1897245|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160506
1897251|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160507
1897276|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160516
1897283|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160517
1897439|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807160837
1897771|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160715
1897774|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160715
1897831|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807160906
1898169|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161054
1899447|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34134|openbsd|4.2|200807161430
1899642|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161619
1900007|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161741
1900014|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161731
1901024|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807161945
1901200|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807162036
1901212|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807162227
1901431|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807162323
1901474|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200807162328
1901477|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807170035
1901489|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807162333
1901499|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807162334
1901510|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807162339
1901513|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807162341
1901520|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807162342
1901535|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807162347
1901566|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807162352
1901576|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200807162358
1902813|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807170739
1902859|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807170747
1903090|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807170853
1904723|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-ld|5.11.0 patch 34150|linux|2.6.24.5-smp|200807171449
1904735|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-ld|5.11.0 patch 34150|linux|2.6.24.5-smp|200807171453
1904820|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-64int|5.11.0 patch 34150|netbsd|4.0|200807171506
1904869|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-64int|5.11.0 patch 34150|netbsd|4.0|200807171523
1904936|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34150|linux|2.6.24.5-smp|200807171529
1905990|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807180620
1907801|unknown|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Licence|1.0|sun4-solaris|5.10.0|solaris|2.9|200807181658
1909274|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807182328
1909836|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34151|freebsd|7.0-release|200807190141
1909974|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807190317
1910043|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34151|openbsd|4.3|200807190545
1911641|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807191421
1912343|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807191741
1914094|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807192239
1915717|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807200325
1916521|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807200940
1916732|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807201023
1916950|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807201014
1917372|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807201134
1917468|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807201154
1918191|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807201617
1918224|unknown|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Pony|1.1.2|sun4-solaris|5.10.0|solaris|2.9|200807201729
1918463|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|sun4-solaris|5.10.0|solaris|2.9|200807201834
1918665|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|sun4-solaris|5.10.0|solaris|2.9|200807201949
1918745|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807201910
1918958|pass|200807|chris@bingosnet.co.uk|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807202018
1918963|pass|200807|chris@bingosnet.co.uk|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807202019
1918968|pass|200807|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807202020
1919527|pass|200807|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210026
1919530|pass|200807|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210028
1919544|pass|200807|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210034
1919550|pass|200807|chris@bingosnet.co.uk|Class-CanBeA|1.2|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210037
1919562|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210043
1919563|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210044
1919567|pass|200807|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210047
1919574|pass|200807|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210049
1919576|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210051
1919615|pass|200807|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210107
1919619|pass|200807|chris@bingosnet.co.uk|File-Overwrite|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210109
1919621|pass|200807|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210110
1919622|pass|200807|chris@bingosnet.co.uk|NestedMap|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210111
1919632|pass|200807|chris@bingosnet.co.uk|Net-Random|2.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210118
1919642|pass|200807|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210120
1919662|pass|200807|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210132
1919679|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210141
1919693|pass|200807|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210154
1919695|pass|200807|chris@bingosnet.co.uk|Statistics-ChiSquare|0.5|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210155
1919696|pass|200807|chris@bingosnet.co.uk|Statistics-SerialCorrelation|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210155
1919699|pass|200807|chris@bingosnet.co.uk|Sub-WrapPackages|1.2|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210156
1919701|pass|200807|chris@bingosnet.co.uk|Tie-Hash-Longest|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210157
1919703|pass|200807|chris@bingosnet.co.uk|Tie-Hash-Rank|1.0.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210158
1919707|pass|200807|chris@bingosnet.co.uk|Tie-STDOUT|1.03|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210159
1919712|pass|200807|chris@bingosnet.co.uk|Tie-Scalar-Decay|1.1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210200
1919717|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210202
1919719|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210201
1920793|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807210841
1920887|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807210931
1921536|pass|200807|andy@hexten.net|Data-Compare|1.19|i86pc-solaris-thread-multi|5.10.0|solaris|2.11|200807211405
1922183|fail|200807|stro@cpan.org|Bryar|3.0|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807211946
1924105|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34151|linux|2.6.16.38|200807220155
1924198|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200807220244
1924342|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200807220346
1926834|pass|200807|stro@cpan.org|Data-Hexdumper|1.4|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807221251
1926928|pass|200807|stro@cpan.org|Data-Compare|1.19|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807221609
1927030|pass|200807|stro@cpan.org|Data-Hexdumper|1.4|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807221523
1927087|pass|200807|stro@cpan.org|Data-Compare|1.19|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807221639
1927327|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807222103
1927555|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807222147
1929231|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807230207
1929554|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807230416
1929713|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807230450
1930126|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34153|netbsd|4.0|200807230525
1930619|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200807230704
1930745|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-64int|5.11.0 patch 34153|openbsd|4.1|200807230724
1930792|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200807230733
1931384|pass|200807|stro@cpan.org|Tie-Hash-Longest|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200807230824
1932393|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807231418
1932727|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807231536
1938533|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200807242216
1938537|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200807242218
1938542|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200807242218
1938547|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200807242219
1939381|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi|5.11.0 patch 34156|freebsd|6.2-release|200807242148
1939657|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807250026
1939754|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807250038
1939827|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807250047
1939856|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807250056
1939913|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807250107
1939928|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807250109
1939959|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807250115
1939961|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807250116
1940011|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807250126
1940530|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807250139
1940570|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200807250150
1940772|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807250514
1940799|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.11.0 patch 34156|freebsd|7.0-release|200807250125
1941869|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807251244
1941928|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807251315
1942156|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807251421
1943494|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200807252350
1943498|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200807260004
1943503|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200807260004
1943506|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.8.8|linux|2.6.14|200807260005
1943508|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200807260005
1943509|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200807260006
1943511|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200807260006
1943532|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200807260004
1943533|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200807260003
1943639|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807260040
1944678|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807260447
1944791|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807260424
1945089|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807260451
1945112|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807260601
1945113|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807260602
1945116|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807260603
1945635|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807260730
1945982|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807260851
1946153|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807260936
1946430|pass|200807|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|IP35-irix-64int|5.8.8|irix|6.5|200807261226
1946495|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807261047
1946586|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807261115
1946745|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807261603
1946879|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807261633
1947584|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i686-linux|5.6.2|linux|2.4.27-3-686|200807261910
1947597|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i686-linux|5.8.8|linux|2.4.27-3-686|200807261915
1947656|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200807261930
1947672|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200807261935
1947857|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200807261455
1947861|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200807261956
1948026|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|IP35-irix-64int|5.8.8|irix|6.5|200807262244
1948071|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807262300
1948183|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200807262320
1949069|pass|200807|stro@cpan.org|Net-Random|2.0|i686-linux|5.10.0|linux|2.4.27-2-386|200807270954
1950303|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807271731
1950420|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200807271749
1950511|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807271712
1950562|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807271826
1950606|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34160|openbsd|4.2|200807271738
1950656|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200807271846
1950912|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807271901
1950950|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807271910
1950981|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34160|openbsd|4.2|200807271922
1951060|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807271959
1952306|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200807280602
1952445|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200807280711
1952552|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807280659
1952593|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807280707
1952613|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807280712
1952631|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807280716
1952647|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807280721
1952670|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807280726
1952689|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807280730
1953802|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34160|openbsd|4.2|200807281343
1953922|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200807281437
1953930|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807281439
1954513|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807281812
1954596|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807281904
1954667|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807282035
1955416|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807282252
1955426|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807282255
1955429|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200807282358
1955430|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200807282359
1955431|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200807282359
1955432|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200807282359
1955435|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200807282359
1955436|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807282257
1955437|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200807290000
1955439|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200807290000
1955441|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200807290000
1955445|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807282259
1955448|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807282301
1955452|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807282303
1955457|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807282305
1955474|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807282307
1955483|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200807290007
1955880|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807290246
1955968|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200807290338
1955990|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807290252
1955999|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807290256
1956268|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807290547
1956270|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807290547
1956271|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807290548
1956531|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200807290813
1956557|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807290823
1956909|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807290951
1956961|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200807290901
1957223|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807291103
1957283|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807291013
1957288|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807291014
1957376|pass|200807|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200807291735
1957406|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200807291045
1957407|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200807291045
1957413|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200807291009
1957470|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200807290505
1957471|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200807291005
1957476|pass|200807|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200807291808
1957513|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807291115
1957650|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|IP35-irix-64int|5.8.8|irix|6.5|200807291312
1957671|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200807291216
1958030|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807291444
1958035|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807291445
1958203|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807291541
1958905|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807291925
1958907|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807291926
1958966|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807291953
1959723|pass|200807|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200807300117
1959756|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807300048
1959797|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807300109
1959916|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807300151
1959917|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200807300151
1959918|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807300152
1959919|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807300152
1959921|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807300153
1959922|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807300153
1959923|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807300153
1959924|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807300154
1959925|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807300154
1959926|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200807300154
1960114|pass|200807|jeff@zeroclue.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-2level|5.10.0|darwin|9.2.0|200807300151
1960233|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807300451
1960358|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807300435
1960665|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807300600
1960702|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807300611
1960894|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807300708
1961785|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807301059
1961787|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807301059
1962019|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807301409
1962097|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807301357
1962234|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807301233
1962240|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807301234
1962428|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807301314
1962664|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807301544
1962973|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807301640
1963162|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807301740
1963239|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807301538
1963241|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807301539
1963368|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807301800
1963405|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807301617
1964343|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807302232
1964347|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807302232
1964707|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807310048
1964708|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807310049
1964821|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807310133
1965204|pass|200807|stro@cpan.org|Sort-MultipleFields|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200807310506
1965814|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807310624
1966158|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807310826
1966586|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807311051
1966756|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807311155
1966845|pass|200807|stro@cpan.org|Number-Phone|1.6|i686-linux|5.10.0|linux|2.4.27-2-386|200807311319
1966860|pass|200807|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.4.27-2-386|200807311323
1967293|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807311603
1967574|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807311835
1967656|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807311918
1967811|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200807312059
1967829|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807312046
1968131|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200807312348
1968132|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200807312348
1968342|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808010101
1968348|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808010102
1968695|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010330
1968845|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808010255
1968847|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808010255
1968849|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808010256
1968851|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808010256
1968853|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808010256
1968854|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808010257
1968856|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808010257
1968858|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808010257
1968859|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808010258
1968861|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808010258
1969122|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010531
1969492|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010701
1969982|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010854
1971018|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808011258
1971041|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200808011303
1971045|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200808011305
1971441|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808011451
1971445|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808011452
1971643|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200808011530
1972120|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808011756
1972121|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808011757
1972217|pass|200808|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200808011840
1972481|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808011953
1972895|pass|200808|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808012154
1973809|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808020555
1974358|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808020821
1975026|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808021053
1975119|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808021219
1975137|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808021124
1975297|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34169|linux|2.6.16.38|200808021204
1976192|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808021702
1976242|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.11.0 patch 34169|linux|2.6.16.38|200808021716
1976243|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808021717
1976693|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808022003
1976706|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808022006
1976985|pass|200808|conrad@fringehead.org|XML-Tiny|1.11|darwin-2level|5.10.0|darwin|9.3.0|200808021334
1976994|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808022237
1977069|pass|200808|stro@cpan.org|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.4.27-2-386|200808022054
1977074|pass|200808|stro@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.4.27-2-386|200808022055
1977127|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808022314
1977128|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808022212
1977200|pass|200808|conrad@fringehead.org|XML-Tiny|1.11|i686-linux-thread-multi|5.8.8|linux|2.6.15.1|200808021437
1977216|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808022336
1978598|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808030831
1978664|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808030849
1978893|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-ld|5.11.0 patch 34169|linux|2.6.16.38|200808031003
1978994|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808031131
1979426|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808031308
1979701|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808031444
1980396|pass|200808|dpavlin@rot13.org ((Dobrica Pavlinusic))|Data-Compare|1.19|i486-linux-gnu|5.10.0|linux|2.6.25.10|200808032133
1980946|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34169|freebsd|7.0-release|200808032245
1981115|na|200808|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200808040140
1981178|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200808040110
1981369|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200808040136
1981852|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34169|openbsd|4.1|200808040345
1981982|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34169|openbsd|4.1|200808040454
1981986|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-thread-multi-64int|5.11.0 patch 34169|freebsd|7.0-release|200808040324
1982322|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808040829
1985957|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200808050827
1985958|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200808050827
1986173|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34170|freebsd|6.2-release|200808050950
1986927|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200808051559
1987031|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34170|linux|2.6.24-19-generic|200808051640
1988273|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34161|linux|2.6.24-19-generic|200808052200
1990402|pass|200808|yanick@cpan.org ("Yanick Champoux")|Data-Compare|1.19|i686-linux|5.10.0|linux|2.6.22-gentoo-r2enkidu|200808060050
1993045|pass|200808|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808061711
1993209|pass|200808|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808061710
1994194|pass|200808|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808062152
1994372|pass|200808|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808062154
1994469|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.5.5|freebsd|6.1-release|200808062231
1994636|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34174|linux|2.6.21.5-smp|200808062134
1996505|pass|200808|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808070918
1996526|pass|200808|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808070921
1996771|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808071017
1997654|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.6.2|freebsd|6.1-release|200808071253
1999527|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200808071845
2000199|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.11.0 patch 34175|dragonfly|2.0.0-release|200808072155
2000255|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808072227
2001810|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.5.5|freebsd|6.1-release|200808080804
2001827|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808080830
2002243|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808080953
2002433|pass|200808|vpit@cpan.org|Devel-CheckLib|0.5|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200808080127
2002615|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200808081055
2002850|pass|200808|vpit@cpan.org|Devel-CheckOS|1.43|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200808080125
2003523|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808081350
2003686|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.6.2|freebsd|6.1-release|200808081425
2004412|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808081652
2004545|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808081722
2004701|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808081737
2005947|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808082105
2006352|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808082202
2007141|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808090233
2008766|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808091214
2009821|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808091353
2010349|pass|200808|stro@cpan.org|Sort-MultipleFields|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200808091937
2011846|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|i86pc-solaris|5.10.0|solaris|2.11|200808100230
2012066|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris|5.10.0|solaris|2.11|200808100338
2012237|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris|5.10.0|solaris|2.11|200808100415
2012452|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris|5.10.0|solaris|2.11|200808100701
2014850|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34192|netbsd|4.0|200808110207
2016490|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808111356
2016902|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808111555
2017203|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808111703
2017416|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris|5.10.0|solaris|2.11|200808111825
2017451|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.19|i86pc-solaris|5.10.0|solaris|2.11|200808111834
2018259|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|DBIx-Class-SingletonRows|0.11|i86pc-solaris|5.10.0|solaris|2.11|200808120046
2018882|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris|5.10.0|solaris|2.11|200808120433
2019240|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34201|freebsd|7.0-release|200808120403
2019367|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34197|linux|2.6.24.5-smp|200808120651
2020015|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808120710
2021100|pass|200808|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24.3|200808120312
2021633|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808121726
2021647|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808121727
2023871|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808131503
2027286|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34203|solaris|2.10|200808141452
2028942|pass|200808|brooks-cpan-tester@deseret.com|Devel-CheckOS|1.43|x86_64-linux|5.8.8|linux|2.6.9-023stab044.4-smp|200808141358
2029012|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.6.24.3|200808150140
2029368|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151003
2029752|pass|200808|stro@cpan.org|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.4.27-2-386|200808151016
2029819|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151231
2029928|pass|200808|stro@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.4.27-2-386|200808151101
2029960|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151305
2030081|pass|200808|stro@cpan.org|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.4.27-2-386|200808151133
2030248|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151443
2032178|pass|200808|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.6.24.3|200808150705
2032940|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200808160849
2035176|pass|200808|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808161754
2035227|pass|200808|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.8|linux|2.6.24.3|200808161251
2035519|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris-64int|5.10.0|solaris|2.11|200808161324
2035534|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.19|i86pc-solaris-64int|5.10.0|solaris|2.11|200808161341
2037202|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.10.0|freebsd|6.1-release|200808170827
2037266|pass|200808|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808170900
2037620|pass|200808|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808171001
2038600|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808171540
2038755|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808171541
2038973|pass|200808|rafl@debian.org|Devel-CheckLib|0.5|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200808171641
2039107|pass|200808|rafl@debian.org|Devel-CheckOS|1.43|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200808171644
2040114|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808172114
2040460|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808172321
2041167|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34204|linux|2.6.16.38|200808180203
2041799|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808180838
2042345|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181112
2042373|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181115
2042962|pass|200808|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.8|linux|2.6.24.3|200808180651
2043275|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.19|i686-linux|5.8.8|linux|2.6.24.3|200808180740
2043444|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181402
2044098|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181544
2044616|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181713
2045471|pass|200808|srezic@cpan.org|Number-Phone|1.6|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808181711
2045989|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181920
2046283|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808181934
2046651|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.10.0|freebsd|6.1-release|200808181958
2047415|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808182212
2048317|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808190533
2048368|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808190548
2048381|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808190550
2048399|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808190553
2048411|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808190557
2048450|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808190614
2048486|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808190632
2048568|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808190645
2048588|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808190658
2048980|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200808182153
2049353|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.6|i86pc-solaris-64int|5.10.0|solaris|2.11|200808190300
2049726|pass|200808|rafl@debian.org|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200808182146
2051551|pass|200808|rafl@debian.org|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200808191418
2051862|pass|200808|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.6.2|linux|2.6.24.3|200808190925
2052618|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808191826
2053168|pass|200808|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808191826
2053301|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808191826
2053463|pass|200808|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808191826
2054987|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200808192316
2055631|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808200539
2055923|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808200749
2055983|pass|200808|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808200749
2057195|pass|200808|shlomif@cpan.org|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200808192108
2057250|pass|200808|rick@jrmyers.net ("Rick Myers")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.8|linux|2.6.24.3|200808200655
2057810|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200808201411
2059653|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808202236
2060673|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808210423
2060880|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808210513
2061033|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200808210107
2061156|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200808210137
2061484|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808210739
2061621|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808210810
2063986|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808211357
2064102|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808211516
2064510|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200808211743
2064513|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200808211743
2064515|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200808211743
2064516|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200808211744
2064523|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.8.8|linux|2.6.14|200808211744
2064530|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200808211746
2064533|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200808211746
2064554|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0 patch 34161|netbsd|4.0|200808211645
2064567|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200808211745
2064936|pass|200808|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200808220323
2064961|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808212029
2065204|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808212130
2065411|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8 patch 34096|netbsd|4.0|200808212048
2066247|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200808220134
2066292|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808220251
2066294|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808220252
2066295|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808220253
2066296|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808220253
2066298|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808220254
2066300|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808220255
2066302|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808220255
2066304|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808220256
2066306|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808220257
2066308|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808220257
2066367|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34212|linux|2.6.21.5-smp|200808220245
2067198|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808220857
2067222|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808220819
2067427|pass|200808|imacat@mail.imacat.idv.tw|Data-Compare|1.20|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200808221703
2067458|pass|200808|imacat@mail.imacat.idv.tw|Data-Compare|1.20|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200808221717
2068324|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0 patch 34161|netbsd|4.0|200808221626
2068382|pass|200808|stro@cpan.org|Data-Compare|1.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200808221842
2068467|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200808221701
2068507|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808221719
2068520|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808221726
2068840|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200808221733
2068887|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200808221740
2068905|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.8 patch 34096|netbsd|4.0|200808221834
2068971|pass|200808|g.grigelionis@computer.org|Data-Compare|1.20|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200808222001
2068972|pass|200808|g.grigelionis@computer.org|Data-Compare|1.20|i586-linux-thread-multi|5.8.8|linux|2.6.16|200808222002
2069329|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd|5.10.0|freebsd|6.1-release|200808222136
2069741|pass|200808|shlomif@cpan.org|Data-Compare|1.20|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200808221504
2069771|pass|200808|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.20|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5|200808222145
2070163|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i686-linux|5.6.2|linux|2.4.27-3-686|200808230033
2070440|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.11.0 patch 34212|linux|2.6.21.5-smp|200808230235
2070919|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.24.3|200808230317
2071133|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.24.3|200808230555
2071338|pass|200808|claco@chrislaco.com|Data-Compare|1.20|darwin-thread-multi-2level|5.8.8|darwin|9.0|200808230018
2071425|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24.3|200808230709
2071692|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200808231339
2072061|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200808231723
2072209|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808231936
2072470|pass|200808|rafl@debian.org|Data-Compare|1.20|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200808232020
2072533|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808231829
2073155|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808232148
2073186|fail|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808232151
2073566|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808232225
2073732|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808232123
2074123|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808232123
2074801|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-thread-multi-64int|5.11.0 patch 34218|freebsd|7.0-release|200808232205
2074805|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34218|freebsd|7.0-release|200808232206
2075907|pass|200808|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.6.2|linux|2.6.24.3|200808240047
2075993|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240708
2076432|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240834
2076708|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240918
2076997|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240951
2077246|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd|5.6.2|freebsd|6.1-release|200808241010
2078672|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-64int|5.11.0 patch 34218|openbsd|4.2|200808241519
2078905|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808241606
2079549|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200808242014
2080095|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-ld|5.11.0 patch 34225|linux|2.6.24-19-generic|200808242229
2081096|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808250450
2081180|pass|200808|rick@jrmyers.net|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24.3|200808250311
2082190|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-64int-ld|5.10.0 patch 34161|linux|2.6.24-19-generic|200808251225
2082734|pass|200808|hohokus@gmail.com|Data-Compare|1.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200808250932
2082785|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808251445
2082915|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200808251519
2083908|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.11.0 patch 34225|netbsd|4.0|200808251845
2084703|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-64int-ld|5.8.8 patch 34096|linux|2.6.24-19-generic|200808260127
2085617|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200808260842
2085777|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.10.0|freebsd|6.1-release|200808260842
2086330|pass|200808|stro@cpan.org|Data-Compare|1.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200808261335
2086870|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-Tiny|1.11|i686-linux|5.8.8|linux|2.6.24.3|200808260813
2086986|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-Tiny|1.11|i686-linux|5.6.2|linux|2.6.24.3|200808260836
2087422|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808261521
2087755|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808261456
2087975|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808261643
2089096|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.10.0|linux|2.6.24.3|200808261322
2089169|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.6.24.3|200808261335
2089572|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808262033
2089756|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200808262039
2089787|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200808262045
2089835|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808262040
2090135|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808262145
2090474|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200808262312
2090475|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200808262313
2090477|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200808262313
2090479|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200808262314
2090489|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.8.8|linux|2.6.14|200808262315
2090503|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200808262318
2090706|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200808262316
2090707|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200808262317
2090725|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i686-linux|5.8.8|linux|2.4.27-3-686|200808262257
2090771|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd|5.10.0|freebsd|6.1-release|200808270000
2092079|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808270619
2092080|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808270619
2092082|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808270620
2092083|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808270621
2092085|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808270621
2092086|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808270622
2092089|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808270623
2092092|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808270624
2092094|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808270625
2092097|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808270625
2092290|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34225|netbsd|4.0|200808270722
2093120|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200808271221
2093398|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200808270738
2093507|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|IP35-irix-64int|5.8.8|irix|6.5|200808271500
2093624|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200808271232
2094114|pass|200808|cpan@herlpacker.co.uk|Data-Compare|1.200_500|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808271419
2094165|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808271658
2094167|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808271700
2094507|fail|200808|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.24.3|200808270846
2094847|pass|200808|stro@cpan.org|Devel-CheckLib|0.5|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808272011
2094886|pass|200808|stro@cpan.org|Devel-CheckLib|0.5|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808272014
2094976|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808271919
2094995|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808271901
2095008|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808271902
2095144|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-FindDependencies|2.0|i686-linux|5.8.8|linux|2.6.24.3|200808271337
2095165|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.24.3|200808271338
2095284|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.6.2|linux|2.6.24.3|200808271348
2095553|fail|200808|rick@jrmyers.net ("Rick Myers")|CPAN-FindDependencies|2.0|i686-linux|5.6.2|linux|2.6.24.3|200808271432
2095708|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.6.24.3|200808271510
2095711|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.8|linux|2.6.24.3|200808271512
2095822|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24.3|200808271549
2095833|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24.3|200808271550
2096531|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808280030
2096537|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808280032
2096958|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808280031
2096961|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808280033
2097113|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808280141
2097115|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808280143
2097915|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808280949
2098421|pass|200808|cpan@herlpacker.co.uk|Data-Compare|1.20|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808280347
2098456|pass|200808|cpan@herlpacker.co.uk|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808281035
2098735|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808281333
2098779|pass|200808|stro@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.4.27-2-386|200808281020
2099111|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808281117
2099969|pass|200808|stro@cpan.org|Data-Compare|1.20|i686-linux|5.10.0|linux|2.4.27-2-386|200808281411
2100251|pass|200808|david@cantrell.org.uk|Data-Compare|1.200_500|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200808281754
2100283|pass|200808|stro@cpan.org|Data-Compare|1.20|i686-linux|5.8.8|linux|2.4.27-2-386|200808281956
2100457|pass|200808|david@cantrell.org.uk|Data-Compare|1.200_500|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200808281721
2101020|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200808282129
2101100|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.10.0|freebsd|6.1-release|200808282130
2101199|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd|5.6.2|freebsd|6.1-release|200808282135
2101531|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808282130
2102011|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808282328
2102284|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200808290030
2102290|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200808290031
2102308|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200808290034
2102312|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200808290034
2102320|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200808290031
2102324|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200808290032
2102325|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200808290033
2102326|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200808290033
2102373|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808282034
2102398|pass|200808|stro@cpan.org|Number-Phone|1.6|i686-linux|5.8.8|linux|2.4.27-2-386|200808290126
2102647|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808290017
2102935|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200808290055
2103035|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290211
2103229|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290227
2103434|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290312
2103568|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290348
2104091|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290554
2105206|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808290814
2105209|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200808290815
2105219|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808290816
2105234|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808290816
2105247|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808290817
2105252|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200808290818
2105258|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808290819
2105265|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808290820
2105938|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808290951
2106681|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808291334
2106692|fail|200808|chris@bingosnet.co.uk|Class-DBI-ClassGenerator|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808291239
2107403|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808291506
2108246|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808291712
2108287|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808291727
2108604|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808292011
2108719|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808292040
2108765|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808291956
2108996|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200808292103
2109051|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808292112
2109463|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808292339
2110749|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808300810
2110879|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808300841
2110994|pass|200808|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.6.2|linux|2.6.24.3|200808300306
2111004|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808300904
2111005|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808300904
2112339|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808301515
2112373|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808301528
2112873|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808301829
2113254|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808302103
2113274|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808302114
2113325|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200808302139
2113593|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808310000
2113928|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808310238
2114152|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808310515
2114170|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808310534
2114229|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808310606
2115011|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311239
2115094|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808311155
2115120|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808311202
2116106|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808311420
2116113|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808311422
2116364|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808311502
2116382|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808311504
2116417|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311548
2116847|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311627
2117292|pass|200808|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.24.3|200808311248
2117351|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311854
2118245|pass|200808|rick@jrmyers.net ("Rick Myers")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24.3|200808311437
2118585|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808312124
2118957|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808312218
2119384|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i686-linux-thread-multi-64int-ld|5.11.0 patch 34237|linux|2.6.16.38|200808312231
2119435|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.11.0 patch 34237|linux|2.6.16.38|200808312239
2119735|pass|200808|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808312337
2119793|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34237|linux|2.6.16.38|200809010033
2120156|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.0|i686-linux|5.10.0|linux|2.4.27-2-386|200809010537
2120442|pass|200809|stro@cpan.org|Data-Compare|1.200_500|i686-linux|5.10.0|linux|2.4.27-2-386|200809010647
2120514|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200809010655
2120517|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809010029
2120778|pass|200809|stro@cpan.org|Data-Compare|1.200_500|i686-linux|5.8.8|linux|2.4.27-2-386|200809010855
2121277|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809011108
2121300|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809011114
2121647|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809011256
2121692|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809011302
2122006|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809011452
2122014|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809011454
2122158|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809011552
2122165|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809011555
2122170|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809011558
2122414|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200809011833
2122416|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200809011833
2122420|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200809011833
2122421|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200809011834
2122424|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8|linux|2.6.14|200809011834
2122425|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200809011834
2122429|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200809011835
2122432|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200809011835
2122703|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809011911
2122729|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809011920
2122923|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.10.0|freebsd|6.1-release|200809012154
2123235|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809012347
2123274|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.6.2|freebsd|6.1-release|200809012355
2123275|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809012355
2123451|pass|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809020814
2123737|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809020145
2123739|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200809020146
2123741|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809020147
2123742|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809020147
2123744|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809020148
2123745|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809020149
2123747|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809020149
2123748|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809020150
2123749|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809020151
2123752|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809020151
2124180|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809020557
2124282|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809020753
2124283|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809020751
2124285|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809020656
2124458|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809020816
2124573|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809020845
2124579|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809020846
2124587|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809020846
2124592|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809020847
2124706|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809020822
2124735|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809020928
2124737|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809020828
2124773|pass|200809|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200809021637
2124774|pass|200809|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809021637
2125023|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809021104
2125137|pass|200809|rafl@debian.org|Data-Compare|1.21|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200809021255
2125465|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34238|openbsd|4.1|200809021411
2125471|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34238|openbsd|4.1|200809021412
2125812|pass|200809|hohokus@gmail.com|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809020949
2126196|pass|200809|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.21|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5|200809012146
2126563|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809021204
2126630|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809021214
2126647|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809021715
2126719|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|i686-linux|5.6.2|linux|2.4.27-3-686|200809021742
2126957|pass|200809|stro@cpan.org|Data-Compare|1.21|i686-linux|5.10.0|linux|2.4.27-2-386|200809022101
2127042|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809021603
2127349|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809021425
2127399|pass|200809|g.grigelionis@computer.org|Data-Compare|1.21|i586-linux-thread-multi|5.8.8|linux|2.6.16|200809022139
2127698|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809022243
2127723|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809022254
2127739|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200809022153
2128059|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809030011
2128162|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200809022328
2128314|pass|200809|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.21|sun4-solaris|5.10.0|solaris|2.8|200809021035
2128711|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34238|openbsd|4.1|200809030050
2128775|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|i686-linux|5.8.8|linux|2.4.27-3-686|200809030101
2129258|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809030255
2129836|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809030817
2130314|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809030928
2130745|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809031006
2131867|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.10.0|solaris|2.11|200809031242
2132073|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809031339
2132570|pass|200809|vpit@cpan.org|Data-Compare|1.200_500|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031533
2132572|pass|200809|vpit@cpan.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031534
2132621|pass|200809|vpit@cpan.org|Devel-CheckOS|1.43|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031543
2132704|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809031335
2132760|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809031347
2132788|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|i686-linux|5.8.8|linux|2.4.27-3-686|200809031526
2132967|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809031015
2133120|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|IP35-irix-64int|5.8.8|irix|6.5|200809031755
2133127|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|IP35-irix-64int|5.8.8|irix|6.5|200809031756
2134058|fail|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809032134
2134276|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200809032122
2134304|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809032125
2134327|fail|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.10.0|freebsd|6.1-release|200809032232
2134426|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200809032244
2134428|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200809032244
2134429|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200809032245
2134431|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.8.8|linux|2.6.14|200809032245
2134432|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200809032245
2134542|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200809032244
2134677|fail|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809032345
2135029|pass|200809|vpit@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809040049
2135133|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|i686-linux|5.6.2|linux|2.4.27-3-686|200809040028
2136726|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809040443
2136741|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809040445
2136884|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809040528
2136914|pass|200809|chris@bingosnet.co.uk|Class-DBI-ClassGenerator|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809040912
2136974|pass|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.6.2|freebsd|6.1-release|200809041033
2137123|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200809041109
2137189|pass|200809|claco@chrislaco.com|Data-Compare|1.21|darwin-thread-multi-2level|5.8.8|darwin|9.0|200809031956
2137306|pass|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809041141
2137485|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809040720
2137803|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809041316
2138046|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200809041517
2138691|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24.3|200809041233
2138785|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809041704
2139060|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.10.0|solaris|2.11|200809042023
2140153|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809042353
2140156|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809042354
2140181|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050030
2140954|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200809050032
2140978|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050207
2141182|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809050112
2142272|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050642
2142646|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809050740
2143390|fail|200809|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809050959
2143413|pass|200809|g.grigelionis@computer.org|Data-Compare|1.21|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200809051001
2143584|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050954
2144940|pass|200809|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|i86pc-solaris-64int|5.10.0|solaris|2.11|200809051418
2145002|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809051336
2145208|pass|200809|jrockway@cpan.org|Data-Compare|1.21|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200809050656
2145547|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809051514
2145666|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.6.24.3|200809051039
2146109|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.8|linux|2.6.24.3|200809051232
2146110|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.8|linux|2.6.24.3|200809051232
2146406|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809051828
2146859|pass|200809|andy@hexten.net|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200809052042
2146903|pass|200809|andy@hexten.net|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200809052044
2146936|pass|200809|shlomif@cpan.org|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200809052248
2146953|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|IP35-irix-64int|5.8.8|irix|6.5|200809052153
2147039|pass|200809|andy@hexten.net|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200809052103
2147815|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060038
2148192|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809060001
2148403|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060245
2148500|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060246
2148806|pass|200809|rjbs@cpan.org|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.1.0|200809060200
2148848|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060205
2148887|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200809060310
2149478|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060620
2150047|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060919
2150562|pass|200809|dillman@ria.buffalo.edu|Data-Compare|1.21|sun4-solaris|5.10.0|solaris|2.9|200809051516
2151414|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-ld|5.11.0 patch 34282|linux|2.6.21.5-smp|200809061758
2151492|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809061318
2152473|fail|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24.3|200809061749
2152821|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809062350
2152856|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070133
2153132|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070233
2154234|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070700
2154322|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070719
2154565|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070831
2155585|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.8|linux|2.6.24.3|200809070542
2155658|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24.3|200809070555
2156076|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34282|linux|2.6.21.5-smp|200809071257
2156378|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.24.3|200809070934
2157510|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809071950
2158290|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809072204
2158758|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|IP35-irix-64int|5.8.8|irix|6.5|200809072310
2158801|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.8|linux|2.4.27-3-686|200809072214
2159044|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809072251
2159070|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809072254
2159366|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.24.3|200809071842
2159738|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809080100
2159772|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809080116
2160285|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809080652
2160582|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809080745
2161534|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809081021
2161756|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.10.0|solaris|2.11|200809081110
2162236|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809081327
2162663|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809080915
2164470|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0 patch 34305|netbsd|4.0|200809081903
2164719|pass|200809|dwheeler@cpan.org|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.4.0|200809081854
2164829|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Net-Random|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809082106
2165191|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809081551
2165321|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809082130
2166664|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809090041
2166850|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809090011
2166888|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809090017
2166963|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090135
2168102|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809090453
2168515|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8 patch 34313|netbsd|4.0|200809090446
2168549|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809090530
2168917|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.8.8|linux|2.6.24.3|200809090101
2169493|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809090845
2169887|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809091001
2170196|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.24.3|200809090442
2170228|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24.3|200809090445
2170535|pass|200809|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809091035
2170688|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809091146
2171000|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809091224
2171365|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809090717
2172415|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24.3|200809090948
2173132|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809091118
2173799|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809091905
2173893|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809091923
2174004|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809091941
2174587|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809092124
2174928|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809092215
2175725|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200809100019
2176322|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809100330
2177303|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0 patch 34305|netbsd|4.0|200809100536
2177586|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-Treo680MessagesDB|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809100233
2178345|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809100908
2179057|pass|200809|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100846
2179468|pass|200809|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100846
2179568|pass|200809|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179569|pass|200809|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179797|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809100822
2179849|pass|200809|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100847
2179889|pass|200809|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179938|pass|200809|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2180325|pass|200809|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100848
2180393|pass|200809|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2180813|pass|200809|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809101259
2180933|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0 patch 34325|freebsd|7.0-release|200809101058
2182471|pass|200809|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809101709
2182493|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8 patch 34313|netbsd|4.0|200809101525
2182526|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8 patch 34327|freebsd|7.0-release|200809101506
2183605|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200809102018
2183883|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809101945
2184050|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.24.3|200809101520
2184500|pass|200809|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102241
2184805|pass|200809|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102322
2185551|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-64int-ld|5.10.0|linux|2.6.24.5-smp|200809110110
2186886|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809110758
2186951|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809110813
2187759|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809110955
2188217|pass|200809|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111052
2188457|pass|200809|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111110
2188515|pass|200809|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111117
2189291|fail|200809|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200809111240
2189385|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809111252
2189538|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809111311
2189654|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809111325
2190278|pass|200809|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111426
2191574|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809111659
2192929|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.8|linux|2.6.24.3|200809111332
2193628|pass|200809|andy@hexten.net|Data-Compare|1.21|i86pc-solaris-thread-multi|5.10.0|solaris|2.11|200809120152
2194022|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34325|freebsd|7.0-release|200809111951
2194874|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8 patch 34327|freebsd|7.0-release|200809112155
2195859|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809120405
2195893|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809120514
2196189|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809120114
2196789|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200809120852
2197199|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Longest|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809121015
2197203|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Statistics-ChiSquare|0.5|i86pc-solaris-64int|5.10.0|solaris|2.11|200809121015
2197209|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809120417
2197970|pass|200809|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809121217
2200967|pass|200809|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809121821
2201560|pass|200809|JOST@cpan.org ("Josts Smokehouse")|NestedMap|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809122005
2202046|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809122121
2202341|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.6.24.3|200809121558
2202370|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809121602
2203007|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809122334
2203270|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809122156
2203548|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809121901
2204171|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.8|linux|2.6.24.3|200809130040
2206477|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200809130456
2206563|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809130623
2206854|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|darwin-2level|5.8.8|darwin|8.10.1|200809130639
2207038|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809130738
2207162|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809130749
2207391|unknown|200809|JOST@cpan.org ("Josts Smokehouse")|Acme-Licence|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809130817
2209250|pass|200809|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809131320
2209305|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34342|linux|2.6.24.5-smp|200809131218
2209944|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 34347|linux|2.6.24.5-smp|200809131408
2210024|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24.3|200809130931
2210032|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809130932
2211035|pass|200809|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809131806
2211723|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24.3|200809131419
2213262|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809131828
2214291|unknown|200809|JOST@cpan.org ("Josts Smokehouse")|Acme-Pony|1.1.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200809140253
2214362|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809140301
2214565|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809140355
2216453|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34342|linux|2.6.22-1-k7|200809140830
2216455|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8 patch 34347|solaris|2.10|200809140729
2216472|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34342|linux|2.6.22-1-k7|200809140834
2216530|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.8|linux|2.6.24.3|200809140241
2216571|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809140745
2217634|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.8|linux|2.6.24.3|200809140716
2217915|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.24.3|200809140815
2218095|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.24.3|200809140844
2218653|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.24.3|200809141107
2220303|pass|200809|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809142146
2220467|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809142250
2220769|pass|200809|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809142343
2221043|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150019
2221441|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150114
2221518|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150145
2222888|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200809150543
2222968|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34342|freebsd|7.0-release|200809150451
2223014|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150650
2223018|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.10.0|linux|2.6.24.3|200809150058
2223485|pass|200809|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809150710
2223644|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150759
2226111|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.8|linux|2.6.24.3|200809151119
2226205|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.8|linux|2.6.24.3|200809151148
2226565|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.6.24.3|200809151239
2228780|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8 patch 34360|freebsd|7.0-release|200809160415
2229376|pass|200809|feldt@nhn.ou.edu|Data-Compare|1.21|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200809151343
2232416|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34372|linux|2.6.24-19-generic|200809170320
2233753|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809171121
2234064|pass|200809|dmdk1@comcast.net|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809170640
2235521|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809171951
2235523|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809171952
2236401|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809172122
2236480|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 34376|linux|2.6.24-19-generic|200809172047
2236751|pass|200809|stro@cpan.org|Data-Compare|1.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809172332
2236778|pass|200809|stro@cpan.org|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809172334
2237726|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34378|linux|2.6.24-19-generic|200809172353
2237796|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.8.8|linux|2.6.24.3|200809171902
2238524|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8 patch 34376|freebsd|6.2-release|200809180053
2238607|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.8|linux|2.6.24.3|200809180105
2238659|pass|200809|chris@bingosnet.co.uk|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180212
2238665|pass|200809|chris@bingosnet.co.uk|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180212
2238669|pass|200809|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180213
2238701|pass|200809|chris@bingosnet.co.uk|Bryar|3.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180218
2238722|pass|200809|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180221
2238727|pass|200809|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180222
2238745|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180325
2238766|pass|200809|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180228
2238776|pass|200809|chris@bingosnet.co.uk|Class-CanBeA|1.2|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180229
2238813|pass|200809|chris@bingosnet.co.uk|Class-DBI-ClassGenerator|1.01|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180234
2238901|pass|200809|chris@bingosnet.co.uk|DBIx-Class-SingletonRows|0.11|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180245
2238908|pass|200809|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180245
2238916|pass|200809|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180246
2238924|pass|200809|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180247
2238937|pass|200809|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180248
2238941|pass|200809|chris@bingosnet.co.uk|File-Overwrite|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180249
2238945|pass|200809|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180249
2238948|pass|200809|chris@bingosnet.co.uk|NestedMap|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180250
2238956|pass|200809|chris@bingosnet.co.uk|Net-Random|2.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180252
2238963|pass|200809|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180253
2238976|pass|200809|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180255
2238977|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180355
2239002|pass|200809|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180258
2239018|pass|200809|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180300
2239023|pass|200809|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180301
2239033|pass|200809|chris@bingosnet.co.uk|Statistics-ChiSquare|0.5|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180302
2239042|pass|200809|chris@bingosnet.co.uk|Statistics-SerialCorrelation|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180303
2239047|pass|200809|chris@bingosnet.co.uk|Sub-WrapPackages|1.2|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180304
2239048|pass|200809|chris@bingosnet.co.uk|Tie-Hash-Longest|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180304
2239051|pass|200809|chris@bingosnet.co.uk|Tie-Hash-Rank|1.0.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180305
2239057|pass|200809|chris@bingosnet.co.uk|Tie-STDOUT|1.03|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180306
2239060|pass|200809|chris@bingosnet.co.uk|Tie-Scalar-Decay|1.1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180307
2239066|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180308
2239072|pass|200809|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180309
2239564|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180543
2240143|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180743
2240621|pass|200809|rlane10@wi.rr.com|Data-Compare|1.21|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5xen|200809171734
2242839|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809182205
2244075|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200809190651
2245958|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191226
2246060|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191305
2246291|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191259
2246429|pass|200809|rlane10@wi.rr.com|Data-Compare|1.21|darwin-2level-ld|5.10.0|darwin|8.11.0|200809190145
2246637|pass|200809|stro@cpan.org|Data-Compare|1.21|i686-linux|5.8.8|linux|2.4.27-2-386|200809191143
2246666|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191147
2246685|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191137
2247058|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34379|linux|2.6.24.3|200809190942
2247620|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34379|linux|2.6.21.5-smp|200809191726
2247631|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8 patch 34376|dragonfly|2.0.0-release|200809191814
2248904|pass|200809|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192112
2248907|pass|200809|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192112
2250153|pass|200809|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192113
2250570|pass|200809|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192112
2250695|pass|200809|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192113
2250965|pass|200809|vpit@cpan.org|Devel-CheckOS|1.43|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809192322
2252554|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34372|dragonfly|2.0.0-release|200809200237
2253129|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809200458
2254479|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.8|linux|2.6.24.3|200809200851
2257805|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809210901
2258126|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809210954
2258972|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.26.5|200809210654
2259096|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809210730
2259896|pass|200809|shlomif@cpan.org|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.27-desktop-0.rc6.3.2mnb|200809211534
2259900|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.6.26.5|200809210835
2259935|pass|200809|vpit@cpan.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809211442
2261013|fail|200809|vpit@cpan.org|Bryar|3.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809211725
2261749|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809211920
2262089|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809211948
2263304|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809212219
2264023|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809220007
2267038|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.01|i686-linux|5.10.0|linux|2.4.27-2-386|200809220120
2270334|pass|200809|andy@hexten.net|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809230309
2272202|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230108
2272391|pass|200809|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230118
2273987|pass|200809|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230243
2274657|pass|200809|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230315
2275372|pass|200809|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230356
2276210|pass|200809|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230438
2276822|pass|200809|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230510
2277905|fail|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809230605
2278342|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230630
2278630|pass|200809|andy@hexten.net|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809231241
2278891|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809230655
2279583|fail|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.26.5|200809230813
2279896|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.26.5|200809230902
2282157|pass|200809|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231319
2282765|pass|200809|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231409
2282820|pass|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.8|linux|2.6.26.5|200809231412
2282898|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231419
2283100|pass|200809|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231436
2283878|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809231648
2284464|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231822
2284488|pass|200809|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231825
2284690|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809240157
2285740|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.8|linux|2.6.26.5|200809240143
2286365|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809240446
2286699|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809240451
2288619|pass|200809|jeff@zeroclue.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.2.0|200809240350
2291076|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.6.26.5|200809241242
2291763|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.26.5|200809241416
2292092|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809241509
2294629|pass|200809|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250030
2296227|pass|200809|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250025
2296959|pass|200809|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250204
2297496|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250318
2297597|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250331
2302018|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.8.8|linux|2.6.26.5|200809251429
2302099|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.6.26.5|200809251442
2309012|pass|200809|mgardner@usatech.com|Data-Compare|1.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200809261128
2309548|pass|200809|gabor@pti.co.il ("Gabor Szabo")|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809261932
2312149|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270000
2312313|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270037
2312446|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270100
2312499|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270110
2312505|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270111
2312544|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270119
2312597|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270128
2312628|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270134
2312795|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270201
2312978|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270224
2313151|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809270448
2313310|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270310
2313316|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270310
2313639|fail|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270349
2313864|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270025
2313873|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270027
2313923|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270027
2314486|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270235
2314715|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270323
2314721|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270324
2314737|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270327
2314821|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.8|linux|2.6.26.5|200809270350
2314935|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270418
2315002|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270429
2315044|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.6.26.5|200809270437
2315047|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270438
2315100|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.8|linux|2.6.26.5|200809270445
2315158|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270455
2315184|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.8|linux|2.6.26.5|200809270459
2315312|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.6.26.5|200809270525
2315331|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270527
2315436|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270540
2315811|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.8|linux|2.6.26.5|200809270632
2315816|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.8|linux|2.6.26.5|200809270633
2315825|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270633
2315835|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270635
2316116|fail|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.8.8|linux|2.6.26.5|200809270712
2316271|pass|200809|eshank@drwholdings.com|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809261140
2316346|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809271246
2316400|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.8|linux|2.6.26.5|200809270757
2316405|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270758
2316406|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.8|linux|2.6.26.5|200809270758
2316478|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.8|linux|2.6.26.5|200809270808
2316644|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270838
2316652|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.8|linux|2.6.26.5|200809270840
2316677|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.6.26.5|200809270844
2316816|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270913
2317346|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.26.5|200809271226
2317418|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.8|linux|2.6.26.5|200809271241
2317421|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809271242
2317491|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271256
2317583|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271305
2317661|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.26.5|200809271316
2317671|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271317
2317715|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.26.5|200809271322
2317727|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809271923
2317778|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271330
2317821|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.26.5|200809271335
2317935|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.26.5|200809271348
2318062|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271359
2318391|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.26.5|200809271435
2318395|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.26.5|200809271436
2318736|fail|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.10.0|linux|2.6.26.5|200809271505
2318831|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809272029
2318871|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.26.5|200809271519
2318877|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271520
2318880|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.26.5|200809271520
2318903|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.26.5|200809271524
2319004|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271550
2319010|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.26.5|200809271551
2319035|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.26.5|200809271557
2319157|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271616
2319483|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.10.0|linux|2.6.26.5|200809271708
2319498|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271713
2322337|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809280900
2323841|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281313
2324323|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281350
2325540|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281607
2325883|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281411
2326598|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281754
2327831|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809282012
2335378|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200809291729
2335380|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200809291729
2335382|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200809291729
2335386|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200809291730
2335389|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8|linux|2.6.14|200809291730
2335392|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200809291730
2336854|fail|200809|chris@bingosnet.co.uk|Palm-SMS|0.02|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809291916
2337033|fail|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809300340
2337154|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809292051
2337323|fail|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291512
2337451|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809292130
2337521|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809292123
2337627|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291552
2337779|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809292158
2339049|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291830
2339181|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809292343
2339185|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809292344
2339198|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809292346
2339210|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809292348
2339578|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809300028
2339645|pass|200809|flemming@ipk-gatersleben.de|Data-Compare|1.21|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200809291527
2339791|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809300132
2339931|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300003
2340018|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809300215
2342112|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.10.0|freebsd|6.1-release|200809300836
2342658|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300359
2342758|pass|200809|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809300923
2342820|pass|200809|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809300936
2342845|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.44|i86pc-solaris-64int|5.10.0|solaris|2.11|200809301041
2343727|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809301219
2343785|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300738
2343916|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|IP35-irix-64int|5.8.8|irix|6.5|200809301357
2343943|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809301300
2343970|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.4.27-3-686|200809301306
2344168|fail|200809|hohokus@gmail.com|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809300838
2344321|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|i686-linux|5.6.2|linux|2.4.27-3-686|200809301358
2344441|pass|200809|martin.evans@easysoft.com|XML-Tiny|1.11|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809301419
2344936|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809300930
2345254|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809301522
2345303|pass|200809|martin.evans@easysoft.com|Devel-CheckOS|1.44|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809301631
2345328|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8 patch 34439|netbsd|4.0|200809301628
2345369|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.6.2|freebsd|6.1-release|200809301737
2345442|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200809301745
2345463|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200809301747
2345489|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200809301750
2345644|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200809301820
2345731|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|i586-linux-thread-multi|5.8.8|linux|2.6.16|200809301848
2345835|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0 patch 34437|netbsd|4.0|200809301800
2345902|pass|200809|vpit@cpan.org|Devel-CheckOS|1.44|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809301921
2346083|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.10.0|linux|2.6.26.5|200809301352
2346495|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809302053
2346541|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809302059
2346554|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.11.0 patch 34444|netbsd|4.0|200809301957
2347621|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.11.0 patch 34448|freebsd|6.2-release|200809301612
2348573|pass|200809|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.44|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5xen|200809300833
2350694|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.6.26.5|200810010205
2351580|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010457
2351637|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010509
2351789|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010542
2351821|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010547
2351822|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010547
2351852|pass|200810|rick@jrmyers.net ("Rick Myers")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010553
2351853|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010553
2351900|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010600
2351912|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010603
2351970|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010615
2352031|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010625
2352092|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010644
2352098|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010644
2352196|fail|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010701
2352283|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010718
2352285|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010718
2352286|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010718
2352415|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010758
2352501|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010816
2352502|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010817
2352512|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010820
2352544|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010829
2352706|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200810011515
2352827|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010943
2352829|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010943
2354265|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810011736
2355010|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810012054
2355042|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810012104
2355309|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.11.0 patch 34451|freebsd|7.0-release|200810012041
2357351|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810020504
2357354|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200810020505
2357359|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200810020506
2357363|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200810020507
2357367|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200810020507
2357371|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200810020508
2357380|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200810020509
2357386|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810020510
2357391|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810020510
2358373|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810020824
2358649|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810020842
2358794|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810020757
2359161|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200810020905
2359337|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810021013
2361236|pass|200810|rlane10@wi.rr.com|Devel-CheckOS|1.44|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5xen|200810020617
2363266|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810022037
2363552|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810021809
2363838|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810021830
2364436|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810022223
2365777|pass|200810|rlane10@wi.rr.com|Devel-CheckOS|1.44|darwin-2level-ld|5.10.0|darwin|8.11.0|200810021301
2366104|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810030138
2366361|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810030315
2366661|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810030522
2366665|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810030523
2366669|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810030525
2372448|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.7|linux|2.6.26.5|200810031624
2373001|pass|200810|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.7|linux|2.6.26.5|200810031758
2373652|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.7|linux|2.6.26.5|200810040007
2373731|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810040024
2373780|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810040031
2374313|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.7|linux|2.6.26.5|200810040228
2374876|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34456|openbsd|4.2|200810040217
2378123|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.6|linux|2.6.26.5|200810040907
2379530|pass|200810|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.6|linux|2.6.26.5|200810041330
2380687|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.6|linux|2.6.26.5|200810041718
2381463|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810041930
2382914|pass|200810|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.8.6|linux|2.6.26.5|200810060430
2384752|pass|200810|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810061018
2386783|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810062050
2386863|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810062112
2387692|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810062332
2387762|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810062317
2388111|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810070108
2389245|pass|200810|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.44|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810071033
2389583|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810070515
2390588|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810070830
2392379|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810071232
2392460|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.7|linux|2.6.26.5|200810070640
2392462|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.7|linux|2.6.26.5|200810070641
2392480|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.7|linux|2.6.26.5|200810070643
2392485|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.7|linux|2.6.26.5|200810070643
2392700|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.7|linux|2.6.26.5|200810070706
2393059|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.7|linux|2.6.26.5|200810070757
2393415|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.7|linux|2.6.26.5|200810070845
2394310|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.7|linux|2.6.26.5|200810071113
2394327|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071115
2394350|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.7|linux|2.6.26.5|200810071118
2394559|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.7|linux|2.6.26.5|200810071146
2394604|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.7|linux|2.6.26.5|200810071150
2394616|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071151
2395006|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.7|linux|2.6.26.5|200810071238
2395145|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.7|linux|2.6.26.5|200810071250
2395438|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071326
2395613|pass|200810|bingos@cpan.org|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810071843
2395781|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.7|linux|2.6.26.5|200810071408
2396275|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.7|linux|2.6.26.5|200810071516
2397251|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.7|linux|2.6.26.5|200810071712
2397252|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071712
2397253|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071712
2397323|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071721
2397374|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071726
2397382|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071728
2397824|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.7|linux|2.6.26.5|200810071837
2397861|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071841
2398034|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080002
2398537|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080002
2398624|pass|200810|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080112
2398627|pass|200810|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080112
2399199|pass|200810|bingos@cpan.org|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080220
2399200|pass|200810|bingos@cpan.org|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080220
2399215|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080123
2399310|pass|200810|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080240
2399311|pass|200810|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080240
2399487|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.6|linux|2.6.26.5|200810080203
2399488|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.6|linux|2.6.26.5|200810080204
2399545|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.6|linux|2.6.26.5|200810080216
2399550|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.6|linux|2.6.26.5|200810080217
2399570|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080323
2400188|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080354
2400201|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080355
2400205|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080357
2400344|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080020
2400375|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080024
2400381|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080025
2400672|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.6|linux|2.6.26.5|200810080103
2400758|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080117
2400962|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080145
2401241|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080229
2401256|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.6|linux|2.6.26.5|200810080232
2401425|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080304
2401687|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.6|linux|2.6.26.5|200810080346
2403309|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081519
2403986|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.6|linux|2.6.26.5|200810081127
2404020|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081130
2404034|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.6|linux|2.6.26.5|200810081132
2404177|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081739
2404347|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.6|linux|2.6.26.5|200810081205
2404417|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.6|linux|2.6.26.5|200810081212
2404428|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081213
2404578|pass|200810|bingos@cpan.org|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810081730
2404816|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081854
2404994|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081912
2405186|pass|200810|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810081836
2405256|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.6|linux|2.6.26.5|200810081345
2405326|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081953
2405457|pass|200810|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810081909
2405496|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.6|linux|2.6.26.5|200810081413
2405826|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081450
2406205|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.6|linux|2.6.26.5|200810081530
2406514|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.6|linux|2.6.26.5|200810081629
2406680|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810082151
2406981|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810082229
2407181|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.6|linux|2.6.26.5|200810081801
2407241|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081808
2407740|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.6|linux|2.6.26.5|200810081940
2408656|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810090900
2408741|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810090314
2410831|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.10.0|linux|2.6.26.6|200810091027
2411206|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.6.26.6|200810091126
2411451|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.7|linux|2.6.26.6|200810091200
2411847|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.6|linux|2.6.26.6|200810091249
2412109|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810091157
2415526|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810100234
2415612|pass|200810|rafl@debian.org|Devel-CheckOS|1.44|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200810100449
2416834|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810101125
2418723|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810102248
2418784|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810102304
2419263|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810110123
2421100|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810111405
2422180|pass|200810|bobtfish@bobtfish.net|XML-Tiny|1.11|darwin-thread-multi-2level|5.8.6|darwin|8.0|200810112343
2423591|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200810121816
2423624|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200810121825
2426648|pass|200810|andy@hexten.net|Devel-CheckOS|1.44|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200810131955
2428930|pass|200810|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140103
2429590|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810140051
2430265|pass|200810|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140047
2430274|pass|200810|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140048
2430283|pass|200810|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140049
2430375|pass|200810|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140054
2430749|pass|200810|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140113
2431812|pass|200810|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140236
2432263|pass|200810|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140315
2433004|pass|200810|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140422
2433208|pass|200810|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140451
2433436|pass|200810|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140518
2433775|pass|200810|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140552
2433845|pass|200810|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140601
2434066|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140623
2434099|pass|200810|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140626
2434685|pass|200810|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140745
2434782|pass|200810|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140000
2435083|pass|200810|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140831
2435324|pass|200810|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140906
2435512|pass|200810|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140948
2435778|pass|200810|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810141032
2435795|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810141034
2437103|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200810141734
2437120|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200810141738
2438337|pass|200810|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810150855
2438472|pass|200810|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810150851
2438808|pass|200810|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810150854
2439360|pass|200810|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810151026
2439526|pass|200810|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810150851
2439551|pass|200810|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810151054
2439931|pass|200810|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810151111
2440340|pass|200810|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810151129
2441130|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151701
2441253|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151730
2441288|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151737
2441374|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151755
2441749|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151724
2442108|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810151925
2442170|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810151943
2442624|pass|200810|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810152056
2442929|pass|200810|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810152045
2443542|pass|200810|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810152301
2443632|pass|200810|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810152300
2445048|fail|200810|mthurn@cpan.org|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200810160055
2446197|fail|200810|alexchorny@gmail.com|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200810160657
2448136|pass|200810|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2449165|pass|200810|andy@hexten.net|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200810170121
2451647|pass|200810|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810172339
2451763|pass|200810|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810172340
2453135|pass|200810|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810180826
2453261|pass|200810|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810180826
2454735|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810181713
2454809|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810181733
2457101|pass|200810|stro@cpan.org|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.4.27-2-386|200810190906
2457513|pass|200810|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810191252
2457553|pass|200810|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810191252
2458962|pass|200810|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810191305
2459015|pass|200810|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810191305
2463982|pass|200810|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810210000
2464503|pass|200810|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810210004
2464860|fail|200810|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810210001
2468226|pass|200810|davidp@preshweb.co.uk ("David Precious")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i486-linux-gnu|5.10.0|linux|2.6.26.1|200810211951
2469182|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810220802
2469824|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810220953
2470404|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810221158
2470612|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810221236
2470971|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810221344
2473021|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200810222203
2473031|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200810222204
2473033|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200810222205
2473060|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200810222159
2473064|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200810222203
2473065|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810222204
2473143|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810222219
2473302|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200810222304
2473339|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200810222312
2473532|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200810222320
2474135|pass|200810|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810222317
2474805|pass|200810|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810222317
2475248|fail|200810|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.45|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200810230753
2475451|pass|200810|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230042
2475879|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810230118
2476257|pass|200810|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810230102
2476350|pass|200810|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810230106
2476362|pass|200810|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810230007
2476412|pass|200810|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810230109
2476585|pass|200810|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230042
2476637|pass|200810|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230040
2476647|pass|200810|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230042
2476744|pass|200810|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810230030
2476833|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810230207
2476865|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810230218
2476895|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810230222
2477132|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810230449
2477135|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810230450
2477139|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810230451
2477330|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810230626
2477361|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810230635
2477363|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810230636
2477713|pass|200810|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.45|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810231631
2477945|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810231041
2478227|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810231107
2478379|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.45|i86pc-solaris-64int|5.10.0|solaris|2.11|200810231248
2478472|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810231132
2478478|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|i686-linux|5.6.2|linux|2.4.27-3-686|200810231222
2478516|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200810231244
2478663|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.10.0|freebsd|6.1-release|200810231414
2478685|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810231416
2478847|fail|200810|hohokus@gmail.com|Devel-CheckOS|1.45|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200810230941
2479494|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810231726
2479548|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810231842
2480107|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2480933|pass|200810|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232151
2480989|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2481074|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|i686-linux|5.8.8|linux|2.4.27-3-686|200810232130
2481082|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.6.2|freebsd|6.1-release|200810232229
2481358|pass|200810|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232100
2481577|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810232239
2481785|pass|200810|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240003
2482494|pass|200810|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240123
2482565|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810240001
2483115|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200810240215
2483233|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810240655
2484095|pass|200810|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240824
2484114|pass|200810|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484151|pass|200810|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484233|pass|200810|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484461|pass|200810|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484591|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810240947
2485089|pass|200810|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240958
2485503|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|IP35-irix-64int|5.8.8|irix|6.5|200810241215
2486019|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|i586-linux-thread-multi|5.8.8|linux|2.6.16|200810241428
2486095|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810241442
2486113|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810241439
2487352|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810241400
2488319|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810250250
2488744|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810250758
2490042|pass|200810|bingos@cpan.org|Data-Compare|1.21|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200810251236
2490325|pass|200810|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251455
2490399|pass|200810|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251455
2490625|pass|200810|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251454
2491173|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810251546
2492058|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810251638
2492134|pass|200810|stro@cpan.org|Devel-CheckOS|1.45|i686-linux|5.8.8|linux|2.4.27-2-386|200810251741
2492206|pass|200810|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251540
2492486|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810251609
2492844|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810251819
2492857|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810251722
2494614|pass|200810|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252226
2494749|pass|200810|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252223
2495081|pass|200810|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252225
2495509|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200810252129
2495552|pass|200810|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252226
2496066|pass|200810|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252228
2496163|pass|200810|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252229
2496323|pass|200810|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810260009
2496562|pass|200810|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810260009
2496914|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810260107
2497613|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810260509
2497640|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810260550
2498986|pass|200810|rafl@debian.org|Devel-CheckOS|1.45|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200810261508
2499251|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810261651
2499275|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810261639
2499297|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810261714
2499318|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200810261821
2499468|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810261939
2500305|pass|200810|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262156
2500744|pass|200810|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262157
2501284|pass|200810|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262302
2501355|pass|200810|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262157
2501608|pass|200810|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262151
2501723|pass|200810|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262157
2502687|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810270422
2502805|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810270652
2502865|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810270725
2503585|pass|200810|autarch@urth.org|Devel-CheckOS|1.45|x86_64-linux-gnu|5.10.0|linux|2.6.24-15-server|200810270459
2504009|pass|200810|stro@cpan.org|Devel-CheckOS|1.45|i686-linux|5.10.0|linux|2.4.27-2-386|200810270430
2504185|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200810271210
2504471|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271551
2504937|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.45|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271734
2505236|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810271551
2505240|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810271740
2505308|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810271749
2505629|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200810271709
2505988|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200810272139
2506062|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200810272155
2506063|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200810272156
2506064|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810272157
2506067|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200810272158
2506068|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200810272158
2506737|pass|200810|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.46|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200810280933
2507019|pass|200810|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810280325
2507269|pass|200810|gabor@pti.co.il ("Gabor Szabo")|Devel-CheckOS|1.45|i486-linux-gnu|5.8.8|linux|2.6.15.7|200810280542
2507534|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810280300
2507692|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810280606
2507696|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810280608
2507698|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810280609
2508250|pass|200810|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810280801
2508475|pass|200810|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810280801
2508788|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810280809
2508796|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810280818
2508800|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810280819
2508952|pass|200810|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.46|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810281653
2509020|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.46|i86pc-solaris-64int|5.10.0|solaris|2.11|200810281028
2509286|pass|200810|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810281129
2509343|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.46|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281250
2509570|pass|200810|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810281247
2509878|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.01|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281524
2509990|pass|200810|JOST@cpan.org ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281554
2510613|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200810281821
2510615|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200810281822
2510625|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200810281825
2510628|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200810281827
2510832|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|i586-linux-thread-multi|5.8.8|linux|2.6.16|200810282005
2510919|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200810282017
2510931|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200810282020
2511490|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810282313
2511798|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810282356
2512110|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290105
2512344|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290145
2512788|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810290214
2512798|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810290216
2513012|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290401
2513016|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290401
2513133|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290409
2513793|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200810290519
2514498|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200810290725
2514504|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290834
2514752|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290912
2514753|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290912
2514837|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290901
2515288|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810291044
2516057|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291518
2516371|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291556
2516446|pass|200810|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810291504
2516478|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.6|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810291616
2516753|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291637
2516933|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200810291659
2516935|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200810291700
2517027|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291722
2517459|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810291723
2517605|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|i686-linux|5.8.8|linux|2.4.27-3-686|200810291747
2517662|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810291800
2517664|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|IP35-irix-64int|5.8.8|irix|6.5|200810291900
2517712|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810291315
2517761|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810291837
2517906|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200810292043
2518027|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200810292138
2518031|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200810292138
2518078|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|i686-linux|5.6.2|linux|2.4.27-3-686|200810292107
2518110|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200810292217
2518115|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200810292218
2518295|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200810292333
2518304|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810292335
2518625|pass|200810|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.10.0|freebsd|6.1-release|200810300137
2519361|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810300654
2519368|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810300657
2519379|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810300700
2519407|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810300804
2519534|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200810300822
2520307|pass|200810|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810301052
2520628|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200810301125
2521123|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200810301043
2521267|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810301300
2521584|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810301248
2521744|pass|200810|rafl@debian.org|Devel-CheckOS|1.46|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200810301406
2521755|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810301308
2521791|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810301311
2522809|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810301439
2522998|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810301500
2524061|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810302041
2524206|pass|200810|alexchorny@gmail.com|Devel-CheckOS|1.46|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200810301605
2524431|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810302038
2524729|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810302110
2524941|pass|200810|alexchorny@gmail.com|Devel-CheckOS|1.46|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200810301734
2525121|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810302318
2525689|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310106
2526519|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310305
2528098|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310740
2528209|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310756
2528306|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810310543
2528355|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810310720
2528663|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810310637
2529022|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810310743
2529027|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810311016
2529118|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810310945
2529333|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810310847
2529508|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810311157
2529526|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200810311155
2529589|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|Number-Phone|1.6|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810311207
2529657|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.45|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810311221
2529744|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|XML-Tiny|1.11|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810311244
2529946|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810311309
2529997|pass|200810|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.46|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200810311256
2530130|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200810311510
2530145|pass|200810|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.45|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200810311042
2530332|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810311512
2530558|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200810311714
2530598|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200810311724
2531155|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810312117
2531165|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810312125
2532014|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811010701
2532160|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811010744
2532466|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200811010839
2532502|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811010844
2532782|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811010932
2532885|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811011018
2534035|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200811011812
2534107|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811011558
2534123|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200811011854
2534583|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811012020
2535111|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.6.2|freebsd|6.1-release|200811012242
2535874|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811020919
2536236|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811021008
2536237|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811021009
2537140|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811021430
2537248|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811021456
2538157|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811021941
2538385|pass|200811|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811021942
2539180|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200811030147
2539183|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811030150
2539727|pass|200811|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811030815
2541079|pass|200811|schwern@pobox.com|Devel-CheckOS|1.46|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200811030129
2541577|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811031621
2542036|pass|200811|vpit@cpan.org|Devel-CheckOS|1.46|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811031927
2542522|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811032027
2542678|pass|200811|rlane10@wi.rr.com|Devel-CheckOS|1.46|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200811031045
2542819|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811032155
2542832|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811032156
2543230|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811032210
2543298|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i486-linux-gnu|5.8.8|linux|2.6.22.10|200811032250
2543970|pass|200811|vpit@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811040106
2544048|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811040119
2544168|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811040106
2544179|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811040109
2544575|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811040415
2544934|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040531
2544949|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200811040433
2544952|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200811040434
2545268|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040626
2545541|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040747
2545569|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040753
2546290|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|sun4-solaris-64int|5.8.4|solaris|2.10|200811041057
2546913|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811041319
2546981|pass|200811|altblue@gmail.com ("Marius Feraru")|File-Find-Rule-Permissions|1.3|x86_64-linux|5.11.0 patch 34595|linux|2.6.18-8.1.14.el5|200811040044
2547071|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811041235
2547087|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811041339
2548496|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811041751
2548813|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042025
2550270|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200811050048
2550539|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811050439
2551320|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811050829
2552614|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051252
2552717|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051322
2552720|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051322
2552776|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051334
2553083|fail|200811|cbrown@mail ((root))|Devel-CheckOS|1.46|i386-linux|5.8.8|linux|2.6.18-53.1.14.el5xen|200811041414
2553764|pass|200811|rlane10@wi.rr.com|Devel-CheckOS|1.46|darwin-2level-ld|5.10.0|darwin|8.11.0|200811041145
2554662|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811051937
2555016|pass|200811|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200811051933
2555052|pass|200811|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200811051938
2555055|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811052048
2555227|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811052117
2555567|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811052217
2555720|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811052249
2556200|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200811052353
2556214|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200811052355
2556218|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200811052355
2556227|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200811052357
2556243|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200811052354
2556397|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811060121
2556513|pass|200811|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.49_01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200811061104
2556889|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811060446
2557660|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811060652
2557834|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811060723
2557935|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200811060740
2557975|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200811060755
2558649|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811061111
2558755|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.49_01|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811061133
2558802|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.49_01|i86pc-solaris-64int|5.10.0|solaris|2.11|200811061140
2560242|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811061914
2560840|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811062110
2560842|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811062111
2561302|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200811062317
2561375|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200811062340
2561391|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200811062353
2561849|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200811070206
2562116|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811070355
2562127|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811070401
2562184|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811070616
2562584|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811070944
2563372|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071258
2563389|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071301
2563414|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200811071300
2563590|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200811071224
2563595|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200811071225
2564255|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071441
2564363|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200811071500
2564732|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071535
2565220|pass|200811|vpit@cpan.org|Devel-CheckOS|1.49_01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811071653
2565716|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071809
2567524|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811072307
2567855|fail|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.02|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811080017
2567904|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811080031
2569847|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200811081210
2570655|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811081538
2570711|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811081443
2570723|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811081452
2571920|pass|200811|alexchorny@gmail.com|Sub-WrapPackages|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200811081546
2571947|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811082138
2572453|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811082341
2573394|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090239
2573577|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090313
2574056|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090553
2574416|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090653
2575216|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811091043
2575228|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811091048
2575313|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200811081751
2575535|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811082110
2575964|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811090137
2576097|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811090239
2576216|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811090327
2576354|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811090437
2576423|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811090541
2577302|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811082145
2577534|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811090310
2577669|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811090432
2577802|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811091331
2578105|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811091341
2578208|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811090209
2578531|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811090232
2579270|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811090245
2579695|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200811091603
2579703|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200811091604
2579710|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200811091605
2579751|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811091712
2580238|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811092001
2580961|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200811092241
2580967|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200811092243
2582050|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811100723
2582078|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811100726
2582326|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811100809
2582385|pass|200811|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|1.21|i486-linux-gnu|5.10.0|linux|2.6.24-15-server|200811100919
2583005|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811100952
2583698|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811101153
2583840|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811101204
2584335|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811101218
2585044|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811101523
2585532|pass|200811|mw487.yahoo.com@gmail.com|Data-Compare|1.21|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811101037
2585862|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Longest|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811101759
2585863|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Statistics-ChiSquare|0.5|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811101759
2586407|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811102044
2587312|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811110028
2587440|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811110042
2587527|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811110103
2587638|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|i686-linux|5.8.8|linux|2.4.27-3-686|200811110029
2587640|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200811110031
2587641|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|IP35-irix-64int|5.8.8|irix|6.5|200811110131
2587663|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200811110042
2587691|pass|200811|JOST@cpan.org ("Josts Smokehouse")|NestedMap|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811110154
2587697|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|i686-linux|5.6.2|linux|2.4.27-3-686|200811110046
2587984|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110308
2589161|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110650
2589185|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110713
2589391|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811110737
2590240|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110919
2590531|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200811110903
2591312|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811111117
2591868|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811111124
2591883|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811111127
2593003|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200811110859
2593091|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811111247
2593304|unknown|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Licence|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811111642
2593570|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200811111625
2593601|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200811111628
2593627|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200811111630
2593732|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200811111649
2594983|pass|200811|gabor@pti.co.il ("Gabor Szabo")|Devel-CheckOS|1.46|i486-linux-gnu|5.10.0|linux|2.6.24-15-server|200811112313
2595600|pass|200811|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.46|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811111753
2595945|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200811120055
2595946|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200811120056
2595947|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200811120056
2595949|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200811120056
2595950|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200811120056
2595952|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200811120057
2596294|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200811120059
2596797|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200811120242
2597159|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811120500
2597576|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811120650
2597637|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811120708
2597801|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200811120642
2597814|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200811120644
2597818|pass|200811|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200811121544
2597982|pass|200811|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120755
2597996|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120755
2598013|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811120757
2598086|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811120801
2598113|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200811120803
2598372|pass|200811|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120809
2598466|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811120819
2598531|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811120822
2598573|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811120825
2599401|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811121000
2599568|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811120954
2600248|unknown|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Pony|1.1.2|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121057
2600283|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121101
2600480|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121135
2600709|pass|200811|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121131
2601466|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.10.0|solaris|2.11|200811121400
2601594|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121411
2601746|pass|200811|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121403
2601943|pass|200811|hohokus@gmail.com|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200811120834
2602130|pass|200811|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121457
2602468|pass|200811|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121457
2603473|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200811121908
2603481|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811121719
2603489|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811121720
2603493|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200811121914
2603691|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200811121920
2603694|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200811121922
2603695|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200811121923
2604162|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|i586-linux-thread-multi|5.8.8|linux|2.6.16|200811122335
2604312|pass|200811|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130001
2604455|pass|200811|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130001
2604575|pass|200811|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130001
2604699|pass|200811|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130026
2606310|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811130757
2606331|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811130802
2606456|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811130758
2606908|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811130906
2606926|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811130910
2607802|pass|200811|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131049
2608821|pass|200811|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131306
2609436|pass|200811|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131443
2609496|pass|200811|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131443
2609715|pass|200811|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131532
2609908|pass|200811|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811131500
2610048|pass|200811|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811131522
2610198|pass|200811|robbiebow@gmail.com|CPAN-FindDependencies|2.0|i486-linux-gnu|5.10.0|linux|2.6.26.1|200811122351
2610256|pass|200811|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131615
2610415|pass|200811|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200811140034
2610452|pass|200811|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2610645|pass|200811|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2611193|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200811131835
2611223|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200811131840
2611233|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200811131921
2611260|pass|200811|vpit@cpan.org|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811131847
2611359|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200811131852
2611588|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811131811
2611689|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811131825
2612452|pass|200811|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132052
2612701|pass|200811|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132107
2613115|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200811132141
2614137|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811132239
2615275|pass|200811|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132348
2615288|pass|200811|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132348
2616015|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811140029
2616757|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140150
2617296|pass|200811|mthurn@cpan.org|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200811140257
2617329|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140403
2617636|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140518
2618156|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811140733
2618435|pass|200811|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811140748
2618695|pass|200811|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811140750
2619006|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140834
2620460|pass|200811|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141004
2620572|pass|200811|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811140748
2620625|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811141025
2621323|pass|200811|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141123
2621490|pass|200811|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141123
2621677|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200811140501
2621832|pass|200811|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141209
2621900|pass|200811|srezic@cpan.org|Data-Compare|1.21|i686-linux|5.8.9|linux|2.6.18-4-486|200811141203
2622725|pass|200811|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.50|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811140858
2623012|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|i686-linux|5.6.2|linux|2.4.27-3-686|200811141453
2623102|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200811141519
2623103|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200811141519
2623107|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|i686-linux|5.8.8|linux|2.4.27-3-686|200811141519
2624397|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|IP35-irix-64int|5.8.8|irix|6.5|200811141813
2624447|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811141816
2625842|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811142302
2626311|pass|200811|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811150006
2626493|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811142318
2626630|pass|200811|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811150007
2626667|pass|200811|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811150007
2626762|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150024
2626763|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200811142331
2627138|pass|200811|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811150006
2627681|pass|200811|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811150124
2628382|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811150359
2628475|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150517
2628657|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200811150456
2628664|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200811150458
2628823|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150634
2629266|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150819
2632873|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200811161135
2632879|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200811161137
2633154|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200811161249
2633214|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200811161305
2633552|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811161440
2634255|pass|200811|rlane10@wi.rr.com|Devel-CheckOS|1.50|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200811151624
2634399|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811161651
2634650|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811161637
2634691|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811161641
2635457|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811161927
2636444|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811162117
2637023|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811162226
2638283|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811170451
2639731|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200811171306
2640048|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811171609
2641399|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811172327
2641438|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811172217
2641746|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200811180027
2641757|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd|5.10.0|freebsd|6.1-release|200811180029
2642172|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200811180125
2642177|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180126
2642350|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200811180144
2642369|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd|5.6.2|freebsd|6.1-release|200811180117
2642985|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200811180237
2643177|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180351
2643414|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180445
2643566|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180515
2643594|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180512
2643742|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200811180453
2644577|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811180914
2644766|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811180946
2645722|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811181254
2645781|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811181218
2645990|pass|200811|JOST@cpan.org ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181441
2646137|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181505
2646760|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181722
2647154|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811181754
2647682|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811182002
2649448|pass|200811|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190447
2650706|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190859
2651864|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811191400
2652026|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811191553
2652487|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris-64int|5.8.9|solaris|2.11|200811191829
2652489|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811191830
2652993|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811191942
2653123|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192129
2653317|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192205
2653319|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192205
2653778|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811192255
2654011|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811192320
2654013|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.6|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192332
2654271|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200003
2654660|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200044
2655089|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200228
2655915|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811200359
2656392|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200620
2657124|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.8.9|solaris|2.11|200811200832
2657474|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200932
2658270|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811201152
2658653|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811201322
2658696|pass|200811|stro@cpan.org|Data-Compare|1.21|armv5tejl-linux|5.8.8|linux|2.6.17.14|200811201730
2658954|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811201415
2659533|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811201758
2659844|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811201838
2659938|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811201900
2660119|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811201917
2660519|fail|200811|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811202023
2660902|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811202057
2660920|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811202100
2661386|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811202109
2662093|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200811210002
2662766|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200811210158
2663127|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811210309
2664231|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811210935
2664535|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811211039
2664721|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200811211129
2664815|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811211137
2666546|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811212250
2666633|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811212337
2667070|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220320
2667220|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220401
2667663|pass|200811|stro@cpan.org|Data-Compare|1.21|armv5tejl-linux|5.10.0|linux|2.6.17.14|200811220848
2667763|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220614
2668317|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220920
2669079|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811221129
2669945|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811221537
2669975|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811221546
2672840|pass|200811|jeff@zeroclue.com|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.18.8|200811230307
2672888|pass|200811|rafl@debian.org|Devel-CheckOS|1.50|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811230413
2673381|pass|200811|rafl@debian.org|XML-DoubleEncodedEntities|1.0|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811230651
2673626|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811230505
2674615|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811230922
2675217|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811231348
2676161|pass|200811|rafl@debian.org|Data-Compare|1.21|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811232125
2678038|pass|200811|rafl@debian.org|Class-DBI-ClassGenerator|1.01|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240747
2678887|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200811240554
2679219|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811240814
2680013|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811241933
2680361|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200811242131
2682122|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811250602
2682515|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811250743
2682752|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200811250844
2683184|pass|200811|stro@cpan.org|Devel-CheckOS|1.50|armv5tejl-linux|5.10.0|linux|2.6.17.14|200811251247
2684229|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200811251034
2684539|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.18-4-686|200811250930
2685559|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200811250431
2686529|fail|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200811252007
2686586|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811252018
2687313|pass|200811|stsc@refcnt.org ("Steven Schubiger")|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200811252254
2687773|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811260025
2690322|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811260930
2690890|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261142
2691240|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261244
2691249|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200811261146
2691266|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200811261148
2691526|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261302
2691558|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811261249
2691588|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811261259
2692351|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261736
2694091|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.18-4-686|200811270500
2694990|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271010
2695035|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271013
2695139|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271036
2696271|pass|200811|rafl@debian.org|Devel-CheckOS|1.50|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200811271420
2696614|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271526
2696650|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271534
2697611|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271846
2698909|pass|200811|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811272231
2699083|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.8.9|freebsd|7.0-release|200811272254
2699400|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200811272249
2700276|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811280245
2701374|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811280622
2702042|pass|200811|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.8.9|freebsd|7.0-release|200811280745
2703484|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281247
2703503|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281252
2704176|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281304
2704505|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281414
2704593|fail|200811|ackack1024@gmail.com|Bryar|3.0|x86_64-linux-gnu|5.10.0|linux|2.6.22-3-vserver-amd64|200811280034
2705095|pass|200811|srezic@cpan.org|Sort-MultipleFields|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281600
2705307|pass|200811|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281656
2705560|pass|200811|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281702
2706019|pass|200811|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281903
2706021|pass|200811|srezic@cpan.org|CPU-Emulator-Z80|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281903
2706119|pass|200811|srezic@cpan.org|Data-Transactional|1.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281903
2706439|pass|200811|srezic@cpan.org|Number-Phone|1.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200811282003
2707483|pass|200811|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290019
2707819|pass|200811|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290036
2707901|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290043
2708650|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290213
2708838|pass|200811|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290207
2709107|pass|200811|srezic@cpan.org|Games-Dice-Advanced|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290314
2709271|pass|200811|srezic@cpan.org|Sub-WrapPackages|1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290315
2709871|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811290459
2710189|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290641
2710754|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290915
2710866|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290937
2712234|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811291301
2712827|pass|200811|srezic@cpan.org|Class-CanBeA|1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291334
2713044|pass|200811|srezic@cpan.org|File-Overwrite|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291335
2714072|pass|200811|srezic@cpan.org|Palm-SMS|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291337
2714520|pass|200811|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291334
2716111|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811300040
2716120|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811300042
2717845|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200811300924
2718220|pass|200811|"Rick Myers <rick@jrmyers.net>"|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24.3|200811300444
2719984|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200811301552
2720540|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200811301659
2720556|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200811301658
2722147|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811302019
2723860|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200812010046
2724097|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812010137
2724251|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200812010203
2724627|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200812010311
2726411|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|XML-DoubleEncodedEntities|1.0|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812011403
2726822|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812011210
2729332|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812020300
2730254|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200812020607
2730352|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200812020629
2730753|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812020858
2731076|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812020307
2731451|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021111
2731466|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021113
2732934|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021428
2732946|fail|200812|rivy@cpan.org ("Roy Ivy III")|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812020341
2732948|fail|200812|rivy@cpan.org ("Roy Ivy III")|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812020454
2733597|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021605
2734063|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021726
2735721|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812022258
2736160|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812030416
2736235|pass|200812|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.18-4-686|200812030547
2736945|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812030843
2736963|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812030850
2736968|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812030852
2737577|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812031025
2739030|pass|200812|stro@cpan.org|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812031531
2739588|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812031553
2739594|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812031554
2741814|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812032155
2743024|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812040607
2743095|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812040643
2743368|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812040926
2743415|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812040920
2744247|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812041138
2745522|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812041617
2746236|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812041816
2746682|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812041910
2747434|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812042145
2747547|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200812042206
2748728|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200812050103
2748988|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812050338
2749116|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812050401
2749471|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812050437
2749841|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812050514
2751713|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Devel-CheckOS|1.50|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812051112
2752288|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200812051129
2753021|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812051438
2753040|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812051434
2753936|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812051658
2754877|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812052029
2755272|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812052216
2756192|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200812060213
2757104|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812060801
2757570|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200812060938
2757875|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200812061144
2760109|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200812061806
2760549|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812062053
2760698|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812062121
2761654|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812062319
2762696|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Data-Compare|1.21|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812070205
2763041|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812070419
2763250|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812070354
2764240|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812070834
2765084|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071006
2766527|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812071127
2767043|pass|200812|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071009
2767155|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071006
2768263|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812071746
2768458|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812071756
2770111|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812072059
2770543|pass|200812|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072153
2772224|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080152
2772792|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080334
2773286|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080534
2773440|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080645
2774364|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.8.8|linux|2.6.18-92.el5|200812080935
2775728|pass|200812|srezic@cpan.org|Sort-MultipleFields|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081416
2776027|pass|200812|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081449
2776080|pass|200812|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081449
2776152|pass|200812|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081527
2776594|pass|200812|srezic@cpan.org|Data-Transactional|1.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081622
2776837|pass|200812|srezic@cpan.org|CPU-Emulator-Z80|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081622
2776950|pass|200812|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081622
2777481|pass|200812|srezic@cpan.org|Number-Phone|1.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081700
2779448|pass|200812|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.9|freebsd|7.0-release|200812082312
2782107|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812090949
2782725|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812091105
2782913|pass|200812|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091107
2782968|pass|200812|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091102
2782974|pass|200812|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091123
2782996|pass|200812|srezic@cpan.org|CPU-Emulator-Z80|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091124
2783051|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091126
2783242|pass|200812|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091127
2784434|pass|200812|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091209
2784544|pass|200812|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091124
2785638|pass|200812|srezic@cpan.org|Sort-MultipleFields|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091256
2785705|pass|200812|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091234
2786578|pass|200812|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091332
2787491|pass|200812|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091414
2787559|pass|200812|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091415
2788027|pass|200812|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091415
2788306|pass|200812|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091137
2789178|pass|200812|srezic@cpan.org|Number-Phone|1.6|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091232
2789378|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091137
2789569|pass|200812|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091145
2790751|pass|200812|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091637
2791311|pass|200812|srezic@cpan.org|Data-Transactional|1.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091130
2791699|pass|200812|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091636
2791702|pass|200812|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091135
2793718|pass|200812|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812092201
2794124|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812092252
2794647|pass|200812|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.8.9|freebsd|7.0-release|200812092124
2795233|pass|200812|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.8.8|freebsd|7.0-release|200812100006
2795306|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812100101
2795329|pass|200812|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100013
2796282|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812100345
2796290|pass|200812|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200812100246
2796907|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812100621
2798039|pass|200812|srezic@cpan.org|Games-Dice-Advanced|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100855
2798287|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812101018
2798388|pass|200812|srezic@cpan.org|Games-Dice-Advanced|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812101005
2800622|pass|200812|srezic@cpan.org|File-Overwrite|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812101524
2800852|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200812101452
2800876|pass|200812|srezic@cpan.org|File-Overwrite|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812101524
2801403|pass|200812|fayland@gmail.com ("Fayland Lam")|Data-Compare|1.21|i386-linux|5.8.6|linux|2.6.9-34.elsmp|200812100817
2801494|pass|200812|srezic@cpan.org|Class-CanBeA|1.2|amd64-freebsd|5.8.8|freebsd|7.0-release|200812101628
2801623|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200812101728
2802464|pass|200812|srezic@cpan.org|Class-CanBeA|1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200812101824
2804353|pass|200812|srezic@cpan.org|Palm-SMS|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200812102246
2804681|pass|200812|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812102312
2804813|pass|200812|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812102313
2805174|pass|200812|srezic@cpan.org|Palm-SMS|0.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200812102313
2805789|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812110053
2806541|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.10.0|freebsd|7.0-release|200812110753
2808229|pass|200812|srezic@cpan.org|Statistics-SerialCorrelation|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812111228
2808263|pass|200812|srezic@cpan.org|Statistics-SerialCorrelation|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812111228
2809562|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812111431
2809848|pass|200812|srezic@cpan.org|Tie-Hash-Longest|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812111619
2809851|pass|200812|srezic@cpan.org|Statistics-ChiSquare|0.5|amd64-freebsd|5.8.8|freebsd|7.0-release|200812111619
2809905|pass|200812|srezic@cpan.org|Statistics-ChiSquare|0.5|amd64-freebsd|5.8.9|freebsd|7.0-release|200812111619
2810112|pass|200812|srezic@cpan.org|Tie-Hash-Longest|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812111619
2811405|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.6.2|freebsd|7.0-release|200812112151
2811883|pass|200812|srezic@cpan.org|NestedMap|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812112229
2811921|pass|200812|srezic@cpan.org|NestedMap|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812112230
2812369|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200812112308
2812566|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200812112335
2813036|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200812120105
2813038|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200812120105
2814278|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812120728
2814386|unknown|200812|srezic@cpan.org|Acme-Licence|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812120840
2814813|unknown|200812|srezic@cpan.org|Acme-Licence|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812120848
2817042|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.18-4-686|200812121620
2817047|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200812121621
2817048|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121621
2817254|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121634
2817255|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121637
2818742|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121927
2819533|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.0-release|200812122018
2820611|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200812130038
2820804|pass|200812|andy@hexten.net|Devel-CheckOS|1.50|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200812130117
2821002|pass|200812|srezic@cpan.org|Tie-Hash-Rank|1.0.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812130246
2821016|pass|200812|srezic@cpan.org|Tie-Hash-Rank|1.0.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812130246
2821110|pass|200812|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812130257
2821122|pass|200812|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812130257
2821229|unknown|200812|srezic@cpan.org|Acme-Pony|1.1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200812130246
2821240|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812130223
2821344|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200812130233
2821357|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812130239
2821406|unknown|200812|srezic@cpan.org|Acme-Pony|1.1.2|amd64-freebsd|5.8.8|freebsd|7.0-release|200812130246
2821425|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812130252
2822282|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812130920
2823527|fail|200812|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200812131152
2823660|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812131155
2824656|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812131413
2828016|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200812140459
2828047|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812140608
2829387|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200812141129
2829396|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200812141130
2830115|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141423
2830148|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141427
2830281|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|darwin-2level|5.10.0|darwin|8.11.1|200812141408
2830300|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|darwin-2level|5.10.0|darwin|8.11.1|200812141411
2831034|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141557
2831500|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141707
2832569|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141947
2832650|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812141901
2832930|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.18-4-686|200812142100
2833867|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812142334
2835370|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200812150522
2836735|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.18-4-686|200812151501
2836740|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200812151502
2839840|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200812160329
2843801|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812161611
2844746|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812161906
2845107|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812161942
2845633|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812162048
2845878|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812162120
2845909|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812162124
2846388|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812162214
2846671|pass|200812|stro@cpan.org|DBIx-Class-SingletonRows|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200812162354
2847277|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812162242
2847950|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812170001
2849222|pass|200812|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200812161530
2849275|pass|200812|wolfman.ncsu2000@gmail.com|Devel-CheckOS|1.50|darwin-2level|5.10.0|darwin|9.5.0|200812161800
2849289|pass|200812|wolfman.ncsu2000@gmail.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.5.0|200812161813
2849440|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170143
2851400|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170447
2853227|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170252
2853285|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200812170858
2854457|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812171144
2854842|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171258
2854913|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171312
2855399|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812171405
2856215|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171459
2856409|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171511
2856657|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.18-4-686|200812171543
2857148|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812171628
2857770|pass|200812|rhaen@cpan.org (Ulrich Habel)|Devel-CheckOS|1.50|i386-netbsd|5.10.0|netbsd|5.0_beta|200812171618
2857853|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812171615
2858912|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171346
2859596|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171524
2861126|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180001
2861439|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812180152
2861591|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180115
2861592|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180115
2861966|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200812180150
2862222|pass|200812|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180223
2862505|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180258
2862575|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180311
2862576|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180311
2862849|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812180450
2862970|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180409
2863975|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812180758
2864299|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812180750
2864423|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812180724
2864465|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200812180809
2864474|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812180809
2864717|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812180844
2864805|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180358
2865836|pass|200812|vutral@gmail.com|Data-Compare|1.21|x86_64-linux-gnu|5.8.8|linux|2.6.26-1-vserver-amd64|200812180200
2866826|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812181205
2867138|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180825
2867688|pass|200812|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180954
2867800|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181506
2868546|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812181749
2868648|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812181801
2868649|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181203
2868906|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812181830
2869146|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181305
2869551|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181348
2870198|pass|200812|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812190343
2870238|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812182045
2870415|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812182102
2870523|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812182112
2870612|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812182118
2870726|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812182127
2870795|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812182132
2870944|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812182149
2871153|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812182009
2871313|pass|200812|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181620
2871351|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200812182222
2871924|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181711
1883728|pass|200807|mw487.yahoo.com@gmail.com|Data-Hexdumper|1.4|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200807120916
1896279|pass|200807|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200807151949
1973625|pass|200808|mw487.yahoo.com@gmail.com|XML-Tiny|1.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200808020125
2498600|pass|200810|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.44|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200810260600
2315664|pass|200809|jeff@zeroclue.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.2.0|200809261459
2315682|pass|200809|jeff@zeroclue.com|XML-DoubleEncodedEntities|1.0|darwin-2level|5.10.0|darwin|9.2.0|200809261539
2316178|pass|200809|jeff@zeroclue.com|Devel-CheckOS|1.43|darwin-2level|5.10.0|darwin|9.2.0|200809261645
2348696|fail|200809|jeff@zeroclue.com|Class-DBI-ClassGenerator|1.0|darwin-2level|5.10.0|darwin|9.2.0|200809300310
2637111|pass|200811|jeff@zeroclue.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.2.0|200811161337
2637310|pass|200811|jeff@zeroclue.com|Devel-CheckOS|1.50|darwin-2level|5.10.0|darwin|9.2.0|200811161412
2637720|pass|200811|jeff@zeroclue.com|Devel-CheckOS|1.49_01|darwin-2level|5.10.0|darwin|9.2.0|200811161554
2873201|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812190000
2873297|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.6.2|freebsd|7.0-release|200812190105
2873610|pass|200812|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812190833
2874399|pass|200812|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190150
2874665|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190220
2874953|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190259
2876360|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190134
2876685|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190216
2877419|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190843
2879660|fail|200812|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190819
2879718|pass|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190830
2880250|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812191538
2881650|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191723
2881720|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191233
2882111|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191310
2882117|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191310
2882982|pass|200812|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191448
2883908|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812192235
2883928|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812192238
2884187|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812192209
2885389|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200009
2885630|pass|200812|rhaen@cpan.org (Ulrich Habel)|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812200028
2886280|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812200127
2886887|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200250
2886959|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200256
2887031|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200305
2887113|pass|200812|imacat@mail.imacat.idv.tw|Number-Phone|1.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812201113
2887212|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812200322
2891001|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200928
2891047|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200931
2892048|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812201605
2892266|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812201627
2892522|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812201714
2893169|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812201808
2893502|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200812201849
2894325|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812201534
2895545|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812202304
2895875|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812202348
2896124|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812210021
2897833|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210048
2898774|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210302
2900393|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812211106
2900660|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210640
2900706|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812211142
2901362|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210758
2901366|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210758
2902320|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812211533
2902335|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211037
2902449|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211052
2902457|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211052
2902634|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812211616
2903009|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211211
2904781|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211756
2905324|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812220006
2906678|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220428
2906994|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812220523
2907217|pass|200812|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220121
2908320|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812220925
2908326|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812220926
2908670|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220416
2909264|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220542
2909708|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220645
2910034|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200812221231
2910076|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200812221239
2911775|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200812221903
2911789|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200812221905
2912851|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812222326
2913208|pass|200812|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812221817
2913520|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812230056
2913521|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812230057
2913601|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230007
2913921|pass|200812|rhaen@cpan.org (Ulrich Habel)|Data-Compare|1.21|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812230056
2914905|pass|200812|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230350
2915226|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230458
2915479|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200812230552
2915507|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200812230557
2916888|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230351
2917138|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230432
2918558|unknown|200812|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232145
2918561|unknown|200812|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232145
2918563|pass|200812|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232146
2918583|fail|200812|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232149
2918586|pass|200812|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232150
2918589|pass|200812|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232150
2918601|pass|200812|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232151
2918602|pass|200812|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232152
2918628|pass|200812|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.4|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232157
2918631|pass|200812|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232158
2918634|pass|200812|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232158
2918638|pass|200812|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232159
2918643|pass|200812|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232159
2918646|pass|200812|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232159
2918650|pass|200812|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232200
2918661|pass|200812|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232201
2918668|pass|200812|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232202
2918680|pass|200812|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232204
2918697|pass|200812|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232206
2918699|pass|200812|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232206
2918700|pass|200812|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232206
2918704|pass|200812|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232207
2918710|pass|200812|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232207
2918712|pass|200812|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232207
2918716|pass|200812|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232208
2918718|pass|200812|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232208
2918720|pass|200812|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232209
2918721|pass|200812|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232209
2918722|pass|200812|imacat@mail.imacat.idv.tw|XML-Tiny|1.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232209
2919291|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812231502
2919546|fail|200812|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231042
2919615|pass|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231050
2921115|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812231853
2921664|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231501
2921955|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231537
2921957|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231537
2922125|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812232106
2922744|pass|200812|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231759
2923002|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812232325
2923611|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240212
2924466|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240452
2924504|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240457
2924535|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240004
2926641|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812240957
2926853|pass|200812|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int|5.6.2|linux|2.4.26|200812241109
2928116|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812241554
2929091|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812241937
2929486|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200812242118
2929897|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812250031
2929898|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812250031
2930317|pass|200812|yanick@cpan.org ("Yanick Champoux")|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.22-gentoo-r2enkidu|200812241237
2933025|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812251348
2933026|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812251348
2933659|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200812252043
2938494|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200812262114
2939739|pass|200812|davidrw@cpan.org|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200812270346
2939983|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.18-4-686|200812270958
2940826|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812271408
2943274|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812272317
2943341|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812272329
2947073|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812280846
2947328|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812280915
2948935|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812281405
2949187|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200812281409
2949939|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812281750
2950457|pass|200812|bingos@cpan.org|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812282054
2951440|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812290139
2953740|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812291511
2953742|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812291512
2953993|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812291627
2953998|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812291628
2955398|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812292207
2956271|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812300130
2956422|pass|200812|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300215
2956428|pass|200812|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300215
2956429|pass|200812|bingos@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300216
2956431|pass|200812|bingos@cpan.org|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300218
2956432|pass|200812|bingos@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300217
2956452|pass|200812|bingos@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956453|pass|200812|bingos@cpan.org|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956454|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300224
2956456|pass|200812|bingos@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956457|pass|200812|bingos@cpan.org|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300221
2956461|pass|200812|bingos@cpan.org|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300221
2956463|pass|200812|bingos@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300222
2956465|pass|200812|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300218
2956474|pass|200812|bingos@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300222
2956487|pass|200812|bingos@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300221
2956494|pass|200812|bingos@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956495|pass|200812|bingos@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300219
2956497|pass|200812|bingos@cpan.org|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300219
2957197|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812300611
2962681|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812311512
2963147|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812311739
2963177|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812311740
2963351|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812311746
2963683|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812311840
2964004|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812312003
2964005|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812312004
2964154|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812312109
2964386|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812312216
2965522|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901010245
2966094|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901010440
2970431|pass|200812|schwern@pobox.com|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200812311350
2972816|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901020241
2975571|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901020803
2975607|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901020814
2977034|pass|200901|pjacklam@online.no|Statistics-ChiSquare|0.5|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200901021648
2977742|pass|200901|pjacklam@online.no|Statistics-SerialCorrelation|1.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200901021812
2980384|pass|200901|vutral@gmail.com|Devel-CheckOS|1.50|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.26-1-vserver-amd64|200901021136
2983106|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901031244
2984385|fail|200901|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901031821
2988399|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200901041000
2989226|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901040921
2989280|pass|200901|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901040940
2989302|pass|200901|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901040946
2989367|pass|200901|cpan.dcollins.5100rc2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901040956
2989567|pass|200901|cpan.dcollins.blead@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041021
2989644|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901041630
2990077|pass|200901|cpan.dcollins.5100@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041115
2990207|pass|200901|cpan.dcollins.blead@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041121
2990404|pass|200901|cpan.dcollins.blead@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041140
2990588|pass|200901|cpan.dcollins.5100@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041158
2990736|pass|200901|cpan.dcollins.5100@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041218
2992341|pass|200901|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041437
2992353|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041438
2992362|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041439
2992423|pass|200901|cpan.dcollins.5100@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041444
2992512|pass|200901|cpan.dcollins.589@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901041452
2993181|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200901042205
2993215|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041606
2993227|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200901042207
2993275|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041611
2993573|pass|200901|cpan.dcollins.589@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901041638
2994599|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901050025
2995379|pass|200901|cpan.dcollins.s1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041443
2995415|pass|200901|bobtfish@bobtfish.net|Devel-CheckOS|1.50|darwin-thread-multi-2level|5.8.6|darwin|8.0|200901042109
2995926|pass|200901|fayland@gmail.com ("Fayland Lam")|Devel-CheckOS|1.50|i386-linux-thread-multi|5.8.6|linux|2.6.9-34.elsmp|200901050300
2997005|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901051045
2998795|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901051656
2998800|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901051657
2998880|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901051709
2998888|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901051710
3002020|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901052322
3002205|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901052336
3002265|pass|200901|cpan.dcollins.5100rc1@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901051840
3002332|pass|200901|cpan.dcollins.5100@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901051843
3002521|pass|200901|cpan.dcollins.5100rc2@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901051851
3002553|pass|200901|cpan.dcollins.blead@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901051852
3002714|pass|200901|cpan.dcollins.589@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901060007
3002946|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901060033
3003702|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901060245
3006895|pass|200901|alceu.freitas.jr@gmail.com|Devel-CheckOS|1.50|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-14-server|200901060041
3007544|pass|200901|cpan.dcollins.s1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901060632
3007551|pass|200901|cpan.dcollins.s2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901060633
3008585|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901061355
3009674|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901061558
3009704|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901061600
3010481|pass|200901|stsc@refcnt.org ("Steven Schubiger")|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.18-4-686|200901061820
3011821|fail|200901|imacat@mail.imacat.idv.tw|Palm-SMS|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901070326
3012451|pass|200901|davidrw@cpan.org|XML-Tiny|1.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061526
3012845|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901062203
3012853|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901062203
3013870|pass|200901|cpan.dcollins.s3@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061635
3013872|pass|200901|cpan.dcollins.s3@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061637
3013892|pass|200901|cpan.dcollins.s3@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061659
3014349|pass|200901|cpan.dcollins.s3@gmail.com|Tie-STDOUT|1.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061658
3014615|pass|200901|davidrw@cpan.org|Class-DBI-ClassGenerator|1.01|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901070159
3016330|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070353
3016455|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070404
3016625|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070424
3016659|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070428
3016712|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070434
3016961|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200901071102
3016985|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200901071103
3017173|pass|200901|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070523
3017384|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200901071212
3017425|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200901071218
3017659|pass|200901|cpan.dcollins.589@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070642
3017842|pass|200901|cpan.dcollins.blead@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070657
3017848|pass|200901|cpan.dcollins.blead@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070657
3017959|pass|200901|cpan.dcollins.589@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070708
3017965|pass|200901|cpan.dcollins.589@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070709
3018043|pass|200901|cpan.dcollins.blead@gmail.com|Tie-STDOUT|1.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070717
3018049|pass|200901|cpan.dcollins.blead@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070717
3018162|pass|200901|cpan.dcollins.589@gmail.com|Tie-STDOUT|1.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070729
3018177|pass|200901|cpan.dcollins.589@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070730
3020466|pass|200901|davidrw@cpan.org|Sort-MultipleFields|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901071550
3020801|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901071613
3021091|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200901072153
3021121|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200901072157
3022738|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901080309
3022740|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901080310
3023078|pass|200901|davidrw@cpan.org|Data-Hexdumper|1.4|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080347
3023203|pass|200901|davidrw@cpan.org|Palm-Treo680MessagesDB|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080417
3025042|pass|200901|davidrw@cpan.org|DBIx-Class-SingletonRows|0.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080854
3025313|pass|200901|davidrw@cpan.org|Data-Transactional|1.02|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081022
3025402|pass|200901|davidrw@cpan.org|CPU-Emulator-Memory|1.1001|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081046
3025405|pass|200901|davidrw@cpan.org|CPU-Emulator-Z80|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081046
3026194|pass|200901|davidrw@cpan.org|Number-Phone|1.6|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081254
3026216|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.18-4-686|200901081931
3028031|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901082204
3028034|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901082205
3030345|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901090719
3030353|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901090720
3030465|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901090743
3031056|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901090940
3032394|pass|200901|davidrw@cpan.org|Devel-CheckLib|0.5|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901090906
3034476|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901092038
3034562|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901092059
3034980|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901092019
3035363|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901092309
3035629|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901092346
3035762|pass|200901|davidrw@cpan.org|CPAN-FindDependencies|2.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901091803
3036705|pass|200901|davidrw@cpan.org|Bryar|3.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901100141
3037456|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901100503
3038236|pass|200901|davidrw@cpan.org|File-Find-Rule-Permissions|1.3|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901100102
3041175|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200901101721
3041177|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200901101722
3041179|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200901101722
3041195|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200901101721
3041654|pass|200901|davidrw@cpan.org|Tie-STDOUT|1.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901101247
3041909|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901101400
3042141|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901101443
3042195|pass|200901|cpan.dcollins.5100rc2@gmail.com|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901101450
3042321|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901102116
3042349|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200901102120
3042384|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.8.8|freebsd|7.0-release|200901102120
3042646|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.10.0|freebsd|7.0-release|200901102230
3042724|pass|200901|davidrw@cpan.org|Palm-TreoPhoneCallDB|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901101653
3042788|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901102307
3043291|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901110038
3043567|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200901110034
3043569|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200901110035
3043571|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200901110036
3043574|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200901110037
3044048|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901110423
3045008|pass|200901|davidrw@cpan.org|Net-Random|2.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901110346
3045176|pass|200901|stro@cpan.org|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200901111157
3045241|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901111027
3045453|na|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.6.2|freebsd|7.0-release|200901111226
3045905|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901110805
3045969|pass|200901|imacat@mail.imacat.idv.tw|Palm-SMS|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901112222
3046396|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901111740
3046521|pass|200901|davidrw@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111201
3046732|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|i686-linux|5.8.8|linux|2.4.27-3-686|200901111739
3046733|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901111741
3046741|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|IP35-irix-64int|5.8.8|irix|6.5|200901111842
3046858|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901111813
3047439|pass|200901|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.03|i86pc-solaris-64int|5.10.0|solaris|2.11|200901112123
3047586|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901111422
3047835|pass|200901|bingos@cpan.org|Number-Phone|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901111319
3048049|pass|200901|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112144
3049043|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901120101
3049355|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901120147
3049614|pass|200901|davidrw@cpan.org|Games-Dice-Advanced|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901120250
3050815|pass|200901|davidrw@cpan.org|Sub-WrapPackages|1.2|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901120204
3051732|pass|200901|bingos@cpan.org|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901120939
3051755|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901121042
3051816|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901121104
3051972|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901121204
3051993|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200901121217
3052076|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200901121238
3052262|pass|200901|mohsen_basirat@yahoo.com ("Mohsen Basirat")|Devel-CheckOS|1.50|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.15.7|200901121712
3052901|unknown|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901121535
3052903|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901121535
3055025|pass|200901|vpit@cpan.org|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901122043
3055128|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901121940
3055305|pass|200901|davidrw@cpan.org|File-Overwrite|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901121509
3055374|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901122015
3055379|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901122016
3055877|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901122120
3055888|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901122223
3056023|pass|200901|davidrw@cpan.org|Class-CanBeA|1.2|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901121639
3056648|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.18-4-686|200901130030
3057594|pass|200901|bingos@cpan.org|Palm-SMS|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901130224
3057888|pass|200901|bingos@cpan.org|Palm-SMS|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901130306
3058988|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901130645
3059229|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901130719
3060174|pass|200901|rhaen@cpan.org (Ulrich Habel)|Palm-SMS|0.03|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901131039
3060676|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901131256
3060926|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901131342
3061039|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901131400
3061210|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901131417
3061988|pass|200901|bingos@cpan.org|Palm-SMS|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901131530
3062551|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901131827
3062786|fail|200901|davidrw@cpan.org|Palm-SMS|0.02|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901131320
3062866|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901131833
3062876|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901131934
3062904|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200901131439
3062953|pass|200901|davidrw@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901131345
3063656|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200901131705
3064812|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901140209
3064835|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901140213
3066864|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901141226
3068176|pass|200901|davidrw@cpan.org|Statistics-SerialCorrelation|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901141202
3068842|pass|200901|davidrw@cpan.org|Tie-Hash-Longest|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901141522
3068845|pass|200901|davidrw@cpan.org|Statistics-ChiSquare|0.5|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901141522
3069414|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200901142328
3069447|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200901142332
3069556|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901142247
3070623|pass|200901|davidrw@cpan.org|NestedMap|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901150300
3071702|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901150848
3071881|pass|200901|billf@FreeBSD.org ("Bill Fumerola")|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200901150502
3071928|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901150934
3072868|pass|200901|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.8.9|linux|2.6.26-1-amd64|200901151555
3073733|unknown|200901|davidrw@cpan.org|Acme-Licence|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901151351
3075263|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901160127
3075384|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200901160205
3075501|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200901160244
3076468|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901160745
3076974|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901161005
3077674|unknown|200901|davidrw@cpan.org|Acme-Pony|1.1.2|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901160944
3077761|pass|200901|davidrw@cpan.org|Tie-Hash-Rank|1.0.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901161000
3077829|pass|200901|davidrw@cpan.org|Tie-Scalar-Decay|1.1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901161016
3078106|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901161557
3078430|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200901161710
3078438|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200901161710
3078481|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|alpha-netbsd|5.10.0|netbsd|4.0.1|200901161717
3078818|pass|200901|stro@cpan.org|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901162017
3078878|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901161836
3079684|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901162124
3080154|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901162347
3080479|fail|200901|bingos@cpan.org|Bryar|3.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200901170133
3080489|pass|200901|bingos@cpan.org|Bryar|3.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200901170134
3080494|pass|200901|bingos@cpan.org|Bryar|3.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200901170135
3080878|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901170309
3080893|pass|200901|bingos@cpan.org|Palm-SMS|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200901170310
3081216|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901170539
3082000|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901171011
3082067|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901171023
3082188|pass|200901|bingos@cpan.org|Data-Compare|1.21|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200901171047
3082367|fail|200901|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200901171254
3083075|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901171606
3083181|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901171631
3083183|fail|200901|srezic@cpan.org|Bryar|3.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901171727
3083730|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901171928
3083833|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901171941
3083867|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901171848
3084047|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901172007
3084160|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901172023
3084385|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901172058
3084426|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901172105
3084438|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901172106
3084638|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901172128
3084851|pass|200901|bingos@cpan.org|Palm-SMS|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200901172048
3084921|fail|200901|david@cantrell.org.uk|Bryar|3.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901172056
3084958|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200901172201
3085078|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200901172216
3085202|fail|200901|david@cantrell.org.uk|Bryar|3.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200901172135
3085316|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901172246
3085423|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901172306
3085556|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901172221
3086173|fail|200901|rhaen@cpan.org (Ulrich Habel)|Bryar|3.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901180013
3087406|pass|200901|bingos@cpan.org|Data-Compare|1.21|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200901180805
3087642|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901181036
3087651|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.18-4-686|200901181040
3088536|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901181254
3088616|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901181318
3088650|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901181322
3090667|pass|200901|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.6.2|freebsd|7.0-release|200901181839
3091576|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200901182023
3091579|fail|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200901182024
3092109|pass|200901|davidrw@cpan.org|Palm-SMS|0.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901181726
3093276|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200901190415
3093840|pass|200901|rhaen@cpan.org (Ulrich Habel)|XML-Tiny|1.11|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901190727
3093903|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901190842
3094021|pass|200901|mw487.yahoo.com@gmail.com|Palm-SMS|0.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200901190317
3094816|pass|200901|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200901191104
3094992|pass|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200901191135
3096218|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200901191507
3098209|pass|200901|vpit@cpan.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901192012
3099593|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901192222
3100693|pass|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901200111
3100701|pass|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200901200112
3101214|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901200327
3101252|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901200336
3101452|fail|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901200437
3101854|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901200624
3102253|pass|200901|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200902
3102255|pass|200901|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200902
3102288|pass|200901|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200910
3102298|pass|200901|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200911
3102315|pass|200901|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200914
3102316|pass|200901|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200914
3102331|pass|200901|david@cantrell.org.uk|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200917
3102333|pass|200901|david@cantrell.org.uk|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200917
3102335|pass|200901|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200918
3102336|pass|200901|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200918
3102343|pass|200901|david@cantrell.org.uk|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200919
3102344|pass|200901|david@cantrell.org.uk|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200919
3102349|pass|200901|david@cantrell.org.uk|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200919
3102350|pass|200901|david@cantrell.org.uk|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200919
3103416|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.18-4-686|200901201357
3103802|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901201514
3103902|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201433
3104594|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201511
3104600|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901201745
3104736|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201620
3105743|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200901202105
3106475|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901210141
3106869|fail|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901210230
3107068|pass|200901|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901210203
3107565|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901210553
3108972|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901211210
3110542|pass|200901|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901211610
3110600|pass|200901|jeff@zeroclue.com|Data-Compare|1.21|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901211747
3113403|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901220631
3113641|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901220740
3113680|fail|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901220746
3114002|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901220912
3114664|pass|200901|jeff@zeroclue.com|Palm-SMS|0.03|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901221238
3115222|pass|200901|jeff@zeroclue.com|Devel-CheckOS|1.50|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901221507
3115892|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901221741
3116396|pass|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200901221937
3117051|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901230015
3117085|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200901222352
3117087|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200901222352
3117361|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200901230056
3117362|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200901230056
3117364|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200901230057
3117366|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200901230057
3117367|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200901230058
3117644|pass|200901|davidrw@cpan.org|XML-Tiny|1.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901230321
3118206|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200901230711
3118207|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200901230711
3118208|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200901230712
3118210|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200901230712
3118228|pass|200901|rhaen@cpan.org (Ulrich Habel)|Sort-MultipleFields|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901230618
3118327|pass|200901|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200901231542
3118848|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901230907
3118883|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901230915
3118982|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901230931
3119057|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901230944
3119145|pass|200901|imacat@mail.imacat.idv.tw|XML-Tiny|1.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901231703
3119175|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901231013
3119384|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901231045
3119456|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901230847
3119457|fail|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901230847
3119467|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901231101
3119468|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200901231102
3119496|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901231107
3119536|pass|200901|rhaen@cpan.org (Ulrich Habel)|Data-Hexdumper|1.4|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901231015
3119538|pass|200901|rhaen@cpan.org (Ulrich Habel)|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901231015
3119547|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200901231117
3119557|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901231119
3119755|pass|200901|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.18-4-686|200901231144
3119819|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901231154
3119868|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200901231104
3120019|pass|200901|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200901231250
3120191|pass|200901|stro@cpan.org|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901231349
3120883|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200901231435
3121016|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200901231510
3121194|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|IP35-irix-64int|5.8.8|irix|6.5|200901231653
3121313|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901231606
3121412|fail|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200901231613
3121414|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901231614
3121468|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200901231624
3121519|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901231637
3121780|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901231729
3121783|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901231729
3121805|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|alpha-netbsd|5.10.0|netbsd|4.0.1|200901231732
3121822|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901231134
3121964|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200901231757
3122534|pass|200901|stro@cpan.org|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200901232155
3122728|pass|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200901232029
3123194|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901232207
3123823|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200901240027
3124660|pass|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200901240355
3124819|pass|200901|rhaen@cpan.org (Ulrich Habel)|Data-Transactional|1.02|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240442
3124845|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901240449
3124901|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901240508
3124996|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240538
3124997|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240538
3125657|pass|200901|rhaen@cpan.org (Ulrich Habel)|Number-Phone|1.6|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901241015
3125747|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int|5.8.8|linux|2.4.26|200901241042
3125882|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.10.0|freebsd|7.0-release|200901241208
3126151|fail|200901|bingos@cpan.org|Bryar|3.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901241232
3126500|pass|200901|vpit@cpan.org|XML-Tiny|1.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901241509
3126707|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901241438
3126734|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200901241543
3126741|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200901241546
3127495|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200901241718
3128380|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200901242139
3128767|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200901242313
3129686|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901250159
3129721|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200901250314
3130481|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200901251022
3130866|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901251109
3132000|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.18-4-686|200901251705
3133636|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901260223
3133678|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901260246
3133836|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901260340
3133852|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901260346
3135680|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901261141
3135783|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901261204
3135813|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901261309
3136871|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.18-4-686|200901261733
3137864|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901262051
3138299|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.6.2|freebsd|7.0-release|200901262311
3139120|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200901270014
3139208|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200901270020
3141201|pass|200901|rhaen@cpan.org (Ulrich Habel)|Devel-CheckLib|0.5|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901270439
3142492|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901271224
3142519|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200901271139
3143418|pass|200901|rlane10@wi.rr.com|Devel-CheckOS|1.50|darwin-2level-ld|5.10.0|darwin|8.11.0|200901270153
3144749|pass|200901|cjfields@bioperl.org|XML-Tiny|1.12|darwin-2level|5.10.0|darwin|9.2.0|200901271052
3146371|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200901280126
3146470|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901280201
3147913|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901281125
3148184|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901280748
3148256|pass|200901|rlane10@wi.rr.com|XML-Tiny|1.12|darwin-2level-ld|5.10.0|darwin|8.11.0|200901271703
3148341|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901280757
3149104|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200901281115
3150091|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200901281345
3150295|pass|200901|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|x86_64-linux-ld|5.10.0|linux|2.6.27-9-generic|200901281506
3150835|pass|200901|bingos@cpan.org|XML-Tiny|1.12|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200901281559
3151148|pass|200901|bingos@cpan.org|XML-Tiny|1.12|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901281647
3152204|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200901290241
3152777|fail|200901|cpan.dcollins.blead@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901290338
3152825|fail|200901|cpan.dcollins.5100@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901290342
3152896|pass|200901|cpan.dcollins.589@gmail.com|XML-Tiny|1.12|i686-linux-thread-multi|0|linux|2.6.24-19-generic|200901290345
3153489|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290133
3153540|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290155
3153617|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901290218
3153623|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901290218
3155515|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291200
3155540|pass|200901|rhaen@cpan.org (Ulrich Habel)|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901291236
3156187|pass|200901|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200901291442
3157695|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901291950
3160093|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901300249
3160855|pass|200901|stro@cpan.org|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300559
3161599|pass|200901|vovkasm@gmail.com|Devel-CheckOS|1.50|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200901291221
3162691|pass|200901|rafl@debian.org|XML-Tiny|1.12|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200901301249
3164246|fail|200901|stro@cpan.org|Bryar|3.0|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300758
3164789|pass|200901|stro@cpan.org|Data-Compare|1.21|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300941
3165345|pass|200901|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901302022
3166563|pass|200901|stro@cpan.org|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901301436
3167132|pass|200901|stro@cpan.org|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901310037
3169338|pass|200901|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310904
3170148|pass|200901|cpan.dcollins.5100rc2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310956
3170593|pass|200901|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311032
3170596|pass|200901|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311033
3172441|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.18-4-686|200901312121
3174834|pass|200902|cpan.dcollins.s2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010413
3175183|pass|200902|cpan.dcollins.s2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010025
3175187|pass|200902|cpan.dcollins.s2@gmail.com|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010025
3175190|pass|200902|cpan.dcollins.s2@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010026
3175292|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902010655
3179540|pass|200902|cpan.dcollins.s3@gmail.com|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902010425
3179541|pass|200902|cpan.dcollins.s3@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902010426
3180592|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902020000
3181192|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902020221
3182198|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902020811
3183037|pass|200902|"Rick Myers <rick@jrmyers.net>"|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.24.3|200902020456
3183902|pass|200902|mw487.yahoo.com@gmail.com|XML-Tiny|1.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902020835
3184408|pass|200902|david@cantrell.org.uk|Devel-CheckOS|1.50|alpha-netbsd|5.10.0|netbsd|4.0.1|200902021525
3191738|pass|200902|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902031317
3192181|pass|200902|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902031533
3192224|pass|200902|cpan.dcollins.589@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902031541
3197695|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902041136
3199931|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902041348
3200634|pass|200902|cpan.dcollins.5100rc1@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902041611
3201003|pass|200902|cpan.dcollins.589@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902041637
3201070|pass|200902|cpan.dcollins.5100@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902041642
3201739|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902042227
3202413|pass|200902|cpan.dcollins.blead@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902041845
3202691|pass|200902|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050005
3203291|pass|200902|cpan.dcollins.blead@gmail.com|XML-Tiny|1.12|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902050051
3203507|pass|200902|cpan.dcollins.589@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902050126
3203592|pass|200902|cpan.dcollins.5100@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050138
3203703|pass|200902|cpan.dcollins.5100rc2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050153
3204141|pass|200902|cpan.dcollins.s2@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902050245
3204156|pass|200902|cpan.dcollins.s1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050246
3205407|fail|200902|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902050311
3206339|pass|200902|cpan.dcollins.s3@gmail.com|XML-Tiny|1.12|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902050349
3208246|pass|200902|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902051031
3213350|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902061023
3213352|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902061023
3215542|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902061735
3216711|pass|200902|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902061552
3216816|pass|200902|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902061600
3217019|pass|200902|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902061619
3217037|pass|200902|cpan.dcollins.5100rc2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902061620
3218461|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902070106
3218624|pass|200902|cpan.dcollins.5100rc1@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070118
3218884|pass|200902|cpan.dcollins.5100rc2@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070140
3219189|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Acme-Licence|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902070159
3219367|pass|200902|cpan.dcollins.5100rc1@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070212
3219384|pass|200902|cpan.dcollins.589@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902070214
3220795|pass|200902|conrad@fringehead.org|XML-Tiny|1.12|i686-linux-thread-multi|5.8.8|linux|2.6.15.1|200902070724
3221614|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200902071240
3224567|fail|200902|cpan.dcollins.5100rc1@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071349
3224768|fail|200902|cpan.dcollins.5100rc2@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071412
3225052|fail|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Bryar|3.0|i686-linux-thread-multi|5.11.0|linux|2.6.24-19-generic|200902071438
3225185|fail|200902|cpan.dcollins.5100@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071454
3225616|fail|200902|cpan.dcollins.589@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902071557
3226001|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902072146
3228066|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Compare|1.21|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080045
3228078|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080046
3228080|pass|200902|cpan.dcollins.s2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080047
3228096|pass|200902|cpan.dcollins.s1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080048
3228468|pass|200902|cpan.dcollins.s2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080154
3228535|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080204
3228645|pass|200902|cpan.dcollins.s1@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080221
3228672|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080223
3229258|pass|200902|cpan.dcollins.s2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080325
3229365|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Transactional|1.02|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080337
3229624|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080412
3229661|pass|200902|cpan.dcollins.s1@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080429
3229992|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200902081022
3231564|pass|200902|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902081118
3234425|pass|200902|cpan.dcollins.s3@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080247
3234610|pass|200902|cpan.dcollins.s3@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080440
3234863|pass|200902|cpan.dcollins.s3@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080058
3235226|fail|200902|cpan.dcollins.s1@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902081804
3235347|pass|200902|cpan.dcollins.s1@gmail.com|File-Overwrite|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902081818
3236420|pass|200902|cpan.dcollins.5100rc2@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902090231
3237946|fail|200902|cpan.dcollins.s3@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902081759
3238067|pass|200902|cpan.dcollins.s3@gmail.com|File-Overwrite|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902081811
3241426|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902090952
3248516|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.11.0 patch GitLive-blead-571-gabd7186|freebsd|7.0-release|200902100616
3248801|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902100738
3250417|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902101618
3250471|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902101618
3250472|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902101619
3250474|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200902101619
3250744|pass|200902|vpit@cpan.org|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902101730
3251797|fail|200902|srezic@cpan.org|Class-DBI-ClassGenerator|1.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200902102136
3251800|fail|200902|srezic@cpan.org|Class-DBI-ClassGenerator|1.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200902102137
3253184|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902110020
3253190|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902110021
3253193|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902110021
3253196|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902110022
3254544|pass|200902|stro@cpan.org|Class-DBI-ClassGenerator|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200902111048
3254633|pass|200902|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200902111002
3255045|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902111054
3255279|pass|200902|stro@cpan.org|Class-DBI-ClassGenerator|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200902111226
3255635|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902111125
3255810|pass|200902|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902110651
3255941|pass|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902110701
3256844|pass|200902|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111334
3257582|fail|200902|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111508
3257662|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111527
3257851|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902111702
3257963|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111626
3257998|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111642
3258974|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902111436
3259008|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902112038
3259025|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902112039
3261709|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200902120108
3261898|pass|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902120041
3261996|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120052
3262138|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902120103
3262234|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120113
3262294|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902120218
3262299|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902120219
3265350|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902120642
3265360|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902120643
3265374|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902120644
3265384|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200902120644
3266094|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902120728
3266287|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902120641
3266296|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902120642
3266310|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902120643
3266324|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902120644
3266336|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902120644
3266568|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902120759
3266624|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902120803
3266713|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902120810
3266717|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902120811
3266782|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902120816
3266798|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902120817
3266826|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902120819
3266862|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902120822
3266923|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902120826
3266930|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902120826
3266942|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902120829
3266967|fail|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120156
3267164|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902120827
3267710|pass|200902|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902121636
3267890|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902120848
3267897|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902120849
3268096|pass|200902|stsc@refcnt.org ("Steven Schubiger")|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902120906
3268661|pass|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120317
3269601|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902121144
3269616|pass|200902|stsc@refcnt.org ("Steven Schubiger")|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121046
3269792|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902121156
3270080|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902121212
3270337|fail|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120317
3270411|pass|200902|david@cantrell.org.uk|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902121133
3270416|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902121133
3270447|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902121135
3270521|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902121138
3270540|pass|200902|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200902121239
3270551|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902121139
3270557|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902121139
3271644|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902120647
3271687|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|IP35-irix-64int|5.8.8|irix|6.5|200902121350
3271833|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.11.0 patch GitLive-blead-586-gbf8d130|dragonfly|2.0.1-release|200902121301
3271836|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.11.0 patch GitLive-blead-586-gbf8d130|dragonfly|2.0.1-release|200902121302
3272255|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200902121410
3274307|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902121120
3274314|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200902121642
3274403|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121136
3274420|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121148
3274757|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902121026
3274801|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121009
3277322|pass|200902|vpit@cpan.org|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902122314
3277323|pass|200902|vpit@cpan.org|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902122314
3277605|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902122321
3277641|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902122330
3278249|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902130222
3278252|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902130224
3278253|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902130224
3278261|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902130226
3278265|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902130228
3278510|pass|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130403
3278514|pass|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130404
3278624|pass|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130426
3278647|fail|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130430
3278687|fail|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130437
3278888|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902130506
3278906|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902130508
3279442|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130117
3279575|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130135
3279584|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130140
3279762|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130205
3279767|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130206
3279782|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130209
3279783|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130209
3279795|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130211
3279831|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130143
3279851|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130218
3279881|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130222
3279884|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130222
3279887|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130223
3280014|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130206
3280113|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130242
3280118|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130242
3280195|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130217
3280220|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130218
3280379|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130241
3280434|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130208
3282049|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902131032
3283396|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902131210
3284607|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902131335
3284616|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902131335
3284640|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902131336
3284645|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902131337
3285123|pass|200902|david@cantrell.org.uk|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902131414
3285410|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902131427
3285656|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131449
3285662|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131449
3286678|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.11.0 patch GitLive-blead-586-gbf8d130|dragonfly|2.0.1-release|200902131602
3286793|pass|200902|david@cantrell.org.uk|Data-Hexdumper|1.4|alpha-netbsd|5.10.0|netbsd|4.0.1|200902131639
3287792|pass|200902|DCOLLINS@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131259
3287853|pass|200902|DCOLLINS@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131303
3288094|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131824
3288267|pass|200902|DCOLLINS@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131331
3289850|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131553
3290684|pass|200902|DCOLLINS@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131711
3290989|pass|200902|DCOLLINS@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131707
3291093|pass|200902|DCOLLINS@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131736
3291362|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902132304
3292665|pass|200902|DCOLLINS@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140153
3292741|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902140201
3292994|pass|200902|DCOLLINS@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140226
3293864|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902140448
3294438|pass|200902|DCOLLINS@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140611
3295481|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140941
3296521|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141346
3296543|pass|200902|vpit@cpan.org|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902141449
3296553|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141348
3297056|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200902141525
3297671|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141721
3297672|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141721
3297826|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141805
3297827|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141805
3298349|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200902142025
3299270|na|200902|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902141839
3299284|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902142345
3299336|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902142358
3299776|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902150211
3300040|pass|200902|stro@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux|5.8.8|linux|2.4.27-2-386|200902150627
3300729|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200902151252
3300774|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902151202
3301130|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151348
3301165|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151403
3301170|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902151405
3301764|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151648
3302206|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151819
3302467|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151946
3302727|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.26-1-686|200902152131
3303098|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902152207
3303160|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902152222
3303730|na|200902|mw487.yahoo.com@gmail.com|File-Find-Rule-Permissions|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902160237
3304723|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160838
3305048|pass|200902|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.50|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160458
3305227|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.10.0|linux|2.6.26-1-amd64|200902161030
3305573|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161140
3305574|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161140
3305575|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161141
3305989|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902161345
3306057|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161418
3306061|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161419
3306114|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161437
3306119|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161438
3306331|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161540
3307158|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161944
3308048|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902162341
3308194|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902170123
3308261|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902170043
3308262|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902170043
3308787|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902170331
3308827|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902170439
3308828|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902170439
3308834|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902170441
3310414|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902171055
3310417|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902171056
3310951|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902171245
3310981|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171256
3310984|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171257
3310986|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171257
3311763|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902171613
3311770|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902171615
3311833|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200902171626
3311838|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200902171628
3312523|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171851
3312527|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171852
3312528|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171852
3312547|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171858
3313856|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902180101
3314145|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180250
3314146|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180251
3314147|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180251
3314380|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902180628
3314697|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180908
3315628|fail|200902|david@cantrell.org.uk|Devel-CheckOS|1.50|alpha-netbsd|5.10.0|netbsd|4.0.1|200902181717
3315922|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200902181923
3315923|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181859
3315924|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181859
3316609|pass|200902|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.10.0|freebsd|7.0-release|200902182306
3316832|pass|200902|nothingmuch@woobling.org|Number-Phone|1.6|darwin-2level|5.10.0|darwin|9.5.0|200902180429
3317708|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902190325
3317709|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902190325
3319416|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200902192108
3319696|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902192157
3319956|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200902192303
3320276|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902200023
3324808|pass|200902|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902211006
3327140|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902212229
3328741|pass|200902|rafl@debian.org|Data-Compare|1.21|i686-linux|5.10.0 patch 35117|linux|2.6.26|200902220600
3333867|pass|200902|amoore@cpan.org|Devel-CheckOS|1.50|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-vserver-amd64|200902201428
3334176|pass|200902|robbiebow@gmail.com|XML-Tiny|1.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200902210007
3338316|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.26-1-686|200902240333
3340932|pass|200902|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241007
3341552|pass|200902|rlane10@wi.rr.com|XML-Tiny|1.12|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200902240849
3341581|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241802
3341582|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241803
3341737|pass|200902|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241227
3341904|pass|200902|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241255
3342039|pass|200902|stsc@refcnt.org ("Steven Schubiger")|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241926
3346325|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250724
3346932|fail|200902|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902251044
3347107|pass|200902|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200902251135
3349261|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902260148
3352078|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200902262119
3352080|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902262119
3352085|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902262120
3352093|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902262121
3352100|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200902262122
3353126|pass|200902|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.7|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200902271203
3353363|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902270501
3353364|fail|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902270502
3353366|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902270502
3353368|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902270503
3353370|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902270504
3353687|fail|200902|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902270834
3353773|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902270856
3353774|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902270856
3353789|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902270858
3353791|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902270858
3353827|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902270912
3353916|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902270333
3353946|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|IP35-irix-64int|5.8.8|irix|6.5|200902271043
3353951|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|alpha-netbsd|5.10.0|netbsd|4.0.1|200902270944
3353992|pass|200902|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902271007
3354110|pass|200902|stro@cpan.org|Number-Phone|1.7|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200902271249
3354296|pass|200902|bingos@cpan.org|Number-Phone|1.7|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902271144
3354607|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902271440
3354908|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902271547
3354922|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902271551
3354973|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902271607
3354988|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902271610
3355007|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902271622
3355038|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902271628
3355060|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902271632
3355113|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902271647
3355219|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902271720
3355254|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902271734
3355279|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902271747
3355302|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902271753
3355851|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200902272217
3355852|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902272217
3355853|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902272217
3355855|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902272218
3355857|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200902272218
3355866|pass|200902|jeff@zeroclue.com|Number-Phone|1.7|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200902271806
3356531|pass|200902|imacat@mail.imacat.idv.tw|Number-Phone|1.7|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902281038
3356612|pass|200902|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902280311
3356623|pass|200902|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902280316
3356777|pass|200902|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280441
3356927|pass|200902|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280043
3356934|pass|200902|jeff@zeroclue.com|WWW-Facebook-Go-SGF|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200902280232
3357167|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902280650
3357170|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902280651
3357172|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902280651
3357177|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902280652
3357179|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902280652
3357896|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902281049
3357927|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902281058
3357935|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902281101
3357936|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902281101
3358192|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902281044
3358211|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902281147
3358215|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902281049
3358222|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902281050
3358228|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902281051
3358230|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902281051
3358296|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902281159
3358327|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902281205
3358334|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902281207
3358375|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902281214
3358451|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902281225
3358473|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902281129
3358486|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902281231
3358523|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902281236
3358653|pass|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281256
3358806|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281317
3359047|pass|200902|imacat@mail.imacat.idv.tw|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902282106
3359183|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281433
3359184|fail|200902|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281433
3359404|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|IP35-irix-64int|5.8.8|irix|6.5|200902281458
3359423|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902280802
3359435|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200902281406
3359467|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200902281413
3361773|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010203
3361986|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010417
3361987|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010417
3362264|pass|200903|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010236
3362437|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010430
3362476|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010501
3362477|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010501
3362672|pass|200902|fraterm@gmail.com ("Michael Costello")|Games-Dice-Advanced|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902251649
3363187|pass|200903|ddascaNOSPAMlescu+perl@gmail.com|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903010109
3363239|pass|200903|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903011245
3365498|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903012102
3365757|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200903011738
3365916|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903012256
3365934|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903012259
3365938|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903012259
3366828|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200903020206
3366830|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200903020207
3367215|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903020448
3367317|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903020511
3367403|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903020548
3368772|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903020338
3369508|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903021113
3369636|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7|i86pc-solaris-64int|5.10.0|solaris|2.11|200903021131
3370474|pass|200903|mw487.yahoo.com@gmail.com|WWW-Facebook-Go-SGF|1.0|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903020825
3370622|fail|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903021355
3370624|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903021356
3370646|pass|200903|stro@cpan.org|Number-Phone|1.7|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903021601
3370863|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903021540
3371042|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903021605
3371207|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903021526
3371208|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903021527
3371319|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903021641
3371534|pass|200903|celavie@reflec.net|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-stable|200903030026
3371966|pass|200903|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903021943
3371990|pass|200903|vpit@cpan.org|Number-Phone|1.7|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903021851
3371992|pass|200903|vpit@cpan.org|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903021851
3372150|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200903021324
3372917|pass|200903|srezic@cpan.org|WWW-Facebook-Go-SGF|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903022059
3373060|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903021515
3373083|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903022124
3373129|pass|200903|srezic@cpan.org|WWW-Facebook-Go-SGF|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903021740
3373799|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903021749
3374116|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd|5.8.9|freebsd|7.0-release|200903022347
3374224|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903030048
3374226|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903030048
3374228|fail|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903030048
3374230|fail|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903030048
3374233|fail|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903030049
3374537|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903030102
3374541|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903030103
3374545|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903030104
3374547|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903030105
3374750|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030203
3375107|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030405
3375181|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030438
3375678|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Hexdumper|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903031600
3375854|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd|5.8.8|freebsd|7.0-release|200903030841
3375906|pass|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903030846
3375935|fail|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903030842
3376003|pass|200903|stro@cpan.org|Data-Hexdumper|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903031017
3376143|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903030846
3376204|fail|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903030901
3376205|fail|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903030901
3376245|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903031006
3376388|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903030923
3376391|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903030923
3376394|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903030923
3376396|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903030924
3376399|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903030924
3376402|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903030924
3376603|fail|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903031107
3376628|pass|200903|srezic@cpan.org|WWW-Facebook-Go-SGF|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903031114
3376690|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903031126
3376977|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903031107
3376983|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903031106
3376995|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903031108
3376999|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903031108
3377004|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903031109
3377008|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903031109
3377010|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903031110
3377104|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd|5.10.0|freebsd|7.0-release|200903031227
3377162|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903030544
3377164|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903031144
3377188|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030649
3377445|fail|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|IP35-irix-64int|5.8.8|irix|6.5|200903031410
3377483|pass|200903|stro@cpan.org|Data-Hexdumper|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903031520
3377737|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030918
3377808|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200903031436
3377817|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200903031440
3377827|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200903031443
3378296|pass|200903|vpit@cpan.org|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903031724
3378717|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903031901
3378760|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903031914
3378766|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903031709
3378769|fail|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903031710
3378774|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903031711
3378779|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903031920
3378905|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903031945
3379056|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903032006
3379235|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031831
3379239|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031832
3379242|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031833
3379675|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903032132
3379920|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903031608
3380352|pass|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903032321
3380383|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200903031730
3380787|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200903032349
3380790|fail|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200903032349
3380793|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200903032350
3381107|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903040954
3381153|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903040107
3381161|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903040109
3381165|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903040109
3381314|pass|200903|rafl@debian.org|Devel-CheckOS|1.50|i686-linux|5.10.0 patch 35117|linux|2.6.26|200903040244
3381952|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux|5.10.0|linux|2.6.24-16-generic|200903040438
3381971|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200903040447
3382079|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903040529
3382082|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903040529
3382085|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903040529
3382088|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903040530
3382093|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903040530
3382348|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903040723
3382351|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903040724
3382352|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903040724
3382353|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903040724
3382356|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903040724
3382532|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903040755
3382536|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903040755
3382539|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903040755
3382543|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903040756
3382546|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903040757
3382726|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903040229
3382737|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903040830
3382782|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903041638
3382952|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903040901
3382968|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200903040850
3382976|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903040850
3383001|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903040905
3383013|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903040906
3383018|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903040908
3383058|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903040913
3383067|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903040914
3383081|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903040916
3383082|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903040916
3383133|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903040923
3383214|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903040939
3383265|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903040946
3383266|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7001|i86pc-solaris-64int|5.10.0|solaris|2.11|200903040947
3383285|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903040948
3383297|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903040951
3383298|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|2.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200903040951
3383333|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903040957
3383344|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903040958
3383352|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903040959
3383392|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041003
3383416|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903040907
3383419|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903040908
3383426|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903040909
3383427|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903040910
3383430|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903040911
3383436|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903041012
3383439|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903041013
3383503|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903041024
3383506|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903041024
3383516|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040929
3383518|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040929
3383522|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040930
3383528|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040930
3383529|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903041029
3383530|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040931
3383537|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903041031
3383578|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903041039
3383581|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903041040
3383645|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7001|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903041052
3383680|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903041055
3383696|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903041057
3383712|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041059
3383871|pass|200903|srezic@cpan.org|Data-Hexdumper|2.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200903041124
3383873|pass|200903|srezic@cpan.org|Number-Phone|1.7001|amd64-freebsd|5.8.8|freebsd|7.0-release|200903041124
3383884|pass|200903|srezic@cpan.org|Data-Hexdumper|2.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200903041124
3383890|pass|200903|srezic@cpan.org|Number-Phone|1.7001|amd64-freebsd|5.8.9|freebsd|7.0-release|200903041124
3383913|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903041127
3384092|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903041038
3384100|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903041037
3384102|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903041038
3384103|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903041038
3384107|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903041038
3384109|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903041039
3384135|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903041143
3384205|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903041158
3384281|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903041202
3384304|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903041109
3384306|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903041109
3384341|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903041116
3384344|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903041116
3384369|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903041119
3384394|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903041122
3384414|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903041225
3384430|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903041226
3384433|pass|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903040627
3384755|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903041228
3384765|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903041328
3384898|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903041349
3385165|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200903041329
3385169|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903040729
3385170|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|IP35-irix-64int|5.8.8|irix|6.5|200903041429
3385180|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|alpha-netbsd|5.10.0|netbsd|4.0.1|200903041330
3385185|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|IP35-irix-64int|5.8.8|irix|6.5|200903041430
3385186|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903040730
3385358|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041508
3385592|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|alpha-netbsd|5.10.0|netbsd|4.0.1|200903041453
3385967|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041643
3386102|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200903041112
3386212|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903041734
3386561|pass|200903|jeff@zeroclue.com|Number-Phone|1.7001|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903041403
3386772|pass|200903|jeff@zeroclue.com|Data-Hexdumper|2.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903041429
3386876|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903041348
3386892|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903041953
3386922|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041859
3386923|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041859
3386926|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041900
3386933|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041901
3386935|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041902
3386953|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041906
3386956|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041907
3386960|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041908
3386963|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903041408
3386964|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041909
3386966|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041909
3387615|pass|200903|vpit@cpan.org|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903042226
3387618|pass|200903|vpit@cpan.org|Number-Phone|1.7001|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903042226
3388547|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|darwin-2level|5.8.8|darwin|8.10.1|200903050018
3388595|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|darwin-2level|5.8.8|darwin|8.10.1|200903050014
3388761|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903041839
3389169|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903050033
3389170|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200903050034
3389617|pass|200903|imacat@mail.imacat.idv.tw|Data-Hexdumper|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200903050937
3389619|pass|200903|imacat@mail.imacat.idv.tw|Number-Phone|1.7001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200903050937
3390053|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050143
3390068|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050144
3390118|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050148
3390121|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903050207
3390143|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050151
3390155|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050154
3390420|pass|200903|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903050332
3390534|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050302
3390548|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050305
3390571|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050309
3390594|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050313
3390605|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050315
3390892|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903050437
3391727|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050909
3391729|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050909
3391733|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050909
3391738|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050910
3391742|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050910
3392030|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903050542
3392087|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903051257
3392232|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903051216
3392252|pass|200903|stro@cpan.org|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903051347
3392548|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903050934
3392941|pass|200903|stro@cpan.org|Number-Phone|1.7001|i686-linux|5.8.8|linux|2.4.27-2-386|200903051756
3392975|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|i686-linux|5.8.8|linux|2.4.27-2-386|200903051811
3393896|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903052053
3393977|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052019
3393978|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903052119
3393979|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052020
3393983|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052021
3393987|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052022
3393991|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052022
3393992|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052023
3393993|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052024
3393994|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052024
3393998|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052025
3394001|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052026
3394811|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903060006
3394812|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903060006
3395620|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060320
3396073|fail|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903060413
3396937|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060140
3396972|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060145
3397007|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060153
3398350|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060920
3398353|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060920
3398356|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060921
3398359|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060922
3398714|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061047
3398715|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061047
3398718|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061048
3398719|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061048
3399200|pass|200903|wiml@hhhh.org ("Wim Lewis")|Data-Compare|1.21|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903060635
3399415|pass|200903|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.50|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903060359
3399606|fail|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.6.2|freebsd|7.0-release|200903061321
3400328|pass|200903|jeff@zeroclue.com|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903061106
3400566|pass|200903|jeff@zeroclue.com|Class-DBI-ClassGenerator|1.02|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903061141
3400760|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200903061726
3402040|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903062206
3402043|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903062207
3402047|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903062208
3402073|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903061715
3402101|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903062221
3402102|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903062222
3402123|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903062227
3402294|pass|200903|wiml@hhhh.org ("Wim Lewis")|Number-Phone|1.7001|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903061436
3402578|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903061847
3402619|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903061853
3403043|pass|200903|wiml@hhhh.org ("Wim Lewis")|Data-Hexdumper|2.01|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903070103
3403100|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070116
3403108|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903070117
3403117|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903070118
3403137|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070122
3403736|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070313
3405049|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070410
3405051|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070410
3405056|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070411
3405059|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070411
3405351|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070215
3405396|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070223
3406350|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903071031
3406352|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903071031
3407116|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070810
3407411|fail|200903|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070908
3407689|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071005
3408610|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903071849
3409215|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903071956
3409216|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903071956
3409217|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903071957
3409218|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903071957
3409221|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903071958
3409224|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903071958
3409433|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071534
3410628|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200903080045
3410629|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200903080045
3410697|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200903080056
3410701|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200903080057
3410785|pass|200903|wiml@hhhh.org ("Wim Lewis")|WWW-Facebook-Go-SGF|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903080117
3411223|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903080355
3413241|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903080806
3413246|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903080806
3413250|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903080807
3413609|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903080941
3413612|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903080942
3413618|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903080943
3414071|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081224
3414706|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080832
3414730|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200903081232
3414735|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200903081233
3414778|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081336
3415688|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080949
3416662|pass|200903|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081106
3417264|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081156
3417554|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081217
3417556|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081217
3418403|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903081817
3418859|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081707
3419060|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200903081816
3419484|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200903081843
3419998|pass|200903|andy@hexten.net|Number-Phone|1.7001|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200903081913
3420027|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200903081844
3420231|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200903081934
3420457|pass|200903|mw487.yahoo.com@gmail.com|Data-Hexdumper|2.0|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903081447
3420461|pass|200903|mw487.yahoo.com@gmail.com|Data-Hexdumper|2.01|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903081447
3420511|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081949
3421225|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903082133
3421549|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903082153
3422121|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903082230
3422231|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903082142
3422238|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903082142
3423019|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903082250
3423020|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903082250
3423089|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903082257
3423098|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903082257
3424260|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090043
3424877|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903090300
3425196|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903090334
3426959|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090206
3427647|pass|200903|robbiebow@gmail.com|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.27.12-bytemark-kvm-2009-01-19|200903081933
3427864|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|darwin-2level|5.10.0|darwin|8.11.1|200903090908
3428320|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|darwin-2level|5.10.0|darwin|8.11.1|200903090944
3429036|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903090621
3429122|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200903091028
3429125|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200903091028
3429200|pass|200903|andy@hexten.net|XML-Tiny|1.12|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200903091037
3430089|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090817
3430157|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903091224
3430161|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903091224
3430774|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090923
3430799|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091326
3431136|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091507
3431433|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091553
3432109|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7001|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091715
3432266|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|2.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091737
3432780|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091743
3432782|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903091743
3432791|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903091744
3432792|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091744
3432823|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903091752
3432825|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091752
3433115|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091937
3433223|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091448
3433735|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091554
3433824|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|darwin-2level|5.10.0|darwin|8.11.1|200903092103
3435889|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100012
3436233|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200903100102
3436234|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200903100102
3436244|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200903100107
3436248|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200903100107
3436251|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200903100107
3436264|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200903100111
3436378|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100127
3436660|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|darwin-2level|5.10.0|darwin|8.11.1|200903100300
3438231|pass|200903|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903100553
3438300|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903100603
3438753|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100206
3439120|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100249
3440035|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100910
3442981|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903101451
3443504|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200903101557
3443517|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200903101600
3443590|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101721
3444113|fail|200903|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101914
3444566|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200903102015
3444689|pass|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903101529
3445958|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903102314
3447750|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110110
3448115|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110152
3448116|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110152
3448665|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903110407
3449044|pass|200903|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110055
3449473|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903110155
3449905|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110303
3450966|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110521
3451017|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110525
3451064|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110530
3454103|pass|200903|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903111728
3454359|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903111825
3454728|pass|200903|wiml@hhhh.org ("Wim Lewis")|File-Find-Rule-Permissions|2.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903111057
3455393|pass|200903|wiml@hhhh.org ("Wim Lewis")|Class-DBI-ClassGenerator|1.02|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903111319
3456798|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120344
3457511|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120621
3457645|pass|200903|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903121351
3457736|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903120723
3458680|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121023
3459045|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121113
3459049|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121113
3460507|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121340
3460510|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121341
3461344|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121559
3462720|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903122020
3463819|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903130108
3463931|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903130248
3465138|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903130506
3465343|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903130506
3465694|pass|200903|imacat@mail.imacat.idv.tw|Number-Phone|1.7001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903130752
3465821|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903130753
3466396|pass|200903|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903131717
3466703|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903130953
3466799|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200903131129
3466849|pass|200903|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200903131138
3468132|pass|200903|stsc@refcnt.org ("Steven Schubiger")|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903131416
3469791|fail|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903131232
3469863|pass|200903|stro@cpan.org|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903131838
3470390|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903131832
3471591|pass|200903|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200903132118
3471674|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200903132130
3471716|pass|200903|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200903132137
3471747|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903132143
3471944|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903131707
3472752|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903140007
3472893|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903140030
3473021|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903132326
3473195|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903140004
3473280|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903140119
3473457|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903140126
3474262|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903140457
3475587|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200903141057
3475598|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200903141059
3478862|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903142218
3479437|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903150100
3479784|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903150152
3479831|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903150155
3480135|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903150231
3480589|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200903150254
3480603|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200903150257
3480725|pass|200903|altblue@gmail.com ("Marius Feraru")|File-Find-Rule-Permissions|2.0|x86_64-linux-ld|5.11.0 patch 34814|linux|2.6.18-8.1.14.el5|200903150508
3484221|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny|1.12|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903150641
3484466|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7001|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151603
3484593|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151623
3485297|pass|200903|stsc@refcnt.org ("Steven Schubiger")|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151937
3486175|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903152227
3486458|pass|200903|stsc@refcnt.org ("Steven Schubiger")|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152329
3486512|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152339
3487569|pass|200903|wiml@hhhh.org ("Wim Lewis")|Bryar|3.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903160205
3488580|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.12|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160713
3488911|fail|200903|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160816
3489194|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160913
3490224|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903161107
3490226|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903161107
3490918|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903161442
3491374|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903161647
3491538|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903161711
3492140|pass|200903|davidp@preshweb.co.uk ("David Precious")|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.25-arch|200903161551
3493752|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903162119
3494921|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903170108
3495035|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903170142
3496132|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903170623
3497708|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171141
3498489|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171356
3498810|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903171325
3498811|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903171326
3499162|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171005
3499565|pass|200903|stsc@refcnt.org ("Steven Schubiger")|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171548
3500158|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171644
3500365|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171701
3500366|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171702
3500825|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171239
3501411|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171321
3501453|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171324
3502969|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903172207
3503401|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.8.9|solaris|2.11|200903172316
3504009|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903180121
3505486|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903180644
3505747|pass|200903|wiml@hhhh.org ("Wim Lewis")|Palm-SMS|0.03|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903180634
3505952|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903180809
3506577|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903180948
3508025|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903180845
3508796|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903181554
3509047|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200903181634
3509470|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903181802
3509667|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903181331
3510210|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903182051
3510213|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903182052
3510216|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903182052
3510219|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903182052
3510221|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903182053
3510266|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903182103
3510267|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903182103
3510270|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903182104
3510271|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903182104
3510272|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903182104
3510507|pass|200903|srezic@cpan.org|Tie-STDOUT|1.04|amd64-freebsd|5.8.8|freebsd|7.0-release|200903182159
3510539|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00001|amd64-freebsd|5.8.8|freebsd|7.0-release|200903182159
3510719|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903181731
3510799|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.15.7|200903182137
3511122|pass|200903|srezic@cpan.org|Tie-STDOUT|1.04|amd64-freebsd|5.8.9|freebsd|7.0-release|200903182307
3511126|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00001|amd64-freebsd|5.8.9|freebsd|7.0-release|200903182307
3511659|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Net-Random|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903190022
3512182|fail|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Tie-STDOUT|1.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903191101
3512192|unknown|200903|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191006
3512193|unknown|200903|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191006
3512194|pass|200903|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191006
3512204|fail|200903|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191010
3512211|pass|200903|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191014
3512212|pass|200903|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191015
3512220|pass|200903|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191016
3512223|pass|200903|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191017
3512235|pass|200903|imacat@mail.imacat.idv.tw|Data-Hexdumper|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191024
3512236|pass|200903|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191025
3512238|pass|200903|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191026
3512240|pass|200903|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191026
3512241|pass|200903|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191027
3512243|pass|200903|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191027
3512244|pass|200903|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191027
3512249|pass|200903|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191029
3512252|pass|200903|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191030
3512254|pass|200903|imacat@mail.imacat.idv.tw|Palm-SMS|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191030
3512260|pass|200903|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191033
3512267|pass|200903|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191035
3512269|pass|200903|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191036
3512270|pass|200903|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191036
3512272|pass|200903|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191036
3512274|pass|200903|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191037
3512276|pass|200903|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191037
3512277|pass|200903|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191037
3512278|pass|200903|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191038
3512279|pass|200903|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191038
3512280|pass|200903|imacat@mail.imacat.idv.tw|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191039
3512281|pass|200903|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191039
3512282|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|1.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191039
3512723|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903190435
3512726|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903190436
3512730|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903190436
3512732|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903190437
3512745|pass|200903|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200903190441
3512756|pass|200903|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903190442
3512761|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903190443
3512763|fail|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903190443
3512765|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903190444
3512768|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903190445
3512770|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903190445
3512870|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.04|i686-linux|5.10.0|linux|2.6.24-16-generic|200903190118
3513067|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.04|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903190214
3513168|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903190736
3513171|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903190737
3513172|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903190738
3513190|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903190741
3513319|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.04|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190313
3513627|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903190858
3513667|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903190903
3513705|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903190911
3513752|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903190918
3514131|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190513
3514222|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190527
3514265|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903191031
3514284|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903191032
3514450|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903191050
3514603|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903191106
3514626|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903191112
3514633|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903191114
3514636|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903191114
3514642|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903191115
3514644|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903191115
3514646|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903191115
3514703|fail|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903191026
3514760|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903191037
3514762|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903191037
3514825|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903191145
3514837|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903191147
3514919|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903191058
3514920|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903191058
3514926|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903191058
3514927|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903191058
3514928|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903191058
3514929|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903191059
3514932|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|IP35-irix-64int|5.8.8|irix|6.5|200903191159
3514941|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|IP35-irix-64int|5.8.8|irix|6.5|200903191200
3515451|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.04|i86pc-solaris-64int|5.10.0|solaris|2.11|200903191309
3515460|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.04|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191309
3515841|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.03|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903191348
3516228|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903191430
3516815|pass|200903|srezic@cpan.org|Tie-STDOUT|1.0401|amd64-freebsd|5.8.8|freebsd|7.0-release|200903191542
3516820|pass|200903|srezic@cpan.org|Tie-STDOUT|1.0401|amd64-freebsd|5.8.9|freebsd|7.0-release|200903191542
3517280|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903191041
3517288|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903191042
3517406|pass|200903|vpit@cpan.org|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903191657
3517408|pass|200903|vpit@cpan.org|Tie-STDOUT|1.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903191657
3517530|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|alpha-netbsd|5.10.0|netbsd|4.0.1|200903191606
3517545|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191708
3517591|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|alpha-netbsd|5.10.0|netbsd|4.0.1|200903191613
3517857|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Net-Random|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903191747
3518618|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903191904
3518622|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903191905
3518626|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903191905
3518630|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903191905
3518902|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Tie-STDOUT|1.0401|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903200505
3519294|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192213
3519476|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.0401|i86pc-solaris-64int|5.8.9|solaris|2.11|200903192252
3519930|pass|200903|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.0401|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903200737
3520270|pass|200903|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903200039
3520688|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903200149
3520693|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903200149
3520943|pass|200903|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200903200234
3521634|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200903200450
3521637|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200903200451
3521945|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200649
3522453|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200831
3523302|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903201002
3523443|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903201125
3523482|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903201032
3523542|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903201048
3523565|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.0401|i86pc-solaris-64int|5.10.0|solaris|2.11|200903201150
3523570|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903201050
3523774|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200709
3524017|pass|200903|mw487.yahoo.com@gmail.com|Data-Compare|1.21|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903200644
3524561|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200852
3525084|pass|200903|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200957
3525224|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903201411
3525228|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903201411
3525231|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903201411
3525361|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|IP35-irix-64int|5.8.8|irix|6.5|200903201527
3525455|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903200934
3525648|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201059
3526141|pass|200903|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903201711
3526262|pass|200903|mw487.yahoo.com@gmail.com|App-Rsnapshot|1.999_00001|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903201123
3526283|pass|200903|mw487.yahoo.com@gmail.com|Tie-STDOUT|1.04|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903201125
3526658|pass|200903|jeff@zeroclue.com|Tie-STDOUT|1.0401|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903201232
3527602|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903201955
3528147|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201608
3528227|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903202116
3528282|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903202120
3528444|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903202141
3528491|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903202153
3530152|pass|200903|jeff@zeroclue.com|XML-Tiny|1.12|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903210049
3531127|pass|200903|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903210333
3531128|pass|200903|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903210333
3532274|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903210706
3532966|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903210906
3533115|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903210929
3533218|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903210942
3533310|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903210954
3533360|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903210959
3533420|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903211005
3533527|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903211019
3533709|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211154
3533794|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210609
3534113|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211313
3534161|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210730
3534550|pass|200903|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210856
3534829|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210950
3534902|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211012
3534903|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211012
3536683|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903212122
3537407|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903212336
3537410|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903212337
3537440|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903212340
3537553|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211915
3537731|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903220057
3537940|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903220152
3538595|pass|200903|stsc@refcnt.org ("Steven Schubiger")|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903220542
3539726|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903220404
3540905|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903221312
3541592|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903221019
3542439|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903221302
3543019|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|alpha-netbsd|5.10.0|netbsd|4.0.1|200903221846
3543663|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903231839
3543712|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903231841
3543725|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903231841
3543743|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903231841
3543767|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903231841
3543775|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903231842
3543917|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903231920
3543931|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903231919
3543940|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903231920
3543947|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903231920
3543950|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903231919
3544025|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903231845
3544026|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903231846
3544041|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903231846
3544052|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903231846
3544061|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903231846
3544390|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903231722
3544510|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903231856
3544518|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903231856
3544523|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903231856
3544536|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903231856
3544542|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903231856
3544566|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903231857
3544576|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903231857
3544582|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903231857
3544589|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903231857
3544595|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903231858
3544694|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903231220
3544698|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903231220
3544836|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231902
3544999|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903231804
3545036|pass|200903|stro@cpan.org|Tie-STDOUT|1.0401|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903232010
3545236|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231914
3545305|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903230850
3545318|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|IP35-irix-64int|5.8.8|irix|6.5|200903231445
3545341|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903231219
3545344|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903231219
3545356|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903231220
3545359|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903231219
3545396|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903231146
3545524|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231921
3545942|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903231146
3546005|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903231219
3546015|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|IP35-irix-64int|5.8.8|irix|6.5|200903231446
3546021|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903230850
3546188|pass|200903|stro@cpan.org|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903231721
3546325|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231957
3546579|pass|200903|joerg.meltzer@tngtech.com|Statistics-ChiSquare|0.5|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903202041
3546789|pass|200903|stro@cpan.org|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903231721
3546847|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903231959
3547067|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903232002
3547241|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903232010
3547300|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903231825
3547429|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903232015
3547445|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903231219
3547513|pass|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231619
3547604|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903232122
3547639|pass|200903|vpit@cpan.org|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903232124
3547641|pass|200903|vpit@cpan.org|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903232124
3547644|pass|200903|vpit@cpan.org|XML-Tiny|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903232125
3547942|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903232132
3547988|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903232133
3547996|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd|5.8.8|freebsd|7.0-release|200903230959
3548000|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903230951
3548134|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232038
3548140|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903232138
3548272|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232044
3548571|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903230950
3548634|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd|5.8.9|freebsd|7.0-release|200903230959
3548675|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd|5.10.0|freebsd|7.0-release|200903230950
3548700|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903231709
3548747|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903230936
3549305|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903231843
3549316|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903231904
3549574|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903232309
3549583|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903232310
3549697|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903232326
3549789|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903232333
3549959|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903232350
3550179|pass|200903|srezic@cpan.org|XML-Tiny|2.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200903240027
3550185|pass|200903|srezic@cpan.org|XML-Tiny|2.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200903240027
3550663|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|alpha-netbsd|5.10.0|netbsd|4.0.1|200903240013
3550666|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903240013
3551079|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903240155
3551318|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903240220
3551770|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903240140
3552004|pass|200903|wiml@hhhh.org ("Wim Lewis")|Tie-STDOUT|1.04|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903240157
3552056|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903240301
3552082|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903240304
3552096|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903240305
3552169|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240220
3552224|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903240226
3552227|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903240227
3552235|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903240227
3552241|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903240228
3552246|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903240228
3552290|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903240333
3552560|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903240412
3552584|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240317
3552585|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240318
3552589|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903241218
3552779|pass|200903|stro@cpan.org|XML-Tiny|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903240557
3552945|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240036
3553106|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny|2.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903240507
3553294|pass|200903|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240140
3553704|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240746
3554087|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Pony|1.1.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240834
3554135|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240839
3554188|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240844
3554305|pass|200903|d@0x64.nl|XML-Tiny|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-vserver-amd64|200903240903
3554433|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200903240929
3554502|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200903240941
3555426|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903241009
3555528|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903241028
3555538|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903241029
3555544|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903241029
3555546|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903241029
3555674|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903240557
3555877|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903241923
3556013|pass|200903|srezic@cpan.org|Tie-STDOUT|1.0401|amd64-freebsd|5.10.0|freebsd|7.0-release|200903241134
3556057|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200903241247
3556133|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|IP35-irix-64int|5.8.8|irix|6.5|200903241304
3556768|pass|200903|wiml@hhhh.org ("Wim Lewis")|Tie-STDOUT|1.0401|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903240520
3556968|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241025
3557357|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903241616
3557359|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903241616
3557362|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903241616
3557364|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903241617
3557365|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903241617
3558301|pass|200903|vpit@cpan.org|XML-Tiny|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903241824
3558484|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241341
3558529|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241346
3558594|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241353
3558628|pass|200903|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200903241856
3558630|pass|200903|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200903241856
3558927|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903241925
3558930|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903241926
3559662|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200903241939
3559855|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241557
3559860|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903241559
3559875|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903242101
3559935|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903242113
3559959|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903242120
3560034|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903242129
3560064|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903242134
3560100|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903242141
3560239|pass|200903|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903242158
3560610|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903241757
3560630|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903242303
3560710|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903242257
3560711|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903242257
3561062|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200903250014
3561086|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|2.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903250817
3561365|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903250020
3561367|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903250021
3561370|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903250021
3561371|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903250022
3561374|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903250022
3562303|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250325
3562318|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250329
3562737|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903250551
3563098|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903250709
3563141|pass|200903|jeff@zeroclue.com|XML-Tiny|2.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903250057
3563825|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|2.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903251621
3564052|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903250958
3564100|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903251008
3564228|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903250928
3564250|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250530
3564369|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250546
3564388|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200903251050
3564403|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903251051
3564847|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903251141
3564861|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903251142
3564868|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903251143
3564872|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903251143
3564984|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|IP35-irix-64int|5.8.8|irix|6.5|200903251300
3565581|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903251518
3565643|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903250926
3565703|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903251535
3565957|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903251638
3566933|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903251423
3567226|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903252029
3567665|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903252155
3567755|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903252209
3567789|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903252221
3567935|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903252301
3568012|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903251813
3568671|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903260159
3568750|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903260210
3568971|pass|200903|stro@cpan.org|Tie-STDOUT|1.0401|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903260328
3569002|na|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903260131
3569364|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903260232
3569614|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903260408
3569673|pass|200903|stro@cpan.org|XML-Tiny|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903260543
3569676|pass|200903|stro@cpan.org|XML-Tiny|2.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903260543
3569685|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903260448
3569832|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903260602
3569889|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903260619
3570331|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903260921
3570936|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903261306
3571424|pass|200903|vpit@cpan.org|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903261519
3571513|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903261537
3571722|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903261630
3572107|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|alpha-netbsd|5.10.0|netbsd|4.0.1|200903261745
3572189|fail|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903261438
3572382|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903262109
3572539|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903262207
3572541|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903262208
3572542|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903262208
3572544|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903262208
3572566|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903262207
3573086|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903270223
3573087|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903270223
3573090|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903270224
3573091|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903270224
3573092|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903270225
3573233|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903270437
3573263|pass|200903|mw487.yahoo.com@gmail.com|App-Rsnapshot|1.999_00002|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270349
3573267|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903270450
3573273|pass|200903|mw487.yahoo.com@gmail.com|Tie-STDOUT|1.0401|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270354
3573289|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny|2.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270359
3573302|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny|2.01|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270404
3573322|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny|2.02|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270408
3573406|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903270429
3573410|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903270430
3573412|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903270431
3573416|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903270432
3573647|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903270713
3573648|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903270714
3573650|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903270714
3573653|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903270715
3573661|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903270714
3574074|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903271006
3574086|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903271010
3574271|pass|200903|srezic@cpan.org|Palm-ProjectGutenberg|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903271109
3574273|pass|200903|srezic@cpan.org|XML-Tiny-DOM|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903271109
3574386|pass|200903|srezic@cpan.org|Palm-ProjectGutenberg|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903271139
3574389|pass|200903|srezic@cpan.org|XML-Tiny-DOM|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903271139
3574412|pass|200903|srezic@cpan.org|Palm-ProjectGutenberg|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903271144
3574522|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903271207
3574597|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-ProjectGutenberg|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903271236
3574616|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903271242
3574721|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903271155
3574752|pass|200903|srezic@cpan.org|XML-Tiny-DOM|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903271248
3574754|pass|200903|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.10.0|freebsd|7.0-release|200903271248
3574948|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-ProjectGutenberg|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903271359
3574992|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903271407
3575086|pass|200903|imacat@mail.imacat.idv.tw|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903272207
3575087|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903272207
3575127|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903271442
3575128|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903271442
3575131|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903271443
3575139|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903271443
3575150|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903271446
3575152|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903271446
3575155|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903271446
3575157|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903271446
3575165|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|IP35-irix-64int|5.8.8|irix|6.5|200903271548
3575178|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|IP35-irix-64int|5.8.8|irix|6.5|200903271549
3575183|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903270950
3575190|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903270951
3575386|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903271648
3575715|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903271834
3576094|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903272138
3576535|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903272253
3576573|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903272304
3576611|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903272313
3576677|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272228
3576682|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272229
3576684|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272230
3576687|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272230
3576690|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272231
3576692|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272231
3576693|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272232
3576695|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272232
3576696|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272232
3576697|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272233
3576699|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272233
3576703|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272234
3577002|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280002
3577004|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280003
3577006|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280003
3577008|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280004
3577009|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280004
3577010|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280004
3577308|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903280207
3577393|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903280229
3577450|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903280242
3577573|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903280324
3577575|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903280324
3577583|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903280328
3577608|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903280342
3577869|pass|200903|stro@cpan.org|XML-Tiny|2.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200903280542
3579366|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280828
3579374|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280829
3579377|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280829
3579378|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280829
3579379|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280830
3579381|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280830
3579993|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903281104
3580618|pass|200903|vpit@cpan.org|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903281310
3580816|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903281344
3581058|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903281428
3581125|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903281437
3581301|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903281506
3581327|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200903281511
3581513|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200903281541
3581646|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281617
3581806|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903281709
3581807|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903281709
3581810|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903281709
3581811|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903281710
3581937|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281730
3581939|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281730
3581947|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903281733
3582122|pass|200903|mw487.yahoo.com@gmail.com|Palm-ProjectGutenberg|1.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903281219
3582142|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny-DOM|1.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903281228
3582218|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903281847
3582251|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903281900
3582472|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281951
3583310|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903282254
3584044|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290210
3584046|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290210
3584053|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290212
3584054|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290212
3584056|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290213
3584057|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290213
3584059|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290213
3584060|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290213
3584063|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290214
3584065|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290214
3584067|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290215
3584068|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290215
3584223|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903290346
3584453|pass|200903|wiml@hhhh.org ("Wim Lewis")|Palm-ProjectGutenberg|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290302
3584480|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903290511
3584613|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny|2.02|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290354
3584614|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny-DOM|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290354
3584921|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903290702
3584925|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903290703
3585039|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903290725
3585613|pass|200903|jrockway@cpan.org|Devel-CheckOS|1.50|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200903290223
3586133|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903290841
3586140|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903290842
3586405|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903291116
3586415|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903291116
3586479|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903291131
3586482|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903291132
3586589|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903291141
3586590|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903291142
3586596|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903291145
3586763|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903291146
3586908|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903291305
3587082|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903291255
3587086|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903291256
3587090|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903291257
3587096|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903291258
3587117|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903291405
3587202|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903291437
3587445|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903291553
3587657|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903291707
3587659|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903291708
3588290|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903291943
3588299|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903291947
3589424|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292305
3589430|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292306
3589434|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292306
3589438|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292307
3589441|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292307
3589667|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300020
3590005|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300137
3590013|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300138
3590016|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300138
3590019|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300139
3590022|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300139
3590024|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300139
3590214|pass|200903|dpavlin@mail.carnet.hr ((Dobrica Pavlinusic))|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200903291243
3590330|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300240
3590346|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300243
3590358|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300243
3590362|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300244
3590364|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300244
3590365|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300245
3591761|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903301050
3592268|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903301410
3592316|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903301425
3592550|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903301631
3592645|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903301725
3593115|pass|200903|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.10.0|freebsd|7.0-release|200903301938
3593460|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903302108
3594715|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903302358
3594734|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903310101
3594735|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903310101
3594737|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903310101
3594739|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903310102
3594740|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903310102
3594930|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310034
3594932|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310035
3594935|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310035
3594939|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310035
3596610|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903310949
3596674|pass|200903|srezic@cpan.org|CPAN-ParseDistribution|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903311022
3596921|pass|200903|srezic@cpan.org|CPAN-ParseDistribution|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903311140
3597111|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903311237
3597535|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Longest|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903311348
3597540|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Statistics-ChiSquare|0.5|i86pc-solaris-64int|5.8.9|solaris|2.11|200903311348
3598037|pass|200903|JOST@cpan.org ("Josts Smokehouse")|NestedMap|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903311601
3598426|pass|200903|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903311745
3598489|fail|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903311758
3599000|pass|200903|vpit@cpan.org|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903311950
3599005|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903311949
3599123|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903312016
3599215|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903312027
3599216|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903312027
3599296|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903312058
3599357|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903312122
3599358|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903312122
3600007|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904010109
3600092|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904010131
3600096|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904010131
3600318|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904010256
3600378|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904010307
3600381|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904010308
3600446|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904010223
3600447|fail|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904010223
3600452|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904010224
3600458|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904010224
3600460|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904010225
3600555|unknown|200904|JOST@cpan.org ("Josts Smokehouse")|Acme-Licence|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200904010340
3601251|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904010645
3601308|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904010700
3601310|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904010701
3601360|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904010719
3601436|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904010735
3601437|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904010735
3601744|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904010901
3602008|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904010949
3602019|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904010952
3602020|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904010952
3603155|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200904011512
3603860|unknown|200904|JOST@cpan.org ("Josts Smokehouse")|Acme-Pony|1.1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200904011903
3603920|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904011913
3604078|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904012003
3604311|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904012112
3604363|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904012126
3604365|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904012126
3605518|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020140
3605817|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904020337
3605909|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020310
3605911|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020310
3605912|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020311
3605913|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020311
3605954|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020325
3605956|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020325
3605959|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020325
3605961|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020326
3606229|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904020534
3606611|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904020700
3606847|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904020743
3607633|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904021027
3607793|pass|200904|robertl@apnic.net ("Robert Loomans")|Devel-CheckOS|1.50|darwin-2level|5.8.9|darwin|9.6.0|200904021324
3608076|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904021138
3608085|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904021139
3608456|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021148
3608783|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021255
3608913|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021322
3608915|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021322
3608917|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021323
3608920|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021323
3609426|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021453
3609427|pass|200904|bingos@cpan.org|XML-Tiny|2.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021453
3609430|pass|200904|bingos@cpan.org|XML-Tiny|2.02|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021454
3609434|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021455
3609715|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904021648
3609947|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904021720
3610573|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904021909
3610654|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904021824
3610818|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021855
3611181|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904022028
3611182|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904022028
3611184|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904022028
3611311|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904022227
3611855|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904030024
3612013|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904030058
3612224|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904030145
3612304|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030106
3612451|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904030237
3612586|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030203
3612589|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030204
3612594|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030204
3612599|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030204
3612661|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904030220
3612953|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.5|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904030345
3614296|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031032
3615014|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031219
3615015|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031218
3615017|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031219
3615019|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031219
3615594|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904031454
3615737|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031416
3615882|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904031539
3615941|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904031548
3615943|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904031548
3616110|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031517
3616162|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031523
3616164|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031523
3616166|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031524
3616172|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031524
3617528|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904032207
3617530|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904032208
3618032|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904040010
3618034|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904040011
3618080|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904032301
3618277|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904040114
3618566|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040114
3618569|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040114
3618573|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040115
3618574|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040115
3619170|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904040529
3619818|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904041027
3620321|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904041102
3620694|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200904041222
3620861|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904041247
3620865|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904041247
3620869|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904041248
3620872|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904041248
3620876|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904041249
3621107|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200904041323
3621125|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904041324
3621175|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904041231
3621703|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904041354
3621706|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904041354
3621707|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904041355
3621740|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|IP35-irix-64int|5.8.8|irix|6.5|200904041500
3621743|fail|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904041401
3622234|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904041256
3622465|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-ParseDistribution|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904041634
3622917|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200904041534
3622955|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904041037
3622967|pass|200904|vpit@cpan.org|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904041740
3623373|pass|200904|vpit@cpan.org|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904041825
3623390|pass|200904|imacat@mail.imacat.idv.tw|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904050025
3623642|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904041853
3624010|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904041918
3624201|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904041947
3624209|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904041948
3624211|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904041949
3624218|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904041950
3624520|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904042025
3624896|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904042142
3625954|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904050300
3626144|pass|200904|mw487.yahoo.com@gmail.com|CPAN-ParseDistribution|1.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904050203
3626151|pass|200904|mw487.yahoo.com@gmail.com|CPAN-ParseDistribution|1.1|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904050206
3626411|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904050529
3626460|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904050443
3626467|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904050545
3626468|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904050446
3626985|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904050812
3627105|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200904050646
3627107|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200904050646
3627237|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904050906
3627363|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200904050733
3627619|pass|200904|imacat@mail.imacat.idv.tw|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904051702
3627914|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904051201
3628315|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904051221
3628483|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904050713
3628484|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051247
3628488|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904050715
3628489|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051248
3628529|pass|200904|gbnewby@pglaf.org|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200904041432
3629249|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904051436
3629350|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904051451
3629363|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904051554
3629655|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904051007
3629950|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051636
3629968|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904051104
3630550|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904051940
3630585|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904051943
3630586|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904051943
3630802|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200904052110
3630881|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904052136
3630957|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904052157
3630962|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904052200
3630964|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904052201
3631667|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904060130
3631839|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060002
3631841|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060003
3631872|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904060012
3631909|fail|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904060019
3632095|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200904060047
3632405|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060149
3632410|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060150
3632981|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060348
3633178|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904060532
3633188|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904060534
3633189|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904060535
3633340|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060524
3633672|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060656
3633726|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904060815
3633731|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904060817
3633915|fail|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-ParseDistribution|1.1|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904060702
3634114|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904060955
3634376|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904060949
3634380|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904060948
3635106|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904061418
3635115|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904061419
3635202|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904061240
3635443|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200904061316
3635458|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200904061318
3635492|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904061420
3635562|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904061337
3636897|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200904061911
3637726|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904062127
3637732|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904062128
3638024|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904062301
3638137|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904062316
3638390|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904062331
3638592|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904062356
3639113|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904070103
3639258|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904070125
3639671|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904070144
3639750|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904070253
3639839|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904070307
3639841|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904070308
3639874|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904070314
3639943|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904070330
3640031|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904070350
3640428|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904070543
3640458|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904070559
3640599|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904070646
3640896|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904070835
3641616|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904070943
3641619|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904070943
3642009|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904071147
3642489|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904071249
3642682|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904071314
3642897|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904071341
3643160|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904071425
3643257|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904071440
3643326|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071350
3643334|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071351
3643337|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904071452
3643421|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904071505
3643446|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904071410
3644809|pass|200904|vpit@cpan.org|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904072002
3644998|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904071930
3645002|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904071931
3645140|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071949
3645311|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904072005
3645341|pass|200904|andy@hexten.net|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200904072008
3645865|pass|200904|andy@hexten.net|XML-Tiny|2.02|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904072111
3646314|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904072225
3647537|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080155
3647539|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080156
3649102|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080645
3649671|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904080929
3650941|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081220
3651243|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|IP35-irix-64int|5.8.8|irix|6.5|200904081359
3651762|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904081425
3652871|pass|200904|dwheeler@cpan.org|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.22-14-server|200904080954
3652872|pass|200904|dwheeler@cpan.org|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.22-14-server|200904080943
3653457|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081927
3654298|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904082250
3655288|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904082327
3656098|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904090224
3656214|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904090249
3656269|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904090258
3656711|pass|200904|dwheeler@cpan.org|Tie-STDOUT|1.0401|darwin-2level|5.10.0|darwin|9.4.0|200904090220
3657442|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904090703
3657444|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904090703
3657898|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904090900
3659046|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904090625
3659207|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904091315
3659521|pass|200904|rbo@consol.de|CPAN-ParseDistribution|1.1|i86pc-solaris|5.8.9|solaris|2.11|200904091411
3660936|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904091856
3660950|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904091859
3660953|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904091859
3661190|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904091951
3661194|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904091953
3661200|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904091955
3661720|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-64int-2level|5.11.0|darwin|8.11.0|200904092115
3663059|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904100252
3663113|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904100254
3663130|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904100257
3663135|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904100259
3665282|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904101142
3665462|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904101316
3665463|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904101317
3666408|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904101647
3666412|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904101647
3666418|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904101648
3666419|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904101648
3666422|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904101649
3666526|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904101716
3666529|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904101716
3666530|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904101716
3666532|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904101716
3666533|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904101717
3666693|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904101757
3667070|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904101935
3667265|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904102034
3667809|pass|200904|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904102136
3667850|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904102241
3667997|pass|200904|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904102211
3668285|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904102302
3668290|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904102303
3668303|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904102305
3668307|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904102307
3668313|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904102309
3668332|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904102314
3668333|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904102314
3668336|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904102314
3668341|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904102315
3668344|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904102315
3668637|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904110025
3669587|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904110524
3669697|pass|200904|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904110546
3669701|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904110547
3669983|pass|200904|rbo@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris|5.8.9|solaris|2.11|200904110110
3670253|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904110808
3670344|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904110838
3670581|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904110950
3670786|pass|200904|imacat@mail.imacat.idv.tw|File-Overwrite|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904111703
3670787|pass|200904|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904111705
3670972|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904111148
3671812|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904111457
3671841|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.1|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200904110604
3671921|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904111418
3671933|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904111420
3671958|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904111422
3671966|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904111422
3671968|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904111423
3671986|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904111425
3671987|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904111425
3671989|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904111425
3672303|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904111514
3673158|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904111849
3673322|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904111940
3673327|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904111941
3673330|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904111943
3673341|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904111944
3673347|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904111945
3673462|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200904111759
3673524|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200904111808
3673976|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904112031
3674255|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904112228
3674301|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904112136
3674302|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904112236
3674568|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904112239
3674592|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904112246
3674685|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904120011
3674725|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904120026
3675380|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904120326
3675877|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904120543
3675939|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904120451
3676520|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904120718
3676538|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904120721
3676555|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904120724
3676567|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904120727
3676770|pass|200904|stro@cpan.org|File-Overwrite|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904121012
3676811|pass|200904|stro@cpan.org|Palm-Treo680MessagesDB|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904121020
3677176|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904120949
3677215|fail|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904121654
3677558|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904121214
3677582|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904121218
3677585|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904121218
3677677|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904120533
3677679|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|IP35-irix-64int|5.8.8|irix|6.5|200904121233
3677690|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904121136
3677694|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904121136
3677705|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904121138
3677715|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|IP35-irix-64int|5.8.8|irix|6.5|200904121239
3677718|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904121140
3677760|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904120544
3678067|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904121309
3678342|pass|200904|rbo@cpan.org|Data-Hexdumper|2.01|i86pc-solaris|5.8.9|solaris|2.11|200904111029
3678549|pass|200904|rbo@cpan.org|File-Overwrite|1.1|i86pc-solaris|5.8.9|solaris|2.11|200904111029
3679336|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904121852
3679622|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200904121834
3679791|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904122029
3679848|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904122207
3679985|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904122256
3680058|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|IP35-irix-64int|5.8.8|irix|6.5|200904122346
3680213|fail|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-FindDependencies|2.1|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904121332
3680401|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904130004
3680421|pass|200904|wiml@hhhh.org ("Wim Lewis")|File-Overwrite|1.1|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904130014
3680428|pass|200904|wiml@hhhh.org ("Wim Lewis")|Palm-Treo680MessagesDB|1.01|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904130020
3680687|pass|200904|mw487.yahoo.com@gmail.com|File-Overwrite|1.1|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904130235
3680698|pass|200904|mw487.yahoo.com@gmail.com|Data-Hexdumper|2.01|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904130243
3680714|pass|200904|mw487.yahoo.com@gmail.com|Palm-Treo680MessagesDB|1.01|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904130252
3681040|pass|200904|wiml@hhhh.org ("Wim Lewis")|XML-DoubleEncodedEntities|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904130612
3681236|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904131004
3681861|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904131503
3682050|pass|200904|rlane10@wi.rr.com|XML-Tiny|2.02|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904130132
3682126|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904131554
3682211|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.1|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904121400
3682515|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200904131742
3682604|pass|200904|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200904131757
3682605|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200904131757
3682785|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904131854
3682970|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904131945
3683418|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132058
3683420|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132059
3683424|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132059
3683427|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132100
3683680|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904132306
3683773|pass|200904|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904132322
3683778|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200904132322
3684604|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.1|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904140025
3685097|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904140317
3685119|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140319
3685120|pass|200904|bingos@cpan.org|File-Overwrite|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140319
3685123|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140320
3685129|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140321
3685611|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904140556
3685710|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904140738
3686714|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904141231
3687107|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904141257
3687255|pass|200904|srezic@cpan.org|File-Overwrite|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200904141439
3687289|pass|200904|srezic@cpan.org|Palm-Treo680MessagesDB|1.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200904141439
3687345|pass|200904|srezic@cpan.org|File-Overwrite|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200904141439
3687369|pass|200904|srezic@cpan.org|Palm-Treo680MessagesDB|1.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200904141439
3687408|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200904141441
3687414|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200904141441
3687598|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904141418
3688168|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904141611
3689000|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904142030
3689111|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904142102
3689380|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904142158
3689410|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904142215
3689414|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904142216
3689416|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904142216
3689418|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904142216
3689420|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904142217
3689445|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904142121
3689581|pass|200904|chris@bingosnet.co.uk|CPAN-FindDependencies|2.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904142204
3689645|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904142219
3690140|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904150111
3690145|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904150112
3690149|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904150113
3690156|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904150114
3690164|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904150115
3690177|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904150111
3690235|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.51|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904150832
3690479|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150130
3690480|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150131
3690482|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150131
3690486|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150132
3690766|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904150349
3690836|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200904150405
3690863|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-Scalar-Decay|1.1.1|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200904150412
3690870|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-Scalar-Decay|1.1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904150413
3691104|fail|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904151219
3691281|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904150506
3691282|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904150506
3691289|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904150507
3691292|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904150508
3691297|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904150508
3691669|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904150658
3691680|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904150701
3691685|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904150704
3691690|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904150706
3691796|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150736
3691976|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904150938
3692050|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904150954
3692064|pass|200904|srezic@cpan.org|Devel-CheckOS|1.51|amd64-freebsd|5.8.8|freebsd|7.0-release|200904150955
3692160|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904151026
3692177|pass|200904|srezic@cpan.org|Devel-CheckOS|1.51|amd64-freebsd|5.8.9|freebsd|7.0-release|200904150956
3692215|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904151038
3692304|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904151003
3692360|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904151117
3692395|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904151124
3692403|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904151125
3692406|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.51|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904151126
3692451|fail|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904151736
3692454|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.51|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904151736
3692469|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.2|amd64-freebsd|5.8.8|freebsd|7.0-release|200904151136
3692582|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904151159
3692610|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904151102
3692612|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904151102
3692624|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904151103
3692643|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200904151200
3692688|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904151209
3692721|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904151214
3692765|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904151219
3692814|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904151230
3693164|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.51|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904151423
3693322|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904151252
3693326|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904151252
3693331|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904151252
3693332|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904151252
3693348|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151253
3693370|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904151355
3693374|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|IP35-irix-64int|5.8.8|irix|6.5|200904151357
3693389|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904151259
3693395|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|IP35-irix-64int|5.8.8|irix|6.5|200904151359
3693548|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904151416
3693685|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904151438
3693711|pass|200904|rbo@cpan.org|Devel-CheckOS|1.51|i86pc-solaris|5.8.9|solaris|2.11|200904150933
3693736|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904151446
3693782|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904151359
3693785|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904151359
3693788|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904151400
3693827|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904151506
3693832|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904151507
3693866|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.51|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904150913
3693957|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904151415
3694015|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|alpha-netbsd|5.10.0|netbsd|4.0.1|200904151340
3694242|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|alpha-netbsd|5.10.0|netbsd|4.0.1|200904151425
3694346|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200904151639
3694355|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200904151640
3694378|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.51|i86pc-solaris-64int|5.10.0|solaris|2.11|200904151642
3694404|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.51|i86pc-solaris-64int|5.8.9|solaris|2.11|200904151644
3694762|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200904151733
3694843|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904151746
3695011|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151716
3695012|pass|200904|bingos@cpan.org|File-Overwrite|1.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151717
3695015|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151718
3695019|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151719
3695030|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904151821
3695208|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200904151752
3695260|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904151157
3695317|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904151204
3695533|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904151943
3695611|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904152002
3695614|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904152003
3695769|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904152033
3695776|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904152033
3695784|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904152034
3695792|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904152036
3695802|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904152037
3695809|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904152038
3695814|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904152039
3695818|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904152039
3695822|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904152040
3695825|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904152040
3695871|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904152040
3695873|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904152033
3695962|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904151958
3695963|pass|200904|bingos@cpan.org|File-Overwrite|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904151958
3695966|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904151959
3695971|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904152000
3695991|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904152113
3696112|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904152134
3696172|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904152145
3696173|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904152145
3696185|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904152146
3696198|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904152147
3696204|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904152149
3696211|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904152150
3696445|fail|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160547
3696455|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.52|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160549
3696474|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904152156
3696534|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904152309
3696603|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.22|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904152321
3696610|fail|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.52|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904152322
3696638|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904152324
3696737|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.22|amd64-freebsd|5.8.8|freebsd|7.0-release|200904152339
3696740|pass|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd|5.8.8|freebsd|7.0-release|200904152339
3696760|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904152341
3696881|fail|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd|5.10.0|freebsd|7.0-release|200904152339
3696927|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904160009
3696929|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904160009
3696932|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904160009
3696933|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904160010
3696942|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904160010
3696985|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904160010
3697047|pass|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd|5.8.9|freebsd|7.0-release|200904152339
3697051|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.22|amd64-freebsd|5.8.9|freebsd|7.0-release|200904152339
3697443|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|alpha-netbsd|5.10.0|netbsd|4.0.1|200904160029
3697658|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904160212
3697661|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904160212
3697664|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904160213
3697667|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904160213
3697672|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904160213
3697681|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904160216
3697686|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904160216
3697687|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904160217
3697689|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904160217
3697691|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904160217
3697695|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904160212
3697696|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904160216
3697839|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.22|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160953
3697852|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.53|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160955
3698066|fail|200904|bingos@cpan.org|Devel-CheckOS|1.51|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904160241
3698154|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160302
3698167|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160305
3698170|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904160406
3698182|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160308
3698196|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160311
3698215|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160315
3698216|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160316
3698221|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160317
3698225|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160317
3698229|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160318
3698483|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904160416
3698515|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904160535
3698542|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904160440
3698588|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904161250
3698615|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160458
3698621|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160501
3698622|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160501
3698629|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160502
3698635|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160505
3698638|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160506
3698644|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160509
3698651|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160510
3698659|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904160612
3698660|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160513
3698868|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904160731
3698897|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904160744
3698917|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160653
3698918|fail|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160653
3698921|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160654
3698928|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160655
3698931|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160656
3698936|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904160756
3698962|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904160810
3699083|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904160905
3699108|pass|200904|stro@cpan.org|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904161014
3699130|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904160920
3699294|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160853
3699296|fail|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160854
3699302|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160855
3699305|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160855
3699309|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160856
3699334|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904160901
3699335|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160901
3699347|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160904
3699349|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160905
3699352|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160905
3699354|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160905
3699356|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160905
3699362|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.8.8|freebsd|7.0-release|200904161006
3699364|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.8.9|freebsd|7.0-release|200904161006
3699412|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904161016
3699434|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160921
3699435|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160921
3699436|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160921
3699446|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160923
3699448|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160924
3699452|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160924
3699634|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904161058
3699689|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904161108
3699793|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.55|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904161132
3699835|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904161141
3699865|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904161151
3699890|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904161154
3700013|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904161213
3700046|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904161220
3700137|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904161238
3700142|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904161239
3700159|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.55|i86pc-solaris-64int|5.10.0|solaris|2.11|200904161243
3700181|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.22|i86pc-solaris-64int|5.10.0|solaris|2.11|200904161247
3700255|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904161257
3700428|fail|200904|rbo@cpan.org|Devel-CheckOS|1.52|i86pc-solaris|5.8.9|solaris|2.11|200904161252
3700429|pass|200904|rbo@cpan.org|Devel-CheckOS|1.54|i86pc-solaris|5.8.9|solaris|2.11|200904161253
3700580|pass|200904|vovkasm@gmail.com|Data-Compare|1.21|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904161244
3700604|pass|200904|rbo@cpan.org|Data-Compare|1.21|i86pc-solaris|5.8.9|solaris|2.11|200904161251
3700606|fail|200904|rlane10@wi.rr.com|Devel-CheckOS|1.52|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904151613
3700607|pass|200904|rbo@cpan.org|Devel-CheckOS|1.53|i86pc-solaris|5.8.9|solaris|2.11|200904161252
3700608|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.21|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904151607
3700675|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904161300
3700689|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.55|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904162002
3700699|pass|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.22|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904162002
3700802|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904161420
3700855|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.55|i86pc-solaris-64int|5.8.9|solaris|2.11|200904161429
3700876|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|IP35-irix-64int|5.8.8|irix|6.5|200904161433
3700878|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161333
3700879|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161333
3700889|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161335
3700892|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.22|i86pc-solaris-64int|5.8.9|solaris|2.11|200904161435
3700893|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161335
3700897|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161335
3700898|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161336
3700906|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.55|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904161244
3700915|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161337
3700923|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161337
3700932|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161338
3701100|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904161508
3701231|pass|200904|perl@galumph.com|Data-Compare|1.21|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904160835
3701233|pass|200904|perl@galumph.com|Devel-CheckOS|1.55|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904160836
3701244|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904161438
3701250|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161439
3701272|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161440
3701274|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|IP35-irix-64int|5.8.8|irix|6.5|200904161540
3701280|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161441
3701283|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|IP35-irix-64int|5.8.8|irix|6.5|200904161542
3701292|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160844
3701302|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160847
3701313|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160850
3701328|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160852
3701336|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|IP35-irix-64int|5.8.8|irix|6.5|200904161553
3701360|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160856
3701364|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|IP35-irix-64int|5.8.8|irix|6.5|200904161556
3701375|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160857
3701376|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|IP35-irix-64int|5.8.8|irix|6.5|200904161557
3701409|pass|200904|rbo@cpan.org|Devel-CheckOS|1.55|i86pc-solaris|5.8.9|solaris|2.11|200904161251
3701563|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904161628
3701865|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904161629
3701866|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904161629
3701926|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904161625
3701950|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|alpha-netbsd|5.10.0|netbsd|4.0.1|200904161544
3701958|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|alpha-netbsd|5.10.0|netbsd|4.0.1|200904161547
3702192|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904161825
3702825|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904162043
3702871|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904162057
3703003|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904162132
3703107|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904162151
3703291|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904162243
3704326|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.2|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170012
3704346|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.55|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170014
3704350|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.51|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170015
3704357|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.52|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170015
3704463|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904170236
3704959|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904170420
3705061|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170354
3705069|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170355
3705074|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170357
3705076|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170357
3705077|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170357
3705083|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170359
3705086|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170359
3705088|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170400
3705090|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170400
3705092|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170401
3705096|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170401
3705097|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170402
3705102|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170403
3705110|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904170506
3705385|pass|200904|mw487.yahoo.com@gmail.com|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170421
3705570|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904170603
3705571|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904170603
3705943|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|i586-linux-thread-multi|5.8.8|linux|2.6.16|200904170928
3705964|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904170932
3706504|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904161129
3706862|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170513
3706881|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.53|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170515
3706888|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.54|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170516
3706926|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904171221
3707014|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904171230
3707079|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904171236
3707088|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904171238
3707109|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904171244
3707132|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904171249
3707175|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904171258
3707227|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904171312
3707238|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904171314
3707283|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904171322
3707312|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904171327
3707380|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904171338
3707387|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904171339
3707555|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904171325
3707562|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.53|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904171427
3707707|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.55|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904161129
3707731|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904171506
3707753|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904171514
3707782|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904171525
3707857|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904171555
3707898|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904171608
3708089|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904171656
3708330|pass|200904|pjacklam@online.no|Data-Compare|1.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904171748
3708863|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904171943
3708869|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171826
3708879|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171827
3708885|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171829
3708888|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171829
3708889|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171830
3708893|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171831
3708899|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171832
3708903|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171832
3708906|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171833
3708910|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171834
3708913|pass|200904|bingos@cpan.org|File-Overwrite|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171834
3708914|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171834
3708923|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171835
3709033|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904172019
3709199|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904172101
3709250|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904172013
3709262|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904171515
3709288|pass|200904|g.grigelionis@computer.org|Data-Compare|1.21|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904172118
3709289|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904172118
3709298|pass|200904|g.grigelionis@computer.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904172119
3709300|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904172119
3709547|fail|200904|pjacklam@online.no|Devel-CheckOS|1.55|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904172205
3709845|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904172309
3709888|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904172317
3710027|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904172350
3710168|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904180024
3710224|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904180036
3710228|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904180037
3710275|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904180043
3710325|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904180052
3710339|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904180056
3710409|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904180107
3710481|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904180126
3710486|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904180127
3710507|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904180134
3710635|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904180042
3710656|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904180208
3710687|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904180217
3710690|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904180217
3710693|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904180217
3710910|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904180322
3711100|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904180431
3711124|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904180440
3711324|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904180605
3711836|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904180850
3712046|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904180957
3712074|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904181005
3712084|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904181009
3712117|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904181018
3712154|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904181031
3712201|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904181042
3712331|pass|200904|rafl@debian.org|Devel-CheckOS|1.55|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904181111
3713368|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181256
3713375|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181257
3713385|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181258
3713392|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181259
3713394|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181259
3713400|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181300
3713403|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181301
3713406|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181301
3713411|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181301
3713415|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181302
3713419|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181303
3713425|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181303
3713433|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181304
3713482|pass|200904|srezic@cpan.org|Palm-Treo680MessagesDB|1.01|amd64-freebsd|5.10.0|freebsd|7.0-release|200904181406
3713483|pass|200904|srezic@cpan.org|Data-Hexdumper|2.01|amd64-freebsd|5.10.0|freebsd|7.0-release|200904181406
3713486|pass|200904|srezic@cpan.org|File-Overwrite|1.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200904181405
3713957|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904181510
3714500|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904181617
3714794|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904181659
3715020|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904181616
3715154|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904181755
3715210|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.22|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904181757
3716195|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904181959
3716205|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182002
3716217|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904182105
3716223|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182007
3716248|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182011
3716250|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182011
3716256|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182013
3716268|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182016
3716273|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182018
3716288|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182023
3716312|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182026
3716319|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904182127
3716321|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182028
3716329|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182029
3716711|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904182241
3716898|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904182313
3717157|fail|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904182352
3717404|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904190035
3717449|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904190046
3717554|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904190101
3717897|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904190102
3717979|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904190219
3718102|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904190250
3718197|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904190312
3718257|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904190328
3718259|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904190328
3718332|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904190340
3718358|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904190347
3718408|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904190401
3718419|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904190405
3718448|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904190411
3718634|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904190449
3718803|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904190528
3723291|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200335
3723298|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200337
3723300|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200338
3723304|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200338
3723305|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200344
3723306|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200344
3723307|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200346
3723309|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200346
3723310|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200347
3723312|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200348
3723315|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200348
3724208|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904200841
3724364|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200809
3724375|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200812
3724381|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200813
3724385|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200813
3724396|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200815
3724398|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200816
3724403|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200817
3724406|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200818
3724411|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200819
3724601|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904200947
3724609|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904200948
3724639|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904200955
3724668|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904201002
3724684|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904201005
3724709|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904201010
3724728|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904201016
3724755|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904201022
3724790|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904201029
3724819|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904201034
3724880|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904201045
3724938|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904201058
3725088|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904201132
3725160|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904201141
3725185|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904201146
3725199|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904201148
3725219|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904201151
3725238|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904201154
3725319|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904201204
3725491|pass|200904|g.grigelionis@computer.org|Data-Compare|1.21|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904201225
3725493|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904201225
3725988|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904201313
3726992|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904201702
3727080|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904201714
3727330|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904201755
3727412|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904201809
3727421|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904201810
3727434|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904201811
3727441|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904201813
3727449|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904201814
3728598|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.3|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904202124
3728816|na|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202058
3728819|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202100
3728820|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202101
3728822|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202101
3728828|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202102
3728830|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202103
3728833|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202104
3728838|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202104
3728847|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202105
3728963|pass|200904|andy@hexten.net|Devel-CheckOS|1.55|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904202118
3728970|fail|200904|andy@hexten.net|CPAN-FindDependencies|2.3|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904202118
3729431|pass|200904|andy@hexten.net|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200904202204
3729436|pass|200904|andy@hexten.net|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200904202205
3729527|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.3|amd64-freebsd|5.8.9|freebsd|7.0-release|200904202316
3729538|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.3|amd64-freebsd|5.8.8|freebsd|7.0-release|200904202316
3730353|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904210221
3730560|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904210315
3731025|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904210421
3731123|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904210449
3731153|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904210459
3731188|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904210506
3731214|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904210513
3732414|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904211037
3732484|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904211049
3732497|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904211050
3732504|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904211051
3732601|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904211107
3732673|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904211127
3733498|fail|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904211956
3733541|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904211405
3733622|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211319
3733628|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211321
3733633|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211321
3733635|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211321
3733638|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211323
3733639|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211323
3733643|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211324
3733649|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211325
3733654|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211325
3733901|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904211517
3734631|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904211738
3735091|pass|200904|graham@crookham.uklinux.net ("GRAHAMC")|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904202224
3735253|pass|200904|rlane10@wi.rr.com|Devel-CheckOS|1.55|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904210958
3735696|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904211933
3736091|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904212045
3736343|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904212140
3736348|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904212141
3736349|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904212141
3736351|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904212142
3736355|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904212142
3736358|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904212142
3736397|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.3|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904211000
3736538|pass|200904|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.10.0|freebsd|7.0-release|200904211809
3736540|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.10.0|freebsd|7.0-release|200904211809
3736586|pass|200904|graham@crookham.uklinux.net ("GRAHAMC")|Devel-CheckOS|1.55|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904202225
3736692|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd|5.8.8|freebsd|7.0-release|200904212244
3736710|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200904212244
3737329|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904220116
3737335|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904220118
3737504|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904220216
3737791|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904220325
3737845|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904220338
3737921|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904220358
3738009|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904220332
3738026|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904220339
3738055|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904220347
3738078|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904220355
3738085|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220359
3738089|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220401
3738092|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220401
3738093|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220402
3738095|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220403
3738099|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220404
3738101|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220404
3738103|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220405
3738105|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220405
3738107|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220406
3738174|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904220526
3739036|pass|200904|stro@cpan.org|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904221022
3739496|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.6|i86pc-solaris-64int|5.10.0|solaris|2.11|200904221055
3739537|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904221716
3739552|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904221121
3739700|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904221207
3739803|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904221131
3739804|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904221131
3739805|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904221131
3739916|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904221945
3739979|fail|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.3|i86pc-solaris-64int|5.10.0|solaris|2.11|200904221302
3740301|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.6|i86pc-solaris-64int|5.8.9|solaris|2.11|200904221431
3740358|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904221445
3740534|fail|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200904221523
3740568|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904221433
3740676|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904221555
3740742|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904221608
3740942|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904221541
3740944|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904221541
3741133|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904221617
3741180|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904221622
3741191|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904221625
3741239|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904221134
3741646|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|alpha-netbsd|5.10.0|netbsd|4.0.1|200904221657
3741701|pass|200904|andy@hexten.net|Devel-CheckOS|1.6|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904221804
3741729|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221810
3741743|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221813
3741746|pass|200904|bingos@cpan.org|Data-Compare|1.21|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221814
3741749|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221814
3741761|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221816
3741770|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904221820
3741772|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221819
3741774|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221820
3741779|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221821
3741782|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221821
3741785|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221822
3741786|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221823
3741984|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|IP35-irix-64int|5.8.8|irix|6.5|200904222007
3742241|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904222050
3742242|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904222050
3742247|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904222051
3742248|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904222052
3742250|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904222053
3742281|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904222051
3742293|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904222102
3742333|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904222111
3742412|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904222132
3742496|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904221500
3742690|pass|200904|vpit@cpan.org|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222235
3742837|pass|200904|srezic@cpan.org|Number-Phone|1.7002|amd64-freebsd|5.8.8|freebsd|7.0-release|200904222223
3742974|pass|200904|srezic@cpan.org|Number-Phone|1.7002|amd64-freebsd|5.8.9|freebsd|7.0-release|200904222317
3742978|fail|200904|vpit@cpan.org|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3742982|pass|200904|vpit@cpan.org|Devel-CheckOS|1.53|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3742984|pass|200904|vpit@cpan.org|Devel-CheckOS|1.54|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3742985|pass|200904|vpit@cpan.org|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3743025|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904222324
3743175|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904222342
3743379|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904222316
3743517|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222338
3743527|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222340
3743532|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222341
3743533|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222341
3743540|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222344
3743550|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222346
3743554|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222347
3743559|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222348
3743568|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222349
3743572|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222350
3743584|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222350
3743594|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222350
3743599|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|IP35-irix-64int|5.8.8|irix|6.5|200904230055
3743879|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904230202
3743931|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904230209
3744118|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.7002|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904230953
3744206|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904230222
3744768|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.6|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904230430
3745119|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|i586-linux-thread-multi|5.8.8|linux|2.6.16|200904230834
3745223|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904230759
3745330|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904230929
3745585|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904230417
3745669|pass|200904|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904231048
3745673|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.6|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904231049
3745700|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|alpha-netbsd|5.10.0|netbsd|4.0.1|200904231000
3745928|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904231250
3746082|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7002|i86pc-solaris-64int|5.10.0|solaris|2.11|200904231336
3746441|pass|200904|perl@galumph.com|Devel-CheckOS|1.6|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904230730
3747207|pass|200904|graham@crookham.uklinux.net (grahamc)|Devel-CheckOS|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904222039
3747587|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904231510
3747588|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904231511
3747656|pass|200904|graham@crookham.uklinux.net (grahamc)|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904222039
3747700|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904231629
3747701|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.3|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904231630
3747736|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904231641
3747919|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904220947
3747965|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904231613
3748134|pass|200904|imacat@mail.imacat.idv.tw|Number-Phone|1.7002|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904232345
3748320|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904231723
3748339|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904231728
3748368|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904231732
3748395|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904231135
3749018|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232018
3749019|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232019
3749020|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232019
3749037|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232020
3749039|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232022
3749040|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232022
3749042|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232023
3749043|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232023
3749044|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232024
3749236|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904232247
3749317|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232216
3749327|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232218
3749331|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904232319
3749333|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232221
3749335|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232221
3749339|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232222
3749341|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232223
3749342|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232224
3749967|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904240251
3750112|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|IP35-irix-64int|5.8.8|irix|6.5|200904240351
3750288|pass|200904|rafl@debian.org|Devel-CheckOS|1.6|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904240443
3750365|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904240507
3750428|pass|200904|mw487.yahoo.com@gmail.com|Number-Phone|1.7002|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904240323
3750794|pass|200904|conrad@fringehead.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.15.1|200904240509
3751177|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904240935
3751200|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904240943
3751273|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904240959
3751300|pass|200904|stro@cpan.org|Number-Phone|1.7002|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904241106
3751313|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904241010
3751335|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904241013
3751396|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904241024
3751451|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904240931
3751552|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904241046
3751655|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904241102
3751673|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904241106
3751873|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904241143
3751933|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904241156
3751957|pass|200904|chris@bingosnet.co.uk|Data-Compare|1.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904241103
3751962|fail|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.6|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904241106
3751994|pass|200904|graham@crookham.uklinux.net (grahamc)|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904241112
3751996|pass|200904|graham@crookham.uklinux.net (grahamc)|Devel-CheckOS|1.6|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904241112
3751999|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904241212
3752017|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904241216
3752070|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241125
3752071|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241125
3752074|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241126
3752077|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241127
3752411|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux|5.10.0|linux|2.6.24-16-generic|200904240708
3752666|pass|200904|jozef@kutej.net|Data-Compare|1.21|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.24-16-server|200904240956
3752767|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.6|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904232256
3753230|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux|5.10.0|linux|2.6.24-16-generic|200904240812
3753280|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904241419
3753952|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241000
3754394|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7002|i86pc-solaris-64int|5.8.9|solaris|2.11|200904241651
3754413|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904241552
3754463|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241558
3754611|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904241617
3754612|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904241617
3754753|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904241730
3754769|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904241730
3754773|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904241732
3754780|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904241733
3754794|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904241734
3754804|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904241736
3754822|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904241638
3754984|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904241804
3755155|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904241736
3755239|fail|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.31|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904250145
3755251|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904241846
3755265|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904241848
3755343|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904241904
3755475|pass|200904|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241324
3755480|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241325
3755500|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904241230
3755524|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.31|amd64-freebsd|5.8.8|freebsd|7.0-release|200904241932
3755535|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.31|amd64-freebsd|5.8.9|freebsd|7.0-release|200904241932
3755595|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904241938
3755654|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd|5.10.0|freebsd|7.0-release|200904241945
3755655|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.31|amd64-freebsd|5.10.0|freebsd|7.0-release|200904241946
3755754|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904242010
3755808|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904242021
3755856|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904242034
3755926|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904242044
3755979|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904242055
3756028|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904242105
3756175|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|IP35-irix-64int|5.8.8|irix|6.5|200904242129
3756299|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241547
3756303|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904242147
3756367|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904242156
3756386|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904242158
3756410|pass|200904|graham@crookham.uklinux.net (grahamc)|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904242101
3756411|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7002|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904242202
3756554|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904242220
3756734|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904242249
3756742|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904242249
3756935|pass|200904|graham@crookham.uklinux.net (grahamc)|Number-Phone|1.7002|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904242214
3757069|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241735
3757071|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241735
3757072|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241735
3757286|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904242314
3757288|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904242314
3757515|pass|200904|stro@cpan.org|CPAN-FindDependencies|2.22|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250143
3757560|pass|200904|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241850
3757653|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250007
3757656|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250008
3757672|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904250110
3757769|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241928
3757811|pass|200904|stro@cpan.org|Devel-CheckOS|1.51|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250235
3757816|pass|200904|stro@cpan.org|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250235
3757821|pass|200904|stro@cpan.org|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250236
3757882|pass|200904|stro@cpan.org|File-Overwrite|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250244
3758008|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904250210
3758015|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904250211
3758091|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904250223
3758131|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904250230
3758311|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250100
3758317|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250101
3758626|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904250349
3758652|pass|200904|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.6|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250154
3758867|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250240
3759204|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250451
3759215|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250452
3759542|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904250703
3759665|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904250732
3759804|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904250800
3759940|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904250831
3759967|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904250835
3760167|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904250915
3760372|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904250955
3760593|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904251042
3760611|pass|200904|wiml@hhhh.org ("Wim Lewis")|Number-Phone|1.7002|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250845
3760645|pass|200904|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250449
3760648|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250450
3760696|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904251102
3760790|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904251116
3760964|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904251202
3761010|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904251119
3761056|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904251228
3761077|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904251232
3761269|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904251319
3761271|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904251319
3761274|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904251319
3761278|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904251320
3761281|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904251320
3761286|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904251319
3761319|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904251331
3761437|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250755
3761486|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904251405
3761534|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904251313
3761596|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904251320
3761689|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904251339
3761690|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904251340
3761967|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904252232
3762012|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904251535
3762132|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904251555
3762182|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904251605
3762329|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251029
3762330|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251029
3762331|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251029
3762620|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904251727
3762639|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|alpha-netbsd|5.10.0|netbsd|4.0.1|200904251533
3762744|pass|200904|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251158
3762786|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904251809
3762920|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251241
3763213|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904251928
3763224|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251330
3763229|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251330
3763251|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904251933
3763491|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904251902
3763586|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904251915
3763708|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904251934
3763711|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904251935
3763802|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904252047
3763826|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251452
3763884|fail|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-FindDependencies|2.3|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250925
3763999|pass|200904|chris@bingosnet.co.uk|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200904252024
3764002|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200904252024
3764063|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904252033
3764122|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.61|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904252146
3764154|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904252053
3764412|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904252235
3764683|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904251627
3764724|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904252333
3764898|pass|200904|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.8.8|freebsd|7.0-release|200904260010
3764940|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252324
3764942|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252325
3764975|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252332
3765147|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904260003
3765169|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904260009
3765217|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.3|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904251817
3765224|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.31|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904251818
3765227|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904260118
3765262|pass|200904|andy@hexten.net|Devel-CheckLib|0.5|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904260027
3765268|pass|200904|andy@hexten.net|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904260027
3765271|pass|200904|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904260028
3765398|pass|200904|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251955
3765401|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251956
3765490|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260119
3765615|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904260245
3766096|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260220
3766148|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904260432
3766572|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260011
3766574|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260011
3766834|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904260605
3766904|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260119
3766926|pass|200904|rafl@debian.org|Devel-CheckOS|1.61|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904260725
3767135|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260239
3767169|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260247
3767249|pass|200904|stro@cpan.org|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904261010
3767261|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904260912
3767274|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260315
3767283|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260817
3767321|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260824
3767505|pass|200904|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.8.9|freebsd|7.0-release|200904261005
3767632|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260444
3767815|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|i586-linux-thread-multi|5.8.8|linux|2.6.16|200904261135
3767860|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200904261145
3767871|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904261147
3767886|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904261149
3767915|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904261157
3767931|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904261200
3768036|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.61|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904261826
3768106|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904261137
3768134|pass|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.31|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904261842
3768174|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904261156
3768175|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904261157
3768183|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904261158
3768188|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|IP35-irix-64int|5.8.8|irix|6.5|200904261259
3768319|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904261224
3768507|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200904261411
3768528|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904261438
3768683|pass|200904|mahony357@gmail.com|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904261331
3768777|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904261440
3768809|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904261605
3768833|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904261609
3769345|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904261816
3769368|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904261820
3769380|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904261822
3769387|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904261724
3769389|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904261724
3769824|pass|200904|rbo@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.9|solaris|2.11|200904262006
3769899|pass|200904|perl@galumph.com|Devel-CheckOS|1.61|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904261324
3770031|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904262055
3770222|pass|200904|rbo@cpan.org|Devel-CheckOS|1.6|i86pc-solaris|5.8.9|solaris|2.11|200904262149
3770224|pass|200904|rbo@cpan.org|Number-Phone|1.7002|i86pc-solaris|5.8.9|solaris|2.11|200904262149
3770403|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262137
3770413|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262139
3770417|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262140
3770422|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262141
3770507|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904262258
3770532|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904262302
3770689|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904262338
3770695|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904262341
3770842|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904270029
3771093|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904270141
3771121|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904270146
3771166|pass|200904|rbo@cpan.org|Devel-CheckLib|0.5|i86pc-solaris|5.8.9|solaris|2.11|200904270200
3771314|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904270241
3771492|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904270336
3771562|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904270355
3771570|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904270359
3771823|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904270545
3771931|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904270645
3771937|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904270649
3771942|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904270552
3772667|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.61|i86pc-solaris-64int|5.8.9|solaris|2.11|200904271104
3772733|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.61|i86pc-solaris-64int|5.10.0|solaris|2.11|200904271124
3772807|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|alpha-netbsd|5.10.0|netbsd|4.0.1|200904270948
3773291|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.31|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200904261329
3773445|pass|200904|rlane10@wi.rr.com|Devel-CheckOS|1.61|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200904261836
3773590|pass|200904|autarch@urth.org|Data-Compare|1.21|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200904260010
3773627|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.31|i86pc-solaris-64int|5.8.9|solaris|2.11|200904271350
3773760|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904271405
3773819|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.61|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904271440
3773940|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904271338
3774046|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904270857
3774128|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271417
3774129|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271417
3774340|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.31|i86pc-solaris-64int|5.10.0|solaris|2.11|200904271553
3774385|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904271504
3774457|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904271625
3774858|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271652
3774866|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271654
3774869|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271655
3774891|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271703
3775202|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904271953
3775330|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904272030
3775439|pass|200904|vpit@cpan.org|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904272049
3775679|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904272127
3775715|pass|200904|vpit@cpan.org|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904272130
3775831|pass|200904|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904272049
3775998|pass|200904|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.6.2|freebsd|7.0-release|200904272220
3776161|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.32|amd64-freebsd|5.8.9|freebsd|7.0-release|200904272252
3776447|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904272316
3776963|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904280605
3777050|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904280630
3777051|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904280631
3777053|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904280633
3777056|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904280634
3777058|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904280635
3777198|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.32|amd64-freebsd|5.8.8|freebsd|7.0-release|200904280733
3777442|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904280848
3777893|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904280902
3777894|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904280902
3777918|pass|200904|david@cantrell.org.uk|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904280904
3778066|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.32|i86pc-solaris-64int|5.10.0|solaris|2.11|200904281028
3778254|pass|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904281706
3778307|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904281114
3778362|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904281126
3778393|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904281132
3778404|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904281133
3778421|pass|200904|david@cantrell.org.uk|Devel-CheckLib|0.5|IP35-irix-64int|5.8.8|irix|6.5|200904281138
3778434|pass|200904|david@cantrell.org.uk|Devel-CheckLib|0.5|alpha-netbsd|5.10.0|netbsd|4.0.1|200904280941
3778470|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904281053
3778597|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904281221
3778659|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904281232
3778665|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904281234
3778723|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904281241
3778728|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904281242
3778820|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904281258
3778845|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904281304
3778850|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904281305
3778979|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904281229
3778984|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904281230
3778995|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904281231
3779035|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904281335
3779045|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904281338
3779152|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904281358
3779265|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.61|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904270954
3779397|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904281429
3779398|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281329
3779417|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281331
3779422|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281332
3779429|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281333
3779519|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904281446
3779698|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904281518
3779737|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904280824
3779839|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904281536
3780093|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|alpha-netbsd|5.10.0|netbsd|4.0.1|200904281411
3780218|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.32|i86pc-solaris-64int|5.8.9|solaris|2.11|200904281623
3780258|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904281631
3780333|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904281640
3780350|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904281643
3780720|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904281745
3780767|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904281652
3780780|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904281753
3780929|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904281811
3781088|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904281838
3781112|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904281842
3781409|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904281918
3781501|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904281836
3781566|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904281946
3781635|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904282007
3781657|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904282013
3782039|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904282213
3782162|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904282244
3782193|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904282252
3782206|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904282256
3782208|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904282256
3782306|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904282326
3782329|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904282329
3782385|pass|200904|andy@hexten.net|Data-Compare|1.21|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904282237
3782702|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904290017
3782820|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904290036
3782937|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904290101
3783353|pass|200904|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290121
3783357|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290121
3783398|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904290230
3783465|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904290245
3783547|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904290304
3783616|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904290330
3783631|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904290338
3784121|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290515
3784125|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904290617
3784126|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904290619
3784212|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904290658
3784349|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290659
3784352|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290701
3784354|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290702
3784356|pass|200904|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290704
3784416|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904290824
3784470|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904290848
3784508|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904290913
3784584|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904290940
3785780|pass|200904|bingos@cpan.org|Data-Compare|1.21|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291413
3785781|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291414
3786349|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291658
3786374|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291245
3786375|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291245
3786752|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291829
3786757|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291831
3786762|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291832
3786765|pass|200904|bingos@cpan.org|Number-Phone|1.7002|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291833
3786800|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291830
3787023|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291943
3787025|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291945
3787027|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291945
3787035|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291952
3787129|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.6.2|freebsd|7.0-release|200904292203
3787388|pass|200904|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904292204
3787390|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904292204
3787668|pass|200904|stro@cpan.org|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904300100
3788148|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300127
3788378|pass|200904|mw487.yahoo.com@gmail.com|Data-Compare|1.21|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200904300152
3788379|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200904300152
3788528|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300343
3788530|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300346
3788531|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300347
3788533|pass|200904|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300348
3791366|pass|200904|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904301840
3791369|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904301841
3791933|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302047
3792051|pass|200904|andy@hexten.net|CPAN-FindDependencies|2.32|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904302114
3792135|pass|200904|andy@hexten.net|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904302127
3792166|pass|200904|andy@hexten.net|Number-Phone|1.7002|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904302132
3792346|pass|200904|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200904302110
3792434|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904302159
3792468|pass|200905|stro@cpan.org|Number-Phone|1.7002|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200905010036
3792530|pass|200905|stro@cpan.org|Palm-Treo680MessagesDB|1.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200905010047
3792552|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302254
3792558|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302256
3792562|pass|200904|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302257
3793477|pass|200905|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.5|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905010115
3795838|pass|200905|mw487.yahoo.com@gmail.com|Number-Phone|1.7002|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905010627
3798266|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200905020231
3798425|pass|200904|pjacklam@cpan.org|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904301235
3799256|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905021016
3799831|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905021209
3800315|pass|200905|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905021953
3800316|pass|200905|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.61|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905021954
3800592|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905021455
3801406|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905021748
3801492|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905021759
3802701|pass|200905|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905022301
3802702|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905022301
3803088|pass|200905|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905022257
3803091|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905022257
3803455|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905030112
3803632|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905030100
3803909|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905030248
3803912|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905030249
3804338|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905030332
3804343|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905030335
3804419|pass|200905|imacat@mail.imacat.idv.tw|Number-Phone|1.7002|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905031103
3804824|pass|200905|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-16-generic|200905030022
3805131|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux|5.10.0|linux|2.6.24-16-generic|200905030120
3806704|pass|200905|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.10.0|freebsd|7.0-release|200905031330
3808378|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905032119
3809209|pass|200905|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040631
3809639|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905040143
3810091|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200905040320
3811253|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux|5.8.9|linux|2.6.24-16-generic|200905040500
3811866|pass|200905|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041318
3811869|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041319
3812299|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041430
3812829|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041555
3813276|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041126
3813585|pass|200905|robin@smidsrod.no ("Robin Smidsrd")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-19-server|200905041419
3813942|pass|200905|robin@smidsrod.no ("Robin Smidsrd")|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-19-server|200905041419
3814105|pass|200905|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041432
3814111|pass|200905|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041433
3814617|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041655
3815130|pass|200905|bingos@cpan.org|Data-Compare|1.21|darwin-2level|5.10.0|darwin|8.11.0|200905050033
3815133|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.10.0|darwin|8.11.0|200905050034
3815377|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|darwin-2level|5.10.0|darwin|8.11.0|200905050255
3815752|pass|200905|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050349
3815894|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-2level|5.10.0|darwin|8.11.0|200905050518
3816195|pass|200905|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050121
3816199|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050121
3816200|pass|200905|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050122
3816446|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905050746
3818121|pass|200905|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905051139
3819847|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200905051643
3819849|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200905051644
3819850|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200905051644
3819852|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200905051644
3819854|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200905051644
3819856|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200905051644
3820757|pass|200905|andy@hexten.net|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905051819
3820777|pass|200905|vpit@cpan.org|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905051924
3820784|pass|200905|andy@hexten.net|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905051826
3820909|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200905051408
3821101|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.8.8|freebsd|7.0-release|200905052035
3821247|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.8.9|freebsd|7.0-release|200905052035
3821470|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.8.9|linux|2.6.24-16-generic|200905051558
3821645|pass|200905|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.2101|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200905052239
3821794|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.10.0|netbsd|5.0|200905052300
3821796|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.10.0|netbsd|5.0|200905052259
3821934|pass|200905|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051735
3821935|pass|200905|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051735
3821991|pass|200905|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051747
3822281|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd|5.10.0|netbsd|5.0|200905060019
3822495|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051922
3822681|pass|200905|mw487.yahoo.com@gmail.com|Data-Compare|1.2101|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905051856
3822707|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-netbsd|5.10.0|netbsd|5.0|200905060142
3823111|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.10.0|darwin|8.11.0|200905060219
3824164|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.2101|i86pc-solaris-64int|5.10.0|solaris|2.11|200905060920
3824202|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905060941
3824283|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200905061003
3824544|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905061050
3824621|pass|200905|bingos@cpan.org|Data-Compare|1.2101|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200905061002
3825050|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905061123
3825074|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905061128
3825318|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905061344
3825400|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200905061358
3825446|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|i586-linux-thread-multi|5.8.8|linux|2.6.16|200905061403
3825468|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200905061406
3825486|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905061407
3825508|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200905061410
3825517|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.2101|i86pc-solaris-64int|5.8.9|solaris|2.11|200905061411
3825562|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200905061417
3825962|pass|200905|vovkasm@gmail.com|Data-Compare|1.2101|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200905061552
3826072|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905061449
3826074|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905061449
3826152|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|IP35-irix-64int|5.8.8|irix|6.5|200905061602
3826166|pass|200905|hohokus@gmail.com|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905061004
3826290|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905061526
3826417|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905061550
3826546|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.10.0|netbsd|5.0|200905061704
3826563|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905061023
3827217|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|alpha-netbsd|5.10.0|netbsd|4.0.1|200905061724
3827671|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905062109
3827931|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905062203
3828033|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.9|darwin|8.11.0|200905062134
3828035|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.9|darwin|8.11.0|200905062135
3828077|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200905062140
3828148|pass|200905|stro@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200905070000
3828188|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905062306
3828298|pass|200905|andy@hexten.net|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200905062236
3828353|pass|200905|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905062243
3828363|pass|200905|andy@hexten.net|Data-Compare|1.2101|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200905062244
3829152|pass|200905|mw487.yahoo.com@gmail.com|Data-Compare|1.2101|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905070209
3829982|pass|200905|srezic@cpan.org|CPAN-FindDependencies|2.32|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905070854
3830653|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071034
3830742|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200905071217
3831100|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.8.9|netbsd|5.0|200905071346
3831101|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.8.9|netbsd|5.0|200905071346
3831175|pass|200905|chris@bingosnet.co.uk|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071323
3831250|unknown|200905|chris@bingosnet.co.uk|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071349
3831510|pass|200905|andy@hexten.net|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071456
3831525|pass|200905|andy@hexten.net|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071459
3832947|unknown|200905|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080400
3832948|unknown|200905|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080400
3832949|pass|200905|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080401
3832962|fail|200905|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080404
3832972|pass|200905|imacat@mail.imacat.idv.tw|Data-Compare|1.2101|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080407
3832976|fail|200905|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080408
3832977|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200905072207
3832980|pass|200905|imacat@mail.imacat.idv.tw|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080408
3832982|pass|200905|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080409
3832989|pass|200905|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080410
3832991|pass|200905|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080410
3832998|pass|200905|imacat@mail.imacat.idv.tw|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080412
3833012|pass|200905|imacat@mail.imacat.idv.tw|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080419
3833014|pass|200905|imacat@mail.imacat.idv.tw|Data-Hexdumper|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080419
3833016|pass|200905|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080420
3833020|pass|200905|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080420
3833022|pass|200905|imacat@mail.imacat.idv.tw|File-Overwrite|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080421
3833024|pass|200905|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080421
3833026|pass|200905|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080421
3833038|pass|200905|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080423
3833043|pass|200905|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080424
3833046|pass|200905|imacat@mail.imacat.idv.tw|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080424
3833049|pass|200905|imacat@mail.imacat.idv.tw|Palm-SMS|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080425
3833062|pass|200905|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080427
3833087|pass|200905|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080429
3833099|pass|200905|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080429
3833101|pass|200905|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080429
3833106|pass|200905|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080430
3833111|pass|200905|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080430
3833115|pass|200905|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080430
3833120|pass|200905|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080431
3833126|pass|200905|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.0401|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080431
3833128|pass|200905|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080432
3833131|pass|200905|imacat@mail.imacat.idv.tw|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080432
3833134|pass|200905|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080432
3833138|pass|200905|imacat@mail.imacat.idv.tw|XML-Tiny|2.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080433
3833142|pass|200905|imacat@mail.imacat.idv.tw|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080433
3833917|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200905072351
3834657|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080150
3834658|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080151
3835537|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-16-generic|200905080005
3835831|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.8.9|netbsd|5.0|200905080644
3835855|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.8.9|darwin|8.11.0|200905080609
3837093|pass|200905|rbo@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.9|solaris|2.11|200905080929
3837100|pass|200905|stro@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200905081029
3837610|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905080414
3837613|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905080414
3837805|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905080432
3837806|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905080432
3839415|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080729
3839555|pass|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080756
3840307|pass|200905|perl@galumph.com|Data-Compare|1.2101|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200905080844
3840803|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200905081721
3841304|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200905081846
3842518|pass|200905|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.6.2|freebsd|7.0-release|200905082312
3842564|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.6.2|freebsd|7.0-release|200905082323
3844038|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.6|darwin|8.11.0|200905090349
3844043|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.6|darwin|8.11.0|200905090350
3844277|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905090423
3844392|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905090347
3845155|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905090843
3845610|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200905091108
3845653|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905091119
3845692|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905091127
3845871|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905091203
3845896|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905091211
3845937|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905091221
3845972|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200905091229
3846010|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905091236
3846040|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905091244
3846042|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200905091245
3846132|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200905091301
3846230|pass|200905|Michael.Finken@rbs.com|Data-Compare|1.2101|sun4-solaris-thread-multi|5.8.9|solaris|2.8|200905071143
3846231|pass|200905|Michael.Finken@rbs.com|Devel-CheckOS|1.61|sun4-solaris-thread-multi|5.8.9|solaris|2.8|200905071151
3846475|pass|200905|pjacklam@cpan.org|Data-Compare|1.2101|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905072052
3846601|fail|200905|rlane10@wi.rr.com|CPAN-FindDependencies|2.32|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200905080144
3846660|pass|200905|rlane10@wi.rr.com|Data-Compare|1.2101|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200905080024
3846786|pass|200905|cpan-testing@yorfeix.de ("yor_feix")|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071553
3847214|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905091431
3847567|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905091522
3847642|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905091531
3847897|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905091607
3847962|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905091613
3848116|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200905091624
3848503|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905091727
3848606|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905091744
3848749|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200905091809
3849492|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905092012
3849637|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200905092050
3850622|pass|200905|rafl@debian.org|Data-Compare|1.2101|i686-linux|5.10.0 patch 35117|linux|2.6.26|200905100223
3851730|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905100302
3851774|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905100313
3852002|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905100338
3852262|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905100417
3853665|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905101236
3853671|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905101237
3854722|pass|200905|wiml@hhhh.org ("Wim Lewis")|Data-Compare|1.2101|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905100830
3855295|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.8.6|darwin|8.11.0|200905102223
3855569|pass|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905101855
3855634|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905101856
3855879|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905101902
3855946|pass|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905101904
3858048|pass|200905|wiml@hhhh.org ("Wim Lewis")|Data-Compare|1.2101|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905110512
3858635|fail|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905110649
3860091|pass|200905|srezic@cpan.org|Data-Compare|1.2101|i686-linux|5.10.0 patch 32633|linux|2.6.18-4-486|200905111645
3860111|pass|200905|srezic@cpan.org|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 32633|linux|2.6.18-4-486|200905111648
3860902|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111419
3860933|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111419
3861309|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111418
3861313|pass|200905|vpit@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905112059
3861333|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905112100
3861384|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111429
3862002|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200905112201
3862199|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905111710
3862234|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905111711
3862278|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111712
3862352|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905111714
3862963|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111703
3863142|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905120049
3865415|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905121106
3865931|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121445
3865970|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121503
3866432|pass|200905|klaus+cpanplus@worstofall.com|XML-Tiny|2.02|x86_64-linux|5.10.0|linux|2.6.26-2-amd64|200905112307
3866600|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121648
3866672|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121707
3867298|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121243
3867367|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905121244
3867430|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200905121814
3867688|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121300
3867833|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121302
3867891|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121303
3868034|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121244
3868356|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121303
3868361|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121303
3868443|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905121243
3868567|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121300
3871030|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.61|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905130330
3871670|pass|200905|carlos.arenas@gmail.com ("Carlos Arenas")|Data-Compare|1.2101|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200905121109
3871692|pass|200905|feldt@nhn.ou.edu|Data-Compare|1.2101|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200905121226
3872252|pass|200905|bingos@cpan.org|Data-Compare|1.2101|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905131201
3872925|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200905131418
3873301|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200905131507
3873855|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905131652
3874469|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905131410
3874619|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905131408
3875271|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905131411
3876132|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140210
3876210|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140219
3876448|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140250
3876779|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905140328
3876804|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140331
3876981|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905140345
3877074|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140352
3877257|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140410
3877258|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140411
3877362|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140422
3877414|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140438
3877416|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140438
3877425|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140442
3878463|pass|200905|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.2101|sun4-solaris|5.10.0|solaris|2.8|200905131225
3879203|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905141049
3880320|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.61|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905140409
3880943|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905141715
3881666|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905142001
3882265|pass|200905|stro@cpan.org|Data-Compare|1.2101|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905141320
3882267|pass|200905|stro@cpan.org|Devel-CheckOS|1.61|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905141320
3882980|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905150019
3883140|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905141850
3883335|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905141852
3883482|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905141855
3883501|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905141855
3883535|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905141855
3883537|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905141855
3883539|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905141855
3883692|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905141852
3883995|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|8.11.0|200905150130
3884008|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905150033
3885227|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905150541
3885426|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905150423
3887461|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905150634
3887713|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150637
3887855|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905150638
3887899|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150638
3888062|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905150635
3888540|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150638
3888600|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckLib|0.5|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905150204
3888996|fail|200905|wiml@hhhh.org ("Wim Lewis")|CPAN-FindDependencies|2.32|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905150235
3889160|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150638
3890023|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905151545
3890319|pass|200905|stro@cpan.org|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905150826
3892169|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905152241
3892171|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905152241
3892187|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905152243
3893299|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905160258
3893392|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.6|darwin|8.0|200905160516
3893393|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.6|darwin|8.0|200905160516
3893785|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905160411
3895555|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200905161150
3895659|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.8|darwin|8.11.0|200905161212
3896788|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200905161745
3896885|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.8|darwin|8.11.0|200905161810
3899197|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905170318
3899239|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905170323
3899385|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170340
3899597|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170418
3899616|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170423
3899744|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170533
3901568|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3901736|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170850
3902510|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170849
3902754|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170853
3903810|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|8.11.0|200905171913
3903814|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|darwin-2level|5.10.0|darwin|8.11.0|200905171913
3905748|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.8.8|darwin|8.11.0|200905172206
3905792|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|darwin-2level|5.8.8|darwin|8.11.0|200905172324
3905794|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|darwin-2level|5.8.8|darwin|8.11.0|200905172325
3906054|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905171815
3906970|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180205
3906972|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905180205
3907796|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180339
3910154|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180739
3910597|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180742
3911090|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905181353
3912678|pass|200905|stro@cpan.org|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905180926
3912774|pass|200905|stro@cpan.org|Devel-CheckLib|0.5|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905180937
3912968|fail|200905|stro@cpan.org|CPAN-FindDependencies|2.32|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905181003
3912977|fail|200905|stro@cpan.org|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905181004
3912993|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.10.0|freebsd|7.0-release|200905181900
3914278|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905182139
3915712|pass|200905|greg@ie-entertainment.com|Number-Phone|1.7002|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200905190111
3918395|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905190739
3922256|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905200604
3923626|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905201215
3925267|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200905201549
3925269|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905201550
3925270|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200905201550
3925276|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200905201549
3925278|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905201550
3925279|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200905201549
3925282|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200905201549
3925284|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200905201550
3925287|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200905201550
3925288|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200905201550
3926043|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905201821
3926195|pass|200905|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.8.8|freebsd|7.0-release|200905201843
3926207|pass|200905|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200905201843
3926255|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905201855
3926260|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905201855
3926301|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905201855
3926309|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905201855
3926349|fail|200905|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckLib|0.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200905210212
3927224|pass|200905|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.6|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200905202240
3927536|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210821
3927537|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210822
3927602|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210845
3927655|pass|200905|chris@bingosnet.co.uk|Devel-CheckLib|0.6|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200905210001
3927702|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210009
3930716|pass|200905|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905211947
3931297|fail|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905211335
3931371|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905211342
3931388|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905211343
3931429|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905211347
3931632|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905211406
3932334|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|IP35-irix-64int|5.8.8|irix|6.5|200905211604
3932445|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905210919
3933523|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220344
3933614|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905211900
3933643|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905211904
3934778|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220810
3935179|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|alpha-netbsd|5.10.0|netbsd|4.0.1|200905220006
3938115|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200905221125
3938234|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221943
3938256|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221945
3938262|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221946
3938458|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200905221223
3938461|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905222024
3938864|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200905221259
3939137|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905221335
3939243|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200905221354
3939522|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905221434
3939563|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905221335
3939622|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200905221448
3939738|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905221508
3940204|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230027
3941123|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905221735
3941189|pass|200905|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.6|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905221145
3941639|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230357
3941641|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230358
3941642|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230358
3941779|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200905221923
3942045|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905222137
3942342|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230653
3943144|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905230040
3944102|pass|200905|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905230302
3944728|pass|200905|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905230433
3944815|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231451
3945760|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905232013
3945825|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905232042
3946896|pass|200905|rbo@cpan.org|Devel-CheckLib|0.6|i86pc-solaris|5.8.9|solaris|2.11|200905231646
3947217|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200905231618
3947452|pass|200905|stro@cpan.org|Devel-CheckOS|1.61|i686-linux|5.8.8|linux|2.4.27-2-386|200905231922
3947614|pass|200905|stro@cpan.org|File-Overwrite|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200905231954
3947767|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905231819
3948401|pass|200905|stro@cpan.org|Palm-SMS|0.03|i686-linux|5.8.8|linux|2.4.27-2-386|200905232253
3948791|pass|200905|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905232224
3948813|pass|200905|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905232227
3949841|pass|200905|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240102
3949982|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200905240207
3950088|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckLib|0.6|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905240126
3950261|pass|200905|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240142
3950486|pass|200905|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240223
3950687|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200905240426
3951877|pass|200905|stro@cpan.org|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905240427
3952325|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200905241455
3952328|pass|200905|stro@cpan.org|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.4.27-2-386|200905240628
3952344|pass|200905|stro@cpan.org|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.4.27-2-386|200905240636
3952453|pass|200905|stro@cpan.org|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.4.27-2-386|200905240701
3952511|pass|200905|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.6|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905240944
3953078|pass|200905|stro@cpan.org|Devel-CheckLib|0.6|armv5tejl-linux|5.10.0|linux|2.6.17.14|200905241945
3953266|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905241909
3953486|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200905242001
3953672|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200905242024
3953722|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905242032
3953754|pass|200905|stro@cpan.org|Number-Phone|1.7002|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241138
3953938|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200905242105
3954098|pass|200905|stro@cpan.org|File-Overwrite|1.1|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241227
3954103|pass|200905|stro@cpan.org|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241228
3954111|pass|200905|stro@cpan.org|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241228
3954159|pass|200905|stro@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241234
3954699|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905242217
3955185|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.6|i86pc-solaris-64int|5.10.0|solaris|2.11|200905250042
3955619|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250031
3955905|pass|200905|stro@cpan.org|File-Overwrite|1.1|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250057
3955907|pass|200905|stro@cpan.org|Data-Hexdumper|2.01|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250057
3955909|pass|200905|stro@cpan.org|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250057
3955933|pass|200905|stro@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250101
3956048|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905250225
3956252|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250305
3957235|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905250831
3957520|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905250916
3957715|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250823
3957939|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905251031
3957957|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905250930
3958002|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905251043
3958219|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905251120
3958335|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905251150
3958478|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905251218
3958767|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.6|i86pc-solaris-64int|5.8.9|solaris|2.11|200905251230
3959198|pass|200905|andy@hexten.net|Tie-STDOUT|1.0401|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905251349
3960221|pass|200905|vpit@cpan.org|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905252113
3960390|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905251912
3960539|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905251513
3962550|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905252356
3965875|pass|200905|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.10.0|freebsd|7.0-release|200905261205
3966727|pass|200905|stro@cpan.org|Devel-CheckLib|0.6|i686-linux|5.8.9|linux|2.6.26-2-686|200905261824
3968082|pass|200905|stro@cpan.org|CPAN-ParseDistribution|1.1|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261024
3968092|pass|200905|stro@cpan.org|CPAN-ParseDistribution|1.1|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261025
3968515|pass|200905|stro@cpan.org|Data-Compare|1.2101|i686-linux|5.8.9|linux|2.6.26-2-686|200905262307
3969871|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905261614
3970073|pass|200905|andy@hexten.net|XML-Tiny-DOM|1.0|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905262208
3970201|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905262216
3970785|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905261800
3970934|pass|200905|stro@cpan.org|Palm-ProjectGutenberg|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261541
3970936|pass|200905|stro@cpan.org|XML-Tiny|2.02|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261541
3970938|pass|200905|stro@cpan.org|XML-Tiny-DOM|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261541
3971071|pass|200905|stro@cpan.org|Palm-ProjectGutenberg|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261550
3971075|pass|200905|stro@cpan.org|XML-Tiny|2.02|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261550
3971076|pass|200905|stro@cpan.org|XML-Tiny-DOM|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261550
3971674|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905270115
3971991|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905270327
3972414|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905270243
3973221|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905270710
3974511|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905271220
3974512|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905271220
3974716|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905270628
3974999|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200905271309
3975011|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905271212
3975338|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905271406
3975400|pass|200905|stro@cpan.org|CPAN-FindDependencies|2.32|i686-linux|5.8.9|linux|2.6.26-2-686|200905271024
3975401|pass|200905|stro@cpan.org|CPAN-ParseDistribution|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200905271024
3975848|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905271536
3976253|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905271657
3976401|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905270931
3977908|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905271951
3978979|pass|200905|stro@rail.org.ua|File-Overwrite|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200905271655
3978981|pass|200905|stro@rail.org.ua|Data-Hexdumper|2.01|i686-linux|5.8.9|linux|2.6.26-2-686|200905271656
3978983|pass|200905|stro@rail.org.ua|Palm-Treo680MessagesDB|1.01|i686-linux|5.8.9|linux|2.6.26-2-686|200905271656
3979017|pass|200905|stro@rail.org.ua|Palm-ProjectGutenberg|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905271734
3979020|pass|200905|stro@rail.org.ua|XML-Tiny|2.02|i686-linux|5.8.9|linux|2.6.26-2-686|200905271734
3979021|pass|200905|stro@rail.org.ua|XML-Tiny-DOM|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905271734
3979028|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905272138
3979302|pass|200905|stro@rail.org.ua|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905271700
3979873|pass|200905|stro@rail.org.ua|Devel-CheckOS|1.61|i686-linux|5.8.9|linux|2.6.26-2-686|200905271507
3981894|pass|200905|stro@cpan.org|Tie-STDOUT|1.0401|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280049
3982598|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905282034
3983062|pass|200905|stro@cpan.org|Tie-STDOUT|1.0401|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280359
3983205|pass|200905|angryxpeh@gmail.com|Number-Phone|1.7002|i686-linux|5.8.9|linux|2.6.26-2-686|200905281629
3983344|pass|200905|angryxpeh@gmail.com|Tie-STDOUT|1.0401|i686-linux|5.8.9|linux|2.6.26-2-686|200905281634
3983422|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200905281215
3983946|pass|200905|angryxpeh@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905281707
3984043|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905282148
3984149|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905282153
3984548|pass|200905|stro@rail.org.ua|File-Find-Rule-Permissions|2.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905281742
3984562|pass|200905|stro@rail.org.ua|Class-DBI-ClassGenerator|1.02|i686-linux|5.8.9|linux|2.6.26-2-686|200905281742
3984915|fail|200905|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282232
3985574|fail|200905|stro@rail.org.ua|Bryar|3.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905281833
3985825|pass|200905|stro@rail.org.ua|Palm-SMS|0.03|i686-linux|5.8.9|linux|2.6.26-2-686|200905281851
3985970|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-SMS|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282335
3987353|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905281706
3988264|pass|200905|stro@cpan.org|Devel-CheckLib|0.6|i686-linux|5.8.8|linux|2.4.27-2-386|200905282049
3988417|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905281918
3989560|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200905282354
3989568|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200905282355
3989571|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200905282355
3989572|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200905282356
3989574|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200905282356
3990031|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905290037
3990082|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905290057
3990807|fail|200905|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Bryar|3.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200905291154
3991125|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200905290549
3991126|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200905290549
3991246|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905290549
3991253|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905290549
3991583|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905290557
3991834|pass|200905|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200905290756
3991926|pass|200905|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200905290756
3992757|pass|200905|stro@cpan.org|Bryar|3.1|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905290228
3992912|fail|200905|stro@cpan.org|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905290241
3993559|fail|200905|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200905291309
3993797|pass|200905|angryxpeh@gmail.com|Sort-MultipleFields|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905291225
3994359|pass|200905|stro@rail.org.ua|DBIx-Class-SingletonRows|0.11|i686-linux|5.8.9|linux|2.6.26-2-686|200905291332
3994449|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905291345
3994539|pass|200905|stro@rail.org.ua|Data-Transactional|1.02|i686-linux|5.8.9|linux|2.6.26-2-686|200905291345
3994589|pass|200905|stro@rail.org.ua|CPU-Emulator-Memory|1.1001|i686-linux|5.8.9|linux|2.6.26-2-686|200905291349
3994590|pass|200905|stro@rail.org.ua|CPU-Emulator-Z80|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905291349
3994595|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905291356
3994722|fail|200905|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200905291506
3994987|fail|200905|imacat@mail.imacat.idv.tw|Bryar|3.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905292159
3995908|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300347
3995915|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300349
3995917|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300350
3996155|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300447
3996165|fail|200905|david@cantrell.org.uk|Bryar|3.1|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905291955
3996341|pass|200905|bingos@cpan.org|Bryar|3.1|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905292019
3996596|fail|200905|david@cantrell.org.uk|Bryar|3.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905292119
3997084|fail|200905|david@cantrell.org.uk|Bryar|3.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905292253
3997096|fail|200905|david@cantrell.org.uk|Bryar|3.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200905292153
3997099|fail|200905|david@cantrell.org.uk|Bryar|3.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905292253
3997101|fail|200905|david@cantrell.org.uk|Bryar|3.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905292253
3997184|fail|200905|david@cantrell.org.uk|Bryar|3.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905291712
3997908|fail|200905|bingos@cpan.org|Bryar|3.1|i386-freebsd|5.10.0|freebsd|6.4-release|200905300219
3998783|fail|200905|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301407
3998904|fail|200905|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905301428
3999037|pass|200905|bingos@cpan.org|Bryar|3.1|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905300555
4000121|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905300232
4000627|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905300226
4001072|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301917
4001125|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905300137
4001649|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905302148
4002805|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905302344
4002899|fail|200905|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200905301546
4003256|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310010
4003265|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310011
4003268|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310011
4005304|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310250
4005777|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301333
4005881|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301340
4005950|pass|200905|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301042
4005957|pass|200905|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301042
4006119|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301333
4008247|fail|200905|mw487.yahoo.com@gmail.com|Bryar|3.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905301541
4009276|pass|200905|stro@cpan.org|File-Find-Rule-Permissions|2.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301521
4009283|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301821
4009291|pass|200905|stro@cpan.org|File-Find-Rule-Permissions|2.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301521
4009296|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301822
4009317|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301824
4009342|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301827
4009351|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301827
4009385|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301830
4009704|pass|200905|stro@cpan.org|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301622
4009714|pass|200905|stro@cpan.org|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301622
4010371|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311033
4010784|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905310158
4012260|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd|5.10.0|freebsd|6.4-release|200905310442
4012729|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905310448
4012956|pass|200905|rbo@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.10.0|solaris|2.11|200905310735
4013380|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311629
4013417|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311643
4013821|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd|5.10.0|freebsd|6.4-release|200905310831
4013828|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd|5.10.0|freebsd|6.4-release|200905310832
4014333|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905310441
4014385|pass|200905|stro@cpan.org|Palm-SMS|0.03|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310201
4014390|pass|200905|stro@cpan.org|Palm-SMS|0.03|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310201
4014604|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905310547
4015699|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905311413
4015704|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905311414
4015847|pass|200905|angryxpeh@gmail.com|Net-Random|2.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905311817
4016104|pass|200905|stro@rail.org.ua|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.9|linux|2.6.26-2-686|200905311841
4018412|pass|200905|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200905312041
4018415|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200905312042
4018625|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200905312118
4018635|pass|200905|andy@hexten.net|Devel-CheckOS|1.61|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200905312118
4019337|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906010755
4019599|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905311818
4019613|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905311818
4019880|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905311818
4019975|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905311818
4020116|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200906010020
4020384|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906010001
4020468|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906010011
4022257|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200906010824
4022258|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200906010825
4023320|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011123
4023333|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011124
4023338|pass|200906|bingos@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011125
4023444|pass|200906|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906011140
4023447|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906011141
4023828|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906011254
4023836|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906011254
4024227|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011339
4025018|pass|200906|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906010949
4025027|pass|200906|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906010949
4025434|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200906011520
4025448|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200906011521
4025790|pass|200906|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906010949
4025799|pass|200906|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906010949
4026013|fail|200906|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011553
4027417|fail|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.10.0|darwin|8.11.0|200906011750
4027797|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906011344
4028316|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906011344
4028841|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011455
4029091|pass|200906|angryxpeh@gmail.com|Games-Dice-Advanced|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906012212
4029138|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011457
4029140|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906011457
4029816|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906012151
4029830|pass|200906|angryxpeh@gmail.com|Sub-WrapPackages|1.2|i686-linux|5.8.9|linux|2.6.26-2-686|200906012252
4030253|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200906012221
4030498|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906011455
4030818|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906012308
4032104|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906020014
4032230|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011807
4032457|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906020038
4033019|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906020121
4033048|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906020123
4033246|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906020138
4033613|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020005
4033822|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200906020219
4033841|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906020120
4034656|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020119
4034683|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020120
4034978|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906020341
4035010|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200906020242
4036502|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906020008
4036866|fail|200906|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906020106
4037766|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906020904
4038098|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906021009
4038406|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200906021105
4038411|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200906021106
4039570|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906020621
4039591|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020621
4039593|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020621
4039672|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906021204
4040187|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020625
4040188|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020625
4040313|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906020627
4040314|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020627
4040315|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020627
4040612|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020628
4040616|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020629
4041724|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020636
4041728|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020636
4042015|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020638
4042018|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020638
4042251|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200906021544
4042337|fail|200906|bingos@cpan.org|Bryar|3.1|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200906021450
4042410|fail|200906|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906021456
4042573|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200906021605
4042619|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906021607
4042977|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020645
4042981|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020645
4042999|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020645
4043000|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020645
4043001|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020645
4043511|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020621
4043513|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020621
4043521|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020621
4043772|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020625
4044558|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020636
4044562|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020636
4044564|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200906021821
4044666|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020638
4044676|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020638
4044861|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200906021846
4044891|pass|200906|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906021845
4044969|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200906021856
4045029|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906021900
4045037|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020645
4045039|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020645
4045049|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020645
4045066|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020645
4045160|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906021913
4045378|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020627
4046395|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906022048
4046525|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021402
4046528|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021402
4046771|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021404
4047069|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021407
4047073|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021407
4047985|pass|200906|schwern@pobox.com|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200906021052
4047991|pass|200906|schwern@pobox.com|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200906021057
4048772|fail|200906|srezic@cpan.org|Bryar|3.1|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906022339
4048819|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021422
4048820|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021422
4048934|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021423
4048937|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021423
4049386|pass|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.8.6|darwin|8.11.0|200906022347
4049532|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021422
4049989|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021407
4050196|pass|200906|stro@rail.org.ua|Class-CanBeA|1.2|i686-linux|5.8.9|linux|2.6.26-2-686|200906021245
4050204|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021402
4050276|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021425
4050439|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021425
4050880|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906022358
4050996|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030008
4051133|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030017
4051694|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030055
4051725|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030058
4051751|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906030159
4051813|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030102
4051840|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030104
4052180|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030127
4052221|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030131
4052398|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030143
4052442|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030146
4052539|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030153
4052550|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906030354
4052574|fail|200906|stro@cpan.org|Bryar|3.1|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906030456
4052611|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030159
4052705|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906030406
4054379|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906030020
4054443|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030426
4054486|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906030530
4054528|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906030033
4054862|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030505
4055782|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030612
4056092|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030633
4057256|pass|200906|bingos@cpan.org|Data-Compare|1.2101|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906030846
4057732|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030815
4058071|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030840
4058848|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030937
4058853|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030937
4058877|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030939
4060816|fail|200906|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200906031359
4060950|fail|200906|bingos@cpan.org|Bryar|3.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906031307
4061140|fail|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906030820
4062046|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200906031532
4063069|pass|200906|bminton@integ.com (Brian Minton)|CPAN-ParseDistribution|1.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200906031051
4063532|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906031623
4063658|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906031132
4064360|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906031828
4065150|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906031940
4065594|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030642
4065744|fail|200906|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906031928
4066091|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906031901
4066473|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906032149
4066595|pass|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.8.8|darwin|8.11.0|200906032107
4067174|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906032307
4068240|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906032234
4069722|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040023
4069762|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200906040227
4070061|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906040110
4070081|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906040114
4070241|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200906040236
4071032|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906040634
4071178|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906040705
4071435|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906040758
4071944|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040310
4071947|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040311
4071950|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040312
4072917|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906041032
4074002|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906041313
4074158|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906041324
4074628|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040645
4074668|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906041305
4074681|pass|200906|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906040645
4074785|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040813
4075624|pass|200906|bingos@cpan.org|Bryar|3.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200906041417
4076574|fail|200906|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.6.2|freebsd|7.0-release|200906041624
4076787|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041044
4076813|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041046
4076817|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041047
4076839|pass|200906|martin.evans@easysoft.com|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-24-generic|200906041547
4076906|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040716
4076907|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040716
4078890|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906041958
4079026|pass|200906|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.6.2|freebsd|7.0-release|200906042009
4079101|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040716
4079528|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906042054
4080041|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906041402
4080042|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041403
4080044|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041403
4080151|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041953
4080225|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041404
4080265|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041405
4080268|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041405
4080298|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906041405
4080727|pass|200906|angryxpeh@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906042045
4082647|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906042241
4082901|pass|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.8.9|darwin|8.11.0|200906042354
4083377|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041403
4083393|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906041403
4083445|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200906050125
4083492|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041929
4084374|fail|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050048
4084661|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906050114
4084690|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906050116
4084891|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906050336
4085845|pass|200906|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906050339
4085850|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906050339
4085888|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050343
4085890|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050343
4085891|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050343
4086354|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906050649
4086975|pass|200906|stro@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906050708
4087283|fail|200906|martin.evans@easysoft.com|Bryar|3.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200906050919
4088541|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906051551
4088634|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.10.0|darwin|8.11.0|200906051506
4089438|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906051250
4089807|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906051842
4090056|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906052004
4090371|fail|200906|vpit@cpan.org|Bryar|3.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200906052021
4090985|fail|200906|bingos@cpan.org|Bryar|3.1|darwin-64int-2level|5.10.0|darwin|8.11.0|200906052002
4091042|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091064|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091090|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906051407
4092162|pass|200906|stro@rail.org.ua|Tie-Hash-Longest|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906060217
4092166|pass|200906|stro@rail.org.ua|Statistics-ChiSquare|0.5|i686-linux|5.8.9|linux|2.6.26-2-686|200906060217
4092419|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051416
4092650|fail|200906|bingos@cpan.org|Bryar|3.1|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906051644
4093529|pass|200906|stro@rail.org.ua|NestedMap|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200906060335
4095378|unknown|200906|stro@rail.org.ua|Acme-Licence|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200906060527
4096126|fail|200906|bingos@cpan.org|Bryar|3.1|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906060113
4096130|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060016
4096721|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060052
4097751|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060230
4098588|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060357
4099037|pass|200906|wiml@hhhh.org ("Wim Lewis")|Number-Phone|1.7002|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200906060448
4099403|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906060743
4099462|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906060749
4099516|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060556
4099886|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060635
4100288|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906060714
4100537|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060743
4100598|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906060750
4100846|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060816
4101107|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060849
4101805|unknown|200906|angryxpeh@gmail.com|Acme-Pony|1.1.2|i686-linux|5.8.9|linux|2.6.26-2-686|200906061603
4101861|pass|200906|angryxpeh@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906061608
4101912|pass|200906|angryxpeh@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906061613
4102520|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906061251
4103536|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061417
4103574|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061419
4103771|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906061428
4104632|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061401
4104755|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061401
4106121|fail|200906|stro@rail.org.ua|Bryar|3.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906062026
4106719|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906061043
4107433|pass|200906|stro@rail.org.ua|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.26-2-686|200906062144
4107804|pass|200906|stro@rail.org.ua|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.26-2-686|200906062205
4107842|pass|200906|stro@rail.org.ua|Devel-CheckLib|0.6|i686-linux|5.10.0|linux|2.6.26-2-686|200906062206
4108975|pass|200906|DCOLLINS@cpan.org|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906060830
4109420|pass|200906|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906060833
4109422|pass|200906|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060833
4110126|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.10.0|darwin|8.11.0|200906061933
4110635|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.32|i686-linux|5.10.0|linux|2.6.26-2-686|200906070126
4111202|pass|200906|stro@cpan.org|Number-Phone|1.7002|i686-linux|5.10.0|linux|2.6.26-2-686|200906070246
4112697|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.10.0|darwin|8.11.0|200906070221
4112832|pass|200906|stro@cpan.org|File-Overwrite|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906070630
4112835|pass|200906|stro@cpan.org|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.26-2-686|200906070631
4112838|pass|200906|stro@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux|5.10.0|linux|2.6.26-2-686|200906070631
4112872|pass|200906|stro@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906070633
4113208|pass|200906|stro@cpan.org|CPAN-ParseDistribution|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906070750
4113880|pass|200906|stro@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071008
4113882|pass|200906|stro@cpan.org|XML-Tiny|2.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906071008
4113884|pass|200906|stro@cpan.org|XML-Tiny-DOM|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071008
4114361|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906070754
4114381|pass|200906|stro@cpan.org|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.26-2-686|200906071139
4115341|pass|200906|angryxpeh@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071344
4115696|pass|200906|angryxpeh@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071428
4115758|pass|200906|angryxpeh@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906071434
4116423|fail|200906|stro@rail.org.ua|Bryar|3.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071520
4116550|pass|200906|stro@rail.org.ua|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.26-2-686|200906071530
4118608|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906071549
4120363|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906071951
4120629|pass|200906|rafl@debian.org|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.28.7|200906072154
4122034|pass|200906|stro@cpan.org|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906080700
4122125|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906080251
4123367|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906080459
4123425|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906080709
4124786|pass|200906|stro@rail.org.ua|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.26-2-686|200906081751
4124934|pass|200906|stro@rail.org.ua|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906081806
4124973|pass|200906|stro@rail.org.ua|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.26-2-686|200906081810
4124974|pass|200906|stro@rail.org.ua|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906081810
4125580|pass|200906|martin.evans@easysoft.com|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-24-generic|200906081352
4125821|pass|200906|martin.evans@easysoft.com|Devel-CheckLib|0.6|i686-linux|5.10.0|linux|2.6.24-24-generic|200906081405
4125945|pass|200906|angryxpeh@gmail.com|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.26-2-686|200906081908
4125947|pass|200906|angryxpeh@gmail.com|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906081908
4126379|pass|200906|angryxpeh@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906081931
4129535|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.6|darwin|8.11.0|200906081842
4129916|pass|200906|bobtfisg@bobtfish.net|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.6|darwin|8.0|200906071349
4132738|pass|200906|stro@cpan.org|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906090455
4133350|pass|200906|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.26-2-686|200906090720
4133554|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906090743
4134173|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906090949
4134928|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906091245
4134936|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906091246
4138534|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.7|darwin|8.11.0|200906100034
4138539|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.7|darwin|8.11.0|200906100034
4139866|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Sort-MultipleFields|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906101123
4142260|pass|200906|angryxpeh@gmail.com|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906100755
4142536|pass|200906|angryxpeh@gmail.com|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.26-2-686|200906100822
4143368|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906101014
4143371|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906101014
4144065|pass|200906|stro@rail.org.ua|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.26-2-686|200906101046
4146931|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.7|darwin|8.11.0|200906101644
4149099|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906110004
4149969|pass|200906|stro@rail.org.ua|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906110654
4150797|pass|200906|stro@cpan.org|Data-Compare|1.2101|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906110553
4151237|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110554
4151238|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110554
4151430|pass|200906|stro@cpan.org|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906111127
4151723|pass|200906|stro@cpan.org|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906111231
4151782|unknown|200906|stro@cpan.org|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.26-2-686|200906111236
4152494|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110013
4152749|pass|200906|james@mastros.biz|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110155
4153926|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906111355
4156958|pass|200906|angryxpeh@gmail.com|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906120028
4157429|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.32|i686-linux|5.8.8|linux|2.4.27-2-386|200906120425
4157545|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906120255
4157546|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906120255
4159052|unknown|200906|stro@cpan.org|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906120700
4160654|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906121419
4161253|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906121512
4161531|pass|200906|martin.evans@easysoft.com|CPAN-FindDependencies|2.32|i686-linux|5.10.0|linux|2.6.24-24-generic|200906121600
4162193|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121807
4162195|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121807
4163284|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110133
4163504|pass|200906|justin.d.hunter@gmail.com|DBIx-Class-SingletonRows|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906111658
4163607|pass|200906|justin.d.hunter@gmail.com|DBIx-Class-SingletonRows|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120211
4163791|pass|200906|sscaffidi@cpan.org ("Stephen R. Scaffidi")|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906121503
4163792|pass|200906|sscaffidi@cpan.org ("Stephen R. Scaffidi")|CPAN-FindDependencies|2.32|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906121504
4164574|pass|200906|sscaffidi@cpan.org ("Stephen R. Scaffidi")|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906121503
4165500|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130241
4165501|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130241
4165939|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906130512
4170391|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906132113
4170393|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906132113
4170746|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131432
4170748|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131432
4171633|pass|200906|bernt.guldbrandtsen@agrsci.dk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200906132206
4171848|pass|200906|bernt.guldbrandtsen@agrsci.dk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200906132206
4172719|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.1|linux|2.6.28-11-generic|200906142000
4172767|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142003
4172769|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142003
4173110|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142024
4173152|pass|200906|stro@cpan.org|Devel-CheckOS|1.61|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906142234
4173175|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142029
4173177|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.10.0|netbsd|5.0|200906142032
4173179|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142029
4173191|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.10.0|netbsd|5.0|200906142033
4173275|fail|200906|stro@cpan.org|CPAN-FindDependencies|2.32|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906142244
4173343|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142025
4173436|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.1|linux|2.6.28-11-generic|200906142000
4173510|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142053
4173550|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142059
4173699|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142053
4173720|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142059
4173841|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142131
4173843|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142131
4173885|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142135
4173887|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142135
4174106|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142155
4174108|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142155
4174138|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906142158
4174140|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906142158
4175727|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.8|darwin|8.11.0|200906150113
4175728|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.8|darwin|8.11.0|200906150113
4175751|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906150113
4177049|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.10.0|netbsd|5.0|200906150541
4179587|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906151315
4179588|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906151315
4180979|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151602
4180982|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151602
4181712|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151731
4181758|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151731
4181803|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906151741
4181806|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906151742
4182364|pass|200906|gms8994@dp.cx|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906150905
4182740|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.8|darwin|8.11.0|200906151940
4184195|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906152312
4184267|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906152312
4184285|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.9|linux|2.6.28-11-generic|200906152323
4184288|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.9|linux|2.6.28-11-generic|200906152323
4186269|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906160145
4186273|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906160145
4186711|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160453
4186840|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.8.9|netbsd|5.0|200906160407
4186841|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.8.9|netbsd|5.0|200906160408
4188764|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906160908
4188769|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906160909
4189089|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906160950
4189092|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906160950
4189524|pass|200906|martin.evans@easysoft.com|Number-Phone|1.7002|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161036
4191562|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.8.9|netbsd|5.0|200906161701
4191789|pass|200906|martin.evans@easysoft.com|File-Overwrite|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161744
4191793|pass|200906|martin.evans@easysoft.com|Palm-Treo680MessagesDB|1.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161745
4191794|pass|200906|martin.evans@easysoft.com|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161744
4194549|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906170030
4194633|pass|200906|chris@bingosnet.co.uk|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200906170040
4194641|pass|200906|chris@bingosnet.co.uk|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200906170041
4194696|pass|200906|chris@bingosnet.co.uk|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200906170044
4196349|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.9|darwin|8.11.0|200906170635
4196352|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.9|darwin|8.11.0|200906170636
4197647|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-64int|5.10.0|netbsd|5.0|200906171123
4197984|pass|200906|brian@minton.name|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161527
4197987|pass|200906|brian@minton.name|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161527
4197989|pass|200906|brian@minton.name|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161528
4198265|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906171347
4198848|pass|200906|martin.evans@easysoft.com|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906171337
4199185|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906170856
4199315|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906170905
4199443|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906170914
4200321|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906171043
4200571|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906171111
4200944|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-64int|5.10.0|netbsd|5.0|200906171656
4200974|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906171707
4202506|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172010
4202508|fail|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172010
4202822|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172052
4202826|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172052
4203892|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906171949
4203964|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906180051
4204623|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.9|darwin|8.11.0|200906180223
4205084|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-64int|5.10.0|netbsd|5.0|200906180329
4207025|pass|200906|martin.evans@easysoft.com|CPAN-ParseDistribution|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200906180902
4209007|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i386-linux-thread-multi|5.10.0|linux|2.6.29.4-167.fc11.i686.pae|200906181411
4209008|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i386-linux-thread-multi|5.10.0|linux|2.6.29.4-167.fc11.i686.pae|200906181411
4209542|pass|200906|martin.evans@easysoft.com|XML-Tiny|2.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200906181403
4209543|pass|200906|martin.evans@easysoft.com|XML-Tiny-DOM|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906181403
4209545|pass|200906|martin.evans@easysoft.com|Palm-ProjectGutenberg|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906181403
4210156|fail|200906|mithaldu@yahoo.de ("Christian Walde")|CPAN-FindDependencies|2.32|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906181229
4210565|pass|200906|mithaldu@yahoo.de ("Christian Walde")|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906181256
4210731|pass|200906|mithaldu@yahoo.de ("Christian Walde")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906181307
4211385|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.8.9|netbsd|5.0|200906181939
4211656|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906182130
4211659|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906182130
4211768|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906182152
4211772|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906182153
4211979|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906182139
4212534|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906190108
4213195|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906190151
4213783|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.8.9|netbsd|5.0|200906190335
4214392|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906190539
4215243|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906190829
4215435|pass|200906|martin.evans@easysoft.com|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.24-24-generic|200906190910
4216500|fail|200906|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906190702
4216790|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.8.9|netbsd|5.0|200906191232
4216871|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906191442
4216887|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.22|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906191444
4217824|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191534
4217825|fail|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191534
4218587|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191712
4218588|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191712
4218685|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191726
4218686|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191726
4219213|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191842
4219214|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191843
4219360|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906191901
4219362|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906191901
4220310|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906192200
4220718|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906200000
4221040|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906200010
4221487|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906200238
4221697|fail|200906|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906200109
4221730|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906200203
4221876|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906200345
4221929|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906200358
4222308|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906200407
4222506|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906200541
4222674|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906200611
4223752|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906200953
4224528|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906201152
4224762|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906201345
4224764|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906201345
4225170|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201441
4225171|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201441
4225339|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.8.9 patch 35104|darwin|9.7.0|200906201353
4225340|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.9 patch 35104|darwin|9.7.0|200906201353
4225377|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.1|linux|2.6.24-19-server|200906201358
4225380|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.1|linux|2.6.24-19-server|200906201358
4225852|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201540
4226071|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201540
4226872|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.4|linux|2.6.29.4-167.fc11.i686.pae|200906201732
4226873|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.4|linux|2.6.29.4-167.fc11.i686.pae|200906201732
4227643|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906201752
4229584|fail|200906|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210704
4230922|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906210051
4230924|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906210051
4230926|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906210051
4230930|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906210051
4231331|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906210158
4236105|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906210028
4236261|pass|200906|l.mai@web.de|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.22-gentoo-r9|200906202116
4236953|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906210502
4238136|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906210547
4239172|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906210236
4240160|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906210329
4240345|fail|200906|dagolden@cpan.org (DAGOLDEN)|Bryar|3.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210342
4243789|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906211707
4244449|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906211910
4244731|pass|200906|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200906212009
4247092|pass|200906|cpan.dcollins.5100@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906211910
4247684|pass|200906|cpan.dcollins.5100rc1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906211925
4247753|pass|200906|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906211927
4248013|pass|200906|cpan.dcollins.5100@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906211934
4248084|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200906220033
4251240|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906221453
4251743|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906221446
4251848|pass|200906|bejuryu@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906221834
4251867|pass|200906|bejuryu@gmail.com|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906221835
4253035|pass|200906|martin.evans@easysoft.com|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906221800
4253639|pass|200906|cpan.dcollins.5100@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221356
4254403|pass|200906|cpan.dcollins.5100@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221502
4256563|pass|200906|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221508
4257060|pass|200906|cpan.dcollins.smoker3@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221400
4257241|pass|200906|trey+cpanplus@lopsa.org|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|9.6.0|200906220946
4257445|pass|200906|cpan.dcollins.smoker1@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221509
4257522|pass|200906|cpan.dcollins.smoker1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221523
4258090|pass|200906|cpan.dcollins.5100@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221508
4258510|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906221945
4258677|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230017
4259126|pass|200906|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200906230208
4259706|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230323
4259828|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230346
4260121|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230029
4260754|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906230909
4260840|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906230924
4261723|pass|200906|cpan.dcollins.smoker9@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221824
4262108|pass|200906|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221703
4262780|pass|200906|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221710
4262814|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221758
4262837|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221758
4263018|pass|200906|cpan.dcollins.smoker9@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221724
4263139|pass|200906|cpan.dcollins.smoker5@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221709
4263202|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221741
4263433|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221826
4263546|pass|200906|cpan.dcollins.smoker9@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221749
4264057|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230613
4264061|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230615
4264063|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230615
4264204|pass|200906|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221703
4264452|pass|200906|cpan.dcollins.smoker7@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221722
4264557|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230650
4264650|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221826
4264887|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230717
4264898|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230719
4264901|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230719
4265231|pass|200906|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221751
4265284|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230803
4266018|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230941
4266029|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230943
4266032|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230943
4266376|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906231033
4266560|pass|200906|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231042
4266635|pass|200906|cpan.dcollins.smoker7@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906231029
4266730|pass|200906|cpan.dcollins.5100rc1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231048
4267129|pass|200906|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231046
4267328|pass|200906|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231025
4267652|pass|200906|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231048
4268846|pass|200906|cpan.dcollins.589@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231401
4268907|pass|200906|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231357
4269764|fail|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231644
4270035|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906231732
4270206|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906231753
4270668|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231030
4270705|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231852
4270712|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231853
4270714|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231853
4271786|pass|200906|cpan.dcollins.smoker6@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231336
4271912|pass|200906|bingos@cpan.org|Data-Compare|1.2101|cygwin-thread-multi-64int|5.8.9|cygwin|1.5.25(0.15642)|200906240102
4272350|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906231053
4272389|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240030
4272401|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240031
4272402|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240031
4272938|pass|200906|cpan.dcollins.smoker5@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231400
4273258|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240123
4273274|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240123
4273278|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240123
4273573|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906240422
4273577|pass|200906|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906240225
4273942|pass|200906|cpan.dcollins.smoker2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240242
4274783|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240304
4274966|pass|200906|cpan.dcollins.589@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240308
4275950|pass|200906|cpan.dcollins.5100@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240334
4276002|pass|200906|cpan.dcollins.5100rc1@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240335
4276588|pass|200906|cpan.dcollins.smoker6@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240354
4276661|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.8.9|cygwin|1.5.25(0.15642)|200906240456
4276759|pass|200906|cpan.dcollins.smoker5@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240401
4277742|pass|200906|cpan.dcollins.smoker1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231053
4277792|pass|200906|cpan.dcollins.smoker5@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231358
4278381|pass|200906|martin.evans@easysoft.com|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906241058
4278487|pass|200906|martin.evans@easysoft.com|Class-DBI-ClassGenerator|1.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200906241121
4278731|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906241207
4278732|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906241207
4278977|pass|200906|chris@bingosnet.co.uk|Devel-CheckLib|0.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200906241237
4280366|pass|200906|cpan.dcollins.smoker6@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240818
4280769|pass|200906|cpan.dcollins.smoker7@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240828
4281761|pass|200906|cpan.dcollins.smoker6@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240837
4281791|pass|200906|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906240837
4282381|pass|200906|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906241349
4282396|pass|200906|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240906
4282398|pass|200906|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240907
4284099|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906241636
4285516|pass|200906|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906241652
4286189|pass|200906|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906250013
4286216|pass|200906|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906250019
4286319|pass|200906|doug@peaches.acomp.usf.edu|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.1|200906250040
4287492|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906250259
4287740|pass|200906|cpan.dcollins.smoker8@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250305
4288027|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906250311
4288058|pass|200906|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906250312
4289441|pass|200906|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906250343
4289835|pass|200906|cpan.dcollins.smoker7@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250352
4290999|pass|200906|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250016
4291126|pass|200906|cpan.dcollins.smoker9@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906250019
4291491|unknown|200906|cpan.dcollins.5100rc1@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250028
4293122|pass|200906|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250020
4296701|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906251355
4296795|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906251006
4296881|pass|200906|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906251018
4296912|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906251023
4297031|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906251036
4297041|pass|200906|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906251038
4297111|pass|200906|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906251053
4297443|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251104
4297772|pass|200906|cpan.dcollins.smoker4@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251111
4298474|pass|200906|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251109
4298592|pass|200906|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251129
4299025|pass|200906|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251140
4299120|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.7|darwin|8.11.0|200906251643
4299798|pass|200906|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251058
4301056|fail|200906|cpan.dcollins.smoker4@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251211
4301842|pass|200906|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251240
4302977|fail|200906|cpan.dcollins.smoker1@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251214
4303660|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.7|darwin|8.11.0|200906251928
4303725|pass|200906|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906251910
4305765|pass|200906|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251721
4305830|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251724
4306034|pass|200906|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251729
4306186|pass|200906|cpan.dcollins.smoker4@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251734
4306212|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251734
4306299|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906252136
4306305|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906252136
4306889|pass|200906|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251752
4306961|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251754
4307049|pass|200906|cpan.dcollins.smoker9@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251757
4308517|pass|200906|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260053
4308559|pass|200906|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260054
4308574|pass|200906|cpan.dcollins.smoker7@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260055
4308598|pass|200906|cpan.dcollins.smoker9@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260055
4308628|pass|200906|cpan.dcollins.smoker3@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260056
4308703|pass|200906|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260058
4308752|pass|200906|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260059
4308756|pass|200906|cpan.dcollins.smoker8@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260059
4308825|pass|200906|cpan.dcollins.smoker2@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260101
4309027|pass|200906|cpan.dcollins.5100rc1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260105
4309070|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260106
4309291|pass|200906|cpan.dcollins.smoker6@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260111
4309385|pass|200906|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260113
4309484|pass|200906|cpan.dcollins.5100@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260116
4309506|pass|200906|cpan.dcollins.5100rc1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260116
4309588|pass|200906|cpan.dcollins.smoker4@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260120
4309688|pass|200906|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260125
4309712|pass|200906|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260126
4310162|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906260355
4310902|pass|200906|justin.d.hunter@gmail.com|XML-Tiny|2.02|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906260329
4312103|pass|200906|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200906260858
4312187|pass|200906|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200906260858
4312414|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906260955
4312988|pass|200906|justin.d.hunter@gmail.com|DBIx-Class-SingletonRows|0.11|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906260244
4313102|pass|200906|martin.evans@easysoft.com|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.24-24-generic|200906261100
4313231|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200906261215
4317316|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262105
4317411|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262111
4317767|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906261938
4318103|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906262011
4318204|pass|200906|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200906262202
4318612|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|darwin-2level|5.8.8|darwin|8.11.0|200906262308
4318649|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|darwin-2level|5.8.8|darwin|8.11.0|200906262314
4318890|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262341
4318893|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262341
4320925|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906270531
4322043|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906270659
4323204|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906271321
4323337|pass|200906|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906271228
4323458|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906271305
4325233|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906271921
4325267|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|darwin-2level|5.10.0|darwin|8.11.0|200906271923
4325282|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906271924
4325329|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|darwin-2level|5.10.0|darwin|8.11.0|200906271927
4327445|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906272346
4327446|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906272347
4328369|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906271939
4328370|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906271939
4328919|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906280042
4328923|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906280043
4329773|pass|200906|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.6|i686-linux|5.10.0|linux|2.6.24-16-generic|200906280143
4329964|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906280159
4329967|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906280159
4331145|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906280529
4331311|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906280620
4331561|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200906280801
4333266|pass|200906|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906281024
4335328|pass|200906|cpan.dcollins.smoker9@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280837
4336541|pass|200906|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280901
4336660|pass|200906|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280851
4336958|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280909
4337848|pass|200906|cpan.dcollins.smoker2@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280911
4338126|pass|200906|cpan.dcollins.smoker5@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280913
4338141|pass|200906|cpan.dcollins.smoker9@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906280932
4339083|pass|200906|cpan.dcollins.5100@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280951
4339162|pass|200906|cpan.dcollins.5100rc1@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906280952
4340255|pass|200906|cpan.dcollins.smoker4@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906281002
4342508|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906281948
4342896|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906282027
4342971|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906281643
4342973|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906281643
4344688|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906281941
4344689|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906281941
4345375|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906290204
4345739|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290403
4346014|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290511
4346179|pass|200906|cpan.dcollins.smoker4@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906290320
4346423|pass|200906|cpan.dcollins.smoker3@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906290326
4346878|pass|200906|cpan.dcollins.smoker3@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906290334
4349521|pass|200906|andy.situ@verizon.net|CPAN-FindDependencies|2.32|i686-linux-multi-64int-ld|5.10.0|linux|2.6.22.1.emp6|200906281800
4349522|pass|200906|andy.situ@verizon.net|Data-Compare|1.2101|i686-linux-multi-64int-ld|5.10.0|linux|2.6.22.1.emp6|200906281759
4349525|pass|200906|andy.situ@verizon.net|Devel-CheckOS|1.61|i686-linux-multi-64int-ld|5.10.0|linux|2.6.22.1.emp6|200906281759
4349745|pass|200906|stro@rail.org.ua|Data-Compare|1.2101|i386-freebsd|5.8.9|freebsd|7.2-release|200906291011
4350411|pass|200906|stro@rail.org.ua|Devel-CheckOS|1.61|i386-freebsd|5.8.9|freebsd|7.2-release|200906291031
4352487|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906291430
4352831|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906291737
4353274|pass|200906|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906291243
4353903|pass|200906|cpan.dcollins.smoker4@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291325
4354360|pass|200906|cpan.dcollins.5100@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906291335
4354548|pass|200906|cpan.dcollins.smoker6@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906291340
4355022|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906291338
4357835|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291502
4358128|pass|200906|cpan.dcollins.5100@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906291510
4360983|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906300154
4362054|pass|200906|cpan.dcollins.smoker1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300101
4362292|pass|200906|cpan.dcollins.smoker2@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300105
4362961|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906300315
4363024|pass|200906|cpan.dcollins.5100rc1@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300117
4364456|pass|200906|cpan.dcollins.smoker6@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300141
4364718|pass|200906|cpan.dcollins.smoker6@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300145
4365178|pass|200906|cpan.dcollins.smoker6@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300152
4365433|unknown|200906|cpan.dcollins.smoker9@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300155
4365685|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300159
4365787|pass|200906|cpan.dcollins.5100@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300201
4365888|pass|200906|cpan.dcollins.smoker1@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300202
4366244|pass|200906|cpan.dcollins.smoker4@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300209
4366891|pass|200906|cpan.dcollins.smoker1@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300227
4367057|pass|200906|cpan.dcollins.smoker5@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300236
4367508|pass|200906|cpan.dcollins.589@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300257
4367793|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300316
4367830|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200906300319
4367833|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200906300319
4369373|pass|200906|autarch@urth.org|CPAN-FindDependencies|2.32|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906291109
4369545|pass|200906|autarch@urth.org|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906291109
4372180|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-11-generic|200906300902
4372181|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-11-generic|200906300902
4373312|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200906301509
4373520|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200906301546
4374719|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906302243
4376265|pass|200906|cpan.dcollins.5100rc1@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301835
4376353|unknown|200906|cpan.dcollins.589@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301837
4376962|pass|200906|cpan.dcollins.smoker4@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906301855
4377580|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200906301923
4377586|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200906301923
4378278|pass|200906|cpan.dcollins.smoker3@gmail.com|NestedMap|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301933
4378756|pass|200906|cpan.dcollins.589@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301941
4379397|pass|200906|cpan.dcollins.589@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301934
4379510|pass|200906|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906301950
4380054|pass|200906|cpan.dcollins.smoker8@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301958
4380734|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907010006
4381405|pass|200907|cpan.dcollins.5100rc1@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010018
4381480|pass|200907|cpan.dcollins.5100rc1@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010020
4381565|pass|200907|cpan.dcollins.smoker9@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010022
4381647|pass|200907|cpan.dcollins.smoker9@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907010025
4383139|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200907010213
4386726|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907011232
4388882|pass|200907|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010847
4389365|pass|200907|cpan.dcollins.smoker7@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010901
4389466|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907010904
4389471|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010904
4390559|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010946
4392370|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011104
4393000|pass|200907|cpan.dcollins.589@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011140
4393466|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907011756
4393696|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907011825
4396209|pass|200907|cpan.dcollins.smoker8@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011634
4396870|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907012307
4397365|pass|200907|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011731
4397629|pass|200907|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011743
4397871|pass|200907|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907011754
4398048|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907011801
4398109|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907020012
4401123|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907020500
4401703|pass|200907|cpan.dcollins.5100@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907020018
4402079|pass|200907|cpan.dcollins.smoker2@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907020027
4402563|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907020036
4402662|pass|200907|cpan.dcollins.smoker7@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907020037
4402806|unknown|200907|cpan.dcollins.smoker9@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907020040
4402923|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907020407
4403637|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907020442
4403753|pass|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020043
4404374|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907020958
4404515|pass|200907|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.6|darwin|8.11.0|200907020934
4404657|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.6|darwin|8.11.0|200907020957
4406914|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907021521
4409879|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021809
4410317|unknown|200907|cpan.dcollins.smoker8@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907021819
4410628|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021827
4410643|pass|200907|cpan.dcollins.smoker9@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907021828
4411768|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907021857
4411907|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021900
4412245|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021910
4412634|pass|200907|cpan.dcollins.5100@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907021920
4412744|pass|200907|cpan.dcollins.5100@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021922
4412843|pass|200907|cpan.dcollins.5100@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021925
4415915|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907030038
4415917|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907030038
4416234|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907030116
4416235|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907030116
4417709|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907030937
4417843|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907031004
4418646|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907031405
4418889|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907031508
4420028|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031242
4420069|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031243
4421365|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031320
4421418|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031322
4421628|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031327
4422176|pass|200907|cpan.dcollins.5100rc1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031339
4423312|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031403
4423782|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031412
4423788|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907031354
4424134|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907031419
4424754|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907031433
4425156|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031440
4425531|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031447
4425633|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031449
4428458|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907040217
4428667|fail|200907|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907040152
4429095|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907040338
4430488|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907040435
4431380|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907040916
4431488|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907040920
4432357|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907040935
4432507|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907040954
4432711|pass|200907|cpan.dcollins.5100@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041002
4433267|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041017
4433416|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041021
4433817|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041033
4434299|pass|200907|cpan.dcollins.smoker1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041044
4434377|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041046
4434431|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041047
4434822|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041057
4434830|pass|200907|cpan.dcollins.smoker8@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041057
4434913|pass|200907|cpan.dcollins.smoker1@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041100
4435053|pass|200907|cpan.dcollins.smoker6@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041105
4435178|pass|200907|cpan.dcollins.smoker6@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041108
4435781|pass|200907|cpan.dcollins.smoker9@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041120
4435915|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041122
4436030|pass|200907|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907041624
4436039|pass|200907|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907041624
4436679|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041135
4437524|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041137
4438203|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907041740
4438379|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907041822
4438574|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041408
4439125|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041535
4439128|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041536
4439130|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041536
4439187|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041545
4439750|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041609
4439907|pass|200907|cpan.dcollins.smoker5@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041612
4440590|pass|200907|cpan.dcollins.589@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041628
4440681|pass|200907|cpan.dcollins.smoker1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041631
4440764|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041632
4440938|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041635
4441532|pass|200907|cpan.dcollins.smoker9@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041645
4441593|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041647
4441686|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041648
4441764|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041650
4441769|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041650
4441773|pass|200907|cpan.dcollins.5100rc1@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041650
4441847|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041651
4442730|fail|200907|cpan.dcollins.smoker3@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041708
4443279|pass|200907|cpan.dcollins.smoker1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041717
4443318|fail|200907|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041701
4443350|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041719
4443644|unknown|200907|cpan.dcollins.smoker3@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041725
4443691|pass|200907|cpan.dcollins.smoker9@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041710
4443782|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041728
4443798|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041729
4443801|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041729
4443914|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041731
4444062|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041733
4444372|pass|200907|cpan.dcollins.smoker7@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041739
4444450|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041740
4445011|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041648
4445092|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041752
4445360|pass|200907|cpan.dcollins.smoker7@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041757
4445659|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041807
4445660|pass|200907|cpan.dcollins.smoker9@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041750
4446902|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050121
4447563|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050339
4447570|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050345
4447713|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907050513
4448386|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907050232
4448827|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050340
4448992|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907050419
4449242|pass|200907|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|i586-linux-thread-multi|5.8.8|linux|2.6.16|200907051047
4449314|pass|200907|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|i586-linux-thread-multi|5.8.8|linux|2.6.16|200907051101
4449491|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907051055
4449593|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907051123
4450367|pass|200907|cpan.dcollins.smoker6@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907050821
4450490|pass|200907|cpan.dcollins.smoker7@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907050823
4450795|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050829
4450797|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050829
4452009|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050849
4452134|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050851
4452166|pass|200907|cpan.dcollins.smoker4@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050851
4453169|fail|200907|cpan.dcollins.5100rc1@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050908
4453746|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050919
4453930|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050922
4455351|pass|200907|cpan.dcollins.smoker5@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050933
4455472|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050850
4455672|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050946
4455713|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050914
4456258|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051153
4456733|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051330
4457410|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051550
4457415|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051550
4457420|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051551
4457503|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051603
4457970|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051721
4458518|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907051827
4458753|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051905
4458758|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051905
4458760|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051905
4459093|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907060055
4459198|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060002
4459235|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060003
4459339|pass|200907|cpan.dcollins.smoker7@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060005
4460017|pass|200907|cpan.dcollins.smoker2@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060016
4460587|pass|200907|cpan.dcollins.5100@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060029
4461399|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060049
4461543|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060052
4461809|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060056
4461834|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060057
4462295|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060106
4462608|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060113
4462637|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060113
4463158|pass|200907|cpan.dcollins.smoker5@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907060122
4463291|pass|200907|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060125
4464302|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200907060515
4464346|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200907060547
4468253|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907060915
4468263|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907060915
4469069|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907061003
4469070|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907061003
4469126|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907061010
4469127|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907061010
4469467|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907061534
4469874|pass|200907|cpan.dcollins.smoker5@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061049
4469966|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061051
4470351|pass|200907|cpan.dcollins.smoker2@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061102
4470450|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907061604
4470476|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061106
4470995|pass|200907|cpan.dcollins.smoker8@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061117
4471341|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061125
4472031|pass|200907|martin.evans@easysoft.com|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200907061640
4472273|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061145
4472707|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061154
4473025|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061201
4473161|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061205
4473415|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061211
4473727|pass|200907|cpan.dcollins.smoker3@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061219
4473890|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061223
4474028|pass|200907|cpan.dcollins.smoker7@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061227
4474347|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061236
4474377|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061236
4474653|pass|200907|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907061744
4474656|pass|200907|cpan.dcollins.smoker4@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061236
4474702|pass|200907|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061243
4474876|pass|200907|cpan.dcollins.smoker2@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061248
4475142|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061255
4475685|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907061811
4475690|pass|200907|cpan.dcollins.smoker8@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061309
4475730|pass|200907|cpan.dcollins.5100@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061310
4476302|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061325
4477826|pass|200907|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200907062057
4477829|pass|200907|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200907062058
4478620|pass|200907|cpan.dcollins.smoker6@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061748
4480314|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061835
4480609|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061845
4480703|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061849
4480818|pass|200907|cpan.dcollins.smoker7@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061852
4480991|pass|200907|cpan.dcollins.smoker2@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061857
4481096|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907062358
4481331|pass|200907|cpan.dcollins.589@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061907
4483985|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907070132
4483987|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907070133
4484465|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907070209
4484469|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907070209
4484477|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907070210
4484480|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907070210
4487043|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907071123
4487631|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907071220
4488330|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907072218
4488334|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907072218
4488554|pass|200907|martin.evans@easysoft.com|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071340
4488987|pass|200907|martin.evans@easysoft.com|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071423
4489122|pass|200907|martin.evans@easysoft.com|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071446
4489123|pass|200907|martin.evans@easysoft.com|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071446
4490519|unknown|200907|cpan.dcollins.smoker9@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907071128
4490722|pass|200907|cpan.dcollins.589@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071134
4491338|pass|200907|cpan.dcollins.5100@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071153
4491648|pass|200907|ss5@renormalist.net|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.18-5-k7|200907071801
4491970|pass|200907|cpan.dcollins.smoker3@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071209
4492945|pass|200907|cpan.dcollins.smoker8@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071230
4493945|pass|200907|cpan.dcollins.5100@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071302
4494100|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071305
4494147|pass|200907|cpan.dcollins.smoker8@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071307
4494266|pass|200907|cpan.dcollins.smoker4@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071311
4494802|pass|200907|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907071923
4495987|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907080107
4498496|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907080446
4498497|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907080447
4499852|fail|200907|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907080724
4500395|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907080837
4501519|pass|200907|cpan.dcollins.smoker6@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081054
4502199|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907081109
4502950|pass|200907|cpan.dcollins.smoker6@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907081129
4503359|pass|200907|cpan.dcollins.5100@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907081140
4503611|unknown|200907|cpan.dcollins.smoker5@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907081148
4506273|pass|200907|cpan.dcollins.smoker4@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907081254
4506408|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081258
4506417|pass|200907|cpan.dcollins.smoker7@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081258
4507268|pass|200907|cpan.dcollins.smoker3@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081323
4507538|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081340
4508097|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081507
4508098|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081508
4508099|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081508
4508152|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081515
4508318|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907081523
4508840|pass|200907|cpan.dcollins.smoker4@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081538
4509182|pass|200907|cpan.dcollins.smoker6@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081547
4509326|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081556
4509599|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081645
4509603|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081645
4509604|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081645
4509824|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081715
4510040|pass|200907|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907082302
4510454|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081940
4511108|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907090141
4511135|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907090146
4512323|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907090210
4514270|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.5|200907091245
4514274|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.5|200907091246
4514313|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200907091210
4514318|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200907091211
4516516|pass|200907|cpan.dcollins.smoker2@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907090859
4516862|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907092310
4516898|pass|200907|cpan.dcollins.smoker2@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907090910
4517749|pass|200907|cpan.dcollins.5100rc1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907090932
4518220|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907090943
4522360|pass|200907|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091738
4522363|pass|200907|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091739
4522945|pass|200907|andy@hexten.net|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091837
4523041|pass|200907|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091837
4523690|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907100437
4524114|pass|200907|cpan@tenzobox.net ("Axel Bourgeois")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907091837
4525669|pass|200907|stro@cpan.org|File-Overwrite|1.1|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907100211
4525801|pass|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907091913
4526017|pass|200907|cpan.dcollins.589@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907091918
4526603|pass|200907|stro@cpan.org|Palm-Treo680MessagesDB|1.01|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907100229
4527882|pass|200907|cpan.dcollins.589@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907091957
4528213|pass|200907|cpan.dcollins.5100@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907100003
4528724|pass|200907|cpan.dcollins.589@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907100013
4529945|pass|200907|cpan.dcollins.smoker7@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907100034
4530269|pass|200907|cpan.dcollins.smoker3@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907100040
4531091|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907100131
4531093|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907100131
4531593|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907100232
4533438|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.5|200907100801
4535117|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907100556
4535957|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907100714
4537957|pass|200907|cpan.dcollins.5100@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101013
4537994|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101014
4538036|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101014
4538061|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101015
4538757|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101030
4539556|pass|200907|cpan.dcollins.smoker3@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907101051
4539748|pass|200907|stro@cpan.org|DBIx-Class-SingletonRows|0.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907101756
4539762|pass|200907|stro@cpan.org|DBIx-Class-SingletonRows|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907101756
4540515|pass|200907|cpan.dcollins.smoker7@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907101114
4541436|fail|200907|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101149
4541484|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101154
4542079|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101302
4542215|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101330
4542218|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101330
4542219|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101330
4543358|pass|200907|bingos@cpan.org|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907101931
4543386|pass|200907|cpan.dcollins.589@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101430
4543404|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101431
4543480|pass|200907|bingos@cpan.org|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907101934
4543559|pass|200907|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907101936
4545181|fail|200907|bingos@cpan.org|Bryar|3.1|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907102222
4545258|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101735
4545423|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101810
4545446|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101816
4545854|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101943
4545855|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101943
4545857|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101944
4545902|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101955
4546098|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110113
4546170|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907110133
4546199|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907110142
4546359|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110219
4546363|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110219
4546364|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110219
4546583|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110258
4547578|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907110029
4547708|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907110033
4548527|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110055
4549069|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907110104
4549215|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907110107
4549236|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110055
4550044|pass|200907|cpan.dcollins.5100@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907110123
4550155|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907110126
4550566|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907110135
4550796|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110141
4551657|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907110206
4551871|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907110213
4552169|fail|200907|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111633
4552329|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110334
4552622|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907110440
4553175|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200907111006
4553390|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111953
4553648|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110618
4553695|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110626
4555617|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907111212
4557310|pass|200907|andy.situ@verizon.net|Data-Compare|1.2101|i686-linux-multi-64int|5.10.0|linux|2.6.24-24-generic|200907111450
4557311|pass|200907|andy.situ@verizon.net|Devel-CheckOS|1.61|i686-linux-multi-64int|5.10.0|linux|2.6.24-24-generic|200907111450
4557312|pass|200907|andy.situ@verizon.net|CPAN-FindDependencies|2.32|i686-linux-multi-64int|5.10.0|linux|2.6.24-24-generic|200907111452
4559554|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907111941
4559559|fail|200907|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907111941
4559561|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907111941
4560221|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907120121
4562425|fail|200907|cpan.dcollins.5100@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120050
4562775|fail|200907|cpan.dcollins.5100@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120101
4562847|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120103
4563421|fail|200907|cpan.dcollins.smoker5@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907120119
4563690|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120127
4564518|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200907120300
4564797|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907120313
4564920|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907120526
4566493|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907120730
4568057|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130511
4568961|pass|200907|rlane10@wi.rr.com|Devel-CheckOS|1.61|darwin-2level-ld|5.10.0|darwin|8.11.0|200907121520
4568963|fail|200907|rlane10@wi.rr.com|CPAN-FindDependencies|2.32|darwin-2level-ld|5.10.0|darwin|8.11.0|200907121540
4568986|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907121749
4569163|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907121820
4569206|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907121825
4569213|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907121826
4569459|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130909
4569466|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130911
4569469|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130911
4569580|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130931
4569849|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907130011
4569865|fail|200907|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131013
4569996|pass|200907|bob@randomness.org.uk ("bob walker")|Data-Compare|1.2101|i86pc-solaris|5.10.0|solaris|2.10|200907130136
4569997|pass|200907|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.61|i86pc-solaris|5.10.0|solaris|2.10|200907130136
4570245|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907130243
4570369|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130142
4570520|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130147
4570630|pass|200907|cpan.dcollins.smoker9@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907130151
4570637|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130151
4570858|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131158
4570999|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130203
4571219|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130210
4571562|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130222
4571742|pass|200907|cpan.dcollins.smoker1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130228
4572029|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130239
4572034|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130240
4572248|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130246
4572422|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130249
4573064|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130315
4573207|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130321
4573393|pass|200907|cpan@greerga.m-l.org ("George Greer")|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130329
4573407|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130330
4573561|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130341
4573697|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130351
4573726|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131353
4573800|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131400
4573805|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131401
4573806|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131401
4574125|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907130055
4574285|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Transactional|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130132
4574405|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131604
4574480|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130218
4574481|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130219
4576087|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907130623
4577180|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-16-generic|200907130750
4577632|pass|200907|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200907130827
4579815|pass|200907|cpan@greerga.m-l.org ("George Greer")|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131057
4581695|pass|200907|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131334
4582258|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200907131908
4582771|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131451
4582800|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131452
4582802|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131452
4582863|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Transactional|1.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131456
4583851|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131601
4583857|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131601
4583981|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131612
4584863|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200907132227
4585974|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907131849
4586880|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131912
4587509|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907131930
4592037|unknown|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140049
4592306|unknown|200907|cpan.dcollins.smoker9@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140054
4592512|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140058
4592516|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140058
4593018|unknown|200907|cpan.dcollins.smoker2@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140108
4594236|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907140214
4594643|unknown|200907|cpan.dcollins.5100rc1@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140224
4594872|unknown|200907|cpan.dcollins.smoker5@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140228
4594982|pass|200907|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140232
4596367|pass|200907|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140016
4597698|unknown|200907|cpan.dcollins.smoker5@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140102
4598012|unknown|200907|cpan.dcollins.smoker1@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140115
4598708|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140134
4601456|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907140949
4602561|pass|200907|rlane10@wi.rr.com|XML-Tiny|2.02|darwin-2level-ld|5.10.0|darwin|8.11.0|200907131744
4602940|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907141207
4604012|pass|200907|rlane10@wi.rr.com|Data-Compare|1.2101|darwin-2level-ld|5.10.0|darwin|8.11.0|200907140017
4604872|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907141101
4607004|unknown|200907|cpan.dcollins.smoker5@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141440
4607329|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141447
4607619|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150455
4607683|unknown|200907|cpan.dcollins.smoker1@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141456
4607720|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141457
4608133|pass|200907|cpan.dcollins.smoker3@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907141508
4608570|fail|200907|cpan.dcollins.smoker2@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141521
4609794|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907141613
4609870|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141618
4609992|unknown|200907|cpan.dcollins.smoker8@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141626
4610487|unknown|200907|cpan.dcollins.5100rc1@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141651
4610683|pass|200907|cpan.dcollins.smoker7@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141704
4613112|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.10.0|solaris|2.10|200907150041
4613819|pass|200907|cpan.dcollins.5100@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150123
4614138|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150129
4614220|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150130
4614373|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150135
4614428|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.10.0|solaris|2.10|200907150229
4614510|unknown|200907|cpan.dcollins.smoker5@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150139
4614822|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150147
4615657|pass|200907|cpan.dcollins.smoker8@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150203
4615833|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907151208
4616803|pass|200907|cpan.dcollins.5100@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907150231
4616912|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150234
4617048|pass|200907|cpan.dcollins.smoker2@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907150237
4617508|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150252
4617761|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907150301
4617769|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150301
4618251|unknown|200907|cpan.dcollins.smoker8@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150320
4618423|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907150327
4618835|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907150014
4619260|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907150624
4619512|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907151559
4619590|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907150211
4621302|pass|200907|rlane10@wi.rr.com|CPAN-FindDependencies|2.32|darwin-2level-ld|5.10.0|darwin|8.11.0|200907150419
4621671|pass|200907|rlane10@wi.rr.com|Tie-STDOUT|1.0401|darwin-2level-ld|5.10.0|darwin|8.11.0|200907150313
4624249|pass|200907|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907151055
4624872|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.10.0|solaris|2.10|200907151641
4625368|pass|200907|cpan.dcollins.smoker8@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151203
4625837|pass|200907|cpan.dcollins.5100@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151218
4625969|fail|200907|cpan.dcollins.smoker9@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151223
4627715|fail|200907|cpan.dcollins.5100@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151317
4628368|unknown|200907|cpan.dcollins.5100rc1@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151335
4628526|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151339
4628665|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907151342
4628688|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151343
4628794|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907151346
4628889|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151348
4629707|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151407
4630823|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907151434
4630984|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151438
4631460|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151449
4632093|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151505
4633617|pass|200907|jeff@zeroclue.com|Data-Compare|1.2101|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907151433
4634323|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200907160049
4634327|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200907160049
4634331|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200907160050
4634337|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200907160050
4634415|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200907160049
4634416|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200907160049
4634419|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200907160049
4634422|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200907160049
4634425|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200907160049
4634429|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200907160049
4634824|pass|200907|d@0x64.nl|XML-Tiny|2.02|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.18-xen-3.1-1-amd64|200907160148
4634841|pass|200907|bob@randomness.org.uk ("bob walker")|XML-Tiny|2.02|i86pc-solaris|5.10.0|solaris|2.10|200907160049
4634842|pass|200907|bob@randomness.org.uk ("bob walker")|XML-Tiny-DOM|1.1|i86pc-solaris|5.10.0|solaris|2.10|200907160049
4635870|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160216
4636206|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160224
4636248|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160225
4636328|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160227
4636370|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160229
4636463|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160230
4636486|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160231
4636491|pass|200907|cpan.dcollins.smoker9@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160231
4636498|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160231
4636504|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160232
4636816|pass|200907|cpan.dcollins.smoker7@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160239
4636978|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160243
4637219|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160248
4637232|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160248
4637370|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160252
4637559|unknown|200907|cpan.dcollins.smoker6@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160256
4638074|pass|200907|cpan.dcollins.5100@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160309
4638138|unknown|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160311
4638165|pass|200907|cpan.dcollins.smoker5@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907160311
4638490|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160319
4638511|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160319
4638893|pass|200907|cpan.dcollins.5100@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907160326
4638928|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907160327
4639286|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160334
4639697|pass|200907|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907160341
4639780|unknown|200907|cpan.dcollins.smoker9@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160343
4639837|pass|200907|cpan.dcollins.smoker3@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160344
4640761|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160001
4641105|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160007
4641254|unknown|200907|cpan.dcollins.589@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160011
4641365|pass|200907|cpan.dcollins.smoker5@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160013
4641432|unknown|200907|cpan.dcollins.5100rc1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160415
4641695|pass|200907|cpan.dcollins.smoker9@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160020
4641896|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160024
4641964|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907161432
4642113|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Class-CanBeA|1.2|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200907160701
4642584|pass|200907|srezic@cpan.org|XML-Tiny-DOM|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200907160819
4642769|pass|200907|cpan@greerga.m-l.org ("George Greer")|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907160244
4642889|pass|200907|srezic@cpan.org|XML-Tiny-DOM|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200907160819
4643151|pass|200907|rbo@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.10.0|solaris|2.11|200907160938
4643156|pass|200907|rbo@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.10.0|solaris|2.11|200907160938
4643181|pass|200907|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200907160940
4643740|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907160437
4643788|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907161842
4644442|pass|200907|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200907161148
4644963|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sub-WrapPackages|1.2|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907160651
4645303|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907162128
4645305|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907162128
4645687|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161314
4645977|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.4|solaris|2.10|200907161337
4646029|pass|200907|bingos@cpan.org|XML-Tiny|2.02|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200907161354
4646032|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200907161354
4647482|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161648
4647484|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161648
4648067|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.4|solaris|2.10|200907161740
4648068|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.4|solaris|2.10|200907161740
4648200|pass|200907|martin.evans@easysoft.com|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200907161803
4648524|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170335
4648541|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170337
4648543|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170337
4648712|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170406
4648774|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170414
4648795|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170416
4650105|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170713
4651682|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907171043
4651954|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907170132
4652268|pass|200907|cpan.dcollins.smoker5@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170140
4652873|pass|200907|cpan.dcollins.smoker5@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170151
4653083|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-CanBeA|1.2|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907170154
4654658|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170221
4654844|pass|200907|cpan.dcollins.5100@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170224
4655268|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170231
4655618|unknown|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170237
4655837|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170241
4655918|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170242
4656529|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170253
4656980|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170300
4657149|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170303
4657261|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170305
4657302|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170306
4657775|unknown|200907|cpan.dcollins.smoker3@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170314
4658482|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907170719
4660328|pass|200907|mw487.yahoo.com@gmail.com|XML-Tiny|2.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200907170430
4660329|pass|200907|mw487.yahoo.com@gmail.com|XML-Tiny-DOM|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200907170430
4661398|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200907171253
4661401|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200907171253
4661415|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200907171255
4661431|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200907171257
4661464|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200907171300
4661533|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|IP35-irix-64int|5.8.8|irix|6.5|200907171407
4661564|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170808
4661958|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170814
4662192|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200907170718
4662804|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200907171229
4663313|pass|200907|cpan.dcollins.5100@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170837
4663621|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170843
4663720|pass|200907|cpan.dcollins.smoker9@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170844
4664180|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170853
4664278|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171454
4664802|unknown|200907|cpan.dcollins.smoker4@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170904
4665344|pass|200907|cpan.dcollins.smoker9@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170917
4665388|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171517
4665754|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170926
4665870|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170929
4666228|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170938
4666307|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170939
4666852|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170952
4667124|pass|200907|martin.evans@easysoft.com|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200907171458
4667249|pass|200907|cpan.dcollins.5100@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907171001
4667384|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170958
4667385|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907171005
4667875|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907171011
4668443|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907171645
4668869|pass|200907|martin.evans@easysoft.com|XML-Tiny-DOM|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200907171632
4669009|pass|200907|mw487.yahoo.com@gmail.com|XML-Tiny-DOM|1.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200907171046
4669047|pass|200907|imacat@mail.imacat.idv.tw|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200907172349
4669741|pass|200907|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907171303
4670334|pass|200907|jeff@zeroclue.com|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|9.2.0|200907171125
4671283|pass|200907|cpan@greerga.m-l.org ("George Greer")|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907171633
4671648|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907171716
4671927|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907172350
4671999|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.4|solaris|2.10|200907172251
4672619|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907180031
4674327|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180349
4674411|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180350
4674434|pass|200907|cpan.dcollins.smoker7@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180351
4674539|pass|200907|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180353
4674767|pass|200907|cpan.dcollins.smoker7@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180357
4675124|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180003
4675431|pass|200907|cpan.dcollins.smoker3@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180008
4675636|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180011
4675805|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180014
4676270|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180022
4676337|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180023
4676432|pass|200907|cpan.dcollins.smoker4@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180025
4676443|pass|200907|cpan.dcollins.smoker6@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180025
4676767|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180031
4677024|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180035
4677109|fail|200907|cpan.dcollins.smoker7@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180036
4677491|pass|200907|cpan.dcollins.smoker7@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907180043
4677604|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180045
4677657|pass|200907|cpan.dcollins.5100@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180046
4677709|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180047
4677826|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180049
4677839|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180049
4678039|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180052
4678294|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180057
4678300|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180057
4678463|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907180100
4679104|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180111
4679221|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180112
4679505|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180117
4679661|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907180114
4680003|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180126
4680011|pass|200907|cpan.dcollins.smoker5@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180126
4680012|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907180126
4680459|pass|200907|cpan@greerga.m-l.org ("George Greer")|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907180202
4681097|pass|200907|jeff@zeroclue.com|Devel-CheckLib|0.6|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907180052
4683638|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.5|solaris|2.10|200907181645
4683794|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181617
4684198|pass|200907|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200907181909
4684801|pass|200907|cpan@greerga.m-l.org ("George Greer")|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907181501
4684816|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181904
4684817|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181904
4685287|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.5|solaris|2.10|200907182056
4685289|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.5|solaris|2.10|200907182056
4686216|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907182221
4687806|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190148
4688258|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190202
4689003|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sub-WrapPackages|1.2|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907190222
4689093|fail|200907|cpan.dcollins.smoker4@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190225
4689354|pass|200907|cpan.dcollins.smoker2@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190232
4689539|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200907190437
4690135|pass|200907|cpan.dcollins.5100rc1@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190254
4690209|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190256
4690327|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190259
4690343|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190300
4691116|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190322
4691463|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190332
4691475|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190333
4691591|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907190536
4691880|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907190544
4692559|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190004
4692617|pass|200907|cpan.dcollins.589@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190006
4692751|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190010
4692801|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200907190611
4693163|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200907190622
4693332|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190026
4693368|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190027
4693385|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190027
4693973|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190040
4694031|pass|200907|cpan.dcollins.589@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190041
4694233|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907190650
4694248|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200907190653
4694346|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200907190714
4694428|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907190726
4694572|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200907190755
4696598|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907190729
4696871|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907192209
4697025|pass|200907|jeff@zeroclue.com|Number-Phone|1.7002|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907190531
4697271|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190852
4697442|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190855
4697558|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190857
4697654|pass|200907|cpan.dcollins.smoker5@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190859
4698043|pass|200907|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190906
4698512|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190913
4698533|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200907191513
4698863|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190918
4699137|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190922
4699232|pass|200907|cpan.dcollins.smoker3@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190924
4699628|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190923
4699810|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190932
4699875|pass|200907|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190933
4699879|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190933
4700004|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200907191535
4700076|pass|200907|cpan.dcollins.smoker4@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190936
4700385|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190940
4700454|pass|200907|cpan.dcollins.589@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190941
4700870|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190948
4701167|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907190952
4701203|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190953
4701471|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200907191557
4701504|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190958
4701657|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191000
4701675|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907191000
4701711|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191001
4702499|fail|200907|cpan.dcollins.smoker4@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191012
4702819|pass|200907|cpan.dcollins.smoker6@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907191018
4702871|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907191015
4703708|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907191837
4703769|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200249
4704419|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907192050
4705001|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907191638
4705002|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907191638
4705243|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200704
4705297|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200716
4705526|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.5|solaris|2.10|200907192228
4705550|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907191750
4705553|pass|200907|cpan@greerga.m-l.org ("George Greer")|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907191751
4706314|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200907200156
4706513|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200907200225
4707166|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200907200404
4707303|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907200223
4707357|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200907200430
4707437|pass|200907|jeff@zeroclue.com|File-Overwrite|1.1|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200243
4707453|pass|200907|jeff@zeroclue.com|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200247
4707625|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907200308
4708033|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200315
4708183|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200317
4708476|pass|200907|cpan.dcollins.smoker4@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200322
4708494|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907200322
4708730|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200326
4708755|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200327
4708867|pass|200907|cpan.dcollins.smoker5@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907200328
4708923|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200329
4709124|pass|200907|cpan.dcollins.589@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200333
4709294|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200336
4709804|pass|200907|jeff@zeroclue.com|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200352
4709942|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200907200614
4710017|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200907200624
4710203|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200907200652
4710308|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200907200710
4710422|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Class-CanBeA|1.2|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200907200732
4710706|pass|200907|cpan@greerga.m-l.org ("George Greer")|NestedMap|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907200221
4710934|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200907200853
4711638|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200907201049
4711887|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200907201118
4712297|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200907201213
4713036|pass|200907|jeff@zeroclue.com|Palm-ProjectGutenberg|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200517
4713051|pass|200907|jeff@zeroclue.com|XML-Tiny|2.02|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200519
4713053|pass|200907|jeff@zeroclue.com|XML-Tiny-DOM|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200519
4713510|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907201528
4714122|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201409
4714157|pass|200907|smoretti@unil.ch|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.8|linux|2.6.18|200907201503
4714326|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907201106
4714607|unknown|200907|cpan@greerga.m-l.org ("George Greer")|Acme-Licence|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907201132
4714625|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907201734
4714723|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907201744
4714785|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.6|solaris|2.10|200907201628
4714791|pass|200907|smoretti@unil.ch|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.8|linux|2.6.22|200907201511
4715034|pass|200907|smoretti@unil.ch|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.8|linux|2.6.22|200907201456
4715230|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201614
4715231|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201614
4715601|pass|200907|smoretti@unil.ch|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.8|linux|2.6.18|200907201502
4715947|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.6|solaris|2.10|200907201914
4715948|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.6|solaris|2.10|200907201914
4716136|pass|200907|justin.d.hunter@gmail.com|XML-Tiny-DOM|1.1|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200907201206
4716432|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201527
4716993|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201540
4717571|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201556
4717610|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201558
4718756|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201629
4718957|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201634
4719752|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201653
4720131|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201703
4721277|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201731
4721837|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201744
4722317|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907210005
4722318|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907210005
4722383|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200907210015
4722586|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907202212
4722831|fail|200907|cpan@greerga.m-l.org ("George Greer")|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907201938
4723007|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.6|solaris|2.10|200907210047
4723011|pass|200907|jeff@zeroclue.com|Devel-CheckOS|1.61|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907210018
4723047|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.6|solaris|2.10|200907210047
4724039|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907210542
4724306|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907210041
4724307|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907210041
4724353|unknown|200907|cpan@greerga.m-l.org ("George Greer")|Acme-Pony|1.1.2|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907210058
4724408|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907210106
4724466|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907210115
4726820|pass|200907|martin.evans@easysoft.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211436
4727205|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907211641
4727777|pass|200907|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907211740
4728842|pass|200907|cpan.dcollins.smoker8@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211652
4728996|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211656
4729264|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211703
4729664|pass|200907|cpan.dcollins.589@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211713
4729798|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211717
4729813|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211711
4729857|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211719
4729942|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211721
4730085|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211726
4730251|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211730
4730584|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907212339
4730799|pass|200907|cpan.dcollins.5100rc1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211745
4730847|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211746
4731080|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211752
4731095|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211753
4731335|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907220001
4731476|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211805
4731484|pass|200907|cpan.dcollins.589@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211805
4731603|fail|200907|cpan.dcollins.smoker9@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211809
4731685|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211812
4732050|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211826
4732155|pass|200907|cpan.dcollins.smoker5@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211832
4732316|pass|200907|cpan.dcollins.smoker9@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211837
4732353|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211838
4732472|pass|200907|cpan.dcollins.smoker5@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211844
4732595|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211848
4733281|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211904
4733717|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907211915
4733721|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907211915
4733867|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211917
4734326|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211926
4735046|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907220258
4735049|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907220259
4736094|pass|200907|cpan.dcollins.smoker6@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220341
4736223|pass|200907|cpan.dcollins.smoker3@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220343
4736259|pass|200907|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220344
4736492|pass|200907|cpan.dcollins.smoker6@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220348
4736767|pass|200907|cpan.dcollins.smoker6@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220353
4737561|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220007
4737751|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907220637
4738756|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907221021
4738758|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907221022
4739306|pass|200907|lists.perl.cpan-testers@csjewell.fastmail.us ("Curtis Jewell")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200907211532
4740469|pass|200907|cpan.dcollins.smoker8@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220831
4740653|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220840
4740953|pass|200907|lists.perl.cpan-testers@csjewell.fastmail.us ("Curtis Jewell")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.1|200907211527
4740997|pass|200907|cpan.dcollins.5100rc1@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220854
4741094|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220858
4741246|pass|200907|cpan.dcollins.smoker3@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220905
4741469|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220915
4741479|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220915
4741830|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221429
4741849|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.7|solaris|2.10|200907221406
4742430|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221553
4742432|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221553
4742565|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221611
4743085|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.7|solaris|2.10|200907221650
4743087|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.7|solaris|2.10|200907221650
4744386|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.7|solaris|2.10|200907222028
4746636|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907230241
4747402|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907230255
4747480|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907230257
4749275|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Class-CanBeA|1.2|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200907231117
4749357|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907231137
4749367|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907231139
4750418|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200907231350
4750433|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200907231350
4751010|pass|200907|bingos@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231449
4752187|pass|200907|martin.evans@easysoft.com|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200907231741
4753484|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907232226
4753687|pass|200907|bingos@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232225
4757596|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907240637
4758816|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907241207
4759796|pass|200907|martin.evans@easysoft.com|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24-24-generic|200907241418
4761089|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907241927
4761641|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241553
4761907|pass|200907|cpan.dcollins.smoker4@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241558
4761962|pass|200907|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242057
4762027|pass|200907|bingos@cpan.org|Acme-Pony|1.1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242058
4762057|pass|200907|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242059
4762699|pass|200907|cpan.dcollins.smoker1@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241611
4763409|pass|200907|cpan.dcollins.589@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241630
4763679|pass|200907|cpan.dcollins.smoker9@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241638
4764204|pass|200907|cpan.dcollins.smoker9@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241653
4764207|pass|200907|cpan.dcollins.smoker9@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241653
4764410|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241657
4764563|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907242300
4764585|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907242301
4765186|pass|200907|cpan.dcollins.smoker8@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241718
4765197|pass|200907|cpan.dcollins.smoker8@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241719
4765368|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200907242323
4765508|pass|200907|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241727
4766048|fail|200907|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242241
4766195|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241747
4766906|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241806
4766918|pass|200907|cpan.dcollins.5100rc1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241806
4767080|pass|200907|bingos@cpan.org|Class-CanBeA|1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242340
4767090|pass|200907|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242342
4767216|pass|200907|bingos@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250006
4767222|pass|200907|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250007
4767242|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.8|solaris|2.10|200907250014
4767247|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.8|solaris|2.10|200907250015
4767253|pass|200907|bingos@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250014
4767259|pass|200907|bingos@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250016
4767284|pass|200907|bingos@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250020
4767308|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907250127
4767321|pass|200907|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250033
4767455|pass|200907|bingos@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250110
4767658|pass|200907|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250150
4767670|pass|200907|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250152
4767716|pass|200907|bingos@cpan.org|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250158
4768209|pass|200907|bingos@cpan.org|NestedMap|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250354
4768326|pass|200907|bingos@cpan.org|Net-Random|2.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250423
4768447|pass|200907|bingos@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250450
4768469|pass|200907|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250452
4768471|pass|200907|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250452
4768477|pass|200907|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250453
4768479|pass|200907|bingos@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250453
4768725|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200907250641
4768945|pass|200907|bingos@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250620
4768953|pass|200907|bingos@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250621
4768963|pass|200907|bingos@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250622
4768975|pass|200907|bingos@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250624
4769229|pass|200907|bingos@cpan.org|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250742
4769230|pass|200907|bingos@cpan.org|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250743
4769240|pass|200907|bingos@cpan.org|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250744
4769245|pass|200907|bingos@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250745
4769310|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907250304
4769374|pass|200907|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250813
4769404|pass|200907|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250820
4772144|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.8|solaris|2.10|200907251628
4773792|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907251904
4775104|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907260149
4775553|pass|200907|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907260419
4776129|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907260636
4776271|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907260710
4777981|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261352
4777992|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261353
4777994|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261354
4778184|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261507
4778222|pass|200907|cpan@greerga.m-l.org ("George Greer")|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907261530
4779160|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sub-WrapPackages|1.2|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907270040
4779458|pass|200907|cpan.dcollins.smoker5@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270135
4780487|pass|200907|cpan.dcollins.5100rc1@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907270154
4780790|pass|200907|cpan.dcollins.smoker9@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270201
4781139|pass|200907|cpan.dcollins.589@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907270207
4781555|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907270214
4782041|pass|200907|cpan.dcollins.smoker6@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270221
4782527|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270230
4782702|pass|200907|cpan.dcollins.smoker8@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270235
4784721|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907270007
4785258|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907270329
4785363|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.9|solaris|2.10|200907270827
4785631|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907270504
4787287|fail|200907|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200907271524
4787828|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907271030
4787829|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907271031
4788787|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907271228
4789010|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271234
4789800|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271256
4789891|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907271258
4790105|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271302
4790747|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907271317
4790947|unknown|200907|cpan.dcollins.smoker4@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271323
4792200|pass|200907|cpan.dcollins.smoker1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907271353
4792737|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907271403
4793286|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907271415
4793847|pass|200907|cpan.dcollins.589@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907271428
4795317|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.9|solaris|2.10|200907272153
4795937|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907271919
4796030|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907271934
4796876|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.9|solaris|2.10|200907280301
4797142|pass|200907|cpan.dcollins.smoker3@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280347
4797551|fail|200907|cpan.dcollins.smoker6@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907280001
4797652|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280004
4798180|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907280023
4798837|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280044
4798876|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280045
4799411|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280102
4801043|pass|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907280149
4801469|pass|200907|cpan.dcollins.589@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907280202
4805809|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907280904
4805810|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907280904
4807753|fail|200907|cpan.dcollins.5100rc1@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281324
4807821|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281326
4808122|pass|200907|cpan.dcollins.smoker8@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281340
4808250|pass|200907|cpan.dcollins.589@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281346
4808263|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281347
4808312|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281349
4808489|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281357
4808561|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281400
4808910|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281412
4809032|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281417
4809484|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281437
4809580|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281442
4809616|pass|200907|cpan.dcollins.5100rc1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281444
4809766|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281450
4809815|pass|200907|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.2101|i386-netbsd|5.10.0|netbsd|netbsd|200907282118
4809923|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281456
4810049|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281502
4810368|pass|200907|cpan.dcollins.smoker4@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907281517
4810746|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907281534
4810888|pass|200907|vpit@cpan.org|Data-Compare|1.2101|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200907282141
4810893|pass|200907|vpit@cpan.org|Devel-CheckOS|1.61|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200907282142
4810899|pass|200907|vpit@cpan.org|Devel-CheckLib|0.6|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200907282142
4810946|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281544
4811574|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907281615
4811774|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281625
4814578|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|solaris|2.10|200907290313
4819098|pass|200907|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.61|i386-netbsd|5.10.0|netbsd|netbsd|200907291456
4820061|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907290956
4820448|pass|200907|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.02|i386-netbsd|5.10.0|netbsd|netbsd|200907291654
4820449|pass|200907|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny-DOM|1.1|i386-netbsd|5.10.0|netbsd|netbsd|200907291655
4823714|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|solaris|2.10|200907292003
4825395|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907291932
4826793|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300348
4826798|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300349
4826874|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300009
4827916|pass|200907|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907300858
4828085|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300439
4828773|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300553
4828809|pass|200907|bingos@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200907301101
4830093|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907301022
4830604|pass|200907|martin.evans@easysoft.com|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24-24-generic|200907301722
4831139|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907301444
4831877|pass|200907|cpan.dcollins.589@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301639
4832526|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907301658
4832602|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301700
4832848|pass|200907|cpan.dcollins.smoker3@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301702
4832941|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301712
4834489|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301755
4834573|pass|200907|cpan.dcollins.589@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301758
4834631|pass|200907|cpan.dcollins.589@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301800
4835010|pass|200907|cpan.dcollins.smoker8@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301811
4835244|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301818
4835519|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301827
4835549|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301828
4836427|pass|200907|cpan.dcollins.smoker2@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301903
4838604|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907310034
4839855|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Transactional|1.02|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907310542
4840095|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907310646
4840097|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907310646
4840531|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200907311328
4842519|fail|200907|cpan.dcollins.smoker2@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907311410
4844313|pass|200907|cpan.dcollins.smoker3@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907311536
4845009|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907311607
4845743|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907311646
4846078|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907311659
4847414|pass|200907|cpan.dcollins.5100rc1@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907311757
4851358|pass|200908|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200908011250
4851715|pass|200908|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908011425
4852452|pass|200908|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908011244
4853386|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.699_001|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200908020009
4853535|pass|200908|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200908012354
4854502|pass|200908|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020311
4854613|fail|200908|cpan.dcollins.smoker9@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020315
4854637|pass|200908|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020316
4854663|pass|200908|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908020317
4854672|pass|200908|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908020317
4854788|pass|200908|cpan.dcollins.smoker6@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020322
4854794|pass|200908|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020322
4855483|pass|200908|cpan.dcollins.smoker5@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020349
4855884|pass|200908|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020011
4856011|pass|200908|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020017
4856136|pass|200908|cpan.dcollins.smoker3@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020024
4856821|pass|200908|cpan.dcollins.smoker2@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020047
4857016|pass|200908|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020054
4857045|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200908020656
4857064|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200908020657
4857190|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200908020703
4857211|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200908020703
4857222|pass|200908|cpan.dcollins.smoker5@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020104
4857286|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200908020706
4857325|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200908020707
4857353|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200908020708
4858185|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200908020741
4858329|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200908020746
4858505|pass|200908|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020152
4858543|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200908020753
4858638|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200908020756
4858662|pass|200908|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020157
4858721|pass|200908|cpan.dcollins.smoker9@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020159
4858855|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200908020803
4858882|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200908020803
4859017|pass|200908|cpan.dcollins.smoker5@gmail.com|Devel-CheckLib|0.699_001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908020208
4859047|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200908020808
4859059|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200908020809
4859061|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200908020809
4859078|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200908020809
4859113|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200908020811
4859125|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200908020812
4859229|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200908020816
4859281|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200908020818
4859325|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200908020820
4859370|pass|200908|bingos@cpan.org|Devel-CheckLib|0.699_001|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200908020721
4859378|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.10.0|linux|2.6.18-92.el5|200908020822
4859489|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200908020826
4859503|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200908020826
4859523|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200908020827
4859561|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200908020828
4859580|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200908020829
4859600|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200908020830
4859611|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200908020830
4859672|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200908020833
4859778|pass|200908|rbo@cpan.org|Devel-CheckLib|0.699_001|i86pc-solaris|5.10.0|solaris|2.11|200908020837
4859785|pass|200908|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020237
4860035|pass|200908|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908020248
4860130|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200908020859
4860190|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.8.8|freebsd|7.0-release|200908020832
4860202|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200908020909
4860303|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.8.9|freebsd|7.0-release|200908020844
4860543|fail|200908|taro.nishino@gmail.com ("Taro Nishino")|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200908020643
4860975|pass|200908|bob@randomness.org.uk ("bob walker")|Devel-CheckLib|0.699_001|i86pc-solaris|5.10.0|solaris|2.10|200908021022
4861652|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.10.0|freebsd|7.0-release|200908021238
4861742|pass|200908|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200908020651
4863062|fail|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200908021508
4863530|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.6|i386-netbsd|5.10.0|netbsd|netbsd|200908021728
4863806|pass|200908|bingos@cpan.org|Number-Phone|1.7002|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908021643
4863861|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|IP35-irix-64int|5.8.8|irix|6.5|200908021805
4864171|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200908021836
4864176|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200908021836
4864184|pass|200908|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908021338
4864795|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200908021416
4865078|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200908022104
4865325|pass|200908|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908022138
4868519|pass|200908|bingos@cpan.org|Devel-CheckLib|0.699_001|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908031005
4868550|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200908031009
4869499|fail|200908|stro@cpan.org|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200908031336
4869590|pass|200908|jafelds@gmail.com|Data-Compare|1.2101|darwin-64int-ld-2level|5.10.0|darwin|9.6.0|200908030312
4869679|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|alpha-netbsd|5.10.0|netbsd|4.0.1|200908031045
4870075|fail|200908|stro@cpan.org|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200908031415
4870093|fail|200908|stro@cpan.org|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200908031417
4870114|pass|200908|stro@cpan.org|Devel-CheckLib|0.699_001|armv5tejl-linux|5.10.0|linux|2.6.17.14|200908031421
4870354|pass|200908|stro@cpan.org|Devel-CheckLib|0.699_001|armv5tejl-linux|5.8.8|linux|2.6.17.14|200908031450
4871800|pass|200908|jafelds@gmail.com|Devel-CheckOS|1.61|darwin-64int-ld-2level|5.10.0|darwin|9.6.0|200908030306
4872249|pass|200908|bingos@cpan.org|Devel-CheckLib|0.6|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908031644
4873064|pass|200908|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.1|i386-netbsd|5.10.0|netbsd|netbsd|200908031942
4873068|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.01|i386-netbsd|5.10.0|netbsd|netbsd|200908031944
4873109|pass|200908|lists.perl.cpan-testers@csjewell.fastmail.us (Curtis Jewell)|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200908030741
4873170|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200908031927
4873962|pass|200908|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908032028
4874377|pass|200908|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200908031640
4874737|pass|200908|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908032255
4874739|pass|200908|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908032256
4874821|pass|200908|stsc@refcnt.org ("Steven Schubiger")|CPAN-ParseDistribution|1.1|i386-netbsd|5.10.0|netbsd|netbsd|200908040042
4875881|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Palm-ProjectGutenberg|1.0|i386-netbsd|5.10.0|netbsd|netbsd|200908040434
4876401|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.0401|i386-netbsd|5.10.0|netbsd|netbsd|200908040725
4877258|pass|200908|martin.evans@easysoft.com|Devel-CheckLib|0.699_001|i686-linux|5.10.0|linux|2.6.24-24-generic|200908040936
4877958|pass|200908|srezic@cpan.org|Data-Compare|1.2101|i686-linux|5.10.1|linux|2.6.18-4-486|200908041200
4878602|pass|200908|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908040651
4878646|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.10.1|freebsd|7.0-release|200908041253
4878769|fail|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.6.2|freebsd|7.0-release|200908041259
4880208|pass|200908|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200908041021
4881714|pass|200908|cpan.dcollins.smoker9@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041133
4882362|pass|200908|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041204
4882379|pass|200908|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041204
4882585|pass|200908|justin.d.hunter@gmail.com|Devel-CheckLib|0.699_001|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200908040917
4883175|pass|200908|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.10.1|freebsd|7.0-release|200908041713
4883344|pass|200908|cpan.dcollins.smoker8@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041248
4883753|pass|200908|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041308
4883828|pass|200908|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041311
4883883|pass|200908|cpan.dcollins.smoker9@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041313
4884133|pass|200908|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041325
4885068|pass|200908|cpan.dcollins.smoker3@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041418
4885149|pass|200908|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041424
4885175|pass|200908|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041426
4885372|pass|200908|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041436
4885605|pass|200908|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200908041528
4885733|pass|200908|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.10.1|freebsd|7.0-release|200908042214
4886283|pass|200908|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.10.1|freebsd|7.0-release|200908042328
4886309|pass|200908|srezic@cpan.org|XML-Tiny-DOM|1.1|amd64-freebsd|5.10.1|freebsd|7.0-release|200908042328
4887171|pass|200908|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908050155
4888300|pass|200908|bingos@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908050635
4890952|pass|200908|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.699_001|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200908052139
4891402|fail|200908|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.10.1|freebsd|7.0-release|200908051440
4891664|pass|200908|bingos@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908051427
4891879|pass|200908|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.699_001|i86pc-solaris-64int|5.8.9|solaris|2.11|200908051554
4891904|pass|200908|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.10.1|freebsd|7.0-release|200908051556
18561|cpan|200102|DCANTRELL|Data-Hexdumper|0.01||0|||200102091317
20873|cpan|200104|DCANTRELL|Pony|1.00||0|||200104031524
20890|cpan|200104|DCANTRELL|Pony|1.01||0|||200104041148
21135|cpan|200104|DCANTRELL|Tie-Scalar-Decay|1.0||0|||200104101615
21176|cpan|200104|DCANTRELL|Tie-Scalar-Decay|1.1||0|||200104111716
23445|cpan|200105|DCANTRELL|Tie-Scalar-Decay|1.1.1||0|||200105220018
24582|cpan|200106|DCANTRELL|Tie-Hash-Rank|1.0.1||0|||200106132203
24768|cpan|200106|DCANTRELL|Acme-Pony|1.1.1||0|||200106201613
25258|cpan|200107|DCANTRELL|Acme-Pony|1.1.2||0|||200107100907
25259|cpan|200107|DCANTRELL|Tie-Hash-Transactional|1.0||0|||200107100910
60243|cpan|200209|DCANTRELL|Acme-Licence|1.0||0|||200209191118
60385|cpan|200209|DCANTRELL|Data-Hexdumper|1.0.1||0|||200209201431
94015|cpan|200306|DCANTRELL|NestedMap|1.0||0|||200306261034
94177|cpan|200306|DCANTRELL|File-Find-Rule-Permissions|1.0||0|||200306291337
95932|cpan|200307|DCANTRELL|File-Find-Rule-Permissions|1.1||0|||200307222223
97851|cpan|200308|DCANTRELL|Data-Hexdumper|1.1||0|||200308101502
99242|cpan|200308|DCANTRELL|Tie-Hash-Longest|1.0||0|||200308251544
99550|cpan|200308|DCANTRELL|Tie-Hash-Longest|1.0.reupload||0|||200308272113
99713|cpan|200308|DCANTRELL|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid||0|||200308282356
100435|cpan|200309|DCANTRELL|Acme-Scurvy-Whoreson-BilgeRat|1.0||0|||200309030037
107861|cpan|200310|DCANTRELL|Games-Dice-Advanced|1.0||0|||200310202350
108215|cpan|200310|DCANTRELL|Net-Random|1.0||0|||200310222224
110131|cpan|200311|DCANTRELL|Scalar-Properties|0.11||0|||200311042001
110714|cpan|200311|DCANTRELL|Scalar-Properties|0.12||0|||200311091239
111596|cpan|200311|DCANTRELL|Sub-WrapPackages|1.0||0|||200311152027
111637|cpan|200311|DCANTRELL|Statistics-ChiSquare|0.5||0|||200311161610
111698|cpan|200311|DCANTRELL|Tie-Hash-Longest|1.1||0|||200311172142
112068|cpan|200311|DCANTRELL|Statistics-SerialCorrelation|1.0||0|||200311211137
115196|cpan|200312|DCANTRELL|File-Find-Rule-Permissions|1.2||0|||200312172039
115791|cpan|200312|DCANTRELL|Data-Compare|0.03||0|||200312231623
115797|cpan|200312|DCANTRELL|Data-Compare|0.04||0|||200312231817
116341|cpan|200312|DCANTRELL|Data-Compare|0.05||0|||200312302326
117173|cpan|200401|DCANTRELL|Data-Compare|0.06||0|||200401070009
117320|cpan|200401|DCANTRELL|Data-Compare|0.07||0|||200401072031
119293|cpan|200401|DCANTRELL|Data-Compare|0.08||0|||200401201351
119721|cpan|200401|DCANTRELL|Statistics-SerialCorrelation|1.1||0|||200401231925
123317|cpan|200402|DCANTRELL|Data-Hexdumper|1.2||0|||200402201400
123723|cpan|200402|DCANTRELL|Data-Compare|0.09||0|||200402232204
126975|cpan|200403|DCANTRELL|Data-Compare|0.1||0|||200403131033
142433|cpan|200406|DCANTRELL|Data-Compare|0.11||0|||200406022128
148195|cpan|200407|DCANTRELL|Class-CanBeA|1.0||0|||200407102030
153997|cpan|200408|DCANTRELL|Number-Phone|1.0||0|||200408181838
156490|cpan|200409|DCANTRELL|Net-Random|1.1||0|||200409071010
158150|cpan|200409|DCANTRELL|Number-Phone|1.1||0|||200409152348
159942|cpan|200409|DCANTRELL|Number-Phone|1.2||0|||200409222118
162174|cpan|200410|DCANTRELL|Number-Phone|1.2001||0|||200410132026
162938|cpan|200410|DCANTRELL|Number-Phone|1.3||0|||200410202307
163369|cpan|200410|DCANTRELL|Acme-Scurvy-Whoreson-BilgeRat|1.1||0|||200410252258
165706|cpan|200411|DCANTRELL|Data-Transactional|0.1||0|||200411062305
166048|cpan|200411|DCANTRELL|Data-Compare|0.12||0|||200411091935
166051|cpan|200411|DCANTRELL|Data-Compare|0.13||0|||200411092006
166394|cpan|200411|DCANTRELL|Number-Phone|1.3001||0|||200411110010
169396|cpan|200411|DCANTRELL|Number-Phone|1.3002||0|||200411261231
171989|cpan|200412|DCANTRELL|Number-Phone|1.3003||0|||200412052038
175156|cpan|200412|DCANTRELL|Class-CanBeA|1.1||0|||200412210020
198416|cpan|200504|DCANTRELL|Number-Phone|1.3004||0|||200504121820
208303|cpan|200505|DCANTRELL|Number-Phone|1.4||0|||200505182054
219457|cpan|200506|DCANTRELL|Number-Phone|1.4001||0|||200506280014
230200|cpan|200508|DCANTRELL|Number-Phone|1.4002||0|||200508021533
236772|cpan|200508|DCANTRELL|Number-Phone|1.4003||0|||200508240021
258043|cpan|200510|DCANTRELL|Number-Phone|1.4004||0|||200510111715
259958|cpan|200510|DCANTRELL|Number-Phone|1.5||0|||200510161535
275288|cpan|200512|DCANTRELL|Net-Random|1.2||0|||200512132331
278484|cpan|200512|DCANTRELL|Class-CanBeA|1.2||0|||200512272316
286390|cpan|200601|DCANTRELL|File-Overwrite|1.0||0|||200601291736
326764|cpan|200607|DCANTRELL|Tie-STDOUT|1.0||0|||200607032333
326767|cpan|200607|DCANTRELL|Tie-STDOUT|1.01||0|||200607032355
327002|cpan|200607|DCANTRELL|Tie-STDOUT|1.02||0|||200607051519
336599|cpan|200607|DCANTRELL|Sub-WrapPackages|1.1||0|||200607260915
340156|cpan|200608|DCANTRELL|Sub-WrapPackages|1.2||0|||200608021542
344363|cpan|200608|DCANTRELL|Number-Phone|1.51||0|||200608230005
344492|cpan|200608|DCANTRELL|Number-Phone|1.52||0|||200608232313
344495|cpan|200608|DCANTRELL|Number-Phone|1.53||0|||200608240021
344496|cpan|200608|DCANTRELL|Number-Phone-UK-DetailedLocations|1.0||0|||200608240022
344681|cpan|200608|DCANTRELL|Number-Phone|1.54||0|||200608241608
344682|cpan|200608|DCANTRELL|Number-Phone-UK-DetailedLocations|1.1||0|||200608241626
344739|cpan|200608|DCANTRELL|Number-Phone|1.55||0|||200608250215
344740|cpan|200608|DCANTRELL|Number-Phone-UK-DetailedLocations|1.2||0|||200608250220
348326|cpan|200609|DCANTRELL|Games-Dice-Advanced|1.1||0|||200609121951
367316|cpan|200611|DCANTRELL|Data-Compare|0.14||0|||200611011650
385595|cpan|200612|DCANTRELL|Number-Phone|1.56||0|||200612121318
402533|cpan|200701|DCANTRELL|Bryar|3.0||0|||200701201555
402559|cpan|200701|DCANTRELL|Net-Random|1.3||0|||200701210016
406096|cpan|200701|DCANTRELL|XML-Tiny|1.0||0|||200701261523
407368|cpan|200701|DCANTRELL|XML-Tiny|1.01||0|||200701300016
408160|cpan|200701|DCANTRELL|XML-Tiny|1.02||0|||200701302356
409886|cpan|200702|DCANTRELL|XML-Tiny|1.03||0|||200702030348
413165|cpan|200702|DCANTRELL|XML-Tiny|1.04||0|||200702111521
420582|cpan|200702|DCANTRELL|Number-Phone|1.5601||0|||200702241446
421740|cpan|200702|DCANTRELL|Data-Compare|0.15||0|||200702252138
423896|cpan|200702|DCANTRELL|Data-Compare|0.16||0|||200702272131
423938|cpan|200702|DCANTRELL|XML-Tiny|1.05||0|||200702272218
424835|cpan|200702|DCANTRELL|Net-Random|1.4||0|||200702282207
428341|cpan|200703|DCANTRELL|XML-Tiny|1.06||0|||200703042341
435949|cpan|200703|DCANTRELL|XML-DoubleEncodedEntities|1.0||0|||200703122133
437845|cpan|200703|DCANTRELL|Number-Phone-UK-DetailedLocations|1.3||0|||200703142131
437846|cpan|200703|DCANTRELL|Number-Phone|1.57||0|||200703142132
458866|cpan|200704|DCANTRELL|Net-Random|2.0||0|||200704130117
500610|cpan|200706|DCANTRELL|Number-Phone|1.58||0|||200706020101
550752|cpan|200707|DCANTRELL|Palm-TreoPhoneCallDB|1||0|||200707291727
551374|cpan|200707|DCANTRELL|Palm-TreoPhoneCallDB|1.1||0|||200707302337
558544|cpan|200708|DCANTRELL|Data-Compare|0.17||0|||200708071930
581761|cpan|200708|DCANTRELL|CPAN-FindDependencies|1.0||0|||200708180022
582757|cpan|200708|DCANTRELL|CPAN-FindDependencies|1.01||0|||200708190252
583200|cpan|200708|DCANTRELL|CPAN-FindDependencies|1.02||0|||200708191408
586612|cpan|200708|DCANTRELL|Data-Hexdumper|1.3||0|||200708210010
596782|cpan|200708|DCANTRELL|Tie-STDOUT|1.03||0|||200708281235
597396|cpan|200708|DCANTRELL|Data-Transactional|1.0||0|||200708290007
663028|cpan|200709|DCANTRELL|Devel-CheckOS|0.9||0|||200709301722
663314|cpan|200710|DCANTRELL|Devel-CheckOS|0.91||0|||200710011851
663551|cpan|200710|DCANTRELL|Devel-CheckOS|0.92||0|||200710012333
665669|cpan|200710|DCANTRELL|Devel-CheckOS|1.0||0|||200710021803
666093|cpan|200710|DCANTRELL|File-Find-Rule-Permissions|1.3||0|||200710021957
671365|cpan|200710|DCANTRELL|Devel-CheckOS|1.1||0|||200710051605
686172|cpan|200710|DCANTRELL|Devel-AssertLib|0.1||0|||200710141722
686287|cpan|200710|DCANTRELL|Devel-CheckOS|1.2||0|||200710141814
695141|cpan|200710|DCANTRELL|Devel-CheckLib|0.2||0|||200710181942
711234|cpan|200710|DCANTRELL|XML-Tiny|1.07||0|||200710241517
714488|cpan|200710|DCANTRELL|XML-Tiny|1.08||0|||200710251630
723790|cpan|200710|DCANTRELL|XML-Tiny|1.09||0|||200710291857
724374|cpan|200710|DCANTRELL|XML-Tiny|1.10||0|||200710292352
725966|cpan|200710|DCANTRELL|Devel-CheckLib|0.3||0|||200710301630
731691|cpan|200711|DCANTRELL|XML-Tiny|1.11||0|||200711011806
748640|cpan|200711|DCANTRELL|Devel-CheckOS|1.3||0|||200711071912
749350|cpan|200711|DCANTRELL|Devel-CheckOS|1.4||0|||200711072227
749367|cpan|200711|DCANTRELL|Devel-CheckOS|1.41||0|||200711072232
749596|cpan|200711|DCANTRELL|CPAN-FindDependencies|1.1||0|||200711080036
790843|cpan|200711|DCANTRELL|Devel-CheckOS|1.42||0|||200711202144
829798|cpan|200712|DCANTRELL|CPAN-FindDependencies|1.99_01||0|||200712031848
857128|cpan|200712|DCANTRELL|CPAN-FindDependencies|2.0||0|||200712141554
958858|cpan|200801|DCANTRELL|Data-Compare|1.18||0|||200801160015
1039463|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.0||0|||200802142218
1082170|cpan|200802|DCANTRELL|Number-Phone|1.581||0|||200802272246
1085089|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.1||0|||200802282147
1085746|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.001||0|||200802290019
1085778|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.1001||0|||200802290023
1107354|cpan|200803|DCANTRELL|Devel-CheckLib|0.4||0|||200803042253
1157349|cpan|200803|DCANTRELL|Devel-CheckLib|0.5||0|||200803122102
1157413|cpan|200803|DCANTRELL|Devel-CheckOS|1.43||0|||200803122114
1158266|cpan|200803|DCANTRELL|CPU-Emulator-Z80|0.9||0|||200803122349
1443831|cpan|200805|DCANTRELL|Data-Compare|1.19||0|||200805121742
1479315|cpan|200805|DCANTRELL|Data-Hexdumper|1.4||0|||200805181803
1533076|cpan|200805|DCANTRELL|Number-Phone|1.6||0|||200805280206
1689406|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.0||0|||200806132245
1689431|cpan|200806|DCANTRELL|CPU-Emulator-Z80|1.0||0|||200806132246
1699403|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.01||0|||200806141928
1709294|cpan|200806|DCANTRELL|Data-Transactional|1.01||0|||200806161655
1709323|cpan|200806|DCANTRELL|Data-Transactional|1.02||0|||200806161708
1767508|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.02||0|||200806222327
1790577|cpan|200806|DCANTRELL|DBIx-Class-SingletonRows|0.1||0|||200806251641
1792766|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.03||0|||200806252102
1799251|cpan|200806|DCANTRELL|DBIx-Class-SingletonRows|0.11||0|||200806261933
1878761|cpan|200807|DCANTRELL|Palm-Treo680MessagesDB|1.0||0|||200807110042
1943448|cpan|200807|DCANTRELL|Sort-MultipleFields|0.001_01||0|||200807252348
1955427|cpan|200807|DCANTRELL|Sort-MultipleFields|1.0||0|||200807282355
2064291|cpan|200808|DCANTRELL|Data-Compare|1.20||0|||200808211630
2090369|cpan|200808|DCANTRELL|Data-Compare|1.200_500||0|||200808262250
2100400|cpan|200808|DCANTRELL|Class-DBI-ClassGenerator|1.0||0|||200808281915
2122413|cpan|200809|DCANTRELL|Data-Compare|1.21||0|||200809011832
2133359|cpan|200809|DCANTRELL|Class-DBI-ClassGenerator|1.01||0|||200809031834
2335260|cpan|200809|DCANTRELL|Devel-CheckOS|1.44||0|||200809291718
2473005|cpan|200810|DCANTRELL|Devel-CheckOS|1.45||0|||200810222158
2505985|cpan|200810|DCANTRELL|Devel-CheckOS|1.46||0|||200810272138
2556191|cpan|200811|DCANTRELL|Devel-CheckOS|1.49_01||0|||200811052352
2595943|cpan|200811|DCANTRELL|Devel-CheckOS|1.50||0|||200811120055
3041172|cpan|200901|DCANTRELL|Palm-SMS|0.03||0|||200901101720
3115655|cpan|200901|DCANTRELL|XML-Tiny|1.12||0|||200901221756
3250415|cpan|200902|DCANTRELL|Class-DBI-ClassGenerator|1.02||0|||200902101617
3261096|cpan|200902|DCANTRELL|File-Find-Rule-Permissions|2.0||0|||200902120000
3352076|cpan|200902|DCANTRELL|Number-Phone|1.7||0|||200902262116
3355848|cpan|200902|DCANTRELL|WWW-Facebook-Go-SGF|1.0||0|||200902272216
3374215|cpan|200903|DCANTRELL|Data-Hexdumper|2.0||0|||200903030047
3379639|cpan|200903|DCANTRELL|Data-Hexdumper|2.01||0|||200903032129
3380947|cpan|200903|DCANTRELL|Number-Phone|1.7001||0|||200903040118
3510206|cpan|200903|DCANTRELL|Tie-STDOUT|1.04||0|||200903182050
3510257|cpan|200903|DCANTRELL|App-Rsnapshot|1.999_00001||0|||200903182101
3514629|cpan|200903|DCANTRELL|Tie-STDOUT|1.0401||0|||200903191113
3543273|cpan|200903|DCANTRELL|XML-Tiny|2.0||0|||200903222031
3543480|cpan|200903|DCANTRELL|App-Rsnapshot|1.999_00002||0|||200903222104
3544677|cpan|200903|DCANTRELL|XML-Tiny|2.01||0|||200903231919
3557350|cpan|200903|DCANTRELL|XML-Tiny|2.02||0|||200903241615
3572078|cpan|200903|DCANTRELL|XML-Tiny-DOM|1.0||0|||200903261822
3572458|cpan|200903|DCANTRELL|Palm-ProjectGutenberg|1.0||0|||200903262148
3594727|cpan|200903|DCANTRELL|CPAN-ParseDistribution|1.0||0|||200903310100
3620843|cpan|200904|DCANTRELL|CPAN-ParseDistribution|1.1||0|||200904041245
3666403|cpan|200904|DCANTRELL|Palm-Treo680MessagesDB|1.01||0|||200904101646
3666523|cpan|200904|DCANTRELL|File-Overwrite|1.1||0|||200904101715
3673312|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.1||0|||200904111938
3689350|cpan|200904|DCANTRELL|Devel-CheckOS|1.51||0|||200904142157
3690126|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.2||0|||200904150108
3695760|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.21||0|||200904152031
3695763|cpan|200904|DCANTRELL|Devel-CheckOS|1.52||0|||200904152031
3696161|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.22||0|||200904152143
3696921|cpan|200904|DCANTRELL|Devel-CheckOS|1.53||0|||200904160008
3697653|cpan|200904|DCANTRELL|Devel-CheckOS|1.54||0|||200904160211
3697679|cpan|200904|DCANTRELL|Devel-CheckOS|1.55||0|||200904160215
3727292|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.3||0|||200904201753
3736322|cpan|200904|DCANTRELL|Devel-CheckOS|1.6||0|||200904212139
3742215|cpan|200904|DCANTRELL|Number-Phone|1.7002||0|||200904222047
3754728|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.31||0|||200904241728
3761267|cpan|200904|DCANTRELL|Devel-CheckOS|1.61||0|||200904251318
3774732|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.32||0|||200904271731
3819841|cpan|200905|DCANTRELL|Data-Compare|1.2101||0|||200905051643
3925252|cpan|200905|DCANTRELL|Devel-CheckLib|0.6||0|||200905201547
3989559|cpan|200905|DCANTRELL|Bryar|3.1||0|||200905282352
4634312|cpan|200907|DCANTRELL|XML-Tiny-DOM|1.1||0|||200907160048
4852270|cpan|200908|DCANTRELL|Devel-CheckLib|0.699_001||0|||200908011730
